#line 1 "tmp/all.te"
#
# Declarations for type attributes.
# 

# A type attribute can be used to identify a set of types with a similar
# property.  Each type can have any number of attributes, and each
# attribute can be associated with any number of types.  Attributes are
# explicitly declared here, and can then be associated with particular
# types in type declarations.  Attribute names can then be used throughout 
# the configuration to express the set of types that are associated with 
# the attribute.  Except for the MLS attributes, attributes have no implicit
# meaning to SELinux.  The meaning of all other attributes are completely 
# defined through their usage within the configuration, but should be 
# documented here as comments preceding the attribute declaration.  

#####################
# Attributes for MLS:
#

# The mlstrustedreader attribute identifies every domain that can
# override the normal MLS restrictions on reading (i.e. domains
# that can read up).  
attribute mlstrustedreader;

# The mlstrustedwriter attribute identifies every domain that can
# override the normal MLS restrictions on writing (i.e. domains
# that can write down).  
attribute mlstrustedwriter;

# The mlstrustedobject attribute identifies every type that can
# be accessed without normal MLS restrictions (i.e. processes can
# read or write objects with this type regardless of MLS level).  
# Examples:  /dev/null, descriptors created by login
attribute mlstrustedobject;


#########################
# Attributes for domains:
#

# The domain attribute identifies every type that can be 
# assigned to a process.  This attribute is used in TE rules 
# that should be applied to all domains, e.g. permitting 
# init to kill all processes or permitting all processes
# to read a particular file.
attribute domain;

# The privuser attribute identifies every domain that can 
# change its SELinux user identity.  This attribute is used 
# in the constraints configuration.  NOTE:  This attribute
# is not required for domains that merely change the Linux
# uid attributes, only for domains that must change the
# SELinux user identity.
attribute privuser;

# The privrole attribute identifies every domain that can 
# change its SELinux role.  This attribute is used in the 
# constraints configuration.
attribute privrole;

# The privowner attribute identifies every domain that can 
# assign a different SELinux user identity to a file.  This 
# attribute is used in the constraints configuration.
attribute privowner;

# The privlog attribute identifies every domain that can 
# communicate with syslogd through its Unix domain socket.
# This attribute is used in the TE rules in 
# domains/program/syslogd.te to grant such access.  
# XXX If you want to mandate the use of this attribute for all 
# XXX domains that can log, then you should also write corresponding 
# XXX assertions in assert.te to enforce this restriction.  Otherwise,
# XXX it is just an optional convenience for domain writers.
attribute privlog;

# The privmem attribute identifies every domain that can 
# access kernel memory devices.
# This attribute is used in the TE assertions to verify
# that such access is limited to domains that are explicitly
# tagged with this attribute.
attribute privmem;

# The privfd attribute identifies every domain that should have
# file handles inherited widely (IE sshd_t and getty_t).
attribute privfd;

# The privhome attribute identifies every domain that can create files under
# regular user home directories in the regular context (IE act on behalf of
# a user in writing regular files)
attribute privhome;

# The auth attribute identifies every domain that needs
# to perform user authentication and requires access to
# the corresponding authentication data.  
# XXX This attribute is no longer in use except in type declarations.
# XXX It was introduced for the original attempt to put /etc/shadow into
# XXX a separate type and to limit read access to certain domains.  
# XXX Doing so transparently to applications is problematic due to
# XXX the fact that both /etc/passwd and /etc/shadow are recreated
# XXX by the same processes and live in the same directory, so file type
# XXX transition rules cannot specify different default types.  Relocating
# XXX /etc/shadow to a separate subdirectory was tried, but required
# XXX modifications to a lot of applications even after changing
# XXX the pwdb shared library.
attribute auth;

# The admin attribute identifies every administrator domain.
# It is used in TE assertions when verifying that only administrator 
# domains have certain permissions.  
# This attribute is presently associated with sysadm_t and 
# certain administrator utility domains.  
# XXX The use of this attribute should be reviewed for consistency.
# XXX Might want to partition into several finer-grained attributes 
# XXX used in different assertions within assert.te.
attribute admin;

# The userdomain attribute identifies every user domain, presently
# user_t and sysadm_t.  It is used in TE rules that should be applied
# to all user domains.
attribute userdomain;

# attribute for all non-administrative devpts types
attribute userpty_type;

# The user_crond_domain attribute identifies every user_crond domain, presently
# user_crond_t and sysadm_crond_t.  It is used in TE rules that should be
# applied to all user domains.
attribute user_crond_domain;

# The unpriv_userdomain identifies non-administrative users (default user_t)
attribute unpriv_userdomain;

# This attribute is for the main user home directory for unpriv users
attribute user_home_dir_type;

# The gphdomain attribute identifies every gnome-pty-helper derived
# domain.  It is used in TE rules to permit inheritance and use of
# descriptors created by these domains.
attribute gphdomain;


############################
# Attributes for file types:
#

# The file_type attribute identifies all types assigned to files 
# in persistent filesystems.  It is used in TE rules to permit
# the association of all such file types with persistent filesystem
# types, and to permit certain domains to access all such types as 
# appropriate.
attribute file_type;

# The sysadmfile attribute identifies all types assigned to files 
# that should be completely accessible to administrators.  It is used
# in TE rules to grant such access for administrator domains.
attribute sysadmfile;

# The fs_type attribute identifies all types assigned to filesystems
# (not limited to persistent filesystems).
# It is used in TE rules to permit certain domains to mount
# any filesystem and to permit most domains to obtain the
# overall filesystem statistics.
attribute fs_type;

# The root_dir_type attribute identifies all types assigned to 
# root directories of filesystems (not limited to persistent
# filesystems).
# XXX This attribute was used to grant mountassociate permission,
# XXX but this permission is no longer defined.  We can likely
# XXX remove this attribute.
attribute root_dir_type;

# The exec_type attribute identifies all types assigned
# to entrypoint executables for domains.  This attribute is 
# used in TE rules and assertions that should be applied to all 
# such executables.
attribute exec_type;

# The tmpfile attribute identifies all types assigned to temporary 
# files.  This attribute is used in TE rules to grant certain 
# domains the ability to remove all such files (e.g. init, crond).
attribute tmpfile;

# The user_tmpfile attribute identifies all types associated with temporary
# files for unpriv_userdomain domains.
attribute user_tmpfile;

# for the user_xserver_tmp_t etc
attribute xserver_tmpfile;

# The tmpfsfile attribute identifies all types defined for tmpfs 
# type transitions. 
# It is used in TE rules to grant certain domains the ability to
# access all such files.
attribute tmpfsfile;

# The home_type attribute identifies all types assigned to home
# directories.  This attribute is used in TE rules to grant certain
# domains the ability to access all home directory types.
attribute home_type;

# This attribute is for the main user home directory /home/user, to
# distinguish it from sub-dirs.  Often you want a process to be able to
# read the user home directory but not read the regular directories under it.
attribute home_dir_type;

# The ttyfile attribute identifies all types assigned to ttys.
# It is used in TE rules to grant certain domains the ability to
# access all ttys.
attribute ttyfile;

# The ptyfile attribute identifies all types assigned to ptys.
# It is used in TE rules to grant certain domains the ability to
# access all ptys.
attribute ptyfile;

# The pidfile attribute identifies all types assigned to pid files.
# It is used in TE rules to grant certain domains the ability to
# access all such files.
attribute pidfile;


############################
# Attributes for network types:
#

# The socket_type attribute identifies all types assigned to 
# kernel-created sockets.  Ordinary sockets are assigned the 
# domain of the creating process.
# XXX This attribute is unused.  Remove?
attribute socket_type;

# Identifies all types assigned to port numbers to control binding.
attribute port_type;

# Identifies all types assigned to network interfaces to control
# operations on the interface (XXX obsolete, not supported via LSM) 
# and to control traffic sent or received on the interface.
attribute netif_type;

# Identifies all default types assigned to packets received 
# on network interfaces.  
attribute netmsg_type;

# Identifies all types assigned to network nodes/hosts to control
# traffic sent to or received from the node.
attribute node_type;

# Identifier for log files or directories that only exist for log files.
attribute logfile;

# Identifier for lock files (/var/lock/*) or directories that only exist for
# lock files.
attribute lockfile;



##############################
# Attributes for security policy types:
#

# The login_contexts attribute idenitifies the files used
# to define default contexts for login types (e.g., login, cron).
attribute login_contexts;

# Identifier for a domain used by "sendmail -t" (IE user_mail_t,
# sysadm_mail_t, etc)
attribute user_mail_domain;

# Identifies domains that can transition to system_mail_t
attribute privmail;

# Type for non-sysadm home directory
attribute user_home_type;

# For domains that are part of a mail server and need to read user files and
# fifos, and inherit file handles to enable user email to get to the mail
# spool
attribute mta_user_agent;

# For domains that are part of a mail server for delivering messages to the
# user
attribute mta_delivery_agent;

# For web clients such as netscape and squid
attribute web_client_domain;

# For a mail server process that takes TCP connections on port 25
attribute mail_server_domain;


























#
# Macros for all admin domains.
#

#
# admin_domain(domain_prefix)
#
# Define derived types and rules for an administrator domain.
#
# The type declaration and role authorization for the domain must be
# provided separately.  Likewise, domain transitions into this domain
# must be specified separately.  If the every_domain() rules are desired,
# then these rules must also be specified separately.
#

#line 455

##############################
#
# Global macros for the type enforcement (TE) configuration.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# Modified: Howard Holm (NSA), <hdholm@epoch.ncsc.mil>
#           System V IPC added
#

#################################
# 
# Macros for groups of classes and 
# groups of permissions.
#

#
# All directory and file classes
#


#
# All non-directory file classes.
#


#
# Non-device file classes.
#


#
# Device file classes.
#


#
# All socket classes.
#


#
# Datagram socket classes.
# 


#
# Stream socket classes.
#


#
# Unprivileged socket classes (exclude rawip, netlink, packet).
#



# 
# Permissions for getting file attributes.
#


# 
# Permissions for executing files.
#


# 
# Permissions for reading files and their attributes.
#


# 
# Permissions for reading and executing files.
#


# 
# Permissions for reading and writing files and their attributes.
#


# 
# Permissions for reading and appending to files.
#


#
# Permissions for linking, unlinking and renaming files.
# 


#
# Permissions for creating and using files.
# 


# 
# Permissions for reading directories and their attributes.
#


# 
# Permissions for reading and writing directories and their attributes.
#


# 
# Permissions for reading and adding names to directories.
#



#
# Permissions for creating and using directories.
# 


#
# Permissions to mount and unmount file systems.
#


#
# Permissions for using sockets.
# 


#
# Permissions for creating and using sockets.
# 


#
# Permissions for using stream sockets.
# 


#
# Permissions for creating and using stream sockets.
# 



#
# Permissions for sending all signals.
#


#
# Permissions for sending and receiving network packets.
#


#
# Permissions for using System V IPC
#










#################################
# 
# Macros for type transition rules and
# access vector rules.
#

#
# Simple combinations for reading and writing both
# directories and files.
# 
#line 637


#line 642


#line 647


#line 652


#line 657


#line 662


#line 667


##################################
#
# can_getsecurity(domain)
#
# Authorize a domain to get security policy decisions.
#
#line 679


##################################
#
# can_setenforce(domain)
#
# Authorize a domain to set the enforcing flag.
# Due to its sensitivity, always audit this permission.
#
#line 693


##################################
#
# can_loadpol(domain)
#
# Authorize a domain to load a policy configuration.
# Due to its sensitivity, always audit this permission.
#
#line 707


#################################
#
# domain_trans(parent_domain, program_type, child_domain)
#
# Permissions for transitioning to a new domain.
#

#line 759


#################################
#
# domain_auto_trans(parent_domain, program_type, child_domain)
#
# Define a default domain transition and allow it.
#
#line 770


##################################
#
# can_setexec(domain)
#
# Authorize a domain to set its exec context
# (via /proc/pid/attr/exec).
#
#line 785


##################################
#
# can_setfscreate(domain)
#
# Authorize a domain to set its fscreate context
# (via /proc/pid/attr/fscreate).
#
#line 800


#################################
#
# uses_shlib(domain)
#
# Permissions for using shared libraries.
#
#line 819


#################################
#
# can_ptrace(domain, domain)
#
# Permissions for running ptrace (strace or gdb) on another domain
#
#line 829


#################################
#
# can_exec(domain, type)
#
# Permissions for executing programs with
# a specified type without changing domains.
#
#line 840


#################################
#
# can_exec_any(domain)
#
# Permissions for executing a variety
# of executable types.
#
#line 858



#################################
#
# file_type_trans(domain, dir_type, file_type)
#
# Permissions for transitioning to a new file type.
#

#line 889


#################################
#
# file_type_auto_trans(creator_domain, parent_directory_type, file_type, object_class)
#
# the object class will default to notdevfile_class_set if not specified as
# the fourth parameter
#
# Define a default file type transition and allow it.
#
#line 910


#################################
#
# can_network(domain)
#
# Permissions for accessing the network.
# See types/network.te for the network types.
# See net_contexts for security contexts for network entities.
#
#line 988


#################################
#
# can_unix_connect(client, server)
#
# Permissions for establishing a Unix stream connection.
#
#line 998


#################################
#
# can_unix_send(sender, receiver)
#
# Permissions for sending Unix datagrams.
#
#line 1008


#################################
#
# can_tcp_connect(client, server)
#
# Permissions for establishing a TCP connection.
#
#line 1021


#################################
#
# can_udp_send(sender, receiver)
#
# Permissions for sending/receiving UDP datagrams.
#
#line 1032


#################################
#
# can_sysctl(domain)
#
# Permissions for modifying sysctl parameters.
#
#line 1056



##################################
#
# base_pty_perms(domain_prefix)
#
# Base permissions used for can_create_pty() and can_create_other_pty()
#
#line 1076


##################################
#
# can_create_pty(domain_prefix, attributes)
#
# Permissions for creating ptys.
#
#line 1096



##################################
#
# can_create_other_pty(domain_prefix,other_domain)
#
# Permissions for creating ptys for another domain.
#
#line 1112


##################################
#
# read_locale(domain)
#
# Permissions for reading the locale data,
# /etc/localtime and the files that it links to
#
#line 1124



################################################
#
# The following macros are an attempt to start
# partitioning every_domain into finer-grained subsets
# that can be used by individual domains.
#

#
# general_domain_access(domain)
#
# Grant permissions within the domain.
# This includes permissions to processes, /proc/PID files,
# file descriptors, pipes, Unix sockets, and System V IPC objects
# labeled with the domain.
#
#line 1168


#
# general_proc_read_access(domain)
#
# Grant read/search permissions to most of /proc, excluding
# the /proc/PID directories and the /proc/kmsg and /proc/kcore files.
# The general_domain_access macro grants access to the domain /proc/PID
# directories, but not to other domains.  Only permissions to stat
# are granted for /proc/kmsg and /proc/kcore, since these files are more
# sensitive.
# 
#line 1203


#
# base_file_read_access(domain)
#
# Grant read/search permissions to a few system file types.
#
#line 1227


#
# general_file_read_access(domain)
#
# Grant read/search permissions to many system file types.
#
#line 1366


#
# general_file_write_access(domain)
#
# Grant write permissions to a small set of system file types, e.g. 
# /dev/tty, /dev/null, etc.
#
# For shared directories like /tmp, each domain should have its own derived
# type (with a file_type_auto_trans rule) for files created in the shared
# directory.
#
#line 1387


#
# every_test_domain(domain)
#
# Grant permissions common to the test domains.
#
#line 1420


################################
#
# every_domain(domain)
#
# Grant permissions common to most domains.
#
# This macro replaces the rules formerly located in domains/every.te.
# An every_domain macro has been inserted into each domain .te file
# for each domain defined within that file.  If you want a new domain
# to inherit these rules, then you can likewise use this macro in
# your new domain .te file.  However, for least privilege purposes, you 
# may want to consider using macros or individual rules that only include 
# a subset of these permissions for your new domain.  This macro has already 
# been partitioned into a few subsets, with corresponding macros defined 
# above and used in defining this macro.  
#
#line 1447


#######################
# daemon_base_domain(domain_prefix, attribs)
#
# Define a daemon domain with a base set of type declarations
# and permissions that are common to most daemons.
# attribs is the list of attributes which must start with "," if it is not empty
#
# Author:  Russell Coker <russell@coker.com.au>
#
#line 1483

# allow a domain to create its own files under /var/run and to create files
# in directories that are created for it.  For sock_file etc you need to add
# your own rules
#line 1491


#line 1509

#line 1515


# define a sub-domain, $1_t is the parent domain, $2 is the name
# of the sub-domain.
#
#line 1542



#line 1548


#line 1555


#line 1560


#line 1565


#line 1570


#######################
# application_domain(domain_prefix)
#
# Define a domain with a base set of type declarations
# and permissions that are common to simple applications.
#
# Author:  Russell Coker <russell@coker.com.au>
#
#line 1586


#line 1592


#line 1600


#
# Macros for all user login domains.
#

#
# user_domain(domain_prefix)
#
# Define derived types and rules for an ordinary user domain.
#
# The type declaration and role authorization for the domain must be
# provided separately.  Likewise, domain transitions into this domain
# must be specified separately.  
#

#line 1875



###########################################################################
#
# Domains for ordinary users.
#

#line 1974



#line 1980


#
# Macros for chkpwd domains.
#

#
# chkpwd_domain(domain_prefix)
#
# Define a derived domain for the *_chkpwd program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/su.te. 
#

#line 2031

#line 2031

#line 2031

#line 2031


# macro for chroot environments
# Author Russell Coker

# chroot(initial_domain, basename, role, tty_device_type)
#line 2161

#
# Macros for clamscan
#
# Author:  Brian May <bam@snoopy.apana.org.au>
#

#
# clamscan_domain(domain_prefix)
#
# Define a derived domain for the clamscan program when executed
#
#line 2196


#line 2209


#line 2241


#line 2251


#
# Macros for crond domains.
#

#
# Authors:  Jonathan Crowley (MITRE) <jonathan@mitre.org>,
#	    Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#
# crond_domain(domain_prefix)
#
# Define a derived domain for cron jobs executed by crond on behalf 
# of a user domain.  These domains are separate from the top-level domain
# defined for the crond daemon and the domain defined for system cron jobs,
# which are specified in domains/program/crond.te.
#

#line 2346


# When system_crond_t domain executes a type $1 executable then transition to
# domain $2, allow $2 to interact with crond_t as well.
#line 2356

#
# Macros for crontab domains.
#

#
# Authors:  Jonathan Crowley (MITRE) <jonathan@mitre.org>
# Revised by Stephen Smalley <sds@epoch.ncsc.mil>
#

#
# crontab_domain(domain_prefix)
#
# Define a derived domain for the crontab program when executed by
# a user domain.  
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/crontab.te. 
#

#line 2442

#
# Macro for fingerd
#
# Author:  Russell Coker <russell@coker.com.au>
#

#
# fingerd_macro(domain_prefix)
#
# allow fingerd to create a fingerlog file in the user home dir
#
#line 2457

#
# Macros for gpg and pgp
#
# Author:  Russell Coker <russell@coker.com.au>
#
# based on the work of:
# Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#
# gpg_domain(domain_prefix)
#
# Define a derived domain for the gpg/pgp program when executed by
# a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/gpg.te.
#
#line 2542

#
# Macros for gnome-pty-helper domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#

#
# gph_domain(domain_prefix)
#
# Define a derived domain for the gnome-pty-helper program when
# executed by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/gnome-pty-helper.te. 
#
# The *_gph_t domains are for the gnome_pty_helper program.
# This program is executed by gnome-terminal to handle
# updates to utmp and wtmp.  In this regard, it is similar
# to utempter.  However, unlike utempter, gnome-pty-helper
# also creates the pty file for the terminal program.
# There is one *_gph_t domain for each user domain.  
#

#line 2614


#
# Macros for irc domains.
#

#
# Author:  Russell Coker <russell@coker.com.au>
#

#
# irc_domain(domain_prefix)
#
# Define a derived domain for the irc program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/irc.te. 
#

#line 2702

#line 2702

#line 2702

#line 2702

#line 2702

#
# Macros for lpr domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#

#
# lpr_domain(domain_prefix)
#
# Define a derived domain for the lpr/lpq/lprm programs when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/lpr.te. 
#

#line 2809

#
# Macros for mount
#
# Author:  Brian May <bam@snoopy.apana.org.au>
# Extended by Russell Coker <russell@coker.com.au>
#

#
# mount_domain(domain_prefix,dst_domain_prefix)
#
# Define a derived domain for the mount program for anyone.
#
#line 2858

#
# Macros for MTA domains.
#

#
# Author:   Russell Coker <russell@coker.com.au>
# Based on the work of: Stephen Smalley <sds@epoch.ncsc.mil>
#                       Timothy Fraser 
#

#
# mail_domain(domain_prefix)
#
# Define a derived domain for the sendmail program when executed by
# a user domain to send outgoing mail.  These domains are separate and
# independent of the domain used for the sendmail daemon process.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/mta.te. 
#

#line 2965

#
# Macros for netscape/mozilla (or other browser) domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#

#
# netscape_domain(domain_prefix)
#
# Define a derived domain for the netscape/mozilla program when executed by
# a user domain.  
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/netscape.te. 
#
#line 3023

# $1 is the source domain (or domains), $2 is the source role (or roles) and $3
# is the base name for the domain to run.  $1 is normally sysadm_t, and $2 is
# normally sysadm_r.  $4 is the type of program to run and $5 is the domain to
# transition to.
# sample usage:
# run_program(sysadm_t, sysadm_r, init, etc_t, initrc_t)
#
# if you have several users who run the same run_init type program for
# different purposes (think of a run_db program used by several database
# administrators to start several databases) then you can list all the source
# domains in $1, all the source roles in $2, but you may not want to list all
# types of programs to run in $4 and target domains in $5 (as that may permit
# entering a domain from the wrong type).  In such a situation just specify
# one value for each of $4 and $5 and have some rules such as the following:
# domain_trans(run_whatever_t, whatever_exec_t, whatever_t)

#line 3078

#
# Macros for screen domains.
#

#
# Author: Russell Coker <russell@coker.com.au>
# Based on the work of Stephen Smalley <sds@epoch.ncsc.mil>
# and Timothy Fraser
#

#
# screen_domain(domain_prefix)
#
# Define a derived domain for the screen program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/screen.te. 
#

#line 3172

#line 3172

#line 3172

#line 3172

#line 3172

#
# Macros for sendmail domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#           Russell Coker <russell@coker.com.au>
#

#
# sendmail_user_domain(domain_prefix)
#
# Define a derived domain for the sendmail program when executed by
# a user domain to send outgoing mail.  These domains are separate and
# independent of the domain used for the sendmail daemon process.
#

#line 3209


#
# Macros for ssh domains.
#

#
# Author:  Stephen Smalley <sds@epoch.ncsc.mil>
#

# 
# ssh_domain(domain_prefix)
#
# Define a derived domain for the ssh program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/ssh.te. 
#

#line 3379

#line 3379

#line 3379

#line 3379

#
# Macros for su domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#
# su_domain(domain_prefix)
#
# Define a derived domain for the su program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/su.te. 
#


#line 3472

#line 3472

#line 3472

#line 3472

#
# Macros for X client programs ($2 etc)
#

#
# Author: Russell Coker <russell@coker.com.au>
# Based on the work of Stephen Smalley <sds@epoch.ncsc.mil>
# and Timothy Fraser 
#

#
# x_client_domain(domain_prefix)
#
# Define a derived domain for an X program when executed by
# a user domain.  
#
# The type declaration for the executable type for this program ($2_exec_t)
# must be provided separately!
#
# The first parameter is the base name for the domain/role (EG user or sysadm)
# The second parameter is the program name (EG $2)
# The third parameter is the attributes for the domain (if any)
#
#line 3635
#
# Macros for xauth domains.
#

#
# Author:  Russell Coker <russell@coker.com.au>
#

#
# xauth_domain(domain_prefix)
#
# Define a derived domain for the xauth program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/xauth.te. 
#

#line 3722

#line 3722

#line 3722

#line 3722

#line 3722

#
# Macros for X server domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#################################
#
# xserver_domain(domain_prefix)
#
# Define a derived domain for the X server when executed
# by a user domain (e.g. via startx).  See the xdm_t domain
# in domains/program/xdm.te if using an X Display Manager.
#
# The type declarations for the executable type for this program 
# and the log type are provided separately in domains/program/xserver.te. 
#
# FIXME!  The X server requires far too many privileges.
#

#line 3899

#line 3899

#line 3899

#line 3899

#line 3899


#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Device types
#

#
# device_t is the type of /dev.
#
type device_t, file_type;

#
# null_device_t is the type of /dev/null.
#
type null_device_t, file_type, mlstrustedobject;

#
# zero_device_t is the type of /dev/zero.
#
type zero_device_t, file_type, mlstrustedobject;

#
# console_device_t is the type of /dev/console.
#
type console_device_t, file_type;

#
# memory_device_t is the type of /dev/kmem,
# /dev/mem, and /dev/port.
#
type memory_device_t, file_type;

#
# random_device_t is the type of /dev/urandom
# and /dev/random.
#
type random_device_t, file_type;

#
# devtty_t is the type of /dev/tty.
#
type devtty_t, file_type, mlstrustedobject;

#
# tty_device_t is the type of /dev/*tty*
#
type tty_device_t, file_type;

#
# fixed_disk_device_t is the type of 
# /dev/hd* and /dev/sd*.
#
type fixed_disk_device_t, file_type;

#
# removable_device_t is the type of
# /dev/scd* and /dev/fd*.
#
type removable_device_t, file_type;

#
# clock_device_t is the type of
# /dev/rtc.
#
type clock_device_t, file_type;

#
# tun_tap_device_t is the type of /dev/net/tun/* and /dev/net/tap/*
#
type tun_tap_device_t, file_type;

#
# misc_device_t is the type of miscellaneous devices.
# XXX:  FIXME!  Appropriate access to these devices need to be identified.
#
type misc_device_t, file_type;

#
# psaux_t is the type of the /dev/psaux mouse device.
# This type is deprecated and will be removed.
#
type psaux_t, file_type;

#
# A more general type for mouse devices.
#
type mouse_device_t, file_type;

#
# Not sure what these devices are for, but X wants access to them.
#
type agp_device_t, file_type;
type dri_device_t, file_type;

# Type for sound devices.
type sound_device_t, file_type;

# Type for /dev/ppp.
type ppp_device_t, file_type;

# Type for frame buffer /dev/fb/*
type framebuf_device_t, file_type;

# Type for /dev/.devfsd
type devfs_control_t, file_type;

# Type for /dev/cpu/mtrr
type mtrr_device_t, file_type;


# Type for /dev/apm_bios
type apm_bios_t, file_type;

# Type for v4l
type v4l_device_t, file_type;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Devpts types
#

#
# ptmx_t is the type for /dev/ptmx.
#
type ptmx_t, file_type, sysadmfile;

#
# devpts_t is the type of the devpts file system and 
# the type of the root directory of the file system.
#
type devpts_t, fs_type, root_dir_type;


#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#######################################
#
# General file-related types
#

#
# unlabeled_t is the type of unlabeled objects.
# Eventually, once all objects are labeled and 
# controlled by the security policy, unlabeled_t 
# will not be used.
#
type unlabeled_t, fs_type, file_type, root_dir_type, sysadmfile;

#
# fs_t is the default type of an unlabeled
# file system.  When an unlabeled file system is
# mounted read-write, the file system is labeled
# with this type.  Except for the root file system,
# other types may be specified using the fs_contexts
# or fs_contexts.mls file.
#
type fs_t, fs_type;

#
# file_t is the default type of an unlabeled
# file.  When an unlabeled file system is mounted
# read-write, all files in the file system are labeled
# with this type.   Except for the root file system,
# other types may be specified using the fs_contexts
# or fs_contexts.mls file.
#
type file_t, file_type, root_dir_type, sysadmfile;

#
# root_t is the type for the root directory.
#
type root_t, file_type, sysadmfile;

#
# home_root_t is the type for the directory where user home directories
# are created
#
type home_root_t, file_type, sysadmfile;

#
# lost_found_t is the type for the lost+found directories.
#
type lost_found_t, file_type, sysadmfile;

#
# boot_t is the type for files in /boot,
# including the kernel.
#
type boot_t, file_type, root_dir_type, sysadmfile;
# system_map_t is for the system.map files in /boot
type system_map_t, file_type, sysadmfile;

#
# boot_runtime_t is the type for /boot/kernel.h,
# which is automatically generated at boot time.
# only for red hat
type boot_runtime_t, file_type, sysadmfile;

#
# tmp_t is the type of /tmp and /var/tmp.
#
type tmp_t, file_type, sysadmfile, tmpfile;

#
# etc_t is the type of the system etc directories.
#
type etc_t, file_type, sysadmfile;
#
# shadow_t is the type of the /etc/shadow file
#
type shadow_t, file_type;
allow auth shadow_t:file { getattr read };

#
# ld_so_cache_t is the type of /etc/ld.so.cache.
#
type ld_so_cache_t, file_type, sysadmfile;

#
# etc_runtime_t is the type of various
# files in /etc that are automatically
# generated during initialization.
#
type etc_runtime_t, file_type, sysadmfile;

#
# etc_aliases_t is the type of the aliases database.
# etc_mail_t is the type of /etc/mail.
# sendmail needs write access to these files.
#
type etc_aliases_t, file_type, sysadmfile;
type etc_mail_t, file_type, sysadmfile;

# resolv_conf_t is the type of the /etc/resolv.conf file.
# pump needs write access to this file.
type resolv_conf_t, file_type, sysadmfile;

#
# lib_t is the type of files in the system lib directories.
#
type lib_t, file_type, sysadmfile;

#
# shlib_t is the type of shared objects in the system lib
# directories.
#
type shlib_t, file_type, sysadmfile;

#
# ld_so_t is the type of the system dynamic loaders.
#
type ld_so_t, file_type, sysadmfile;

#
# bin_t is the type of files in the system bin directories.
#
type bin_t, file_type, sysadmfile;

#
# ls_exec_t is the type of the ls program.
#
type ls_exec_t, file_type, exec_type, sysadmfile;

#
# shell_exec_t is the type of user shells such as /bin/bash.
#
type shell_exec_t, file_type, exec_type, sysadmfile;

#
# sbin_t is the type of files in the system sbin directories.
#
type sbin_t, file_type, sysadmfile;

#
# usr_t is the type for /usr.
#
type usr_t, file_type, root_dir_type, sysadmfile;

#
# src_t is the type of files in the system src directories.
#
type src_t, file_type, sysadmfile;

#
# var_t is the type for /var.
#
type var_t, file_type, root_dir_type, sysadmfile;

#
# Types for subdirectories of /var.
#
type var_run_t, file_type, sysadmfile;
type var_log_t, file_type, sysadmfile, logfile;
type faillog_t, file_type, sysadmfile, logfile;
type var_lock_t, file_type, sysadmfile, lockfile;
type var_lib_t, file_type, sysadmfile;
# for /var/{spool,lib}/texmf index files
type tetex_data_t, file_type, sysadmfile, tmpfile;
type var_spool_t, file_type, sysadmfile;
type var_yp_t, file_type, sysadmfile;

# Type for /var/log/sa.
type var_log_sa_t, file_type, sysadmfile, logfile;

# Type for /var/log/ksyms.
type var_log_ksyms_t, file_type, sysadmfile, logfile;

# Type for /var/log/lastlog.
type lastlog_t, file_type, sysadmfile, logfile;

# Type for /var/lib/nfs.
type var_lib_nfs_t, file_type, sysadmfile;

#
# wtmp_t is the type of /var/log/wtmp.
#
type wtmp_t, file_type, sysadmfile, logfile;

#
# catman_t is the type for /var/catman.
#
type catman_t, file_type, sysadmfile, tmpfile;

#
# at_spool_t is the type for /var/spool/at.
#
type at_spool_t, file_type, sysadmfile;

#
# cron_spool_t is the type for /var/spool/cron.
#
type cron_spool_t, file_type, sysadmfile;

#
# print_spool_t is the type for /var/spool/lpd and /var/spool/cups.
#
type print_spool_t, file_type, sysadmfile;

#
# mail_spool_t is the type for /var/spool/mail.
#
type mail_spool_t, file_type, sysadmfile;

#
# mqueue_spool_t is the type for /var/spool/mqueue.
#
type mqueue_spool_t, file_type, sysadmfile;

#
# man_t is the type for the man directories.
#
type man_t, file_type, sysadmfile;

#
# readable_t is a general type for
# files that are readable by all domains.
#
type readable_t, file_type, sysadmfile;

# 
# Base type for the tests directory.
# 
type test_file_t, file_type, sysadmfile;

#
# poly_t is the type for the polyinstantiated directories.
#
type poly_t, file_type, sysadmfile;

#
# swapfile_t is for swap files
#
type swapfile_t, file_type, sysadmfile;

#
# locale_t is the type for system localization
# 
type locale_t, file_type;

#
# Allow each file type to be associated with 
# the default file system type.
#
allow file_type fs_t:filesystem associate;

# Allow the pty to be associated with the file system.
allow devpts_t devpts_t:filesystem associate;

type tmpfs_t, file_type, sysadmfile, fs_type, root_dir_type;
allow { tmpfs_t tmp_t } tmpfs_t:filesystem associate;

type usbdevfs_t, fs_type, root_dir_type, sysadmfile;
allow usbdevfs_t usbdevfs_t:filesystem associate;
type usbdevfs_device_t, file_type, sysadmfile;
allow usbdevfs_device_t usbdevfs_t:filesystem associate;

type sysfs_t alias driverfs_t, fs_type, root_dir_type, sysadmfile;
allow sysfs_t sysfs_t:filesystem associate;

type iso9660_t, fs_type, root_dir_type, sysadmfile;
allow iso9660_t iso9660_t:filesystem associate;

type dosfs_t, fs_type, root_dir_type, sysadmfile;
allow dosfs_t dosfs_t:filesystem associate;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

# Modified by Reino Wallin <reino@oribium.com>
# Multi NIC, and IPSEC features

# Modified by Russell Coker
# Move port types to their respective domains, add ifdefs, other cleanups.

############################################
#
# Network types
#

# 
# any_socket_t is the default destination
# socket type for UDP traffic.  Unless a 
# destination socket type is explicitly specified
# using sendto_secure/sendmsg_secure, this type
# is used for the udp_socket sendto permission check.
#
type any_socket_t, socket_type;
role system_r types any_socket_t;

#
# igmp_packet_t is the type of kernel-generated IGMP packets.
# icmp_socket_t is the type of the kernel socket used to send ICMP messages.
# tcp_socket_t is the type of the kernel socket used to send TCP resets.
# scmp_packet_t is the type for SCMP packets used by the SELOPT packet labeling.
#
type igmp_packet_t;
role system_r types igmp_packet_t;
type icmp_socket_t, socket_type;
role system_r types icmp_socket_t;
type tcp_socket_t, socket_type;
role system_r types tcp_socket_t;
type scmp_packet_t;
role system_r types scmp_packet_t;

#
# port_t is the default type of INET port numbers.
# The *_port_t types are used for specific port
# numbers in net_contexts or net_contexts.mls.
#
type port_t, port_type;

#
# netif_t is the default type of network interfaces.
# The netif_*_t types are used for specific network
# interfaces in net_contexts or net_contexts.mls.
#
type netif_t, netif_type;
type netif_eth0_t, netif_type;
type netif_eth1_t, netif_type;
type netif_eth2_t, netif_type;
type netif_lo_t, netif_type;
type netif_ippp0_t, netif_type;

type netif_ipsec0_t, netif_type;
type netif_ipsec1_t, netif_type;
type netif_ipsec2_t, netif_type;

#
# netmsg_t is the default type of unlabeled received messages.
# The netmsg_*_t types are used for specific network
# interfaces in net_contexts or net_contexts.mls.
#
type netmsg_t, netmsg_type;
type netmsg_eth0_t, netmsg_type;
type netmsg_eth1_t, netmsg_type;
type netmsg_eth2_t, netmsg_type;
type netmsg_lo_t, netmsg_type;
type netmsg_ippp0_t, netmsg_type;

type netmsg_ipsec0_t, netmsg_type;
type netmsg_ipsec1_t, netmsg_type;
type netmsg_ipsec2_t, netmsg_type;

#
# node_t is the default type of network nodes.
# The node_*_t types are used for specific network
# nodes in net_contexts or net_contexts.mls.
#
type node_t, node_type;
type node_lo_t, node_type;
type node_internal_t, node_type;

#
# Permissions for the kernel-generated IGMP packets.
#
allow igmp_packet_t netif_type:netif { rawip_send rawip_recv };
allow igmp_packet_t node_type:node { rawip_send rawip_recv };

#
# Permissions for the kernel ICMP socket.
#
allow icmp_socket_t netif_type:netif { rawip_send rawip_recv };
allow icmp_socket_t node_type:node { rawip_send rawip_recv };
allow icmp_socket_t netmsg_type:rawip_socket recvfrom;

#
# Permissions for the kernel TCP reset socket.
#
allow tcp_socket_t netif_type:netif { tcp_send tcp_recv };
allow tcp_socket_t netmsg_type:tcp_socket recvfrom;
allow tcp_socket_t node_type:node { tcp_send tcp_recv };

#
# Allow network messages to be received.
#
allow netmsg_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth0_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth0_t netif_eth0_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_eth1_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth1_t netif_eth1_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_eth2_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth2_t netif_eth2_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_lo_t node_lo_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_lo_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_lo_t netif_lo_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_ippp0_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ippp0_t netif_ippp0_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec0_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec0_t netif_ipsec0_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec1_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec1_t netif_ipsec1_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec2_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec2_t netif_ipsec2_t:netif { tcp_recv udp_recv rawip_recv };

#
# Allow ICMP echo requests to be sent and received, and echo replies to 
# be received (when packets are labeled)
#
#line 4450

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#############################################
#
# NFS types
#

#
# nfs_t is the default type for NFS file systems 
# and their files.  
# The nfs_*_t types are used for specific NFS
# servers in net_contexts or net_contexts.mls.
#
type nfs_t, fs_type, root_dir_type;

#
# Allow NFS files to be associated with an NFS file system.
#
allow nfs_t nfs_t:filesystem associate;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Procfs types
#

#
# proc_t is the type of /proc.
# proc_kmsg_t is the type of /proc/kmsg.
# proc_kcore_t is the type of /proc/kcore.
#
type proc_t, fs_type, root_dir_type;
type proc_kmsg_t;
type proc_kcore_t;

#
# sysctl_t is the type of /proc/sys.
# sysctl_fs_t is the type of /proc/sys/fs.
# sysctl_kernel_t is the type of /proc/sys/kernel.
# sysctl_modprobe_t is the type of /proc/sys/kernel/modprobe.
# sysctl_net_t is the type of /proc/sys/net.
# sysctl_net_unix_t is the type of /proc/sys/net/unix.
# sysctl_vm_t is the type of /proc/sys/vm.
# sysctl_dev_t is the type of /proc/sys/dev.
#
# These types are applied to both the entries in
# /proc/sys and the corresponding sysctl parameters.
#
type sysctl_t;
type sysctl_fs_t;
type sysctl_kernel_t;
type sysctl_modprobe_t;
type sysctl_net_t;
type sysctl_net_unix_t;
type sysctl_vm_t;
type sysctl_dev_t;


#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Security types
#

# 
# security_t is the target type when checking
# the permissions in the security class.  It is also
# applied to selinuxfs inodes.
#
type security_t, fs_type;

#
# policy_config_t is the type of /ss_policy,
# the security server policy configuration.
#
type policy_config_t, file_type;

#
# policy_src_t is the type of the policy source
# files.
#
type policy_src_t, file_type;

#
# default_context_t is the type applied to 
# /etc/security/default_context
#
type default_context_t, file_type, sysadmfile, login_contexts;

#
# file_labels_t is the type of the persistent
# label mapping stored in each file system.
# The mapping files are in the ...security
# subdirectory at the root of each file system.
#
type file_labels_t, file_type, sysadmfile;

#
# no_access_t is the type for objects that should
# only be accessed administratively. 
#
type no_access_t, file_type, sysadmfile;


#DESC Admin - Domains for administrators.
#
#################################

# sysadm_t is the system administrator domain.
type sysadm_t, domain, privlog, privowner, admin, userdomain, web_client_domain, privhome;
allow privhome home_root_t:dir search;

# system_r is authorized for sysadm_t for single-user mode.
role system_r types sysadm_t; 

# sysadm_r is authorized for sysadm_t for the initial login domain.
role sysadm_r types sysadm_t;


#line 4576
# Read system information files in /proc.
#line 4576
allow sysadm_t proc_t:dir { read getattr lock search ioctl };
#line 4576
allow sysadm_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4576

#line 4576
# Stat /proc/kmsg and /proc/kcore.
#line 4576
allow sysadm_t proc_kmsg_t:file { getattr };
#line 4576
allow sysadm_t proc_kcore_t:file { getattr };
#line 4576

#line 4576
# Read system variables in /proc/sys.
#line 4576
allow sysadm_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_t:dir { read getattr lock search ioctl };
#line 4576
allow sysadm_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4576
allow sysadm_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4576
allow sysadm_t sysctl_net_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4576
allow sysadm_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4576
allow sysadm_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4576
allow sysadm_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4576


#line 4577
# Access other processes in the same domain.
#line 4577
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4577
# separately if desired.
#line 4577
allow sysadm_t self:process ~{ptrace setexec setfscreate};
#line 4577

#line 4577
# Access /proc/PID files for processes in the same domain.
#line 4577
allow sysadm_t self:dir { read getattr lock search ioctl };
#line 4577
allow sysadm_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4577

#line 4577
# Access file descriptions, pipes, and sockets
#line 4577
# created by processes in the same domain.
#line 4577
allow sysadm_t self:fd *;
#line 4577
allow sysadm_t self:fifo_file { ioctl read getattr lock write append };
#line 4577
allow sysadm_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4577
allow sysadm_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4577

#line 4577
# Allow the domain to communicate with other processes in the same domain.
#line 4577
allow sysadm_t self:unix_dgram_socket sendto;
#line 4577
allow sysadm_t self:unix_stream_socket connectto;
#line 4577

#line 4577
# Access System V IPC objects created by processes in the same domain.
#line 4577
allow sysadm_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4577
allow sysadm_t self:msg  { send receive };
#line 4577
allow sysadm_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4577
allow sysadm_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4577


# sysadm_t is also granted permissions specific to administrator domains.

#line 4580
# Inherit rules for ordinary users.
#line 4580

#line 4580
# Use capabilities
#line 4580
allow sysadm_t self:capability { setgid chown fowner };
#line 4580
dontaudit sysadm_t self:capability { sys_nice fsetid };
#line 4580

#line 4580
# Type for home directory.
#line 4580

#line 4580
type sysadm_home_dir_t, file_type, sysadmfile, home_dir_type, home_type;
#line 4580
type sysadm_home_t, file_type, sysadmfile, home_type;
#line 4580

#line 4580
type sysadm_tmp_t, file_type, sysadmfile, tmpfile ;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_t tmp_t:dir sysadm_tmp_t;
#line 4580
type_transition sysadm_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# allow ptrace
#line 4580
#can_ptrace(sysadm_t, sysadm_t)
#line 4580

#line 4580
# Create, access, and remove files in home directory.
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_t sysadm_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_t sysadm_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_t sysadm_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_t sysadm_home_dir_t:dir sysadm_home_t;
#line 4580
type_transition sysadm_t sysadm_home_dir_t:{ file lnk_file sock_file fifo_file } sysadm_home_t;
#line 4580

#line 4580

#line 4580

#line 4580
allow sysadm_t sysadm_home_t:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { relabelfrom relabelto };
#line 4580

#line 4580
# Bind to a Unix domain socket in /tmp.
#line 4580
allow sysadm_t sysadm_tmp_t:unix_stream_socket name_bind;
#line 4580

#line 4580
# Type for tty devices.
#line 4580
type sysadm_tty_device_t, file_type, sysadmfile, ttyfile;
#line 4580
# Access ttys.
#line 4580
allow sysadm_t privfd:fd use;
#line 4580
allow sysadm_t sysadm_tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4580
# Use the type when relabeling terminal devices.
#line 4580
type_change sysadm_t tty_device_t:chr_file sysadm_tty_device_t;
#line 4580

#line 4580

#line 4580
# read localization information
#line 4580
allow sysadm_t locale_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4580

#line 4580
# for running TeX programs
#line 4580

#line 4580
allow sysadm_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580
allow sysadm_t tetex_data_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
# Type and access for pty devices.
#line 4580

#line 4580

#line 4580

#line 4580
# Access the pty master multiplexer.
#line 4580
allow sysadm_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580
allow sysadm_t devpts_t:filesystem getattr;
#line 4580

#line 4580
# allow searching /dev/pts
#line 4580
allow sysadm_t devpts_t:dir { getattr read search };
#line 4580

#line 4580
type sysadm_devpts_t, file_type, sysadmfile, ptyfile ;
#line 4580

#line 4580
# Allow the pty to be associated with the file system.
#line 4580
allow sysadm_devpts_t devpts_t:filesystem associate;
#line 4580

#line 4580
# Label pty files with a derived type.
#line 4580
type_transition sysadm_t devpts_t:chr_file sysadm_devpts_t;
#line 4580

#line 4580
# Read and write my pty files.
#line 4580
allow sysadm_t sysadm_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4580

#line 4580

#line 4580

#line 4580
# Use the type when relabeling pty devices.
#line 4580

#line 4580

#line 4580
type_change sysadm_t sshd_devpts_t:chr_file sysadm_devpts_t;
#line 4580

#line 4580
# Connect to sshd.
#line 4580

#line 4580
allow sysadm_t sshd_t:tcp_socket { connectto recvfrom };
#line 4580
allow sshd_t sysadm_t:tcp_socket { acceptfrom recvfrom };
#line 4580
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580

#line 4580

#line 4580
# Connect to ssh proxy.
#line 4580

#line 4580
allow sysadm_t sysadm_ssh_t:tcp_socket { connectto recvfrom };
#line 4580
allow sysadm_ssh_t sysadm_t:tcp_socket { acceptfrom recvfrom };
#line 4580
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580

#line 4580

#line 4580
allow sysadm_t sshd_t:fd use;
#line 4580
allow sysadm_t sshd_t:tcp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580
# Use a Unix stream socket inherited from sshd.
#line 4580
allow sysadm_t sshd_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580

#line 4580
allow sysadm_t boot_t:dir { getattr search };
#line 4580
dontaudit sysadm_t boot_t:dir read;
#line 4580
dontaudit sysadm_t boot_t:lnk_file getattr;
#line 4580
dontaudit sysadm_t boot_t:file { getattr read };
#line 4580
allow sysadm_t system_map_t:file { getattr read };
#line 4580

#line 4580

#line 4580
type sysadm_tmpfs_t, file_type, sysadmfile, tmpfsfile;
#line 4580
# Use this type when creating tmpfs/shm objects.
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_t tmpfs_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_t sysadm_tmpfs_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_t sysadm_tmpfs_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_t tmpfs_t:dir sysadm_tmpfs_t;
#line 4580
type_transition sysadm_t tmpfs_t:{ file lnk_file sock_file fifo_file } sysadm_tmpfs_t;
#line 4580

#line 4580

#line 4580

#line 4580
allow sysadm_tmpfs_t tmpfs_t:filesystem associate;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Read and write /var/catman.
#line 4580
allow sysadm_t catman_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580
allow sysadm_t catman_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580

#line 4580
# Modify mail spool file.
#line 4580
allow sysadm_t mail_spool_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t mail_spool_t:file { ioctl read getattr lock write append };
#line 4580
allow sysadm_t mail_spool_t:lnk_file read;
#line 4580

#line 4580
#
#line 4580
# Allow the query of filesystem quotas
#line 4580
#
#line 4580
allow sysadm_t fs_type:filesystem quotaget;
#line 4580

#line 4580
# Run helper programs.
#line 4580

#line 4580
allow sysadm_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4580

#line 4580
allow sysadm_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_t device_t:dir search;
#line 4580
allow sysadm_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580
allow sysadm_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
# Run programs developed by other users in the same domain.
#line 4580

#line 4580
allow sysadm_t sysadm_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_t sysadm_tmp_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
# Run user programs that require different permissions in their own domain.
#line 4580
# These rules were moved into the individual program domains.
#line 4580

#line 4580
# Instantiate derived domains for a number of programs.
#line 4580
# These derived domains encode both information about the calling
#line 4580
# user domain and the program, and allow us to maintain separation
#line 4580
# between different instances of the program being run by different
#line 4580
# user domains.
#line 4580

#line 4580

#line 4580

#line 4580
# Derived domain based on the calling user domain and the program.
#line 4580
type sysadm_su_t, domain, privlog, auth;
#line 4580

#line 4580
# Transition from the user domain to this domain.
#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow sysadm_t sysadm_su_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit sysadm_t sysadm_su_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow sysadm_t su_exec_t:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_su_t sysadm_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_su_t sysadm_t:fd use;
#line 4580
allow sysadm_t sysadm_su_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_su_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_su_t su_exec_t:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_su_t su_exec_t:file entrypoint;
#line 4580

#line 4580
type_transition sysadm_t su_exec_t:process sysadm_su_t;
#line 4580

#line 4580

#line 4580

#line 4580
allow sysadm_su_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_su_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_su_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_su_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_su_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_su_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_su_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_su_t device_t:dir search;
#line 4580
allow sysadm_su_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
allow sysadm_su_t etc_t:file { getattr read };
#line 4580

#line 4580
allow sysadm_su_t etc_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_su_t locale_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_su_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580
allow sysadm_su_t self:unix_dgram_socket { connect create write };
#line 4580
allow sysadm_su_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580
allow sysadm_su_t proc_t:dir search;
#line 4580
allow sysadm_su_t proc_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_su_t self:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_su_t self:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580
allow sysadm_su_t self:process setsched;
#line 4580
allow sysadm_su_t device_t:dir search;
#line 4580
allow sysadm_su_t self:process { fork sigchld };
#line 4580

#line 4580
# Use capabilities.
#line 4580
allow sysadm_su_t self:capability { setuid setgid net_bind_service chown dac_override sys_nice sys_resource };
#line 4580

#line 4580
# Revert to the user domain when a shell is executed.
#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow sysadm_su_t sysadm_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit sysadm_su_t sysadm_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow sysadm_su_t shell_exec_t:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_t sysadm_su_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_t sysadm_su_t:fd use;
#line 4580
allow sysadm_su_t sysadm_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_t sysadm_su_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_t shell_exec_t:file entrypoint;
#line 4580

#line 4580
type_transition sysadm_su_t shell_exec_t:process sysadm_t;
#line 4580

#line 4580
allow sysadm_su_t bin_t:dir search;
#line 4580
allow sysadm_su_t bin_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_su_t privfd:fd use;
#line 4580

#line 4580
# Write to utmp.
#line 4580
allow sysadm_su_t { var_t var_run_t }:dir search;
#line 4580
allow sysadm_su_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580

#line 4580
# Run chkpwd.
#line 4580

#line 4580
allow sysadm_su_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580

#line 4580
# Inherit and use descriptors from gnome-pty-helper.
#line 4580

#line 4580

#line 4580
# The user role is authorized for this domain.
#line 4580
role sysadm_r types sysadm_su_t;
#line 4580

#line 4580
# Write to the user domain tty.
#line 4580
allow sysadm_su_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_su_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
allow sysadm_su_t { home_root_t sysadm_home_dir_t }:dir search;
#line 4580

#line 4580
# Modify .Xauthority file (via xauth program).
#line 4580

#line 4580

#line 4580
# Access sshd cookie files.
#line 4580
allow sysadm_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580
allow sysadm_su_t sshd_tmp_t:file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_su_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_su_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_su_t sshd_tmp_t:dir sysadm_tmp_t;
#line 4580
type_transition sysadm_su_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# stop su complaining if you run it from a directory with restrictive perms
#line 4580
dontaudit sysadm_su_t file_type:dir search;
#line 4580

#line 4580

#line 4580
# Derived domain based on the calling user domain and the program.
#line 4580
type sysadm_chkpwd_t, domain, privlog, auth;
#line 4580

#line 4580
# Transition from the user domain to this domain.
#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow sysadm_t sysadm_chkpwd_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit sysadm_t sysadm_chkpwd_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow sysadm_t chkpwd_exec_t:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_chkpwd_t sysadm_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_chkpwd_t sysadm_t:fd use;
#line 4580
allow sysadm_t sysadm_chkpwd_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_chkpwd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_chkpwd_t chkpwd_exec_t:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_chkpwd_t chkpwd_exec_t:file entrypoint;
#line 4580

#line 4580
type_transition sysadm_t chkpwd_exec_t:process sysadm_chkpwd_t;
#line 4580

#line 4580

#line 4580
# The user role is authorized for this domain.
#line 4580
role sysadm_r types sysadm_chkpwd_t;
#line 4580

#line 4580

#line 4580
allow sysadm_chkpwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_chkpwd_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_chkpwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_chkpwd_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_chkpwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_chkpwd_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_chkpwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_chkpwd_t device_t:dir search;
#line 4580
allow sysadm_chkpwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
allow sysadm_chkpwd_t etc_t:file { getattr read };
#line 4580
allow sysadm_chkpwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_chkpwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580

#line 4580
allow sysadm_chkpwd_t etc_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_chkpwd_t locale_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_chkpwd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580

#line 4580
# Use capabilities.
#line 4580
allow sysadm_chkpwd_t self:capability setuid;
#line 4580

#line 4580
# Inherit and use descriptors from gnome-pty-helper.
#line 4580

#line 4580

#line 4580
# Inherit and use descriptors from newrole.
#line 4580
allow sysadm_chkpwd_t newrole_t:fd use;
#line 4580

#line 4580
# Write to the user domain tty.
#line 4580
allow sysadm_chkpwd_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_chkpwd_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Derived domain based on the calling user domain and the program.
#line 4580
type sysadm_crontab_t, domain, privlog;
#line 4580

#line 4580
# Transition from the user domain to the derived domain.
#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow sysadm_t sysadm_crontab_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit sysadm_t sysadm_crontab_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow sysadm_t crontab_exec_t:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_crontab_t sysadm_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_crontab_t sysadm_t:fd use;
#line 4580
allow sysadm_t sysadm_crontab_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_crontab_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_crontab_t crontab_exec_t:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_crontab_t crontab_exec_t:file entrypoint;
#line 4580

#line 4580
type_transition sysadm_t crontab_exec_t:process sysadm_crontab_t;
#line 4580

#line 4580

#line 4580
# The user role is authorized for this domain.
#line 4580
role sysadm_r types sysadm_crontab_t;
#line 4580

#line 4580

#line 4580
allow sysadm_crontab_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crontab_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crontab_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_crontab_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_crontab_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crontab_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_crontab_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_crontab_t device_t:dir search;
#line 4580
allow sysadm_crontab_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
allow sysadm_crontab_t etc_t:file { getattr read };
#line 4580
allow sysadm_crontab_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_crontab_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580

#line 4580
allow sysadm_crontab_t etc_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_crontab_t locale_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crontab_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580

#line 4580
# Use capabilities
#line 4580
allow sysadm_crontab_t sysadm_crontab_t:capability { setuid setgid chown };
#line 4580

#line 4580
# Type for temporary files.
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_crontab_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_crontab_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_crontab_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_crontab_t tmp_t:dir sysadm_tmp_t;
#line 4580
type_transition sysadm_crontab_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Type of user crontabs once moved to cron spool.
#line 4580
type sysadm_cron_spool_t, file_type, sysadmfile;
#line 4580
# Use the type when creating files in /var/spool/cron.
#line 4580
allow sysadm_crontab_t sysadm_cron_spool_t:file { getattr read };
#line 4580
allow sysadm_crontab_t { var_t var_spool_t }:dir search;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_crontab_t cron_spool_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_crontab_t sysadm_cron_spool_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_crontab_t sysadm_cron_spool_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_crontab_t cron_spool_t:dir sysadm_cron_spool_t;
#line 4580
type_transition sysadm_crontab_t cron_spool_t:{ file lnk_file sock_file fifo_file } sysadm_cron_spool_t;
#line 4580

#line 4580

#line 4580

#line 4580
allow sysadm_crontab_t self:process { fork { sigchld sigkill sigstop signull signal } };
#line 4580

#line 4580
# crontab signals crond by updating the mtime on the spooldir
#line 4580
allow sysadm_crontab_t cron_spool_t:dir setattr;
#line 4580
# Allow crond to read those crontabs in cron spool.
#line 4580
allow crond_t sysadm_cron_spool_t:file { read getattr lock ioctl };
#line 4580

#line 4580
# Run helper programs as sysadm_t
#line 4580
allow sysadm_crontab_t { bin_t sbin_t }:dir search;
#line 4580
allow sysadm_crontab_t bin_t:lnk_file read;
#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow sysadm_crontab_t sysadm_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit sysadm_crontab_t sysadm_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow sysadm_crontab_t { bin_t sbin_t shell_exec_t }:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_t sysadm_crontab_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_t sysadm_crontab_t:fd use;
#line 4580
allow sysadm_crontab_t sysadm_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_t sysadm_crontab_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_t { bin_t sbin_t shell_exec_t }:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_t { bin_t sbin_t shell_exec_t }:file entrypoint;
#line 4580

#line 4580
type_transition sysadm_crontab_t { bin_t sbin_t shell_exec_t }:process sysadm_t;
#line 4580

#line 4580

#line 4580
# Read user crontabs 
#line 4580
allow sysadm_crontab_t { sysadm_home_t sysadm_home_dir_t }:dir { read getattr lock search ioctl };  
#line 4580
allow sysadm_crontab_t sysadm_home_t:file { read getattr lock ioctl };  
#line 4580
dontaudit sysadm_crontab_t sysadm_home_dir_t:dir write;
#line 4580

#line 4580
# Access the cron log file.
#line 4580
allow sysadm_crontab_t cron_log_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_crontab_t cron_log_t:file { append };
#line 4580

#line 4580
# Access terminals.
#line 4580
allow sysadm_crontab_t device_t:dir search;
#line 4580
allow sysadm_crontab_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_crontab_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# Inherit and use descriptors from gnome-pty-helper.
#line 4580

#line 4580
allow sysadm_crontab_t privfd:fd use;
#line 4580

#line 4580

#line 4580
# Derived domain based on the calling user domain and the program.
#line 4580
type sysadm_ssh_t, domain, privlog;
#line 4580

#line 4580
# Transition from the user domain to the derived domain.
#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow sysadm_t sysadm_ssh_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit sysadm_t sysadm_ssh_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow sysadm_t ssh_exec_t:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_ssh_t sysadm_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_ssh_t sysadm_t:fd use;
#line 4580
allow sysadm_t sysadm_ssh_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_ssh_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_ssh_t ssh_exec_t:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_ssh_t ssh_exec_t:file entrypoint;
#line 4580

#line 4580
type_transition sysadm_t ssh_exec_t:process sysadm_ssh_t;
#line 4580

#line 4580

#line 4580
# The user role is authorized for this domain.
#line 4580
role sysadm_r types sysadm_ssh_t;
#line 4580

#line 4580
# Grant permissions within the domain.
#line 4580

#line 4580
# Access other processes in the same domain.
#line 4580
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4580
# separately if desired.
#line 4580
allow sysadm_ssh_t self:process ~{ptrace setexec setfscreate};
#line 4580

#line 4580
# Access /proc/PID files for processes in the same domain.
#line 4580
allow sysadm_ssh_t self:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Access file descriptions, pipes, and sockets
#line 4580
# created by processes in the same domain.
#line 4580
allow sysadm_ssh_t self:fd *;
#line 4580
allow sysadm_ssh_t self:fifo_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_ssh_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_ssh_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580

#line 4580
# Allow the domain to communicate with other processes in the same domain.
#line 4580
allow sysadm_ssh_t self:unix_dgram_socket sendto;
#line 4580
allow sysadm_ssh_t self:unix_stream_socket connectto;
#line 4580

#line 4580
# Access System V IPC objects created by processes in the same domain.
#line 4580
allow sysadm_ssh_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4580
allow sysadm_ssh_t self:msg  { send receive };
#line 4580
allow sysadm_ssh_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4580
allow sysadm_ssh_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4580

#line 4580

#line 4580
# Use descriptors created by sshd
#line 4580
allow sysadm_ssh_t privfd:fd use;
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_ssh_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t device_t:dir search;
#line 4580
allow sysadm_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t etc_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_ssh_t locale_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580

#line 4580
# Get attributes of file systems.
#line 4580
allow sysadm_ssh_t fs_type:filesystem getattr;
#line 4580

#line 4580

#line 4580
# Read /.
#line 4580
allow sysadm_ssh_t root_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Read /home.
#line 4580
allow sysadm_ssh_t home_root_t:dir { read getattr lock search ioctl };
#line 4580

#line 4580
# Read /usr.
#line 4580
allow sysadm_ssh_t usr_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Read bin and sbin directories.
#line 4580
allow sysadm_ssh_t bin_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t sbin_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580
# Read the devpts root directory.
#line 4580
allow sysadm_ssh_t devpts_t:dir { read getattr lock search ioctl };
#line 4580

#line 4580
# Read /var.
#line 4580
allow sysadm_ssh_t var_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Read /var/run, /var/log.
#line 4580
allow sysadm_ssh_t var_run_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t var_log_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Read /etc.
#line 4580
allow sysadm_ssh_t etc_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Read the linker, shared library, and executable types.
#line 4580
allow sysadm_ssh_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Read /dev directories and any symbolic links.
#line 4580
allow sysadm_ssh_t device_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t device_t:lnk_file { read getattr lock ioctl };
#line 4580

#line 4580
# Read /dev/random.
#line 4580
allow sysadm_ssh_t random_device_t:chr_file { read getattr lock ioctl };
#line 4580

#line 4580
# Read and write /dev/tty and /dev/null.
#line 4580
allow sysadm_ssh_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_ssh_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# Grant permissions needed to create TCP and UDP sockets and
#line 4580
# to access the network.
#line 4580

#line 4580
#
#line 4580
# Allow the domain to create and use UDP and TCP sockets.
#line 4580
# Other kinds of sockets must be separately authorized for use.
#line 4580
allow sysadm_ssh_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_ssh_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send UDP packets.
#line 4580
# Since the destination sockets type is unknown, the generic
#line 4580
# any_socket_t type is used as a placeholder.
#line 4580
#
#line 4580
allow sysadm_ssh_t any_socket_t:udp_socket sendto;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send using any network interface.
#line 4580
# netif_type is a type attribute for all network interface types.
#line 4580
#
#line 4580
allow sysadm_ssh_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4580

#line 4580
#
#line 4580
# Allow packets sent by the domain to be received on any network interface.
#line 4580
#
#line 4580
allow sysadm_ssh_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to receive packets from any network interface.
#line 4580
# netmsg_type is a type attribute for all default message types.
#line 4580
#
#line 4580
allow sysadm_ssh_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to initiate or accept TCP connections 
#line 4580
# on any network interface.
#line 4580
#
#line 4580
allow sysadm_ssh_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4580

#line 4580
#
#line 4580
# Receive resets from the TCP reset socket.
#line 4580
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4580
#
#line 4580
allow sysadm_ssh_t tcp_socket_t:tcp_socket recvfrom;
#line 4580

#line 4580
dontaudit sysadm_ssh_t tcp_socket_t:tcp_socket connectto;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send to any node.
#line 4580
# node_type is a type attribute for all node types.
#line 4580
#
#line 4580
allow sysadm_ssh_t node_type:node { tcp_send udp_send rawip_send };
#line 4580

#line 4580
#
#line 4580
# Allow packets sent by the domain to be received from any node.
#line 4580
#
#line 4580
allow sysadm_ssh_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send NFS client requests via the socket
#line 4580
# created by mount.
#line 4580
#
#line 4580
allow sysadm_ssh_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580

#line 4580
#
#line 4580
# Bind to the default port type.
#line 4580
# Other port types must be separately authorized.
#line 4580
#
#line 4580
allow sysadm_ssh_t port_t:udp_socket name_bind;
#line 4580
allow sysadm_ssh_t port_t:tcp_socket name_bind;
#line 4580

#line 4580

#line 4580
# for sshing to a ssh tunnel
#line 4580

#line 4580
allow sysadm_ssh_t sysadm_ssh_t:tcp_socket { connectto recvfrom };
#line 4580
allow sysadm_ssh_t sysadm_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4580
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580

#line 4580

#line 4580
# Use capabilities.
#line 4580
allow sysadm_ssh_t self:capability { setuid setgid dac_override dac_read_search };
#line 4580

#line 4580
# Run helpers.
#line 4580

#line 4580
allow sysadm_ssh_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4580

#line 4580
allow sysadm_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_ssh_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_ssh_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_ssh_t device_t:dir search;
#line 4580
allow sysadm_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580

#line 4580
# Read the ssh key file.
#line 4580
allow sysadm_ssh_t sshd_key_t:file { read getattr lock ioctl };
#line 4580

#line 4580
# Access the ssh temporary files.
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_ssh_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_ssh_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_ssh_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_ssh_t tmp_t:dir sshd_tmp_t;
#line 4580
type_transition sysadm_ssh_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 4580

#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t sysadm_tmp_t:dir { read getattr lock search ioctl };
#line 4580

#line 4580
# for rsync
#line 4580
allow sysadm_ssh_t sysadm_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580

#line 4580
# Access the users .ssh directory.
#line 4580
type sysadm_home_ssh_t, file_type, sysadmfile;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_ssh_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_ssh_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition { sysadm_ssh_t sysadm_ssh_t } sysadm_home_dir_t:dir sysadm_home_ssh_t;
#line 4580
type_transition { sysadm_ssh_t sysadm_ssh_t } sysadm_home_dir_t:{ file lnk_file sock_file fifo_file } sysadm_home_ssh_t;
#line 4580

#line 4580

#line 4580

#line 4580
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_ssh_t:lnk_file { getattr read };
#line 4580
dontaudit sysadm_ssh_t sysadm_home_t:dir search;
#line 4580

#line 4580
allow sshd_t sysadm_home_ssh_t:dir { read getattr lock search ioctl };
#line 4580
allow sshd_t sysadm_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580
allow sysadm_t sysadm_home_ssh_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580
allow sysadm_t sysadm_home_ssh_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580

#line 4580

#line 4580
# for /bin/sh used to execute xauth
#line 4580
dontaudit sysadm_ssh_t proc_t:dir search;
#line 4580

#line 4580
# Inherit and use descriptors from gnome-pty-helper.
#line 4580

#line 4580

#line 4580
# Connect to sshd.
#line 4580

#line 4580

#line 4580
allow sysadm_ssh_t sshd_t:tcp_socket { connectto recvfrom };
#line 4580
allow sshd_t sysadm_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4580
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580

#line 4580

#line 4580

#line 4580
# Write to the user domain tty.
#line 4580
allow sysadm_ssh_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_ssh_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# Allow the user shell to signal the ssh program.
#line 4580
allow sysadm_t sysadm_ssh_t:process signal;
#line 4580
# allow ps to show ssh
#line 4580
allow sysadm_t sysadm_ssh_t:dir { search getattr read };
#line 4580
allow sysadm_t sysadm_ssh_t:{ file lnk_file } { read getattr };
#line 4580

#line 4580
# Allow the ssh program to communicate with ssh-agent.
#line 4580
allow sysadm_ssh_t sysadm_tmp_t:sock_file write;
#line 4580
allow sysadm_ssh_t sysadm_t:unix_stream_socket connectto;
#line 4580
allow sysadm_ssh_t sshd_t:unix_stream_socket connectto;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Instantiate a derived domain for user cron jobs.
#line 4580

#line 4580
# Derived domain for user cron jobs, user user_crond_domain if not system
#line 4580

#line 4580
type sysadm_crond_t, domain, user_crond_domain;
#line 4580

#line 4580

#line 4580
# Permit a transition from the crond_t domain to this domain.
#line 4580
# The transition is requested explicitly by the modified crond 
#line 4580
# via execve_secure.  There is no way to set up an automatic
#line 4580
# transition, since crontabs are configuration files, not executables.
#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to transition to the new domain.
#line 4580
#
#line 4580
allow crond_t sysadm_crond_t:process transition;
#line 4580

#line 4580
#
#line 4580
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4580
#
#line 4580
dontaudit crond_t sysadm_crond_t:process noatsecure;
#line 4580

#line 4580
#
#line 4580
# Allow the process to execute the program.
#line 4580
# 
#line 4580
allow crond_t shell_exec_t:file { read { getattr execute } };
#line 4580

#line 4580
#
#line 4580
# Allow the process to reap the new domain.
#line 4580
#
#line 4580
allow sysadm_crond_t crond_t:process sigchld;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to inherit and use file 
#line 4580
# descriptions from the creating process and vice versa.
#line 4580
#
#line 4580
allow sysadm_crond_t crond_t:fd use;
#line 4580
allow crond_t sysadm_crond_t:fd use;
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to write back to the old domain via a pipe.
#line 4580
#
#line 4580
allow sysadm_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to read and execute the program.
#line 4580
#
#line 4580
allow sysadm_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4580

#line 4580
#
#line 4580
# Allow the new domain to be entered via the program.
#line 4580
#
#line 4580
allow sysadm_crond_t shell_exec_t:file entrypoint;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# The user role is authorized for this domain.
#line 4580
role sysadm_r types sysadm_crond_t;
#line 4580

#line 4580
# This domain is granted permissions common to most domains.
#line 4580

#line 4580
#
#line 4580
# Allow the domain to create and use UDP and TCP sockets.
#line 4580
# Other kinds of sockets must be separately authorized for use.
#line 4580
allow sysadm_crond_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_crond_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send UDP packets.
#line 4580
# Since the destination sockets type is unknown, the generic
#line 4580
# any_socket_t type is used as a placeholder.
#line 4580
#
#line 4580
allow sysadm_crond_t any_socket_t:udp_socket sendto;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send using any network interface.
#line 4580
# netif_type is a type attribute for all network interface types.
#line 4580
#
#line 4580
allow sysadm_crond_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4580

#line 4580
#
#line 4580
# Allow packets sent by the domain to be received on any network interface.
#line 4580
#
#line 4580
allow sysadm_crond_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to receive packets from any network interface.
#line 4580
# netmsg_type is a type attribute for all default message types.
#line 4580
#
#line 4580
allow sysadm_crond_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to initiate or accept TCP connections 
#line 4580
# on any network interface.
#line 4580
#
#line 4580
allow sysadm_crond_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4580

#line 4580
#
#line 4580
# Receive resets from the TCP reset socket.
#line 4580
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4580
#
#line 4580
allow sysadm_crond_t tcp_socket_t:tcp_socket recvfrom;
#line 4580

#line 4580
dontaudit sysadm_crond_t tcp_socket_t:tcp_socket connectto;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send to any node.
#line 4580
# node_type is a type attribute for all node types.
#line 4580
#
#line 4580
allow sysadm_crond_t node_type:node { tcp_send udp_send rawip_send };
#line 4580

#line 4580
#
#line 4580
# Allow packets sent by the domain to be received from any node.
#line 4580
#
#line 4580
allow sysadm_crond_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send NFS client requests via the socket
#line 4580
# created by mount.
#line 4580
#
#line 4580
allow sysadm_crond_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580

#line 4580
#
#line 4580
# Bind to the default port type.
#line 4580
# Other port types must be separately authorized.
#line 4580
#
#line 4580
allow sysadm_crond_t port_t:udp_socket name_bind;
#line 4580
allow sysadm_crond_t port_t:tcp_socket name_bind;
#line 4580

#line 4580
allow sysadm_crond_t resolv_conf_t:file { getattr read };
#line 4580

#line 4580
allow sysadm_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_crond_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t device_t:dir search;
#line 4580
allow sysadm_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t self:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crond_t self:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580
allow sysadm_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_crond_t etc_runtime_t:file { getattr read };
#line 4580
allow sysadm_crond_t self:process { fork { sigchld sigkill sigstop signull signal } };
#line 4580
allow sysadm_crond_t proc_t:dir { getattr search read };
#line 4580
allow sysadm_crond_t proc_t:file { getattr read };
#line 4580

#line 4580
allow sysadm_crond_t etc_t:lnk_file read;
#line 4580

#line 4580
allow sysadm_crond_t locale_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crond_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t sysctl_kernel_t:dir search;
#line 4580
allow sysadm_crond_t sysctl_kernel_t:file { getattr read };
#line 4580
allow sysadm_crond_t var_spool_t:dir search;
#line 4580
allow sysadm_crond_t fs_t:filesystem getattr;
#line 4580

#line 4580
allow sysadm_crond_t devtty_t:chr_file { read write };
#line 4580

#line 4580
# Use capabilities.
#line 4580
allow sysadm_crond_t sysadm_crond_t:capability dac_override;
#line 4580

#line 4580
# Inherit and use descriptors from initrc.
#line 4580
allow sysadm_crond_t initrc_t:fd use;
#line 4580

#line 4580
# 
#line 4580
# Since crontab files are not directly executed,
#line 4580
# crond must ensure that the crontab file has
#line 4580
# a type that is appropriate for the domain of
#line 4580
# the user cron job.  It performs an entrypoint
#line 4580
# permission check for this purpose.
#line 4580
#
#line 4580
allow sysadm_crond_t sysadm_cron_spool_t:file entrypoint;
#line 4580

#line 4580
# Access user files and dirs.
#line 4580
allow sysadm_crond_t home_root_t:dir search;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_crond_t sysadm_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_crond_t sysadm_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_crond_t sysadm_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_crond_t sysadm_home_dir_t:dir sysadm_home_t;
#line 4580
type_transition sysadm_crond_t sysadm_home_dir_t:{ file lnk_file sock_file fifo_file } sysadm_home_t;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580
allow sysadm_crond_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_crond_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580

#line 4580
type_transition sysadm_crond_t tmp_t:dir sysadm_tmp_t;
#line 4580
type_transition sysadm_crond_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Run helper programs.
#line 4580

#line 4580
allow sysadm_crond_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crond_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4580

#line 4580
allow sysadm_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_crond_t ld_so_t:file execute_no_trans;
#line 4580
allow sysadm_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4580
allow sysadm_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4580
allow sysadm_crond_t device_t:dir search;
#line 4580
allow sysadm_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580

#line 4580
# Run scripts in user home directory.
#line 4580

#line 4580
allow sysadm_crond_t sysadm_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
# ps does not need to access /boot when run from cron
#line 4580
dontaudit sysadm_crond_t boot_t:dir search;
#line 4580
# quiet other ps operations
#line 4580
dontaudit sysadm_crond_t domain:dir getattr;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Read the mouse.
#line 4580
allow sysadm_t mouse_device_t:chr_file { read getattr lock ioctl };
#line 4580
# Access other miscellaneous devices.
#line 4580
allow sysadm_t misc_device_t:{ file lnk_file sock_file fifo_file chr_file blk_file } { ioctl read getattr lock write append };
#line 4580

#line 4580
# Use the network.
#line 4580

#line 4580
#
#line 4580
# Allow the domain to create and use UDP and TCP sockets.
#line 4580
# Other kinds of sockets must be separately authorized for use.
#line 4580
allow sysadm_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580
allow sysadm_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send UDP packets.
#line 4580
# Since the destination sockets type is unknown, the generic
#line 4580
# any_socket_t type is used as a placeholder.
#line 4580
#
#line 4580
allow sysadm_t any_socket_t:udp_socket sendto;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send using any network interface.
#line 4580
# netif_type is a type attribute for all network interface types.
#line 4580
#
#line 4580
allow sysadm_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4580

#line 4580
#
#line 4580
# Allow packets sent by the domain to be received on any network interface.
#line 4580
#
#line 4580
allow sysadm_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to receive packets from any network interface.
#line 4580
# netmsg_type is a type attribute for all default message types.
#line 4580
#
#line 4580
allow sysadm_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to initiate or accept TCP connections 
#line 4580
# on any network interface.
#line 4580
#
#line 4580
allow sysadm_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4580

#line 4580
#
#line 4580
# Receive resets from the TCP reset socket.
#line 4580
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4580
#
#line 4580
allow sysadm_t tcp_socket_t:tcp_socket recvfrom;
#line 4580

#line 4580
dontaudit sysadm_t tcp_socket_t:tcp_socket connectto;
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send to any node.
#line 4580
# node_type is a type attribute for all node types.
#line 4580
#
#line 4580
allow sysadm_t node_type:node { tcp_send udp_send rawip_send };
#line 4580

#line 4580
#
#line 4580
# Allow packets sent by the domain to be received from any node.
#line 4580
#
#line 4580
allow sysadm_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4580

#line 4580
#
#line 4580
# Allow the domain to send NFS client requests via the socket
#line 4580
# created by mount.
#line 4580
#
#line 4580
allow sysadm_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4580

#line 4580
#
#line 4580
# Bind to the default port type.
#line 4580
# Other port types must be separately authorized.
#line 4580
#
#line 4580
allow sysadm_t port_t:udp_socket name_bind;
#line 4580
allow sysadm_t port_t:tcp_socket name_bind;
#line 4580

#line 4580
allow sysadm_t resolv_conf_t:file { getattr read };
#line 4580
# for perl
#line 4580
dontaudit sysadm_t resolv_conf_t:file ioctl;
#line 4580

#line 4580
#
#line 4580
# connect_secure and sendmsg_secure calls with a 
#line 4580
# peer or destination socket SID can be enforced
#line 4580
# when using the loopback interface.  Enforcement
#line 4580
# for real network interfaces will be possible when
#line 4580
# a packet labeling mechanism is integrated.
#line 4580
#
#line 4580
allow sysadm_t node_lo_t:node enforce_dest;
#line 4580

#line 4580
# Communicate within the domain.
#line 4580

#line 4580
allow sysadm_t sysadm_t:udp_socket { sendto };
#line 4580
allow sysadm_t sysadm_t:udp_socket { recvfrom };
#line 4580

#line 4580

#line 4580
allow sysadm_t sysadm_t:tcp_socket { connectto recvfrom };
#line 4580
allow sysadm_t sysadm_t:tcp_socket { acceptfrom recvfrom };
#line 4580
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4580

#line 4580

#line 4580
# Connect to inetd.
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
# Connect data port to ftpd.
#line 4580

#line 4580

#line 4580
# Connect to portmap.
#line 4580

#line 4580

#line 4580
# Inherit and use sockets from inetd
#line 4580

#line 4580

#line 4580
# Allow system log read
#line 4580
#allow sysadm_t kernel_t:system syslog_read;
#line 4580
# else do not log it
#line 4580
dontaudit sysadm_t kernel_t:system syslog_read;
#line 4580

#line 4580
# Very permissive allowing every domain to see every type.
#line 4580
allow sysadm_t kernel_t:system { ipc_info };
#line 4580

#line 4580
# When the user domain runs ps, there will be a number of access
#line 4580
# denials when ps tries to search /proc.  Do not audit these denials.
#line 4580
dontaudit sysadm_t domain:dir { read getattr lock search ioctl };
#line 4580
dontaudit sysadm_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580

#line 4580
# Some shells ask for w access to utmp, but will operate
#line 4580
# correctly without it.  Do not audit write denials to utmp.
#line 4580
dontaudit sysadm_t initrc_var_run_t:file { getattr read write };
#line 4580

#line 4580
# do not audit getattr on tmpfile, otherwise ls -l /tmp fills the logs
#line 4580
dontaudit sysadm_t tmpfile:{ dir file lnk_file sock_file fifo_file chr_file blk_file } getattr;
#line 4580

#line 4580
# do not audit getattr on disk devices, otherwise KDE fills the logs
#line 4580
dontaudit sysadm_t { removable_device_t fixed_disk_device_t }:blk_file getattr;
#line 4580

#line 4580

#line 4580
# Access the sound device.
#line 4580
allow sysadm_t sound_device_t:chr_file { getattr read write ioctl };
#line 4580

#line 4580

#line 4580

#line 4580
# Get attributes of file systems.
#line 4580
allow sysadm_t fs_type:filesystem getattr;
#line 4580

#line 4580
# Read and write /dev/tty and /dev/null.
#line 4580
allow sysadm_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_t zero_device_t:chr_file { { ioctl read getattr lock write append } execute };
#line 4580
allow sysadm_t random_device_t:chr_file { getattr read };
#line 4580

#line 4580
# Read the devpts root directory.
#line 4580
allow sysadm_t devpts_t:dir { read getattr lock search ioctl };
#line 4580

#line 4580

#line 4580
# Violates the goal of limiting write access to checkpolicy.
#line 4580
#rw_dir_create_file(sysadm_t, policy_config_t)
#line 4580

#line 4580

#line 4580
allow sysadm_crond_t var_log_t:file { read getattr lock ioctl };
#line 4580

#line 4580

#line 4580
# Allow system log read
#line 4580
allow sysadm_t kernel_t:system syslog_read;
#line 4580

#line 4580
# Use capabilities other than sys_module.
#line 4580
allow sysadm_t self:capability ~sys_module;
#line 4580

#line 4580
# Get security policy decisions.
#line 4580

#line 4580
allow sysadm_t security_t:dir { read search getattr };
#line 4580
allow sysadm_t security_t:file { getattr read write };
#line 4580
allow sysadm_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 4580

#line 4580

#line 4580
# Use system operations.
#line 4580
allow sysadm_t kernel_t:system *;
#line 4580

#line 4580
# Set password information for other users.
#line 4580
allow sysadm_t self:passwd { passwd chfn chsh };
#line 4580

#line 4580
# Change system parameters.
#line 4580

#line 4580
allow sysadm_t sysctl_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_fs_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_kernel_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_net_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_net_unix_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_net_unix_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_vm_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t sysctl_dev_t:file { setattr { ioctl read getattr lock write append } };
#line 4580
allow sysadm_t sysctl_modprobe_t:file { setattr { ioctl read getattr lock write append } };
#line 4580

#line 4580

#line 4580
# Create and use all files that have the sysadmfile attribute.
#line 4580
allow sysadm_t sysadmfile:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_t sysadmfile:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580
# Set a context other than the default one for newly created files.
#line 4580

#line 4580
allow sysadm_t self:process setfscreate;
#line 4580
allow sysadm_t proc_t:dir search;
#line 4580
allow sysadm_t proc_t:lnk_file read;
#line 4580
allow sysadm_t self:dir search;
#line 4580
allow sysadm_t self:file { read write };
#line 4580

#line 4580

#line 4580
# Access removable devices.
#line 4580
allow sysadm_t removable_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };
#line 4580

#line 4580
# Communicate with the init process.
#line 4580
allow sysadm_t initctl_t:fifo_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# Examine all processes.
#line 4580
allow sysadm_t domain:dir { read getattr lock search ioctl };
#line 4580
allow sysadm_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4580
allow sysadm_t domain:process getattr;
#line 4580

#line 4580
# Send signals to all processes.
#line 4580
allow sysadm_t { domain unlabeled_t }:process { sigchld sigkill sigstop signull signal };
#line 4580

#line 4580
# Access all user terminals.
#line 4580
allow sysadm_t tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_t ttyfile:chr_file { ioctl read getattr lock write append };
#line 4580
allow sysadm_t ptyfile:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# allow setting up tunnels
#line 4580
allow sysadm_t tun_tap_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# Run init (telinit).
#line 4580

#line 4580
allow sysadm_t init_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
# Run programs from user home directories.
#line 4580
# Not ideal, but typical if users want to login as both sysadm_t or user_t.
#line 4580

#line 4580
allow sysadm_t user_home_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580
# Run programs from /usr/src.
#line 4580

#line 4580
allow sysadm_t src_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4580

#line 4580

#line 4580
# Run admin programs that require different permissions in their own domain.
#line 4580
# These rules were moved into the appropriate program domain file.
#line 4580

#line 4580
# added by mayerf@tresys.com
#line 4580
# The following rules are temporary until such time that a complete
#line 4580
# policy management infrastructure is in place so that an administrator
#line 4580
# cannot directly manipulate policy files with arbitrary programs.
#line 4580
#
#line 4580
allow sysadm_t policy_src_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580
allow sysadm_t policy_src_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4580

#line 4580
# Remove the binary policy.
#line 4580
allow sysadm_t policy_config_t:file unlink;
#line 4580

#line 4580
# Relabel all files.
#line 4580
allow sysadm_t file_type:dir { getattr read search relabelfrom relabelto };
#line 4580
allow sysadm_t file_type:{ file lnk_file sock_file fifo_file chr_file blk_file } { getattr relabelfrom relabelto };
#line 4580

#line 4580
# Create files in /tmp/orbit-* and /tmp/.ICE-unix
#line 4580
# with our derived tmp type rather than user_tmp_t.
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# Allow the process to modify the directory.
#line 4580
#
#line 4580
allow sysadm_t user_tmpfile:dir { read getattr lock search ioctl add_name remove_name write };
#line 4580

#line 4580
#
#line 4580
# Allow the process to create the file.
#line 4580
#
#line 4580

#line 4580

#line 4580
allow sysadm_t sysadm_tmp_t:sock_file { create ioctl read getattr lock write setattr append link unlink rename };
#line 4580

#line 4580

#line 4580
type_transition sysadm_t user_tmpfile:sock_file sysadm_tmp_t;
#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580

#line 4580
#
#line 4580
# A user who is authorized for sysadm_t may nonetheless have
#line 4580
# a home directory labeled with user_home_t if the user is expected
#line 4580
# to login in either user_t or sysadm_t.  Hence, the derived domains
#line 4580
# for programs need to be able to access user_home_t.  
#line 4580
# 
#line 4580

#line 4580
# Allow our gph domain to write to .xsession-errors.
#line 4580

#line 4580

#line 4580
# Allow our crontab domain to unlink a user cron spool file.
#line 4580
allow sysadm_crontab_t user_cron_spool_t:file unlink;
#line 4580

#line 4580
#
#line 4580
# Allow sysadm to execute quota commands against filesystems and files.
#line 4580
#
#line 4580
allow sysadm_t fs_type:filesystem quotamod;
#line 4580

#line 4580
# Grant read and write access to /dev/console.
#line 4580
allow sysadm_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 4580

#line 4580
# for lsof
#line 4580
allow sysadm_t domain:{ tcp_socket udp_socket rawip_socket netlink_socket packet_socket unix_stream_socket unix_dgram_socket } getattr;
#line 4580

#line 4580

#line 4580


# Allow administrator domains to set the enforcing flag.

#line 4583
allow admin security_t:dir { read search getattr };
#line 4583
allow admin security_t:file { getattr read write };
#line 4583
allow admin security_t:security setenforce;
#line 4583
auditallow admin security_t:security setenforce;
#line 4583





#DESC Httpd admin -  Domain for httpd administrators
########################################
# httpd_admin domain macro and rules for 
# httpd_admin_t
########################################

# Uses some types defined in apache.te, so conditionally defined this macro.
# The intent is to remove this file in the future.
#
#line 4732

#DESC User - Domains for ordinary users.
#
#################################

#line 4736

#line 4736
# user_t/user_t is an unprivileged users domain.
#line 4736
type user_t, domain, userdomain, unpriv_userdomain, web_client_domain;
#line 4736

#line 4736
# user_r is authorized for user_t for the initial login domain.
#line 4736
role user_r types user_t;
#line 4736
allow system_r user_r;
#line 4736

#line 4736
# Grant permissions within the domain.
#line 4736

#line 4736
# Access other processes in the same domain.
#line 4736
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4736
# separately if desired.
#line 4736
allow user_t self:process ~{ptrace setexec setfscreate};
#line 4736

#line 4736
# Access /proc/PID files for processes in the same domain.
#line 4736
allow user_t self:dir { read getattr lock search ioctl };
#line 4736
allow user_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Access file descriptions, pipes, and sockets
#line 4736
# created by processes in the same domain.
#line 4736
allow user_t self:fd *;
#line 4736
allow user_t self:fifo_file { ioctl read getattr lock write append };
#line 4736
allow user_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736

#line 4736
# Allow the domain to communicate with other processes in the same domain.
#line 4736
allow user_t self:unix_dgram_socket sendto;
#line 4736
allow user_t self:unix_stream_socket connectto;
#line 4736

#line 4736
# Access System V IPC objects created by processes in the same domain.
#line 4736
allow user_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4736
allow user_t self:msg  { send receive };
#line 4736
allow user_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4736
allow user_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4736
;
#line 4736

#line 4736
# Grant read/search permissions to some of /proc.
#line 4736
allow user_t proc_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t proc_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
# Read /.
#line 4736
allow user_t root_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /home.
#line 4736
allow user_t home_root_t:dir { read getattr lock search ioctl };
#line 4736

#line 4736
# Read /usr.
#line 4736
allow user_t usr_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read bin and sbin directories.
#line 4736
allow user_t bin_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736
allow user_t sbin_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
# Read directories and files with the readable_t type.
#line 4736
# This type is a general type for "world"-readable files.
#line 4736
allow user_t readable_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Stat /...security and lost+found.
#line 4736
allow user_t file_labels_t:dir getattr;
#line 4736
allow user_t lost_found_t:dir getattr;
#line 4736

#line 4736

#line 4736

#line 4736
# Read the /tmp directory and any /tmp files with the base type.
#line 4736
# Temporary files created at runtime will typically use derived types.
#line 4736
allow user_t tmp_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /var, /var/spool, /var/run.
#line 4736
allow user_t var_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736
allow user_t var_spool_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736
allow user_t var_run_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
allow user_t sysctl_kernel_t:dir search;
#line 4736
allow user_t sysctl_kernel_t:file { getattr read };
#line 4736

#line 4736
# Read /etc.
#line 4736
allow user_t etc_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736
allow user_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
# for running depmod as part of the kernel packaging process
#line 4736
allow user_t modules_conf_t:file { getattr read };
#line 4736

#line 4736
# Read man directories and files.
#line 4736
allow user_t man_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /dev directories and any symbolic links.
#line 4736
allow user_t device_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t device_t:lnk_file { read getattr lock ioctl };
#line 4736

#line 4736
# Do not audit write denials to /etc/ld.so.cache.
#line 4736
dontaudit user_t ld_so_cache_t:file write;
#line 4736

#line 4736
# Execute from the system shared libraries.
#line 4736

#line 4736
allow user_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_t ld_so_t:file execute_no_trans;
#line 4736
allow user_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_t device_t:dir search;
#line 4736
allow user_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736
;
#line 4736

#line 4736
# user_t is also granted permissions specific to user domains.
#line 4736

#line 4736
# Use capabilities
#line 4736
allow user_t self:capability { setgid chown fowner };
#line 4736
dontaudit user_t self:capability { sys_nice fsetid };
#line 4736

#line 4736
# Type for home directory.
#line 4736

#line 4736
type user_home_dir_t, file_type, sysadmfile, home_dir_type, user_home_dir_type, home_type, user_home_type;
#line 4736
type user_home_t, file_type, sysadmfile, home_type, user_home_type;
#line 4736
# do not allow privhome access to sysadm_home_dir_t
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow privhome user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow privhome user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow privhome user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition privhome user_home_dir_t:dir user_home_t;
#line 4736
type_transition privhome user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
type user_tmp_t, file_type, sysadmfile, tmpfile , user_tmpfile;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_t tmp_t:dir user_tmp_t;
#line 4736
type_transition user_t tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# allow ptrace
#line 4736
#can_ptrace(user_t, user_t)
#line 4736

#line 4736
# Create, access, and remove files in home directory.
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_t user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_t user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_t user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_t user_home_dir_t:dir user_home_t;
#line 4736
type_transition user_t user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 4736

#line 4736

#line 4736

#line 4736
allow user_t user_home_t:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { relabelfrom relabelto };
#line 4736

#line 4736
# Bind to a Unix domain socket in /tmp.
#line 4736
allow user_t user_tmp_t:unix_stream_socket name_bind;
#line 4736

#line 4736
# Type for tty devices.
#line 4736
type user_tty_device_t, file_type, sysadmfile, ttyfile;
#line 4736
# Access ttys.
#line 4736
allow user_t privfd:fd use;
#line 4736
allow user_t user_tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4736
# Use the type when relabeling terminal devices.
#line 4736
type_change user_t tty_device_t:chr_file user_tty_device_t;
#line 4736

#line 4736

#line 4736
# read localization information
#line 4736
allow user_t locale_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4736

#line 4736
# for running TeX programs
#line 4736

#line 4736
allow user_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
allow user_t tetex_data_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
# Type and access for pty devices.
#line 4736

#line 4736

#line 4736

#line 4736
# Access the pty master multiplexer.
#line 4736
allow user_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736
allow user_t devpts_t:filesystem getattr;
#line 4736

#line 4736
# allow searching /dev/pts
#line 4736
allow user_t devpts_t:dir { getattr read search };
#line 4736

#line 4736
type user_devpts_t, file_type, sysadmfile, ptyfile , userpty_type;
#line 4736

#line 4736
# Allow the pty to be associated with the file system.
#line 4736
allow user_devpts_t devpts_t:filesystem associate;
#line 4736

#line 4736
# Label pty files with a derived type.
#line 4736
type_transition user_t devpts_t:chr_file user_devpts_t;
#line 4736

#line 4736
# Read and write my pty files.
#line 4736
allow user_t user_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4736

#line 4736

#line 4736

#line 4736
# Use the type when relabeling pty devices.
#line 4736

#line 4736

#line 4736
type_change user_t sshd_devpts_t:chr_file user_devpts_t;
#line 4736

#line 4736
# Connect to sshd.
#line 4736

#line 4736
allow user_t sshd_t:tcp_socket { connectto recvfrom };
#line 4736
allow sshd_t user_t:tcp_socket { acceptfrom recvfrom };
#line 4736
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736

#line 4736

#line 4736
# Connect to ssh proxy.
#line 4736

#line 4736
allow user_t user_ssh_t:tcp_socket { connectto recvfrom };
#line 4736
allow user_ssh_t user_t:tcp_socket { acceptfrom recvfrom };
#line 4736
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736

#line 4736

#line 4736
allow user_t sshd_t:fd use;
#line 4736
allow user_t sshd_t:tcp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736
# Use a Unix stream socket inherited from sshd.
#line 4736
allow user_t sshd_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736

#line 4736
allow user_t boot_t:dir { getattr search };
#line 4736
dontaudit user_t boot_t:dir read;
#line 4736
dontaudit user_t boot_t:lnk_file getattr;
#line 4736
dontaudit user_t boot_t:file { getattr read };
#line 4736
allow user_t system_map_t:file { getattr read };
#line 4736

#line 4736

#line 4736
type user_tmpfs_t, file_type, sysadmfile, tmpfsfile;
#line 4736
# Use this type when creating tmpfs/shm objects.
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_t tmpfs_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_t user_tmpfs_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_t user_tmpfs_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_t tmpfs_t:dir user_tmpfs_t;
#line 4736
type_transition user_t tmpfs_t:{ file lnk_file sock_file fifo_file } user_tmpfs_t;
#line 4736

#line 4736

#line 4736

#line 4736
allow user_tmpfs_t tmpfs_t:filesystem associate;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Read and write /var/catman.
#line 4736
allow user_t catman_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736
allow user_t catman_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736

#line 4736
# Modify mail spool file.
#line 4736
allow user_t mail_spool_t:dir { read getattr lock search ioctl };
#line 4736
allow user_t mail_spool_t:file { ioctl read getattr lock write append };
#line 4736
allow user_t mail_spool_t:lnk_file read;
#line 4736

#line 4736
#
#line 4736
# Allow the query of filesystem quotas
#line 4736
#
#line 4736
allow user_t fs_type:filesystem quotaget;
#line 4736

#line 4736
# Run helper programs.
#line 4736

#line 4736
allow user_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4736

#line 4736
allow user_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_t ld_so_t:file execute_no_trans;
#line 4736
allow user_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_t device_t:dir search;
#line 4736
allow user_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736
allow user_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
# Run programs developed by other users in the same domain.
#line 4736

#line 4736
allow user_t user_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_t user_tmp_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
# Run user programs that require different permissions in their own domain.
#line 4736
# These rules were moved into the individual program domains.
#line 4736

#line 4736
# Instantiate derived domains for a number of programs.
#line 4736
# These derived domains encode both information about the calling
#line 4736
# user domain and the program, and allow us to maintain separation
#line 4736
# between different instances of the program being run by different
#line 4736
# user domains.
#line 4736

#line 4736

#line 4736

#line 4736
# Derived domain based on the calling user domain and the program.
#line 4736
type user_su_t, domain, privlog, auth;
#line 4736

#line 4736
# Transition from the user domain to this domain.
#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow user_t user_su_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit user_t user_su_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow user_t su_exec_t:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_su_t user_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_su_t user_t:fd use;
#line 4736
allow user_t user_su_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_su_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_su_t su_exec_t:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_su_t su_exec_t:file entrypoint;
#line 4736

#line 4736
type_transition user_t su_exec_t:process user_su_t;
#line 4736

#line 4736

#line 4736

#line 4736
allow user_su_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_su_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_su_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_su_t ld_so_t:file execute_no_trans;
#line 4736
allow user_su_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_su_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_su_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_su_t device_t:dir search;
#line 4736
allow user_su_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
allow user_su_t etc_t:file { getattr read };
#line 4736

#line 4736
allow user_su_t etc_t:lnk_file read;
#line 4736

#line 4736
allow user_su_t locale_t:dir { read getattr lock search ioctl };
#line 4736
allow user_su_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
allow user_su_t self:unix_dgram_socket { connect create write };
#line 4736
allow user_su_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736
allow user_su_t proc_t:dir search;
#line 4736
allow user_su_t proc_t:lnk_file read;
#line 4736

#line 4736
allow user_su_t self:dir { read getattr lock search ioctl };
#line 4736
allow user_su_t self:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
allow user_su_t self:process setsched;
#line 4736
allow user_su_t device_t:dir search;
#line 4736
allow user_su_t self:process { fork sigchld };
#line 4736

#line 4736
# Use capabilities.
#line 4736
allow user_su_t self:capability { setuid setgid net_bind_service chown dac_override sys_nice sys_resource };
#line 4736

#line 4736
# Revert to the user domain when a shell is executed.
#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow user_su_t user_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit user_su_t user_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow user_su_t shell_exec_t:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_t user_su_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_t user_su_t:fd use;
#line 4736
allow user_su_t user_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_t user_su_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_t shell_exec_t:file entrypoint;
#line 4736

#line 4736
type_transition user_su_t shell_exec_t:process user_t;
#line 4736

#line 4736
allow user_su_t bin_t:dir search;
#line 4736
allow user_su_t bin_t:lnk_file read;
#line 4736

#line 4736
allow user_su_t privfd:fd use;
#line 4736

#line 4736
# Write to utmp.
#line 4736
allow user_su_t { var_t var_run_t }:dir search;
#line 4736
allow user_su_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736

#line 4736
# Run chkpwd.
#line 4736

#line 4736
allow user_su_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736

#line 4736
# Inherit and use descriptors from gnome-pty-helper.
#line 4736

#line 4736

#line 4736
# The user role is authorized for this domain.
#line 4736
role user_r types user_su_t;
#line 4736

#line 4736
# Write to the user domain tty.
#line 4736
allow user_su_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_su_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
allow user_su_t { home_root_t user_home_dir_t }:dir search;
#line 4736

#line 4736
# Modify .Xauthority file (via xauth program).
#line 4736

#line 4736

#line 4736
# Access sshd cookie files.
#line 4736
allow user_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736
allow user_su_t sshd_tmp_t:file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_su_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_su_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_su_t sshd_tmp_t:dir user_tmp_t;
#line 4736
type_transition user_su_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# stop su complaining if you run it from a directory with restrictive perms
#line 4736
dontaudit user_su_t file_type:dir search;
#line 4736

#line 4736

#line 4736
# Derived domain based on the calling user domain and the program.
#line 4736
type user_chkpwd_t, domain, privlog, auth;
#line 4736

#line 4736
# Transition from the user domain to this domain.
#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow user_t user_chkpwd_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit user_t user_chkpwd_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow user_t chkpwd_exec_t:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_chkpwd_t user_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_chkpwd_t user_t:fd use;
#line 4736
allow user_t user_chkpwd_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_chkpwd_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_chkpwd_t chkpwd_exec_t:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_chkpwd_t chkpwd_exec_t:file entrypoint;
#line 4736

#line 4736
type_transition user_t chkpwd_exec_t:process user_chkpwd_t;
#line 4736

#line 4736

#line 4736
# The user role is authorized for this domain.
#line 4736
role user_r types user_chkpwd_t;
#line 4736

#line 4736

#line 4736
allow user_chkpwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_chkpwd_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_chkpwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_chkpwd_t ld_so_t:file execute_no_trans;
#line 4736
allow user_chkpwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_chkpwd_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_chkpwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_chkpwd_t device_t:dir search;
#line 4736
allow user_chkpwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
allow user_chkpwd_t etc_t:file { getattr read };
#line 4736
allow user_chkpwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_chkpwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736

#line 4736
allow user_chkpwd_t etc_t:lnk_file read;
#line 4736

#line 4736
allow user_chkpwd_t locale_t:dir { read getattr lock search ioctl };
#line 4736
allow user_chkpwd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736

#line 4736
# Use capabilities.
#line 4736
allow user_chkpwd_t self:capability setuid;
#line 4736

#line 4736
# Inherit and use descriptors from gnome-pty-helper.
#line 4736

#line 4736

#line 4736
# Inherit and use descriptors from newrole.
#line 4736
allow user_chkpwd_t newrole_t:fd use;
#line 4736

#line 4736
# Write to the user domain tty.
#line 4736
allow user_chkpwd_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_chkpwd_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Derived domain based on the calling user domain and the program.
#line 4736
type user_crontab_t, domain, privlog;
#line 4736

#line 4736
# Transition from the user domain to the derived domain.
#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow user_t user_crontab_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit user_t user_crontab_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow user_t crontab_exec_t:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_crontab_t user_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_crontab_t user_t:fd use;
#line 4736
allow user_t user_crontab_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_crontab_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_crontab_t crontab_exec_t:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_crontab_t crontab_exec_t:file entrypoint;
#line 4736

#line 4736
type_transition user_t crontab_exec_t:process user_crontab_t;
#line 4736

#line 4736

#line 4736
# The user role is authorized for this domain.
#line 4736
role user_r types user_crontab_t;
#line 4736

#line 4736

#line 4736
allow user_crontab_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_crontab_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crontab_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_crontab_t ld_so_t:file execute_no_trans;
#line 4736
allow user_crontab_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crontab_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_crontab_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_crontab_t device_t:dir search;
#line 4736
allow user_crontab_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
allow user_crontab_t etc_t:file { getattr read };
#line 4736
allow user_crontab_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_crontab_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736

#line 4736
allow user_crontab_t etc_t:lnk_file read;
#line 4736

#line 4736
allow user_crontab_t locale_t:dir { read getattr lock search ioctl };
#line 4736
allow user_crontab_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736

#line 4736
# Use capabilities
#line 4736
allow user_crontab_t user_crontab_t:capability { setuid setgid chown };
#line 4736

#line 4736
# Type for temporary files.
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_crontab_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_crontab_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_crontab_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_crontab_t tmp_t:dir user_tmp_t;
#line 4736
type_transition user_crontab_t tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Type of user crontabs once moved to cron spool.
#line 4736
type user_cron_spool_t, file_type, sysadmfile;
#line 4736
# Use the type when creating files in /var/spool/cron.
#line 4736
allow sysadm_crontab_t user_cron_spool_t:file { getattr read };
#line 4736
allow user_crontab_t { var_t var_spool_t }:dir search;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_crontab_t cron_spool_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_crontab_t user_cron_spool_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_crontab_t user_cron_spool_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_crontab_t cron_spool_t:dir user_cron_spool_t;
#line 4736
type_transition user_crontab_t cron_spool_t:{ file lnk_file sock_file fifo_file } user_cron_spool_t;
#line 4736

#line 4736

#line 4736

#line 4736
allow user_crontab_t self:process { fork { sigchld sigkill sigstop signull signal } };
#line 4736

#line 4736
# crontab signals crond by updating the mtime on the spooldir
#line 4736
allow user_crontab_t cron_spool_t:dir setattr;
#line 4736
# Allow crond to read those crontabs in cron spool.
#line 4736
allow crond_t user_cron_spool_t:file { read getattr lock ioctl };
#line 4736

#line 4736
# Run helper programs as user_t
#line 4736
allow user_crontab_t { bin_t sbin_t }:dir search;
#line 4736
allow user_crontab_t bin_t:lnk_file read;
#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow user_crontab_t user_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit user_crontab_t user_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow user_crontab_t { bin_t sbin_t shell_exec_t }:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_t user_crontab_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_t user_crontab_t:fd use;
#line 4736
allow user_crontab_t user_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_t user_crontab_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_t { bin_t sbin_t shell_exec_t }:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_t { bin_t sbin_t shell_exec_t }:file entrypoint;
#line 4736

#line 4736
type_transition user_crontab_t { bin_t sbin_t shell_exec_t }:process user_t;
#line 4736

#line 4736

#line 4736
# Read user crontabs 
#line 4736
allow user_crontab_t { user_home_t user_home_dir_t }:dir { read getattr lock search ioctl };  
#line 4736
allow user_crontab_t user_home_t:file { read getattr lock ioctl };  
#line 4736
dontaudit user_crontab_t user_home_dir_t:dir write;
#line 4736

#line 4736
# Access the cron log file.
#line 4736
allow user_crontab_t cron_log_t:file { read getattr lock ioctl };
#line 4736
allow user_crontab_t cron_log_t:file { append };
#line 4736

#line 4736
# Access terminals.
#line 4736
allow user_crontab_t device_t:dir search;
#line 4736
allow user_crontab_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_crontab_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
# Inherit and use descriptors from gnome-pty-helper.
#line 4736

#line 4736
allow user_crontab_t privfd:fd use;
#line 4736

#line 4736

#line 4736
# Derived domain based on the calling user domain and the program.
#line 4736
type user_ssh_t, domain, privlog;
#line 4736

#line 4736
# Transition from the user domain to the derived domain.
#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow user_t user_ssh_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit user_t user_ssh_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow user_t ssh_exec_t:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_ssh_t user_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_ssh_t user_t:fd use;
#line 4736
allow user_t user_ssh_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_ssh_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_ssh_t ssh_exec_t:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_ssh_t ssh_exec_t:file entrypoint;
#line 4736

#line 4736
type_transition user_t ssh_exec_t:process user_ssh_t;
#line 4736

#line 4736

#line 4736
# The user role is authorized for this domain.
#line 4736
role user_r types user_ssh_t;
#line 4736

#line 4736
# Grant permissions within the domain.
#line 4736

#line 4736
# Access other processes in the same domain.
#line 4736
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4736
# separately if desired.
#line 4736
allow user_ssh_t self:process ~{ptrace setexec setfscreate};
#line 4736

#line 4736
# Access /proc/PID files for processes in the same domain.
#line 4736
allow user_ssh_t self:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Access file descriptions, pipes, and sockets
#line 4736
# created by processes in the same domain.
#line 4736
allow user_ssh_t self:fd *;
#line 4736
allow user_ssh_t self:fifo_file { ioctl read getattr lock write append };
#line 4736
allow user_ssh_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_ssh_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736

#line 4736
# Allow the domain to communicate with other processes in the same domain.
#line 4736
allow user_ssh_t self:unix_dgram_socket sendto;
#line 4736
allow user_ssh_t self:unix_stream_socket connectto;
#line 4736

#line 4736
# Access System V IPC objects created by processes in the same domain.
#line 4736
allow user_ssh_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4736
allow user_ssh_t self:msg  { send receive };
#line 4736
allow user_ssh_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4736
allow user_ssh_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4736

#line 4736

#line 4736
# Use descriptors created by sshd
#line 4736
allow user_ssh_t privfd:fd use;
#line 4736

#line 4736

#line 4736
allow user_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_ssh_t ld_so_t:file execute_no_trans;
#line 4736
allow user_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_ssh_t device_t:dir search;
#line 4736
allow user_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736
allow user_ssh_t etc_t:lnk_file read;
#line 4736

#line 4736
allow user_ssh_t locale_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736

#line 4736
# Get attributes of file systems.
#line 4736
allow user_ssh_t fs_type:filesystem getattr;
#line 4736

#line 4736

#line 4736
# Read /.
#line 4736
allow user_ssh_t root_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /home.
#line 4736
allow user_ssh_t home_root_t:dir { read getattr lock search ioctl };
#line 4736

#line 4736
# Read /usr.
#line 4736
allow user_ssh_t usr_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read bin and sbin directories.
#line 4736
allow user_ssh_t bin_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736
allow user_ssh_t sbin_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
# Read the devpts root directory.
#line 4736
allow user_ssh_t devpts_t:dir { read getattr lock search ioctl };
#line 4736

#line 4736
# Read /var.
#line 4736
allow user_ssh_t var_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /var/run, /var/log.
#line 4736
allow user_ssh_t var_run_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736
allow user_ssh_t var_log_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /etc.
#line 4736
allow user_ssh_t etc_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736
allow user_ssh_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736
allow user_ssh_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read the linker, shared library, and executable types.
#line 4736
allow user_ssh_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736
allow user_ssh_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736
allow user_ssh_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Read /dev directories and any symbolic links.
#line 4736
allow user_ssh_t device_t:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t device_t:lnk_file { read getattr lock ioctl };
#line 4736

#line 4736
# Read /dev/random.
#line 4736
allow user_ssh_t random_device_t:chr_file { read getattr lock ioctl };
#line 4736

#line 4736
# Read and write /dev/tty and /dev/null.
#line 4736
allow user_ssh_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_ssh_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
# Grant permissions needed to create TCP and UDP sockets and
#line 4736
# to access the network.
#line 4736

#line 4736
#
#line 4736
# Allow the domain to create and use UDP and TCP sockets.
#line 4736
# Other kinds of sockets must be separately authorized for use.
#line 4736
allow user_ssh_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_ssh_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send UDP packets.
#line 4736
# Since the destination sockets type is unknown, the generic
#line 4736
# any_socket_t type is used as a placeholder.
#line 4736
#
#line 4736
allow user_ssh_t any_socket_t:udp_socket sendto;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send using any network interface.
#line 4736
# netif_type is a type attribute for all network interface types.
#line 4736
#
#line 4736
allow user_ssh_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4736

#line 4736
#
#line 4736
# Allow packets sent by the domain to be received on any network interface.
#line 4736
#
#line 4736
allow user_ssh_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to receive packets from any network interface.
#line 4736
# netmsg_type is a type attribute for all default message types.
#line 4736
#
#line 4736
allow user_ssh_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to initiate or accept TCP connections 
#line 4736
# on any network interface.
#line 4736
#
#line 4736
allow user_ssh_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4736

#line 4736
#
#line 4736
# Receive resets from the TCP reset socket.
#line 4736
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4736
#
#line 4736
allow user_ssh_t tcp_socket_t:tcp_socket recvfrom;
#line 4736

#line 4736
dontaudit user_ssh_t tcp_socket_t:tcp_socket connectto;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send to any node.
#line 4736
# node_type is a type attribute for all node types.
#line 4736
#
#line 4736
allow user_ssh_t node_type:node { tcp_send udp_send rawip_send };
#line 4736

#line 4736
#
#line 4736
# Allow packets sent by the domain to be received from any node.
#line 4736
#
#line 4736
allow user_ssh_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send NFS client requests via the socket
#line 4736
# created by mount.
#line 4736
#
#line 4736
allow user_ssh_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736

#line 4736
#
#line 4736
# Bind to the default port type.
#line 4736
# Other port types must be separately authorized.
#line 4736
#
#line 4736
allow user_ssh_t port_t:udp_socket name_bind;
#line 4736
allow user_ssh_t port_t:tcp_socket name_bind;
#line 4736

#line 4736

#line 4736
# for sshing to a ssh tunnel
#line 4736

#line 4736
allow user_ssh_t user_ssh_t:tcp_socket { connectto recvfrom };
#line 4736
allow user_ssh_t user_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4736
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736

#line 4736

#line 4736
# Use capabilities.
#line 4736
allow user_ssh_t self:capability { setuid setgid dac_override dac_read_search };
#line 4736

#line 4736
# Run helpers.
#line 4736

#line 4736
allow user_ssh_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4736

#line 4736
allow user_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_ssh_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_ssh_t ld_so_t:file execute_no_trans;
#line 4736
allow user_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_ssh_t device_t:dir search;
#line 4736
allow user_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736
allow user_ssh_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_ssh_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_ssh_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_ssh_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_ssh_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736

#line 4736
# Read the ssh key file.
#line 4736
allow user_ssh_t sshd_key_t:file { read getattr lock ioctl };
#line 4736

#line 4736
# Access the ssh temporary files.
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_ssh_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_ssh_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_ssh_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_ssh_t tmp_t:dir sshd_tmp_t;
#line 4736
type_transition user_ssh_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 4736

#line 4736

#line 4736

#line 4736
allow user_ssh_t user_tmp_t:dir { read getattr lock search ioctl };
#line 4736

#line 4736
# for rsync
#line 4736
allow user_ssh_t user_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736

#line 4736
# Access the users .ssh directory.
#line 4736
type user_home_ssh_t, file_type, sysadmfile;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow { sysadm_ssh_t user_ssh_t } user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow { sysadm_ssh_t user_ssh_t } user_home_ssh_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow { sysadm_ssh_t user_ssh_t } user_home_ssh_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition { sysadm_ssh_t user_ssh_t } user_home_dir_t:dir user_home_ssh_t;
#line 4736
type_transition { sysadm_ssh_t user_ssh_t } user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_ssh_t;
#line 4736

#line 4736

#line 4736

#line 4736
allow { sysadm_ssh_t user_ssh_t } user_home_ssh_t:lnk_file { getattr read };
#line 4736
dontaudit user_ssh_t user_home_t:dir search;
#line 4736

#line 4736
allow sshd_t user_home_ssh_t:dir { read getattr lock search ioctl };
#line 4736
allow sshd_t user_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
allow user_t user_home_ssh_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736
allow user_t user_home_ssh_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736

#line 4736

#line 4736
# for /bin/sh used to execute xauth
#line 4736
dontaudit user_ssh_t proc_t:dir search;
#line 4736

#line 4736
# Inherit and use descriptors from gnome-pty-helper.
#line 4736

#line 4736

#line 4736
# Connect to sshd.
#line 4736

#line 4736

#line 4736
allow user_ssh_t sshd_t:tcp_socket { connectto recvfrom };
#line 4736
allow sshd_t user_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4736
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736

#line 4736

#line 4736

#line 4736
# Write to the user domain tty.
#line 4736
allow user_ssh_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_ssh_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736
# Allow the user shell to signal the ssh program.
#line 4736
allow user_t user_ssh_t:process signal;
#line 4736
# allow ps to show ssh
#line 4736
allow user_t user_ssh_t:dir { search getattr read };
#line 4736
allow user_t user_ssh_t:{ file lnk_file } { read getattr };
#line 4736

#line 4736
# Allow the ssh program to communicate with ssh-agent.
#line 4736
allow user_ssh_t user_tmp_t:sock_file write;
#line 4736
allow user_ssh_t user_t:unix_stream_socket connectto;
#line 4736
allow user_ssh_t sshd_t:unix_stream_socket connectto;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Instantiate a derived domain for user cron jobs.
#line 4736

#line 4736
# Derived domain for user cron jobs, user user_crond_domain if not system
#line 4736

#line 4736
type user_crond_t, domain, user_crond_domain;
#line 4736

#line 4736

#line 4736
# Permit a transition from the crond_t domain to this domain.
#line 4736
# The transition is requested explicitly by the modified crond 
#line 4736
# via execve_secure.  There is no way to set up an automatic
#line 4736
# transition, since crontabs are configuration files, not executables.
#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to transition to the new domain.
#line 4736
#
#line 4736
allow crond_t user_crond_t:process transition;
#line 4736

#line 4736
#
#line 4736
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4736
#
#line 4736
dontaudit crond_t user_crond_t:process noatsecure;
#line 4736

#line 4736
#
#line 4736
# Allow the process to execute the program.
#line 4736
# 
#line 4736
allow crond_t shell_exec_t:file { read { getattr execute } };
#line 4736

#line 4736
#
#line 4736
# Allow the process to reap the new domain.
#line 4736
#
#line 4736
allow user_crond_t crond_t:process sigchld;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to inherit and use file 
#line 4736
# descriptions from the creating process and vice versa.
#line 4736
#
#line 4736
allow user_crond_t crond_t:fd use;
#line 4736
allow crond_t user_crond_t:fd use;
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to write back to the old domain via a pipe.
#line 4736
#
#line 4736
allow user_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to read and execute the program.
#line 4736
#
#line 4736
allow user_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4736

#line 4736
#
#line 4736
# Allow the new domain to be entered via the program.
#line 4736
#
#line 4736
allow user_crond_t shell_exec_t:file entrypoint;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# The user role is authorized for this domain.
#line 4736
role user_r types user_crond_t;
#line 4736

#line 4736
# This domain is granted permissions common to most domains.
#line 4736

#line 4736
#
#line 4736
# Allow the domain to create and use UDP and TCP sockets.
#line 4736
# Other kinds of sockets must be separately authorized for use.
#line 4736
allow user_crond_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_crond_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send UDP packets.
#line 4736
# Since the destination sockets type is unknown, the generic
#line 4736
# any_socket_t type is used as a placeholder.
#line 4736
#
#line 4736
allow user_crond_t any_socket_t:udp_socket sendto;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send using any network interface.
#line 4736
# netif_type is a type attribute for all network interface types.
#line 4736
#
#line 4736
allow user_crond_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4736

#line 4736
#
#line 4736
# Allow packets sent by the domain to be received on any network interface.
#line 4736
#
#line 4736
allow user_crond_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to receive packets from any network interface.
#line 4736
# netmsg_type is a type attribute for all default message types.
#line 4736
#
#line 4736
allow user_crond_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to initiate or accept TCP connections 
#line 4736
# on any network interface.
#line 4736
#
#line 4736
allow user_crond_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4736

#line 4736
#
#line 4736
# Receive resets from the TCP reset socket.
#line 4736
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4736
#
#line 4736
allow user_crond_t tcp_socket_t:tcp_socket recvfrom;
#line 4736

#line 4736
dontaudit user_crond_t tcp_socket_t:tcp_socket connectto;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send to any node.
#line 4736
# node_type is a type attribute for all node types.
#line 4736
#
#line 4736
allow user_crond_t node_type:node { tcp_send udp_send rawip_send };
#line 4736

#line 4736
#
#line 4736
# Allow packets sent by the domain to be received from any node.
#line 4736
#
#line 4736
allow user_crond_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send NFS client requests via the socket
#line 4736
# created by mount.
#line 4736
#
#line 4736
allow user_crond_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736

#line 4736
#
#line 4736
# Bind to the default port type.
#line 4736
# Other port types must be separately authorized.
#line 4736
#
#line 4736
allow user_crond_t port_t:udp_socket name_bind;
#line 4736
allow user_crond_t port_t:tcp_socket name_bind;
#line 4736

#line 4736
allow user_crond_t resolv_conf_t:file { getattr read };
#line 4736

#line 4736
allow user_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_crond_t ld_so_t:file execute_no_trans;
#line 4736
allow user_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_crond_t device_t:dir search;
#line 4736
allow user_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736
allow user_crond_t self:dir { read getattr lock search ioctl };
#line 4736
allow user_crond_t self:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736
allow user_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4736
allow user_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_crond_t etc_runtime_t:file { getattr read };
#line 4736
allow user_crond_t self:process { fork { sigchld sigkill sigstop signull signal } };
#line 4736
allow user_crond_t proc_t:dir { getattr search read };
#line 4736
allow user_crond_t proc_t:file { getattr read };
#line 4736

#line 4736
allow user_crond_t etc_t:lnk_file read;
#line 4736

#line 4736
allow user_crond_t locale_t:dir { read getattr lock search ioctl };
#line 4736
allow user_crond_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4736

#line 4736

#line 4736
allow user_crond_t sysctl_kernel_t:dir search;
#line 4736
allow user_crond_t sysctl_kernel_t:file { getattr read };
#line 4736
allow user_crond_t var_spool_t:dir search;
#line 4736
allow user_crond_t fs_t:filesystem getattr;
#line 4736

#line 4736
allow user_crond_t devtty_t:chr_file { read write };
#line 4736

#line 4736
# Use capabilities.
#line 4736
allow user_crond_t user_crond_t:capability dac_override;
#line 4736

#line 4736
# Inherit and use descriptors from initrc.
#line 4736
allow user_crond_t initrc_t:fd use;
#line 4736

#line 4736
# 
#line 4736
# Since crontab files are not directly executed,
#line 4736
# crond must ensure that the crontab file has
#line 4736
# a type that is appropriate for the domain of
#line 4736
# the user cron job.  It performs an entrypoint
#line 4736
# permission check for this purpose.
#line 4736
#
#line 4736
allow user_crond_t user_cron_spool_t:file entrypoint;
#line 4736

#line 4736
# Access user files and dirs.
#line 4736
allow user_crond_t home_root_t:dir search;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_crond_t user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_crond_t user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_crond_t user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_crond_t user_home_dir_t:dir user_home_t;
#line 4736
type_transition user_crond_t user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
#
#line 4736
# Allow the process to modify the directory.
#line 4736
#
#line 4736
allow user_crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4736

#line 4736
#
#line 4736
# Allow the process to create the file.
#line 4736
#
#line 4736

#line 4736
allow user_crond_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4736
allow user_crond_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4736

#line 4736

#line 4736
type_transition user_crond_t tmp_t:dir user_tmp_t;
#line 4736
type_transition user_crond_t tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Run helper programs.
#line 4736

#line 4736
allow user_crond_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_crond_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4736

#line 4736
allow user_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4736
allow user_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4736
allow user_crond_t ld_so_t:file execute_no_trans;
#line 4736
allow user_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4736
allow user_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4736
allow user_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4736
allow user_crond_t device_t:dir search;
#line 4736
allow user_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736

#line 4736

#line 4736
allow user_crond_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_crond_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_crond_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_crond_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
allow user_crond_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736

#line 4736
# Run scripts in user home directory.
#line 4736

#line 4736
allow user_crond_t user_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4736

#line 4736

#line 4736
# ps does not need to access /boot when run from cron
#line 4736
dontaudit user_crond_t boot_t:dir search;
#line 4736
# quiet other ps operations
#line 4736
dontaudit user_crond_t domain:dir getattr;
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Read the mouse.
#line 4736
allow user_t mouse_device_t:chr_file { read getattr lock ioctl };
#line 4736
# Access other miscellaneous devices.
#line 4736
allow user_t misc_device_t:{ file lnk_file sock_file fifo_file chr_file blk_file } { ioctl read getattr lock write append };
#line 4736

#line 4736
# Use the network.
#line 4736

#line 4736
#
#line 4736
# Allow the domain to create and use UDP and TCP sockets.
#line 4736
# Other kinds of sockets must be separately authorized for use.
#line 4736
allow user_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736
allow user_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send UDP packets.
#line 4736
# Since the destination sockets type is unknown, the generic
#line 4736
# any_socket_t type is used as a placeholder.
#line 4736
#
#line 4736
allow user_t any_socket_t:udp_socket sendto;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send using any network interface.
#line 4736
# netif_type is a type attribute for all network interface types.
#line 4736
#
#line 4736
allow user_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4736

#line 4736
#
#line 4736
# Allow packets sent by the domain to be received on any network interface.
#line 4736
#
#line 4736
allow user_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to receive packets from any network interface.
#line 4736
# netmsg_type is a type attribute for all default message types.
#line 4736
#
#line 4736
allow user_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to initiate or accept TCP connections 
#line 4736
# on any network interface.
#line 4736
#
#line 4736
allow user_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4736

#line 4736
#
#line 4736
# Receive resets from the TCP reset socket.
#line 4736
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4736
#
#line 4736
allow user_t tcp_socket_t:tcp_socket recvfrom;
#line 4736

#line 4736
dontaudit user_t tcp_socket_t:tcp_socket connectto;
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send to any node.
#line 4736
# node_type is a type attribute for all node types.
#line 4736
#
#line 4736
allow user_t node_type:node { tcp_send udp_send rawip_send };
#line 4736

#line 4736
#
#line 4736
# Allow packets sent by the domain to be received from any node.
#line 4736
#
#line 4736
allow user_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4736

#line 4736
#
#line 4736
# Allow the domain to send NFS client requests via the socket
#line 4736
# created by mount.
#line 4736
#
#line 4736
allow user_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4736

#line 4736
#
#line 4736
# Bind to the default port type.
#line 4736
# Other port types must be separately authorized.
#line 4736
#
#line 4736
allow user_t port_t:udp_socket name_bind;
#line 4736
allow user_t port_t:tcp_socket name_bind;
#line 4736

#line 4736
allow user_t resolv_conf_t:file { getattr read };
#line 4736
# for perl
#line 4736
dontaudit user_t resolv_conf_t:file ioctl;
#line 4736

#line 4736
#
#line 4736
# connect_secure and sendmsg_secure calls with a 
#line 4736
# peer or destination socket SID can be enforced
#line 4736
# when using the loopback interface.  Enforcement
#line 4736
# for real network interfaces will be possible when
#line 4736
# a packet labeling mechanism is integrated.
#line 4736
#
#line 4736
allow user_t node_lo_t:node enforce_dest;
#line 4736

#line 4736
# Communicate within the domain.
#line 4736

#line 4736
allow user_t user_t:udp_socket { sendto };
#line 4736
allow user_t user_t:udp_socket { recvfrom };
#line 4736

#line 4736

#line 4736
allow user_t user_t:tcp_socket { connectto recvfrom };
#line 4736
allow user_t user_t:tcp_socket { acceptfrom recvfrom };
#line 4736
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4736

#line 4736

#line 4736
# Connect to inetd.
#line 4736

#line 4736

#line 4736

#line 4736

#line 4736
# Connect data port to ftpd.
#line 4736

#line 4736

#line 4736
# Connect to portmap.
#line 4736

#line 4736

#line 4736
# Inherit and use sockets from inetd
#line 4736

#line 4736

#line 4736
# Allow system log read
#line 4736
#allow user_t kernel_t:system syslog_read;
#line 4736
# else do not log it
#line 4736
dontaudit user_t kernel_t:system syslog_read;
#line 4736

#line 4736
# Very permissive allowing every domain to see every type.
#line 4736
allow user_t kernel_t:system { ipc_info };
#line 4736

#line 4736
# When the user domain runs ps, there will be a number of access
#line 4736
# denials when ps tries to search /proc.  Do not audit these denials.
#line 4736
dontaudit user_t domain:dir { read getattr lock search ioctl };
#line 4736
dontaudit user_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4736

#line 4736
# Some shells ask for w access to utmp, but will operate
#line 4736
# correctly without it.  Do not audit write denials to utmp.
#line 4736
dontaudit user_t initrc_var_run_t:file { getattr read write };
#line 4736

#line 4736
# do not audit getattr on tmpfile, otherwise ls -l /tmp fills the logs
#line 4736
dontaudit user_t tmpfile:{ dir file lnk_file sock_file fifo_file chr_file blk_file } getattr;
#line 4736

#line 4736
# do not audit getattr on disk devices, otherwise KDE fills the logs
#line 4736
dontaudit user_t { removable_device_t fixed_disk_device_t }:blk_file getattr;
#line 4736

#line 4736

#line 4736
# Access the sound device.
#line 4736
allow user_t sound_device_t:chr_file { getattr read write ioctl };
#line 4736

#line 4736

#line 4736

#line 4736
# Get attributes of file systems.
#line 4736
allow user_t fs_type:filesystem getattr;
#line 4736

#line 4736
# Read and write /dev/tty and /dev/null.
#line 4736
allow user_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4736
allow user_t zero_device_t:chr_file { { ioctl read getattr lock write append } execute };
#line 4736
allow user_t random_device_t:chr_file { getattr read };
#line 4736

#line 4736
# Read the devpts root directory.
#line 4736
allow user_t devpts_t:dir { read getattr lock search ioctl };
#line 4736

#line 4736

#line 4736
# When an ordinary user domain runs su, su may try to
#line 4736
# update the /root/.Xauthority file, and the user shell may
#line 4736
# try to update the shell history. This isnt allowed, but 
#line 4736
# we dont need to audit it.
#line 4736

#line 4736
dontaudit user_su_t sysadm_home_t:dir  { read getattr search write add_name remove_name };
#line 4736
dontaudit user_su_t sysadm_home_t:file { read getattr create write link unlink };
#line 4736
dontaudit user_t    sysadm_home_t:dir { read search getattr };
#line 4736
dontaudit user_t    sysadm_home_t:file { read getattr append };
#line 4736

#line 4736

#line 4736
# Some programs that are left in user_t will try to connect
#line 4736
# to syslogd, but we do not want to let them generate log messages.
#line 4736
# Do not audit.
#line 4736
dontaudit user_t devlog_t:sock_file { read write };
#line 4736
dontaudit user_t syslogd_t:unix_dgram_socket sendto;
#line 4736

#line 4736

#line 4736
# stop warnings about "ls -l" on directories with unlabelled files
#line 4736
dontaudit user_t file_t:{ dir file lnk_file } getattr;
#line 4736


#  Do not add any rules referring to user_t to this file!  That will break
#  support for multiple user roles.

# a role for staff that allows seeing all domains and control over the user_t
# domain

#line 4743

#line 4743
# user_t/staff_t is an unprivileged users domain.
#line 4743
type staff_t, domain, userdomain, unpriv_userdomain, web_client_domain;
#line 4743

#line 4743
# staff_r is authorized for staff_t for the initial login domain.
#line 4743
role staff_r types staff_t;
#line 4743
allow system_r staff_r;
#line 4743

#line 4743
# Grant permissions within the domain.
#line 4743

#line 4743
# Access other processes in the same domain.
#line 4743
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4743
# separately if desired.
#line 4743
allow staff_t self:process ~{ptrace setexec setfscreate};
#line 4743

#line 4743
# Access /proc/PID files for processes in the same domain.
#line 4743
allow staff_t self:dir { read getattr lock search ioctl };
#line 4743
allow staff_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Access file descriptions, pipes, and sockets
#line 4743
# created by processes in the same domain.
#line 4743
allow staff_t self:fd *;
#line 4743
allow staff_t self:fifo_file { ioctl read getattr lock write append };
#line 4743
allow staff_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743

#line 4743
# Allow the domain to communicate with other processes in the same domain.
#line 4743
allow staff_t self:unix_dgram_socket sendto;
#line 4743
allow staff_t self:unix_stream_socket connectto;
#line 4743

#line 4743
# Access System V IPC objects created by processes in the same domain.
#line 4743
allow staff_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4743
allow staff_t self:msg  { send receive };
#line 4743
allow staff_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4743
allow staff_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4743
;
#line 4743

#line 4743
# Grant read/search permissions to some of /proc.
#line 4743
allow staff_t proc_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t proc_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
# Read /.
#line 4743
allow staff_t root_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /home.
#line 4743
allow staff_t home_root_t:dir { read getattr lock search ioctl };
#line 4743

#line 4743
# Read /usr.
#line 4743
allow staff_t usr_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read bin and sbin directories.
#line 4743
allow staff_t bin_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743
allow staff_t sbin_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
# Read directories and files with the readable_t type.
#line 4743
# This type is a general type for "world"-readable files.
#line 4743
allow staff_t readable_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Stat /...security and lost+found.
#line 4743
allow staff_t file_labels_t:dir getattr;
#line 4743
allow staff_t lost_found_t:dir getattr;
#line 4743

#line 4743

#line 4743

#line 4743
# Read the /tmp directory and any /tmp files with the base type.
#line 4743
# Temporary files created at runtime will typically use derived types.
#line 4743
allow staff_t tmp_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /var, /var/spool, /var/run.
#line 4743
allow staff_t var_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743
allow staff_t var_spool_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743
allow staff_t var_run_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
allow staff_t sysctl_kernel_t:dir search;
#line 4743
allow staff_t sysctl_kernel_t:file { getattr read };
#line 4743

#line 4743
# Read /etc.
#line 4743
allow staff_t etc_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743
allow staff_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
# for running depmod as part of the kernel packaging process
#line 4743
allow staff_t modules_conf_t:file { getattr read };
#line 4743

#line 4743
# Read man directories and files.
#line 4743
allow staff_t man_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /dev directories and any symbolic links.
#line 4743
allow staff_t device_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t device_t:lnk_file { read getattr lock ioctl };
#line 4743

#line 4743
# Do not audit write denials to /etc/ld.so.cache.
#line 4743
dontaudit staff_t ld_so_cache_t:file write;
#line 4743

#line 4743
# Execute from the system shared libraries.
#line 4743

#line 4743
allow staff_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_t device_t:dir search;
#line 4743
allow staff_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743
;
#line 4743

#line 4743
# staff_t is also granted permissions specific to user domains.
#line 4743

#line 4743
# Use capabilities
#line 4743
allow staff_t self:capability { setgid chown fowner };
#line 4743
dontaudit staff_t self:capability { sys_nice fsetid };
#line 4743

#line 4743
# Type for home directory.
#line 4743

#line 4743
type staff_home_dir_t, file_type, sysadmfile, home_dir_type, user_home_dir_type, home_type, user_home_type;
#line 4743
type staff_home_t, file_type, sysadmfile, home_type, user_home_type;
#line 4743
# do not allow privhome access to sysadm_home_dir_t
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow privhome staff_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow privhome staff_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow privhome staff_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition privhome staff_home_dir_t:dir staff_home_t;
#line 4743
type_transition privhome staff_home_dir_t:{ file lnk_file sock_file fifo_file } staff_home_t;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
type staff_tmp_t, file_type, sysadmfile, tmpfile , user_tmpfile;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_t staff_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_t staff_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_t tmp_t:dir staff_tmp_t;
#line 4743
type_transition staff_t tmp_t:{ file lnk_file sock_file fifo_file } staff_tmp_t;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# allow ptrace
#line 4743
#can_ptrace(staff_t, staff_t)
#line 4743

#line 4743
# Create, access, and remove files in home directory.
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_t staff_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_t staff_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_t staff_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_t staff_home_dir_t:dir staff_home_t;
#line 4743
type_transition staff_t staff_home_dir_t:{ file lnk_file sock_file fifo_file } staff_home_t;
#line 4743

#line 4743

#line 4743

#line 4743
allow staff_t staff_home_t:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { relabelfrom relabelto };
#line 4743

#line 4743
# Bind to a Unix domain socket in /tmp.
#line 4743
allow staff_t staff_tmp_t:unix_stream_socket name_bind;
#line 4743

#line 4743
# Type for tty devices.
#line 4743
type staff_tty_device_t, file_type, sysadmfile, ttyfile;
#line 4743
# Access ttys.
#line 4743
allow staff_t privfd:fd use;
#line 4743
allow staff_t staff_tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4743
# Use the type when relabeling terminal devices.
#line 4743
type_change staff_t tty_device_t:chr_file staff_tty_device_t;
#line 4743

#line 4743

#line 4743
# read localization information
#line 4743
allow staff_t locale_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4743

#line 4743
# for running TeX programs
#line 4743

#line 4743
allow staff_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
allow staff_t tetex_data_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
# Type and access for pty devices.
#line 4743

#line 4743

#line 4743

#line 4743
# Access the pty master multiplexer.
#line 4743
allow staff_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743
allow staff_t devpts_t:filesystem getattr;
#line 4743

#line 4743
# allow searching /dev/pts
#line 4743
allow staff_t devpts_t:dir { getattr read search };
#line 4743

#line 4743
type staff_devpts_t, file_type, sysadmfile, ptyfile , userpty_type;
#line 4743

#line 4743
# Allow the pty to be associated with the file system.
#line 4743
allow staff_devpts_t devpts_t:filesystem associate;
#line 4743

#line 4743
# Label pty files with a derived type.
#line 4743
type_transition staff_t devpts_t:chr_file staff_devpts_t;
#line 4743

#line 4743
# Read and write my pty files.
#line 4743
allow staff_t staff_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4743

#line 4743

#line 4743

#line 4743
# Use the type when relabeling pty devices.
#line 4743

#line 4743

#line 4743
type_change staff_t sshd_devpts_t:chr_file staff_devpts_t;
#line 4743

#line 4743
# Connect to sshd.
#line 4743

#line 4743
allow staff_t sshd_t:tcp_socket { connectto recvfrom };
#line 4743
allow sshd_t staff_t:tcp_socket { acceptfrom recvfrom };
#line 4743
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743
allow staff_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743

#line 4743

#line 4743
# Connect to ssh proxy.
#line 4743

#line 4743
allow staff_t staff_ssh_t:tcp_socket { connectto recvfrom };
#line 4743
allow staff_ssh_t staff_t:tcp_socket { acceptfrom recvfrom };
#line 4743
allow staff_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743
allow staff_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743

#line 4743

#line 4743
allow staff_t sshd_t:fd use;
#line 4743
allow staff_t sshd_t:tcp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743
# Use a Unix stream socket inherited from sshd.
#line 4743
allow staff_t sshd_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743

#line 4743
allow staff_t boot_t:dir { getattr search };
#line 4743
dontaudit staff_t boot_t:dir read;
#line 4743
dontaudit staff_t boot_t:lnk_file getattr;
#line 4743
dontaudit staff_t boot_t:file { getattr read };
#line 4743
allow staff_t system_map_t:file { getattr read };
#line 4743

#line 4743

#line 4743
type staff_tmpfs_t, file_type, sysadmfile, tmpfsfile;
#line 4743
# Use this type when creating tmpfs/shm objects.
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_t tmpfs_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_t staff_tmpfs_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_t staff_tmpfs_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_t tmpfs_t:dir staff_tmpfs_t;
#line 4743
type_transition staff_t tmpfs_t:{ file lnk_file sock_file fifo_file } staff_tmpfs_t;
#line 4743

#line 4743

#line 4743

#line 4743
allow staff_tmpfs_t tmpfs_t:filesystem associate;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Read and write /var/catman.
#line 4743
allow staff_t catman_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743
allow staff_t catman_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743

#line 4743
# Modify mail spool file.
#line 4743
allow staff_t mail_spool_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_t mail_spool_t:file { ioctl read getattr lock write append };
#line 4743
allow staff_t mail_spool_t:lnk_file read;
#line 4743

#line 4743
#
#line 4743
# Allow the query of filesystem quotas
#line 4743
#
#line 4743
allow staff_t fs_type:filesystem quotaget;
#line 4743

#line 4743
# Run helper programs.
#line 4743

#line 4743
allow staff_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4743

#line 4743
allow staff_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_t device_t:dir search;
#line 4743
allow staff_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743
allow staff_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
# Run programs developed by other users in the same domain.
#line 4743

#line 4743
allow staff_t staff_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_t staff_tmp_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
# Run user programs that require different permissions in their own domain.
#line 4743
# These rules were moved into the individual program domains.
#line 4743

#line 4743
# Instantiate derived domains for a number of programs.
#line 4743
# These derived domains encode both information about the calling
#line 4743
# user domain and the program, and allow us to maintain separation
#line 4743
# between different instances of the program being run by different
#line 4743
# user domains.
#line 4743

#line 4743

#line 4743

#line 4743
# Derived domain based on the calling user domain and the program.
#line 4743
type staff_su_t, domain, privlog, auth;
#line 4743

#line 4743
# Transition from the user domain to this domain.
#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow staff_t staff_su_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit staff_t staff_su_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow staff_t su_exec_t:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_su_t staff_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_su_t staff_t:fd use;
#line 4743
allow staff_t staff_su_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_su_t staff_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_su_t su_exec_t:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_su_t su_exec_t:file entrypoint;
#line 4743

#line 4743
type_transition staff_t su_exec_t:process staff_su_t;
#line 4743

#line 4743

#line 4743

#line 4743
allow staff_su_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_su_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_su_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_su_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_su_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_su_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_su_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_su_t device_t:dir search;
#line 4743
allow staff_su_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
allow staff_su_t etc_t:file { getattr read };
#line 4743

#line 4743
allow staff_su_t etc_t:lnk_file read;
#line 4743

#line 4743
allow staff_su_t locale_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_su_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
allow staff_su_t self:unix_dgram_socket { connect create write };
#line 4743
allow staff_su_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743
allow staff_su_t proc_t:dir search;
#line 4743
allow staff_su_t proc_t:lnk_file read;
#line 4743

#line 4743
allow staff_su_t self:dir { read getattr lock search ioctl };
#line 4743
allow staff_su_t self:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
allow staff_su_t self:process setsched;
#line 4743
allow staff_su_t device_t:dir search;
#line 4743
allow staff_su_t self:process { fork sigchld };
#line 4743

#line 4743
# Use capabilities.
#line 4743
allow staff_su_t self:capability { setuid setgid net_bind_service chown dac_override sys_nice sys_resource };
#line 4743

#line 4743
# Revert to the user domain when a shell is executed.
#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow staff_su_t staff_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit staff_su_t staff_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow staff_su_t shell_exec_t:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_t staff_su_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_t staff_su_t:fd use;
#line 4743
allow staff_su_t staff_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_t staff_su_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_t shell_exec_t:file entrypoint;
#line 4743

#line 4743
type_transition staff_su_t shell_exec_t:process staff_t;
#line 4743

#line 4743
allow staff_su_t bin_t:dir search;
#line 4743
allow staff_su_t bin_t:lnk_file read;
#line 4743

#line 4743
allow staff_su_t privfd:fd use;
#line 4743

#line 4743
# Write to utmp.
#line 4743
allow staff_su_t { var_t var_run_t }:dir search;
#line 4743
allow staff_su_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743

#line 4743
# Run chkpwd.
#line 4743

#line 4743
allow staff_su_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743

#line 4743
# Inherit and use descriptors from gnome-pty-helper.
#line 4743

#line 4743

#line 4743
# The user role is authorized for this domain.
#line 4743
role staff_r types staff_su_t;
#line 4743

#line 4743
# Write to the user domain tty.
#line 4743
allow staff_su_t staff_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_su_t staff_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
allow staff_su_t { home_root_t staff_home_dir_t }:dir search;
#line 4743

#line 4743
# Modify .Xauthority file (via xauth program).
#line 4743

#line 4743

#line 4743
# Access sshd cookie files.
#line 4743
allow staff_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743
allow staff_su_t sshd_tmp_t:file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_su_t staff_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_su_t staff_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_su_t sshd_tmp_t:dir staff_tmp_t;
#line 4743
type_transition staff_su_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } staff_tmp_t;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# stop su complaining if you run it from a directory with restrictive perms
#line 4743
dontaudit staff_su_t file_type:dir search;
#line 4743

#line 4743

#line 4743
# Derived domain based on the calling user domain and the program.
#line 4743
type staff_chkpwd_t, domain, privlog, auth;
#line 4743

#line 4743
# Transition from the user domain to this domain.
#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow staff_t staff_chkpwd_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit staff_t staff_chkpwd_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow staff_t chkpwd_exec_t:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_chkpwd_t staff_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_chkpwd_t staff_t:fd use;
#line 4743
allow staff_t staff_chkpwd_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_chkpwd_t staff_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_chkpwd_t chkpwd_exec_t:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_chkpwd_t chkpwd_exec_t:file entrypoint;
#line 4743

#line 4743
type_transition staff_t chkpwd_exec_t:process staff_chkpwd_t;
#line 4743

#line 4743

#line 4743
# The user role is authorized for this domain.
#line 4743
role staff_r types staff_chkpwd_t;
#line 4743

#line 4743

#line 4743
allow staff_chkpwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_chkpwd_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_chkpwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_chkpwd_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_chkpwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_chkpwd_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_chkpwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_chkpwd_t device_t:dir search;
#line 4743
allow staff_chkpwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
allow staff_chkpwd_t etc_t:file { getattr read };
#line 4743
allow staff_chkpwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_chkpwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743

#line 4743
allow staff_chkpwd_t etc_t:lnk_file read;
#line 4743

#line 4743
allow staff_chkpwd_t locale_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_chkpwd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743

#line 4743
# Use capabilities.
#line 4743
allow staff_chkpwd_t self:capability setuid;
#line 4743

#line 4743
# Inherit and use descriptors from gnome-pty-helper.
#line 4743

#line 4743

#line 4743
# Inherit and use descriptors from newrole.
#line 4743
allow staff_chkpwd_t newrole_t:fd use;
#line 4743

#line 4743
# Write to the user domain tty.
#line 4743
allow staff_chkpwd_t staff_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_chkpwd_t staff_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Derived domain based on the calling user domain and the program.
#line 4743
type staff_crontab_t, domain, privlog;
#line 4743

#line 4743
# Transition from the user domain to the derived domain.
#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow staff_t staff_crontab_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit staff_t staff_crontab_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow staff_t crontab_exec_t:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_crontab_t staff_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_crontab_t staff_t:fd use;
#line 4743
allow staff_t staff_crontab_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_crontab_t staff_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_crontab_t crontab_exec_t:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_crontab_t crontab_exec_t:file entrypoint;
#line 4743

#line 4743
type_transition staff_t crontab_exec_t:process staff_crontab_t;
#line 4743

#line 4743

#line 4743
# The user role is authorized for this domain.
#line 4743
role staff_r types staff_crontab_t;
#line 4743

#line 4743

#line 4743
allow staff_crontab_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_crontab_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crontab_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_crontab_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_crontab_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crontab_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_crontab_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_crontab_t device_t:dir search;
#line 4743
allow staff_crontab_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
allow staff_crontab_t etc_t:file { getattr read };
#line 4743
allow staff_crontab_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_crontab_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743

#line 4743
allow staff_crontab_t etc_t:lnk_file read;
#line 4743

#line 4743
allow staff_crontab_t locale_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_crontab_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743

#line 4743
# Use capabilities
#line 4743
allow staff_crontab_t staff_crontab_t:capability { setuid setgid chown };
#line 4743

#line 4743
# Type for temporary files.
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_crontab_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_crontab_t staff_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_crontab_t staff_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_crontab_t tmp_t:dir staff_tmp_t;
#line 4743
type_transition staff_crontab_t tmp_t:{ file lnk_file sock_file fifo_file } staff_tmp_t;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Type of user crontabs once moved to cron spool.
#line 4743
type staff_cron_spool_t, file_type, sysadmfile;
#line 4743
# Use the type when creating files in /var/spool/cron.
#line 4743
allow sysadm_crontab_t staff_cron_spool_t:file { getattr read };
#line 4743
allow staff_crontab_t { var_t var_spool_t }:dir search;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_crontab_t cron_spool_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_crontab_t staff_cron_spool_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_crontab_t staff_cron_spool_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_crontab_t cron_spool_t:dir staff_cron_spool_t;
#line 4743
type_transition staff_crontab_t cron_spool_t:{ file lnk_file sock_file fifo_file } staff_cron_spool_t;
#line 4743

#line 4743

#line 4743

#line 4743
allow staff_crontab_t self:process { fork { sigchld sigkill sigstop signull signal } };
#line 4743

#line 4743
# crontab signals crond by updating the mtime on the spooldir
#line 4743
allow staff_crontab_t cron_spool_t:dir setattr;
#line 4743
# Allow crond to read those crontabs in cron spool.
#line 4743
allow crond_t staff_cron_spool_t:file { read getattr lock ioctl };
#line 4743

#line 4743
# Run helper programs as staff_t
#line 4743
allow staff_crontab_t { bin_t sbin_t }:dir search;
#line 4743
allow staff_crontab_t bin_t:lnk_file read;
#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow staff_crontab_t staff_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit staff_crontab_t staff_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow staff_crontab_t { bin_t sbin_t shell_exec_t }:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_t staff_crontab_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_t staff_crontab_t:fd use;
#line 4743
allow staff_crontab_t staff_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_t staff_crontab_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_t { bin_t sbin_t shell_exec_t }:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_t { bin_t sbin_t shell_exec_t }:file entrypoint;
#line 4743

#line 4743
type_transition staff_crontab_t { bin_t sbin_t shell_exec_t }:process staff_t;
#line 4743

#line 4743

#line 4743
# Read user crontabs 
#line 4743
allow staff_crontab_t { staff_home_t staff_home_dir_t }:dir { read getattr lock search ioctl };  
#line 4743
allow staff_crontab_t staff_home_t:file { read getattr lock ioctl };  
#line 4743
dontaudit staff_crontab_t staff_home_dir_t:dir write;
#line 4743

#line 4743
# Access the cron log file.
#line 4743
allow staff_crontab_t cron_log_t:file { read getattr lock ioctl };
#line 4743
allow staff_crontab_t cron_log_t:file { append };
#line 4743

#line 4743
# Access terminals.
#line 4743
allow staff_crontab_t device_t:dir search;
#line 4743
allow staff_crontab_t staff_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_crontab_t staff_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
# Inherit and use descriptors from gnome-pty-helper.
#line 4743

#line 4743
allow staff_crontab_t privfd:fd use;
#line 4743

#line 4743

#line 4743
# Derived domain based on the calling user domain and the program.
#line 4743
type staff_ssh_t, domain, privlog;
#line 4743

#line 4743
# Transition from the user domain to the derived domain.
#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow staff_t staff_ssh_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit staff_t staff_ssh_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow staff_t ssh_exec_t:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_ssh_t staff_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_ssh_t staff_t:fd use;
#line 4743
allow staff_t staff_ssh_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_ssh_t staff_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_ssh_t ssh_exec_t:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_ssh_t ssh_exec_t:file entrypoint;
#line 4743

#line 4743
type_transition staff_t ssh_exec_t:process staff_ssh_t;
#line 4743

#line 4743

#line 4743
# The user role is authorized for this domain.
#line 4743
role staff_r types staff_ssh_t;
#line 4743

#line 4743
# Grant permissions within the domain.
#line 4743

#line 4743
# Access other processes in the same domain.
#line 4743
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4743
# separately if desired.
#line 4743
allow staff_ssh_t self:process ~{ptrace setexec setfscreate};
#line 4743

#line 4743
# Access /proc/PID files for processes in the same domain.
#line 4743
allow staff_ssh_t self:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Access file descriptions, pipes, and sockets
#line 4743
# created by processes in the same domain.
#line 4743
allow staff_ssh_t self:fd *;
#line 4743
allow staff_ssh_t self:fifo_file { ioctl read getattr lock write append };
#line 4743
allow staff_ssh_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_ssh_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743

#line 4743
# Allow the domain to communicate with other processes in the same domain.
#line 4743
allow staff_ssh_t self:unix_dgram_socket sendto;
#line 4743
allow staff_ssh_t self:unix_stream_socket connectto;
#line 4743

#line 4743
# Access System V IPC objects created by processes in the same domain.
#line 4743
allow staff_ssh_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4743
allow staff_ssh_t self:msg  { send receive };
#line 4743
allow staff_ssh_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4743
allow staff_ssh_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4743

#line 4743

#line 4743
# Use descriptors created by sshd
#line 4743
allow staff_ssh_t privfd:fd use;
#line 4743

#line 4743

#line 4743
allow staff_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_ssh_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t device_t:dir search;
#line 4743
allow staff_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743
allow staff_ssh_t etc_t:lnk_file read;
#line 4743

#line 4743
allow staff_ssh_t locale_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743

#line 4743
# Get attributes of file systems.
#line 4743
allow staff_ssh_t fs_type:filesystem getattr;
#line 4743

#line 4743

#line 4743
# Read /.
#line 4743
allow staff_ssh_t root_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /home.
#line 4743
allow staff_ssh_t home_root_t:dir { read getattr lock search ioctl };
#line 4743

#line 4743
# Read /usr.
#line 4743
allow staff_ssh_t usr_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read bin and sbin directories.
#line 4743
allow staff_ssh_t bin_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743
allow staff_ssh_t sbin_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
# Read the devpts root directory.
#line 4743
allow staff_ssh_t devpts_t:dir { read getattr lock search ioctl };
#line 4743

#line 4743
# Read /var.
#line 4743
allow staff_ssh_t var_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /var/run, /var/log.
#line 4743
allow staff_ssh_t var_run_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743
allow staff_ssh_t var_log_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /etc.
#line 4743
allow staff_ssh_t etc_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743
allow staff_ssh_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743
allow staff_ssh_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read the linker, shared library, and executable types.
#line 4743
allow staff_ssh_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743
allow staff_ssh_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743
allow staff_ssh_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Read /dev directories and any symbolic links.
#line 4743
allow staff_ssh_t device_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t device_t:lnk_file { read getattr lock ioctl };
#line 4743

#line 4743
# Read /dev/random.
#line 4743
allow staff_ssh_t random_device_t:chr_file { read getattr lock ioctl };
#line 4743

#line 4743
# Read and write /dev/tty and /dev/null.
#line 4743
allow staff_ssh_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_ssh_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
# Grant permissions needed to create TCP and UDP sockets and
#line 4743
# to access the network.
#line 4743

#line 4743
#
#line 4743
# Allow the domain to create and use UDP and TCP sockets.
#line 4743
# Other kinds of sockets must be separately authorized for use.
#line 4743
allow staff_ssh_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_ssh_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send UDP packets.
#line 4743
# Since the destination sockets type is unknown, the generic
#line 4743
# any_socket_t type is used as a placeholder.
#line 4743
#
#line 4743
allow staff_ssh_t any_socket_t:udp_socket sendto;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send using any network interface.
#line 4743
# netif_type is a type attribute for all network interface types.
#line 4743
#
#line 4743
allow staff_ssh_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4743

#line 4743
#
#line 4743
# Allow packets sent by the domain to be received on any network interface.
#line 4743
#
#line 4743
allow staff_ssh_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to receive packets from any network interface.
#line 4743
# netmsg_type is a type attribute for all default message types.
#line 4743
#
#line 4743
allow staff_ssh_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to initiate or accept TCP connections 
#line 4743
# on any network interface.
#line 4743
#
#line 4743
allow staff_ssh_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4743

#line 4743
#
#line 4743
# Receive resets from the TCP reset socket.
#line 4743
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4743
#
#line 4743
allow staff_ssh_t tcp_socket_t:tcp_socket recvfrom;
#line 4743

#line 4743
dontaudit staff_ssh_t tcp_socket_t:tcp_socket connectto;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send to any node.
#line 4743
# node_type is a type attribute for all node types.
#line 4743
#
#line 4743
allow staff_ssh_t node_type:node { tcp_send udp_send rawip_send };
#line 4743

#line 4743
#
#line 4743
# Allow packets sent by the domain to be received from any node.
#line 4743
#
#line 4743
allow staff_ssh_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send NFS client requests via the socket
#line 4743
# created by mount.
#line 4743
#
#line 4743
allow staff_ssh_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743

#line 4743
#
#line 4743
# Bind to the default port type.
#line 4743
# Other port types must be separately authorized.
#line 4743
#
#line 4743
allow staff_ssh_t port_t:udp_socket name_bind;
#line 4743
allow staff_ssh_t port_t:tcp_socket name_bind;
#line 4743

#line 4743

#line 4743
# for sshing to a ssh tunnel
#line 4743

#line 4743
allow staff_ssh_t staff_ssh_t:tcp_socket { connectto recvfrom };
#line 4743
allow staff_ssh_t staff_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4743
allow staff_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743
allow staff_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743

#line 4743

#line 4743
# Use capabilities.
#line 4743
allow staff_ssh_t self:capability { setuid setgid dac_override dac_read_search };
#line 4743

#line 4743
# Run helpers.
#line 4743

#line 4743
allow staff_ssh_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4743

#line 4743
allow staff_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_ssh_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_ssh_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_ssh_t device_t:dir search;
#line 4743
allow staff_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743
allow staff_ssh_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_ssh_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_ssh_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_ssh_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_ssh_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743

#line 4743
# Read the ssh key file.
#line 4743
allow staff_ssh_t sshd_key_t:file { read getattr lock ioctl };
#line 4743

#line 4743
# Access the ssh temporary files.
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_ssh_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_ssh_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_ssh_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_ssh_t tmp_t:dir sshd_tmp_t;
#line 4743
type_transition staff_ssh_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 4743

#line 4743

#line 4743

#line 4743
allow staff_ssh_t staff_tmp_t:dir { read getattr lock search ioctl };
#line 4743

#line 4743
# for rsync
#line 4743
allow staff_ssh_t staff_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743

#line 4743
# Access the users .ssh directory.
#line 4743
type staff_home_ssh_t, file_type, sysadmfile;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow { sysadm_ssh_t staff_ssh_t } staff_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow { sysadm_ssh_t staff_ssh_t } staff_home_ssh_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow { sysadm_ssh_t staff_ssh_t } staff_home_ssh_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition { sysadm_ssh_t staff_ssh_t } staff_home_dir_t:dir staff_home_ssh_t;
#line 4743
type_transition { sysadm_ssh_t staff_ssh_t } staff_home_dir_t:{ file lnk_file sock_file fifo_file } staff_home_ssh_t;
#line 4743

#line 4743

#line 4743

#line 4743
allow { sysadm_ssh_t staff_ssh_t } staff_home_ssh_t:lnk_file { getattr read };
#line 4743
dontaudit staff_ssh_t staff_home_t:dir search;
#line 4743

#line 4743
allow sshd_t staff_home_ssh_t:dir { read getattr lock search ioctl };
#line 4743
allow sshd_t staff_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
allow staff_t staff_home_ssh_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743
allow staff_t staff_home_ssh_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743

#line 4743

#line 4743
# for /bin/sh used to execute xauth
#line 4743
dontaudit staff_ssh_t proc_t:dir search;
#line 4743

#line 4743
# Inherit and use descriptors from gnome-pty-helper.
#line 4743

#line 4743

#line 4743
# Connect to sshd.
#line 4743

#line 4743

#line 4743
allow staff_ssh_t sshd_t:tcp_socket { connectto recvfrom };
#line 4743
allow sshd_t staff_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4743
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743
allow staff_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743

#line 4743

#line 4743

#line 4743
# Write to the user domain tty.
#line 4743
allow staff_ssh_t staff_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_ssh_t staff_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743
# Allow the user shell to signal the ssh program.
#line 4743
allow staff_t staff_ssh_t:process signal;
#line 4743
# allow ps to show ssh
#line 4743
allow staff_t staff_ssh_t:dir { search getattr read };
#line 4743
allow staff_t staff_ssh_t:{ file lnk_file } { read getattr };
#line 4743

#line 4743
# Allow the ssh program to communicate with ssh-agent.
#line 4743
allow staff_ssh_t staff_tmp_t:sock_file write;
#line 4743
allow staff_ssh_t staff_t:unix_stream_socket connectto;
#line 4743
allow staff_ssh_t sshd_t:unix_stream_socket connectto;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Instantiate a derived domain for user cron jobs.
#line 4743

#line 4743
# Derived domain for user cron jobs, user user_crond_domain if not system
#line 4743

#line 4743
type staff_crond_t, domain, user_crond_domain;
#line 4743

#line 4743

#line 4743
# Permit a transition from the crond_t domain to this domain.
#line 4743
# The transition is requested explicitly by the modified crond 
#line 4743
# via execve_secure.  There is no way to set up an automatic
#line 4743
# transition, since crontabs are configuration files, not executables.
#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to transition to the new domain.
#line 4743
#
#line 4743
allow crond_t staff_crond_t:process transition;
#line 4743

#line 4743
#
#line 4743
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4743
#
#line 4743
dontaudit crond_t staff_crond_t:process noatsecure;
#line 4743

#line 4743
#
#line 4743
# Allow the process to execute the program.
#line 4743
# 
#line 4743
allow crond_t shell_exec_t:file { read { getattr execute } };
#line 4743

#line 4743
#
#line 4743
# Allow the process to reap the new domain.
#line 4743
#
#line 4743
allow staff_crond_t crond_t:process sigchld;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to inherit and use file 
#line 4743
# descriptions from the creating process and vice versa.
#line 4743
#
#line 4743
allow staff_crond_t crond_t:fd use;
#line 4743
allow crond_t staff_crond_t:fd use;
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to write back to the old domain via a pipe.
#line 4743
#
#line 4743
allow staff_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to read and execute the program.
#line 4743
#
#line 4743
allow staff_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4743

#line 4743
#
#line 4743
# Allow the new domain to be entered via the program.
#line 4743
#
#line 4743
allow staff_crond_t shell_exec_t:file entrypoint;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# The user role is authorized for this domain.
#line 4743
role staff_r types staff_crond_t;
#line 4743

#line 4743
# This domain is granted permissions common to most domains.
#line 4743

#line 4743
#
#line 4743
# Allow the domain to create and use UDP and TCP sockets.
#line 4743
# Other kinds of sockets must be separately authorized for use.
#line 4743
allow staff_crond_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_crond_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send UDP packets.
#line 4743
# Since the destination sockets type is unknown, the generic
#line 4743
# any_socket_t type is used as a placeholder.
#line 4743
#
#line 4743
allow staff_crond_t any_socket_t:udp_socket sendto;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send using any network interface.
#line 4743
# netif_type is a type attribute for all network interface types.
#line 4743
#
#line 4743
allow staff_crond_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4743

#line 4743
#
#line 4743
# Allow packets sent by the domain to be received on any network interface.
#line 4743
#
#line 4743
allow staff_crond_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to receive packets from any network interface.
#line 4743
# netmsg_type is a type attribute for all default message types.
#line 4743
#
#line 4743
allow staff_crond_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to initiate or accept TCP connections 
#line 4743
# on any network interface.
#line 4743
#
#line 4743
allow staff_crond_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4743

#line 4743
#
#line 4743
# Receive resets from the TCP reset socket.
#line 4743
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4743
#
#line 4743
allow staff_crond_t tcp_socket_t:tcp_socket recvfrom;
#line 4743

#line 4743
dontaudit staff_crond_t tcp_socket_t:tcp_socket connectto;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send to any node.
#line 4743
# node_type is a type attribute for all node types.
#line 4743
#
#line 4743
allow staff_crond_t node_type:node { tcp_send udp_send rawip_send };
#line 4743

#line 4743
#
#line 4743
# Allow packets sent by the domain to be received from any node.
#line 4743
#
#line 4743
allow staff_crond_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send NFS client requests via the socket
#line 4743
# created by mount.
#line 4743
#
#line 4743
allow staff_crond_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743

#line 4743
#
#line 4743
# Bind to the default port type.
#line 4743
# Other port types must be separately authorized.
#line 4743
#
#line 4743
allow staff_crond_t port_t:udp_socket name_bind;
#line 4743
allow staff_crond_t port_t:tcp_socket name_bind;
#line 4743

#line 4743
allow staff_crond_t resolv_conf_t:file { getattr read };
#line 4743

#line 4743
allow staff_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_crond_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_crond_t device_t:dir search;
#line 4743
allow staff_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743
allow staff_crond_t self:dir { read getattr lock search ioctl };
#line 4743
allow staff_crond_t self:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743
allow staff_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4743
allow staff_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_crond_t etc_runtime_t:file { getattr read };
#line 4743
allow staff_crond_t self:process { fork { sigchld sigkill sigstop signull signal } };
#line 4743
allow staff_crond_t proc_t:dir { getattr search read };
#line 4743
allow staff_crond_t proc_t:file { getattr read };
#line 4743

#line 4743
allow staff_crond_t etc_t:lnk_file read;
#line 4743

#line 4743
allow staff_crond_t locale_t:dir { read getattr lock search ioctl };
#line 4743
allow staff_crond_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4743

#line 4743

#line 4743
allow staff_crond_t sysctl_kernel_t:dir search;
#line 4743
allow staff_crond_t sysctl_kernel_t:file { getattr read };
#line 4743
allow staff_crond_t var_spool_t:dir search;
#line 4743
allow staff_crond_t fs_t:filesystem getattr;
#line 4743

#line 4743
allow staff_crond_t devtty_t:chr_file { read write };
#line 4743

#line 4743
# Use capabilities.
#line 4743
allow staff_crond_t staff_crond_t:capability dac_override;
#line 4743

#line 4743
# Inherit and use descriptors from initrc.
#line 4743
allow staff_crond_t initrc_t:fd use;
#line 4743

#line 4743
# 
#line 4743
# Since crontab files are not directly executed,
#line 4743
# crond must ensure that the crontab file has
#line 4743
# a type that is appropriate for the domain of
#line 4743
# the user cron job.  It performs an entrypoint
#line 4743
# permission check for this purpose.
#line 4743
#
#line 4743
allow staff_crond_t staff_cron_spool_t:file entrypoint;
#line 4743

#line 4743
# Access user files and dirs.
#line 4743
allow staff_crond_t home_root_t:dir search;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_crond_t staff_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_crond_t staff_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_crond_t staff_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_crond_t staff_home_dir_t:dir staff_home_t;
#line 4743
type_transition staff_crond_t staff_home_dir_t:{ file lnk_file sock_file fifo_file } staff_home_t;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
#
#line 4743
# Allow the process to modify the directory.
#line 4743
#
#line 4743
allow staff_crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4743

#line 4743
#
#line 4743
# Allow the process to create the file.
#line 4743
#
#line 4743

#line 4743
allow staff_crond_t staff_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4743
allow staff_crond_t staff_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4743

#line 4743

#line 4743
type_transition staff_crond_t tmp_t:dir staff_tmp_t;
#line 4743
type_transition staff_crond_t tmp_t:{ file lnk_file sock_file fifo_file } staff_tmp_t;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Run helper programs.
#line 4743

#line 4743
allow staff_crond_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_crond_t { bin_t sbin_t etc_t }:lnk_file { getattr read };
#line 4743

#line 4743
allow staff_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4743
allow staff_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_crond_t ld_so_t:file execute_no_trans;
#line 4743
allow staff_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4743
allow staff_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4743
allow staff_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4743
allow staff_crond_t device_t:dir search;
#line 4743
allow staff_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743

#line 4743

#line 4743
allow staff_crond_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_crond_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_crond_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_crond_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
allow staff_crond_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743

#line 4743
# Run scripts in user home directory.
#line 4743

#line 4743
allow staff_crond_t staff_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4743

#line 4743

#line 4743
# ps does not need to access /boot when run from cron
#line 4743
dontaudit staff_crond_t boot_t:dir search;
#line 4743
# quiet other ps operations
#line 4743
dontaudit staff_crond_t domain:dir getattr;
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Read the mouse.
#line 4743
allow staff_t mouse_device_t:chr_file { read getattr lock ioctl };
#line 4743
# Access other miscellaneous devices.
#line 4743
allow staff_t misc_device_t:{ file lnk_file sock_file fifo_file chr_file blk_file } { ioctl read getattr lock write append };
#line 4743

#line 4743
# Use the network.
#line 4743

#line 4743
#
#line 4743
# Allow the domain to create and use UDP and TCP sockets.
#line 4743
# Other kinds of sockets must be separately authorized for use.
#line 4743
allow staff_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743
allow staff_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send UDP packets.
#line 4743
# Since the destination sockets type is unknown, the generic
#line 4743
# any_socket_t type is used as a placeholder.
#line 4743
#
#line 4743
allow staff_t any_socket_t:udp_socket sendto;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send using any network interface.
#line 4743
# netif_type is a type attribute for all network interface types.
#line 4743
#
#line 4743
allow staff_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4743

#line 4743
#
#line 4743
# Allow packets sent by the domain to be received on any network interface.
#line 4743
#
#line 4743
allow staff_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to receive packets from any network interface.
#line 4743
# netmsg_type is a type attribute for all default message types.
#line 4743
#
#line 4743
allow staff_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to initiate or accept TCP connections 
#line 4743
# on any network interface.
#line 4743
#
#line 4743
allow staff_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4743

#line 4743
#
#line 4743
# Receive resets from the TCP reset socket.
#line 4743
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4743
#
#line 4743
allow staff_t tcp_socket_t:tcp_socket recvfrom;
#line 4743

#line 4743
dontaudit staff_t tcp_socket_t:tcp_socket connectto;
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send to any node.
#line 4743
# node_type is a type attribute for all node types.
#line 4743
#
#line 4743
allow staff_t node_type:node { tcp_send udp_send rawip_send };
#line 4743

#line 4743
#
#line 4743
# Allow packets sent by the domain to be received from any node.
#line 4743
#
#line 4743
allow staff_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4743

#line 4743
#
#line 4743
# Allow the domain to send NFS client requests via the socket
#line 4743
# created by mount.
#line 4743
#
#line 4743
allow staff_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4743

#line 4743
#
#line 4743
# Bind to the default port type.
#line 4743
# Other port types must be separately authorized.
#line 4743
#
#line 4743
allow staff_t port_t:udp_socket name_bind;
#line 4743
allow staff_t port_t:tcp_socket name_bind;
#line 4743

#line 4743
allow staff_t resolv_conf_t:file { getattr read };
#line 4743
# for perl
#line 4743
dontaudit staff_t resolv_conf_t:file ioctl;
#line 4743

#line 4743
#
#line 4743
# connect_secure and sendmsg_secure calls with a 
#line 4743
# peer or destination socket SID can be enforced
#line 4743
# when using the loopback interface.  Enforcement
#line 4743
# for real network interfaces will be possible when
#line 4743
# a packet labeling mechanism is integrated.
#line 4743
#
#line 4743
allow staff_t node_lo_t:node enforce_dest;
#line 4743

#line 4743
# Communicate within the domain.
#line 4743

#line 4743
allow staff_t staff_t:udp_socket { sendto };
#line 4743
allow staff_t staff_t:udp_socket { recvfrom };
#line 4743

#line 4743

#line 4743
allow staff_t staff_t:tcp_socket { connectto recvfrom };
#line 4743
allow staff_t staff_t:tcp_socket { acceptfrom recvfrom };
#line 4743
allow staff_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743
allow staff_t tcp_socket_t:tcp_socket { recvfrom };
#line 4743

#line 4743

#line 4743
# Connect to inetd.
#line 4743

#line 4743

#line 4743

#line 4743

#line 4743
# Connect data port to ftpd.
#line 4743

#line 4743

#line 4743
# Connect to portmap.
#line 4743

#line 4743

#line 4743
# Inherit and use sockets from inetd
#line 4743

#line 4743

#line 4743
# Allow system log read
#line 4743
#allow staff_t kernel_t:system syslog_read;
#line 4743
# else do not log it
#line 4743
dontaudit staff_t kernel_t:system syslog_read;
#line 4743

#line 4743
# Very permissive allowing every domain to see every type.
#line 4743
allow staff_t kernel_t:system { ipc_info };
#line 4743

#line 4743
# When the user domain runs ps, there will be a number of access
#line 4743
# denials when ps tries to search /proc.  Do not audit these denials.
#line 4743
dontaudit staff_t domain:dir { read getattr lock search ioctl };
#line 4743
dontaudit staff_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4743

#line 4743
# Some shells ask for w access to utmp, but will operate
#line 4743
# correctly without it.  Do not audit write denials to utmp.
#line 4743
dontaudit staff_t initrc_var_run_t:file { getattr read write };
#line 4743

#line 4743
# do not audit getattr on tmpfile, otherwise ls -l /tmp fills the logs
#line 4743
dontaudit staff_t tmpfile:{ dir file lnk_file sock_file fifo_file chr_file blk_file } getattr;
#line 4743

#line 4743
# do not audit getattr on disk devices, otherwise KDE fills the logs
#line 4743
dontaudit staff_t { removable_device_t fixed_disk_device_t }:blk_file getattr;
#line 4743

#line 4743

#line 4743
# Access the sound device.
#line 4743
allow staff_t sound_device_t:chr_file { getattr read write ioctl };
#line 4743

#line 4743

#line 4743

#line 4743
# Get attributes of file systems.
#line 4743
allow staff_t fs_type:filesystem getattr;
#line 4743

#line 4743
# Read and write /dev/tty and /dev/null.
#line 4743
allow staff_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4743
allow staff_t zero_device_t:chr_file { { ioctl read getattr lock write append } execute };
#line 4743
allow staff_t random_device_t:chr_file { getattr read };
#line 4743

#line 4743
# Read the devpts root directory.
#line 4743
allow staff_t devpts_t:dir { read getattr lock search ioctl };
#line 4743

#line 4743

#line 4743
# When an ordinary user domain runs su, su may try to
#line 4743
# update the /root/.Xauthority file, and the user shell may
#line 4743
# try to update the shell history. This isnt allowed, but 
#line 4743
# we dont need to audit it.
#line 4743

#line 4743
dontaudit staff_su_t sysadm_home_t:dir  { read getattr search write add_name remove_name };
#line 4743
dontaudit staff_su_t sysadm_home_t:file { read getattr create write link unlink };
#line 4743
dontaudit staff_t    sysadm_home_t:dir { read search getattr };
#line 4743
dontaudit staff_t    sysadm_home_t:file { read getattr append };
#line 4743

#line 4743

#line 4743
# Some programs that are left in staff_t will try to connect
#line 4743
# to syslogd, but we do not want to let them generate log messages.
#line 4743
# Do not audit.
#line 4743
dontaudit staff_t devlog_t:sock_file { read write };
#line 4743
dontaudit staff_t syslogd_t:unix_dgram_socket sendto;
#line 4743

#line 4743

#line 4743
# stop warnings about "ls -l" on directories with unlabelled files
#line 4743
dontaudit staff_t file_t:{ dir file lnk_file } getattr;
#line 4743

allow staff_t unpriv_userdomain:process { sigchld sigkill sigstop signull signal };

#line 4745
allow staff_t domain:dir { read getattr lock search ioctl };
#line 4745
allow staff_t domain:{ file lnk_file } { read getattr lock ioctl };
#line 4745

allow staff_t { ttyfile ptyfile tty_device_t }:chr_file getattr;

# if adding new user roles make sure you edit the in_user_role macro in
# macros/user_macros.te to match

# lots of user programs accidentally search /root, and also the admin often
# logs in as UID=0 domain=user_t...
dontaudit unpriv_userdomain sysadm_home_dir_t:dir { getattr search };

# system_r is authorized for user_t as a fallback for unmodified daemons.
role system_r types user_t;

# change from role $1_r to $2_r and relabel tty appropriately
#line 4763


#line 4772

#line 4772
#
#line 4772
# Allow the user roles to transition
#line 4772
# into each other.
#line 4772

#line 4772
allow sysadm_r user_r;
#line 4772
type_change user_t sysadm_devpts_t:chr_file user_devpts_t;
#line 4772
type_change user_t sysadm_tty_device_t:chr_file user_tty_device_t;
#line 4772

#line 4772

#line 4772
allow staff_r sysadm_r;
#line 4772
type_change sysadm_t staff_devpts_t:chr_file sysadm_devpts_t;
#line 4772
type_change sysadm_t staff_tty_device_t:chr_file sysadm_tty_device_t;
#line 4772

#line 4772

#line 4772
allow sysadm_r staff_r;
#line 4772
type_change staff_t sysadm_devpts_t:chr_file staff_devpts_t;
#line 4772
type_change staff_t sysadm_tty_device_t:chr_file staff_tty_device_t;
#line 4772

#line 4772


# "ps aux" and "ls -l /dev/pts" make too much noise without this
dontaudit unpriv_userdomain ptyfile:chr_file getattr;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the kernel_t domain.
#

#
# kernel_t is the domain of kernel threads.
# It is also the target type when checking permissions in the system class.
# 
type kernel_t, domain;
role system_r types kernel_t;

#line 4791
# Access other processes in the same domain.
#line 4791
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4791
# separately if desired.
#line 4791
allow kernel_t self:process ~{ptrace setexec setfscreate};
#line 4791

#line 4791
# Access /proc/PID files for processes in the same domain.
#line 4791
allow kernel_t self:dir { read getattr lock search ioctl };
#line 4791
allow kernel_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4791

#line 4791
# Access file descriptions, pipes, and sockets
#line 4791
# created by processes in the same domain.
#line 4791
allow kernel_t self:fd *;
#line 4791
allow kernel_t self:fifo_file { ioctl read getattr lock write append };
#line 4791
allow kernel_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4791
allow kernel_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4791

#line 4791
# Allow the domain to communicate with other processes in the same domain.
#line 4791
allow kernel_t self:unix_dgram_socket sendto;
#line 4791
allow kernel_t self:unix_stream_socket connectto;
#line 4791

#line 4791
# Access System V IPC objects created by processes in the same domain.
#line 4791
allow kernel_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4791
allow kernel_t self:msg  { send receive };
#line 4791
allow kernel_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4791
allow kernel_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4791


#line 4792
# Read system information files in /proc.
#line 4792
allow kernel_t proc_t:dir { read getattr lock search ioctl };
#line 4792
allow kernel_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4792

#line 4792
# Stat /proc/kmsg and /proc/kcore.
#line 4792
allow kernel_t proc_kmsg_t:file { getattr };
#line 4792
allow kernel_t proc_kcore_t:file { getattr };
#line 4792

#line 4792
# Read system variables in /proc/sys.
#line 4792
allow kernel_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_t:dir { read getattr lock search ioctl };
#line 4792
allow kernel_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4792
allow kernel_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4792
allow kernel_t sysctl_net_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4792
allow kernel_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4792
allow kernel_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4792
allow kernel_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4792


#line 4793
# Read /.
#line 4793
allow kernel_t root_t:dir { read getattr lock search ioctl };
#line 4793
allow kernel_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4793

#line 4793
# Read /home.
#line 4793
allow kernel_t home_root_t:dir { read getattr lock search ioctl };
#line 4793

#line 4793
# Read /usr.
#line 4793
allow kernel_t usr_t:dir { read getattr lock search ioctl };
#line 4793
allow kernel_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4793

#line 4793
# Read bin and sbin directories.
#line 4793
allow kernel_t bin_t:dir { read getattr lock search ioctl };
#line 4793
allow kernel_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4793
allow kernel_t sbin_t:dir { read getattr lock search ioctl };
#line 4793
allow kernel_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4793


#line 4794
allow kernel_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4794
allow kernel_t lib_t:lnk_file { read getattr lock ioctl };
#line 4794
allow kernel_t ld_so_t:file { read getattr lock execute ioctl };
#line 4794
allow kernel_t ld_so_t:file execute_no_trans;
#line 4794
allow kernel_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4794
allow kernel_t shlib_t:file { read getattr lock execute ioctl };
#line 4794
allow kernel_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4794
allow kernel_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4794
allow kernel_t device_t:dir search;
#line 4794
allow kernel_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4794


# Use capabilities.
allow kernel_t self:capability *;

# Run init in the init_t domain.

#line 4800

#line 4800

#line 4800
#
#line 4800
# Allow the process to transition to the new domain.
#line 4800
#
#line 4800
allow kernel_t init_t:process transition;
#line 4800

#line 4800
#
#line 4800
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4800
#
#line 4800
dontaudit kernel_t init_t:process noatsecure;
#line 4800

#line 4800
#
#line 4800
# Allow the process to execute the program.
#line 4800
# 
#line 4800
allow kernel_t init_exec_t:file { read { getattr execute } };
#line 4800

#line 4800
#
#line 4800
# Allow the process to reap the new domain.
#line 4800
#
#line 4800
allow init_t kernel_t:process sigchld;
#line 4800

#line 4800
#
#line 4800
# Allow the new domain to inherit and use file 
#line 4800
# descriptions from the creating process and vice versa.
#line 4800
#
#line 4800
allow init_t kernel_t:fd use;
#line 4800
allow kernel_t init_t:fd use;
#line 4800

#line 4800
#
#line 4800
# Allow the new domain to write back to the old domain via a pipe.
#line 4800
#
#line 4800
allow init_t kernel_t:fifo_file { ioctl read getattr lock write append };
#line 4800

#line 4800
#
#line 4800
# Allow the new domain to read and execute the program.
#line 4800
#
#line 4800
allow init_t init_exec_t:file { read getattr lock execute ioctl };
#line 4800

#line 4800
#
#line 4800
# Allow the new domain to be entered via the program.
#line 4800
#
#line 4800
allow init_t init_exec_t:file entrypoint;
#line 4800

#line 4800
type_transition kernel_t init_exec_t:process init_t;
#line 4800


# Share state with the init process.
allow kernel_t init_t:process share;

# Mount and unmount file systems.
allow kernel_t fs_type:filesystem { mount remount unmount getattr };

# Search the persistent label mapping.
allow kernel_t file_labels_t:dir search;

# Send signal to any process.
allow kernel_t domain:process signal;

# Access the console.
allow kernel_t device_t:dir search;
allow kernel_t console_device_t:chr_file { ioctl read getattr lock write append };

# Access the initrd filesystem.
allow kernel_t file_t:chr_file { ioctl read getattr lock write append };

#line 4820
allow kernel_t file_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4820

#line 4823

allow kernel_t self:capability sys_chroot;

allow kernel_t { unlabeled_t root_t file_t }:dir mounton;
allow kernel_t file_t:dir { read getattr lock search ioctl add_name remove_name write };
allow kernel_t file_t:blk_file { create ioctl read getattr lock write setattr append link unlink rename };
allow kernel_t { sysctl_t sysctl_kernel_t }:file { setattr { ioctl read getattr lock write append } };

# Lookup the policy.
allow kernel_t policy_config_t:dir { read getattr lock search ioctl };

# Load the policy configuration.

#line 4835
allow kernel_t security_t:dir { read search getattr };
#line 4835
allow kernel_t security_t:file { getattr read write };
#line 4835
allow kernel_t security_t:security load_policy;
#line 4835
auditallow kernel_t security_t:security load_policy;
#line 4835


#line 4841

#line 4841
# Run insmod (for kernel module loader).
#line 4841

#line 4841

#line 4841

#line 4841
#
#line 4841
# Allow the process to transition to the new domain.
#line 4841
#
#line 4841
allow kernel_t insmod_t:process transition;
#line 4841

#line 4841
#
#line 4841
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4841
#
#line 4841
dontaudit kernel_t insmod_t:process noatsecure;
#line 4841

#line 4841
#
#line 4841
# Allow the process to execute the program.
#line 4841
# 
#line 4841
allow kernel_t insmod_exec_t:file { read { getattr execute } };
#line 4841

#line 4841
#
#line 4841
# Allow the process to reap the new domain.
#line 4841
#
#line 4841
allow insmod_t kernel_t:process sigchld;
#line 4841

#line 4841
#
#line 4841
# Allow the new domain to inherit and use file 
#line 4841
# descriptions from the creating process and vice versa.
#line 4841
#
#line 4841
allow insmod_t kernel_t:fd use;
#line 4841
allow kernel_t insmod_t:fd use;
#line 4841

#line 4841
#
#line 4841
# Allow the new domain to write back to the old domain via a pipe.
#line 4841
#
#line 4841
allow insmod_t kernel_t:fifo_file { ioctl read getattr lock write append };
#line 4841

#line 4841
#
#line 4841
# Allow the new domain to read and execute the program.
#line 4841
#
#line 4841
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 4841

#line 4841
#
#line 4841
# Allow the new domain to be entered via the program.
#line 4841
#
#line 4841
allow insmod_t insmod_exec_t:file entrypoint;
#line 4841

#line 4841
type_transition kernel_t insmod_exec_t:process insmod_t;
#line 4841

#line 4841
allow kernel_t insmod_exec_t:lnk_file read;
#line 4841


# /proc/sys/kernel/modprobe is set to /bin/true if not using modules.

#line 4844
allow kernel_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4844



#DESC Checkpolicy - SELinux policy compliler
#
# Authors:  Frank Mayer, mayerf@tresys.com
# X-Debian-Packages: checkpolicy
#

###########################
# 
# checkpolicy_t is the domain type for checkpolicy
# checkpolicy_exec_t if file type for the executable

type checkpolicy_t, domain;
role sysadm_r types checkpolicy_t;

type checkpolicy_exec_t, file_type, exec_type, sysadmfile;

##########################
# 
# Rules


#line 4867

#line 4867

#line 4867
#
#line 4867
# Allow the process to transition to the new domain.
#line 4867
#
#line 4867
allow sysadm_t checkpolicy_t:process transition;
#line 4867

#line 4867
#
#line 4867
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4867
#
#line 4867
dontaudit sysadm_t checkpolicy_t:process noatsecure;
#line 4867

#line 4867
#
#line 4867
# Allow the process to execute the program.
#line 4867
# 
#line 4867
allow sysadm_t checkpolicy_exec_t:file { read { getattr execute } };
#line 4867

#line 4867
#
#line 4867
# Allow the process to reap the new domain.
#line 4867
#
#line 4867
allow checkpolicy_t sysadm_t:process sigchld;
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to inherit and use file 
#line 4867
# descriptions from the creating process and vice versa.
#line 4867
#
#line 4867
allow checkpolicy_t sysadm_t:fd use;
#line 4867
allow sysadm_t checkpolicy_t:fd use;
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to write back to the old domain via a pipe.
#line 4867
#
#line 4867
allow checkpolicy_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to read and execute the program.
#line 4867
#
#line 4867
allow checkpolicy_t checkpolicy_exec_t:file { read getattr lock execute ioctl };
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to be entered via the program.
#line 4867
#
#line 4867
allow checkpolicy_t checkpolicy_exec_t:file entrypoint;
#line 4867

#line 4867
type_transition sysadm_t checkpolicy_exec_t:process checkpolicy_t;
#line 4867


# able to create and modify binary policy files
allow checkpolicy_t policy_config_t:dir { read getattr lock search ioctl add_name remove_name write };
allow checkpolicy_t policy_config_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };

###########################
# constrain what checkpolicy can use as source files
#

# only allow read of policy source files
allow checkpolicy_t policy_src_t:dir { read getattr lock search ioctl };
allow checkpolicy_t policy_src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# allow test policies to be created in src directories

#line 4882

#line 4882

#line 4882

#line 4882
#
#line 4882
# Allow the process to modify the directory.
#line 4882
#
#line 4882
allow checkpolicy_t policy_src_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4882

#line 4882
#
#line 4882
# Allow the process to create the file.
#line 4882
#
#line 4882

#line 4882
allow checkpolicy_t policy_config_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4882
allow checkpolicy_t policy_config_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4882

#line 4882

#line 4882
type_transition checkpolicy_t policy_src_t:dir policy_config_t;
#line 4882
type_transition checkpolicy_t policy_src_t:{ file lnk_file sock_file fifo_file } policy_config_t;
#line 4882

#line 4882

#line 4882


# directory search permissions for path to source and binary policy files
allow checkpolicy_t root_t:dir search;
allow checkpolicy_t etc_t:dir search;

# Read the devpts root directory.  
allow checkpolicy_t devpts_t:dir { read getattr lock search ioctl };
#line 4891


# Other access
allow checkpolicy_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { read write ioctl getattr };

#line 4895
allow checkpolicy_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4895
allow checkpolicy_t lib_t:lnk_file { read getattr lock ioctl };
#line 4895
allow checkpolicy_t ld_so_t:file { read getattr lock execute ioctl };
#line 4895
allow checkpolicy_t ld_so_t:file execute_no_trans;
#line 4895
allow checkpolicy_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4895
allow checkpolicy_t shlib_t:file { read getattr lock execute ioctl };
#line 4895
allow checkpolicy_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4895
allow checkpolicy_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4895
allow checkpolicy_t device_t:dir search;
#line 4895
allow checkpolicy_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4895

allow checkpolicy_t self:capability dac_override;

allow checkpolicy_t sysadm_tmp_t:file { getattr write } ;

##########################
# Allow users to execute checkpolicy without a domain transition
# so it can be used without privilege to write real binary policy file

#line 4903
allow user_t checkpolicy_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4903


allow checkpolicy_t privfd:fd use;

#DESC Chkpwd - PAM password checking programs
# X-Debian-Packages: libpam-modules
#
# Domains for the /sbin/.*_chkpwd utilities.
#

#
# chkpwd_exec_t is the type of the /sbin/.*_chkpwd executables.
#
type chkpwd_exec_t, file_type, sysadmfile, exec_type;

# Everything else is in the chkpwd_domain macro in
# macros/program/chkpwd_macros.te.
#DESC Crond - Crond daemon
#
# Domains for the top-level crond daemon process and
# for system cron jobs.  The domains for user cron jobs
# are in macros/program/crond_macros.te.
#
# X-Debian-Packages: cron
# Authors:  Jonathan Crowley (MITRE) <jonathan@mitre.org>,
#	    Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

# Domain for crond.  It needs auth to check for locked accounts.

#line 4932

#line 4932
type crond_t, domain, privlog , privrole, privmail, auth, privfd;
#line 4932
type crond_exec_t, file_type, sysadmfile, exec_type;
#line 4932

#line 4932
role system_r types crond_t;
#line 4932

#line 4932

#line 4932

#line 4932

#line 4932
#
#line 4932
# Allow the process to transition to the new domain.
#line 4932
#
#line 4932
allow initrc_t crond_t:process transition;
#line 4932

#line 4932
#
#line 4932
# Do not audit when glibc secure mode is enabled upon the transition.
#line 4932
#
#line 4932
dontaudit initrc_t crond_t:process noatsecure;
#line 4932

#line 4932
#
#line 4932
# Allow the process to execute the program.
#line 4932
# 
#line 4932
allow initrc_t crond_exec_t:file { read { getattr execute } };
#line 4932

#line 4932
#
#line 4932
# Allow the process to reap the new domain.
#line 4932
#
#line 4932
allow crond_t initrc_t:process sigchld;
#line 4932

#line 4932
#
#line 4932
# Allow the new domain to inherit and use file 
#line 4932
# descriptions from the creating process and vice versa.
#line 4932
#
#line 4932
allow crond_t initrc_t:fd use;
#line 4932
allow initrc_t crond_t:fd use;
#line 4932

#line 4932
#
#line 4932
# Allow the new domain to write back to the old domain via a pipe.
#line 4932
#
#line 4932
allow crond_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 4932

#line 4932
#
#line 4932
# Allow the new domain to read and execute the program.
#line 4932
#
#line 4932
allow crond_t crond_exec_t:file { read getattr lock execute ioctl };
#line 4932

#line 4932
#
#line 4932
# Allow the new domain to be entered via the program.
#line 4932
#
#line 4932
allow crond_t crond_exec_t:file entrypoint;
#line 4932

#line 4932
type_transition initrc_t crond_exec_t:process crond_t;
#line 4932

#line 4932

#line 4932
# Inherit and use descriptors from init.
#line 4932
allow crond_t init_t:fd use;
#line 4932
allow crond_t init_t:process sigchld;
#line 4932
allow crond_t privfd:fd use;
#line 4932
allow crond_t newrole_t:process sigchld;
#line 4932
allow crond_t self:process { { sigchld sigkill sigstop signull signal } fork };
#line 4932

#line 4932

#line 4932
allow crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4932
allow crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 4932
allow crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4932
allow crond_t ld_so_t:file execute_no_trans;
#line 4932
allow crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4932
allow crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4932
allow crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4932
allow crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4932
allow crond_t device_t:dir search;
#line 4932
allow crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4932

#line 4932

#line 4932
allow crond_t { self proc_t }:dir { read getattr lock search ioctl };
#line 4932
allow crond_t { self proc_t }:lnk_file read;
#line 4932

#line 4932
allow crond_t device_t:dir { getattr search };
#line 4932
allow crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4932
allow crond_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 4932
allow crond_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4932

#line 4932
# Create pid file.
#line 4932
allow crond_t var_t:dir { getattr search };
#line 4932

#line 4932
type crond_var_run_t alias var_run_crond_t, file_type, sysadmfile, pidfile;
#line 4932

#line 4932

#line 4932

#line 4932

#line 4932
#
#line 4932
# Allow the process to modify the directory.
#line 4932
#
#line 4932
allow crond_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4932

#line 4932
#
#line 4932
# Allow the process to create the file.
#line 4932
#
#line 4932

#line 4932

#line 4932
allow crond_t crond_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 4932

#line 4932

#line 4932
type_transition crond_t var_run_t:file crond_var_run_t;
#line 4932

#line 4932

#line 4932

#line 4932
allow crond_t crond_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4932

#line 4932

#line 4932
allow crond_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4932

#line 4932
# for daemons that look at /root on startup
#line 4932
dontaudit crond_t sysadm_home_dir_t:dir search;
#line 4932

#line 4932
# for df
#line 4932
allow crond_t fs_type:filesystem getattr;
#line 4932

#line 4932

#line 4932
allow crond_t etc_t:lnk_file read;
#line 4932

#line 4932
allow crond_t locale_t:dir { read getattr lock search ioctl };
#line 4932
allow crond_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4932

#line 4932

#line 4932


# This domain is granted permissions common to most domains (including can_net)

#line 4935
# Access other processes in the same domain.
#line 4935
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 4935
# separately if desired.
#line 4935
allow crond_t self:process ~{ptrace setexec setfscreate};
#line 4935

#line 4935
# Access /proc/PID files for processes in the same domain.
#line 4935
allow crond_t self:dir { read getattr lock search ioctl };
#line 4935
allow crond_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4935

#line 4935
# Access file descriptions, pipes, and sockets
#line 4935
# created by processes in the same domain.
#line 4935
allow crond_t self:fd *;
#line 4935
allow crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4935
allow crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4935
allow crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4935

#line 4935
# Allow the domain to communicate with other processes in the same domain.
#line 4935
allow crond_t self:unix_dgram_socket sendto;
#line 4935
allow crond_t self:unix_stream_socket connectto;
#line 4935

#line 4935
# Access System V IPC objects created by processes in the same domain.
#line 4935
allow crond_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4935
allow crond_t self:msg  { send receive };
#line 4935
allow crond_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4935
allow crond_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4935


# Type for the anacron executable.
type anacron_exec_t, file_type, sysadmfile, exec_type;

# Type for temporary files.

#line 4941
type crond_tmp_t, file_type, sysadmfile, tmpfile ;
#line 4941

#line 4941

#line 4941

#line 4941

#line 4941
#
#line 4941
# Allow the process to modify the directory.
#line 4941
#
#line 4941
allow crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4941

#line 4941
#
#line 4941
# Allow the process to create the file.
#line 4941
#
#line 4941

#line 4941
allow crond_t crond_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4941
allow crond_t crond_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4941

#line 4941

#line 4941
type_transition crond_t tmp_t:dir crond_tmp_t;
#line 4941
type_transition crond_t tmp_t:{ file lnk_file sock_file fifo_file } crond_tmp_t;
#line 4941

#line 4941

#line 4941

#line 4941


# Domain for system cron jobs.
type system_crond_t, domain, privlog, privmail;

# Read and write console and ttys.
allow system_crond_t devtty_t:chr_file { ioctl read getattr lock write append };

# Read system information files in /proc.
allow system_crond_t proc_t:dir { read getattr lock search ioctl };
allow system_crond_t proc_t:file { read getattr lock ioctl };
allow system_crond_t proc_t:lnk_file read;

#line 4956


# to stop killall type operations from filling our logs
dontaudit system_crond_t domain:dir search;

# read files in /etc
allow system_crond_t etc_t:{ file lnk_file } { read getattr lock ioctl };
allow system_crond_t etc_runtime_t:file read;


#line 4965
allow { crond_t system_crond_t } etc_t:lnk_file read;
#line 4965

#line 4965
allow { crond_t system_crond_t } locale_t:dir { read getattr lock search ioctl };
#line 4965
allow { crond_t system_crond_t } locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 4965

#line 4965


# Type for log files.
type cron_log_t, file_type, sysadmfile, logfile;
# Use this type when creating files in /var/log.

#line 4970

#line 4970

#line 4970

#line 4970
#
#line 4970
# Allow the process to modify the directory.
#line 4970
#
#line 4970
allow crond_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4970

#line 4970
#
#line 4970
# Allow the process to create the file.
#line 4970
#
#line 4970

#line 4970
allow crond_t cron_log_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4970
allow crond_t cron_log_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4970

#line 4970

#line 4970
type_transition crond_t var_log_t:dir cron_log_t;
#line 4970
type_transition crond_t var_log_t:{ file lnk_file sock_file fifo_file } cron_log_t;
#line 4970

#line 4970

#line 4970


# Use capabilities.
allow crond_t crond_t:capability { setgid setuid net_bind_service };

# Get security policy decisions.

#line 4976
allow crond_t security_t:dir { read search getattr };
#line 4976
allow crond_t security_t:file { getattr read write };
#line 4976
allow crond_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 4976


# for finding binaries and /bin/sh
allow crond_t { bin_t sbin_t }:dir search;
allow crond_t bin_t:lnk_file read;

# Read from /var/spool/cron.
allow crond_t var_lib_t:dir search;
allow crond_t var_spool_t:dir { read getattr lock search ioctl };
allow crond_t cron_spool_t:dir { read getattr lock search ioctl };
allow crond_t cron_spool_t:file { read getattr lock ioctl };

# Read system crontabs
allow crond_t system_crond_script_t:file { read getattr lock ioctl };
allow crond_t system_crond_script_t:dir { read getattr lock search ioctl };

# Read /etc/security/default_contexts.
allow crond_t default_context_t:file { read getattr lock ioctl };

allow crond_t etc_t:file { getattr read };
allow crond_t etc_t:lnk_file read;

# crond tries to search /root.  Not sure why.
allow crond_t sysadm_home_dir_t:dir { read getattr lock search ioctl };

# to search /home
allow crond_t home_root_t:dir { getattr search };
allow crond_t user_home_dir_type:dir { read getattr lock search ioctl };

# Run a shell.

#line 5006
allow crond_t shell_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5006


#line 5014


# This system_r role is authorized for this domain.
role system_r types system_crond_t;


#line 5019
allow system_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5019
allow system_crond_t lib_t:lnk_file { read getattr lock ioctl };
#line 5019
allow system_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 5019
allow system_crond_t ld_so_t:file execute_no_trans;
#line 5019
allow system_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5019
allow system_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 5019
allow system_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5019
allow system_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5019
allow system_crond_t device_t:dir search;
#line 5019
allow system_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5019
;

#line 5020
# Access other processes in the same domain.
#line 5020
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 5020
# separately if desired.
#line 5020
allow system_crond_t self:process ~{ptrace setexec setfscreate};
#line 5020

#line 5020
# Access /proc/PID files for processes in the same domain.
#line 5020
allow system_crond_t self:dir { read getattr lock search ioctl };
#line 5020
allow system_crond_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5020

#line 5020
# Access file descriptions, pipes, and sockets
#line 5020
# created by processes in the same domain.
#line 5020
allow system_crond_t self:fd *;
#line 5020
allow system_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 5020
allow system_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5020
allow system_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5020

#line 5020
# Allow the domain to communicate with other processes in the same domain.
#line 5020
allow system_crond_t self:unix_dgram_socket sendto;
#line 5020
allow system_crond_t self:unix_stream_socket connectto;
#line 5020

#line 5020
# Access System V IPC objects created by processes in the same domain.
#line 5020
allow system_crond_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5020
allow system_crond_t self:msg  { send receive };
#line 5020
allow system_crond_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5020
allow system_crond_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5020
;
allow system_crond_t var_log_t:file { read getattr lock ioctl };

# Type for system crontab files.
type system_crond_script_t, file_type, sysadmfile;

# Permit crond_t to transition to this domain.
# The transition is requested explicitly by the modified crond 
# via execve_secure.  There is no way to set up an automatic
# transition, since crontabs are configuration files, not executables.

#line 5030

#line 5030
#
#line 5030
# Allow the process to transition to the new domain.
#line 5030
#
#line 5030
allow crond_t system_crond_t:process transition;
#line 5030

#line 5030
#
#line 5030
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5030
#
#line 5030
dontaudit crond_t system_crond_t:process noatsecure;
#line 5030

#line 5030
#
#line 5030
# Allow the process to execute the program.
#line 5030
# 
#line 5030
allow crond_t shell_exec_t:file { read { getattr execute } };
#line 5030

#line 5030
#
#line 5030
# Allow the process to reap the new domain.
#line 5030
#
#line 5030
allow system_crond_t crond_t:process sigchld;
#line 5030

#line 5030
#
#line 5030
# Allow the new domain to inherit and use file 
#line 5030
# descriptions from the creating process and vice versa.
#line 5030
#
#line 5030
allow system_crond_t crond_t:fd use;
#line 5030
allow crond_t system_crond_t:fd use;
#line 5030

#line 5030
#
#line 5030
# Allow the new domain to write back to the old domain via a pipe.
#line 5030
#
#line 5030
allow system_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 5030

#line 5030
#
#line 5030
# Allow the new domain to read and execute the program.
#line 5030
#
#line 5030
allow system_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 5030

#line 5030
#
#line 5030
# Allow the new domain to be entered via the program.
#line 5030
#
#line 5030
allow system_crond_t shell_exec_t:file entrypoint;
#line 5030


# Set exec context.

#line 5033
allow crond_t self:process setexec;
#line 5033
allow crond_t proc_t:dir search;
#line 5033
allow crond_t proc_t:lnk_file read;
#line 5033
allow crond_t self:dir search;
#line 5033
allow crond_t self:file { read write };
#line 5033


# Transition to this domain for anacron as well.
# Still need to study anacron.

#line 5037

#line 5037

#line 5037
#
#line 5037
# Allow the process to transition to the new domain.
#line 5037
#
#line 5037
allow initrc_t system_crond_t:process transition;
#line 5037

#line 5037
#
#line 5037
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5037
#
#line 5037
dontaudit initrc_t system_crond_t:process noatsecure;
#line 5037

#line 5037
#
#line 5037
# Allow the process to execute the program.
#line 5037
# 
#line 5037
allow initrc_t anacron_exec_t:file { read { getattr execute } };
#line 5037

#line 5037
#
#line 5037
# Allow the process to reap the new domain.
#line 5037
#
#line 5037
allow system_crond_t initrc_t:process sigchld;
#line 5037

#line 5037
#
#line 5037
# Allow the new domain to inherit and use file 
#line 5037
# descriptions from the creating process and vice versa.
#line 5037
#
#line 5037
allow system_crond_t initrc_t:fd use;
#line 5037
allow initrc_t system_crond_t:fd use;
#line 5037

#line 5037
#
#line 5037
# Allow the new domain to write back to the old domain via a pipe.
#line 5037
#
#line 5037
allow system_crond_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5037

#line 5037
#
#line 5037
# Allow the new domain to read and execute the program.
#line 5037
#
#line 5037
allow system_crond_t anacron_exec_t:file { read getattr lock execute ioctl };
#line 5037

#line 5037
#
#line 5037
# Allow the new domain to be entered via the program.
#line 5037
#
#line 5037
allow system_crond_t anacron_exec_t:file entrypoint;
#line 5037

#line 5037
type_transition initrc_t anacron_exec_t:process system_crond_t;
#line 5037


# Access log files

#line 5040

#line 5040

#line 5040

#line 5040
#
#line 5040
# Allow the process to modify the directory.
#line 5040
#
#line 5040
allow system_crond_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5040

#line 5040
#
#line 5040
# Allow the process to create the file.
#line 5040
#
#line 5040

#line 5040
allow system_crond_t cron_log_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5040
allow system_crond_t cron_log_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5040

#line 5040

#line 5040
type_transition system_crond_t var_log_t:dir cron_log_t;
#line 5040
type_transition system_crond_t var_log_t:{ file lnk_file sock_file fifo_file } cron_log_t;
#line 5040

#line 5040

#line 5040


# Inherit and use descriptors from init.
allow system_crond_t init_t:fd use;

# Inherit and use descriptors from initrc.
allow system_crond_t initrc_t:fd use;

# Write to a socket from initrc.
allow system_crond_t initrc_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Use capabilities.
allow system_crond_t system_crond_t:capability { setgid setuid dac_override fowner net_bind_service fsetid };

# Read the system crontabs.
allow system_crond_t system_crond_script_t:file { read getattr lock ioctl };

# 
# Since crontab files are not directly executed,
# crond must ensure that the crontab file has
# a type that is appropriate for the domain of
# the system cron job.  It performs an entrypoint
# permission check for this purpose.
#
allow system_crond_t system_crond_script_t:file entrypoint;
#line 5067


# Run helper programs in the system_crond_t domain.
allow system_crond_t { bin_t sbin_t }:dir { read getattr lock search ioctl };
allow system_crond_t { bin_t sbin_t }:lnk_file read;

#line 5072
allow system_crond_t { bin_t sbin_t exec_type etc_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5072


# Read from /var/spool/cron.
allow system_crond_t cron_spool_t:dir { read getattr lock search ioctl };
allow system_crond_t cron_spool_t:file { read getattr lock ioctl };

# Write to /var/lib/slocate.db.
allow system_crond_t var_lib_t:dir { read getattr lock search ioctl add_name remove_name write };
allow system_crond_t var_lib_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Update whatis files.
allow system_crond_t catman_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
allow system_crond_t catman_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow system_crond_t man_t:file { read getattr lock ioctl };
allow system_crond_t man_t:lnk_file read;

# Write /var/lock/makewhatis.lock.

#line 5089
type system_crond_lock_t, file_type, sysadmfile, lockfile;
#line 5089

#line 5089

#line 5089

#line 5089

#line 5089
#
#line 5089
# Allow the process to modify the directory.
#line 5089
#
#line 5089
allow system_crond_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5089

#line 5089
#
#line 5089
# Allow the process to create the file.
#line 5089
#
#line 5089

#line 5089

#line 5089
allow system_crond_t system_crond_lock_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5089

#line 5089

#line 5089
type_transition system_crond_t var_lock_t:file system_crond_lock_t;
#line 5089

#line 5089

#line 5089

#line 5089


# Modutils are now combined, so we can no longer distinguish them.
# Let crond run the insmod executable in the insmod_t domain.
#line 5095

#line 5095

#line 5095

#line 5095

#line 5095

#line 5095
#
#line 5095
# Allow the process to transition to the new domain.
#line 5095
#
#line 5095
allow system_crond_t insmod_t:process transition;
#line 5095

#line 5095
#
#line 5095
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5095
#
#line 5095
dontaudit system_crond_t insmod_t:process noatsecure;
#line 5095

#line 5095
#
#line 5095
# Allow the process to execute the program.
#line 5095
# 
#line 5095
allow system_crond_t insmod_exec_t:file { read { getattr execute } };
#line 5095

#line 5095
#
#line 5095
# Allow the process to reap the new domain.
#line 5095
#
#line 5095
allow insmod_t system_crond_t:process sigchld;
#line 5095

#line 5095
#
#line 5095
# Allow the new domain to inherit and use file 
#line 5095
# descriptions from the creating process and vice versa.
#line 5095
#
#line 5095
allow insmod_t system_crond_t:fd use;
#line 5095
allow system_crond_t insmod_t:fd use;
#line 5095

#line 5095
#
#line 5095
# Allow the new domain to write back to the old domain via a pipe.
#line 5095
#
#line 5095
allow insmod_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 5095

#line 5095
#
#line 5095
# Allow the new domain to read and execute the program.
#line 5095
#
#line 5095
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 5095

#line 5095
#
#line 5095
# Allow the new domain to be entered via the program.
#line 5095
#
#line 5095
allow insmod_t insmod_exec_t:file entrypoint;
#line 5095

#line 5095
type_transition system_crond_t insmod_exec_t:process insmod_t;
#line 5095

#line 5095
allow insmod_t crond_t:fifo_file { getattr read write ioctl };
#line 5095
# a rule for privfd may make this obsolete
#line 5095
allow insmod_t crond_t:fd use;
#line 5095
allow insmod_t crond_t:process sigchld;
#line 5095

#line 5095


# for if /var/mail is a symlink
allow crond_t mail_spool_t:lnk_file read;

# Run logrotate in the logrotate_t domain.
#line 5103

#line 5103

#line 5103

#line 5103

#line 5103

#line 5103
#
#line 5103
# Allow the process to transition to the new domain.
#line 5103
#
#line 5103
allow system_crond_t logrotate_t:process transition;
#line 5103

#line 5103
#
#line 5103
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5103
#
#line 5103
dontaudit system_crond_t logrotate_t:process noatsecure;
#line 5103

#line 5103
#
#line 5103
# Allow the process to execute the program.
#line 5103
# 
#line 5103
allow system_crond_t logrotate_exec_t:file { read { getattr execute } };
#line 5103

#line 5103
#
#line 5103
# Allow the process to reap the new domain.
#line 5103
#
#line 5103
allow logrotate_t system_crond_t:process sigchld;
#line 5103

#line 5103
#
#line 5103
# Allow the new domain to inherit and use file 
#line 5103
# descriptions from the creating process and vice versa.
#line 5103
#
#line 5103
allow logrotate_t system_crond_t:fd use;
#line 5103
allow system_crond_t logrotate_t:fd use;
#line 5103

#line 5103
#
#line 5103
# Allow the new domain to write back to the old domain via a pipe.
#line 5103
#
#line 5103
allow logrotate_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 5103

#line 5103
#
#line 5103
# Allow the new domain to read and execute the program.
#line 5103
#
#line 5103
allow logrotate_t logrotate_exec_t:file { read getattr lock execute ioctl };
#line 5103

#line 5103
#
#line 5103
# Allow the new domain to be entered via the program.
#line 5103
#
#line 5103
allow logrotate_t logrotate_exec_t:file entrypoint;
#line 5103

#line 5103
type_transition system_crond_t logrotate_exec_t:process logrotate_t;
#line 5103

#line 5103
allow logrotate_t crond_t:fifo_file { getattr read write ioctl };
#line 5103
# a rule for privfd may make this obsolete
#line 5103
allow logrotate_t crond_t:fd use;
#line 5103
allow logrotate_t crond_t:process sigchld;
#line 5103

#line 5103


#line 5107


# Stat any file and search any directory for find.
allow system_crond_t file_type:{ file lnk_file sock_file fifo_file chr_file blk_file } getattr;
allow system_crond_t file_type:dir { read search getattr };

# Create temporary files.
type system_crond_tmp_t, file_type, sysadmfile, tmpfile;

#line 5115

#line 5115

#line 5115

#line 5115
#
#line 5115
# Allow the process to modify the directory.
#line 5115
#
#line 5115
allow system_crond_t { tmp_t crond_tmp_t }:dir { read getattr lock search ioctl add_name remove_name write };
#line 5115

#line 5115
#
#line 5115
# Allow the process to create the file.
#line 5115
#
#line 5115

#line 5115
allow system_crond_t system_crond_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5115
allow system_crond_t system_crond_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5115

#line 5115

#line 5115
type_transition system_crond_t { tmp_t crond_tmp_t }:dir system_crond_tmp_t;
#line 5115
type_transition system_crond_t { tmp_t crond_tmp_t }:{ file lnk_file sock_file fifo_file } system_crond_tmp_t;
#line 5115

#line 5115

#line 5115


# /sbin/runlevel ask for w access to utmp, but will operate
# correctly without it.  Do not audit write denials to utmp.
dontaudit system_crond_t initrc_var_run_t:file { read write };

# Access accounting summary files.
allow system_crond_t var_log_sa_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow system_crond_t var_log_sa_t:dir { read getattr lock search ioctl add_name remove_name write };

allow system_crond_t fs_t:filesystem getattr;

allow system_crond_t { sysctl_t sysctl_kernel_t }:dir search;
allow system_crond_t sysctl_kernel_t:file { getattr read };

# Access other spool directories like
# /var/spool/anacron and /var/spool/slrnpull.
allow system_crond_t var_spool_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow system_crond_t var_spool_t:dir { read getattr lock search ioctl add_name remove_name write };

# Do not audit attempts to search unlabeled directories (e.g. slocate).
dontaudit system_crond_t unlabeled_t:dir { read getattr lock search ioctl };
dontaudit system_crond_t unlabeled_t:file { read getattr lock ioctl };

#DESC Crontab - Crontab manipulation programs
#
# Domains for the crontab program.
#
# X-Debian-Packages: cron
#

# Type for the crontab executable.
type crontab_exec_t, file_type, sysadmfile, exec_type;

# Everything else is in the crontab_domain macro in
# macros/program/crontab_macros.te.
#DESC Fsadm - Disk and file system administration
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: util-linux e2fsprogs xfsprogs reiserfsprogs parted raidtools2 mount
#

#################################
#
# Rules for the fsadm_t domain.
#
# fsadm_t is the domain for disk and file system
# administration.
# fsadm_exec_t is the type of the corresponding programs.
#
type fsadm_t, domain, privlog;
role system_r types fsadm_t;
role sysadm_r types fsadm_t;


#line 5169
# Access other processes in the same domain.
#line 5169
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 5169
# separately if desired.
#line 5169
allow fsadm_t self:process ~{ptrace setexec setfscreate};
#line 5169

#line 5169
# Access /proc/PID files for processes in the same domain.
#line 5169
allow fsadm_t self:dir { read getattr lock search ioctl };
#line 5169
allow fsadm_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5169

#line 5169
# Access file descriptions, pipes, and sockets
#line 5169
# created by processes in the same domain.
#line 5169
allow fsadm_t self:fd *;
#line 5169
allow fsadm_t self:fifo_file { ioctl read getattr lock write append };
#line 5169
allow fsadm_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5169
allow fsadm_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5169

#line 5169
# Allow the domain to communicate with other processes in the same domain.
#line 5169
allow fsadm_t self:unix_dgram_socket sendto;
#line 5169
allow fsadm_t self:unix_stream_socket connectto;
#line 5169

#line 5169
# Access System V IPC objects created by processes in the same domain.
#line 5169
allow fsadm_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5169
allow fsadm_t self:msg  { send receive };
#line 5169
allow fsadm_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5169
allow fsadm_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5169


# Read system information files in /proc.
allow fsadm_t proc_t:dir { read getattr lock search ioctl };
allow fsadm_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# Read system variables in /proc/sys
allow fsadm_t sysctl_kernel_t:file { read getattr lock ioctl };
allow fsadm_t sysctl_kernel_t:dir { read getattr lock search ioctl };


#line 5179
# Read /.
#line 5179
allow fsadm_t root_t:dir { read getattr lock search ioctl };
#line 5179
allow fsadm_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5179

#line 5179
# Read /home.
#line 5179
allow fsadm_t home_root_t:dir { read getattr lock search ioctl };
#line 5179

#line 5179
# Read /usr.
#line 5179
allow fsadm_t usr_t:dir { read getattr lock search ioctl };
#line 5179
allow fsadm_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5179

#line 5179
# Read bin and sbin directories.
#line 5179
allow fsadm_t bin_t:dir { read getattr lock search ioctl };
#line 5179
allow fsadm_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5179
allow fsadm_t sbin_t:dir { read getattr lock search ioctl };
#line 5179
allow fsadm_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5179


# Read /etc.
allow fsadm_t etc_t:dir { read getattr lock search ioctl };
allow fsadm_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# Read module-related files.
allow fsadm_t modules_conf_t:{ file lnk_file } { read getattr lock ioctl };

# Read /dev directories and any symbolic links.
allow fsadm_t device_t:dir { read getattr lock search ioctl };
allow fsadm_t device_t:lnk_file { read getattr lock ioctl };


#line 5192
allow fsadm_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5192
allow fsadm_t lib_t:lnk_file { read getattr lock ioctl };
#line 5192
allow fsadm_t ld_so_t:file { read getattr lock execute ioctl };
#line 5192
allow fsadm_t ld_so_t:file execute_no_trans;
#line 5192
allow fsadm_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5192
allow fsadm_t shlib_t:file { read getattr lock execute ioctl };
#line 5192
allow fsadm_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5192
allow fsadm_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5192
allow fsadm_t device_t:dir search;
#line 5192
allow fsadm_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5192


type fsadm_exec_t, file_type, sysadmfile, exec_type;

#line 5195

#line 5195

#line 5195
#
#line 5195
# Allow the process to transition to the new domain.
#line 5195
#
#line 5195
allow initrc_t fsadm_t:process transition;
#line 5195

#line 5195
#
#line 5195
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5195
#
#line 5195
dontaudit initrc_t fsadm_t:process noatsecure;
#line 5195

#line 5195
#
#line 5195
# Allow the process to execute the program.
#line 5195
# 
#line 5195
allow initrc_t fsadm_exec_t:file { read { getattr execute } };
#line 5195

#line 5195
#
#line 5195
# Allow the process to reap the new domain.
#line 5195
#
#line 5195
allow fsadm_t initrc_t:process sigchld;
#line 5195

#line 5195
#
#line 5195
# Allow the new domain to inherit and use file 
#line 5195
# descriptions from the creating process and vice versa.
#line 5195
#
#line 5195
allow fsadm_t initrc_t:fd use;
#line 5195
allow initrc_t fsadm_t:fd use;
#line 5195

#line 5195
#
#line 5195
# Allow the new domain to write back to the old domain via a pipe.
#line 5195
#
#line 5195
allow fsadm_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5195

#line 5195
#
#line 5195
# Allow the new domain to read and execute the program.
#line 5195
#
#line 5195
allow fsadm_t fsadm_exec_t:file { read getattr lock execute ioctl };
#line 5195

#line 5195
#
#line 5195
# Allow the new domain to be entered via the program.
#line 5195
#
#line 5195
allow fsadm_t fsadm_exec_t:file entrypoint;
#line 5195

#line 5195
type_transition initrc_t fsadm_exec_t:process fsadm_t;
#line 5195


#line 5196

#line 5196

#line 5196
#
#line 5196
# Allow the process to transition to the new domain.
#line 5196
#
#line 5196
allow sysadm_t fsadm_t:process transition;
#line 5196

#line 5196
#
#line 5196
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5196
#
#line 5196
dontaudit sysadm_t fsadm_t:process noatsecure;
#line 5196

#line 5196
#
#line 5196
# Allow the process to execute the program.
#line 5196
# 
#line 5196
allow sysadm_t fsadm_exec_t:file { read { getattr execute } };
#line 5196

#line 5196
#
#line 5196
# Allow the process to reap the new domain.
#line 5196
#
#line 5196
allow fsadm_t sysadm_t:process sigchld;
#line 5196

#line 5196
#
#line 5196
# Allow the new domain to inherit and use file 
#line 5196
# descriptions from the creating process and vice versa.
#line 5196
#
#line 5196
allow fsadm_t sysadm_t:fd use;
#line 5196
allow sysadm_t fsadm_t:fd use;
#line 5196

#line 5196
#
#line 5196
# Allow the new domain to write back to the old domain via a pipe.
#line 5196
#
#line 5196
allow fsadm_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5196

#line 5196
#
#line 5196
# Allow the new domain to read and execute the program.
#line 5196
#
#line 5196
allow fsadm_t fsadm_exec_t:file { read getattr lock execute ioctl };
#line 5196

#line 5196
#
#line 5196
# Allow the new domain to be entered via the program.
#line 5196
#
#line 5196
allow fsadm_t fsadm_exec_t:file entrypoint;
#line 5196

#line 5196
type_transition sysadm_t fsadm_exec_t:process fsadm_t;
#line 5196


type fsadm_tmp_t, file_type, sysadmfile, tmpfile;

#line 5199

#line 5199

#line 5199

#line 5199
#
#line 5199
# Allow the process to modify the directory.
#line 5199
#
#line 5199
allow fsadm_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5199

#line 5199
#
#line 5199
# Allow the process to create the file.
#line 5199
#
#line 5199

#line 5199
allow fsadm_t fsadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5199
allow fsadm_t fsadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5199

#line 5199

#line 5199
type_transition fsadm_t tmp_t:dir fsadm_tmp_t;
#line 5199
type_transition fsadm_t tmp_t:{ file lnk_file sock_file fifo_file } fsadm_tmp_t;
#line 5199

#line 5199

#line 5199


# remount file system to apply changes
allow fsadm_t fs_t:filesystem remount;

# mkreiserfs needs this
allow fsadm_t proc_t:filesystem getattr;

# mkreiserfs and other programs need this for UUID
allow fsadm_t random_device_t:chr_file { getattr read };

# Use capabilities.  ipc_lock is for losetup
allow fsadm_t self:capability { ipc_lock sys_rawio sys_admin };

# Write to /etc/mtab.

#line 5214

#line 5214

#line 5214

#line 5214
#
#line 5214
# Allow the process to modify the directory.
#line 5214
#
#line 5214
allow fsadm_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5214

#line 5214
#
#line 5214
# Allow the process to create the file.
#line 5214
#
#line 5214

#line 5214

#line 5214
allow fsadm_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5214

#line 5214

#line 5214
type_transition fsadm_t etc_t:file etc_runtime_t;
#line 5214

#line 5214

#line 5214


# Inherit and use descriptors from init.
allow fsadm_t init_t:fd use;

# Run other fs admin programs in the fsadm_t domain.

#line 5220
allow fsadm_t fsadm_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5220


# Access disk devices.
allow fsadm_t fixed_disk_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };
allow fsadm_t removable_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };

# Access lost+found.
allow fsadm_t lost_found_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
allow fsadm_t lost_found_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };

# Recreate /mnt/cdrom. 
allow fsadm_t file_t:dir { search read getattr rmdir create };

# Recreate /dev/cdrom.
allow fsadm_t device_t:dir { read getattr lock search ioctl add_name remove_name write };
allow fsadm_t device_t:lnk_file { unlink create };

# Enable swapping to devices and files
allow fsadm_t swapfile_t:file { getattr swapon };
allow fsadm_t fixed_disk_device_t:blk_file { getattr swapon };

# XXX Why does updfstab run insmod?

#line 5242

#line 5242

#line 5242
#
#line 5242
# Allow the process to transition to the new domain.
#line 5242
#
#line 5242
allow fsadm_t insmod_t:process transition;
#line 5242

#line 5242
#
#line 5242
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5242
#
#line 5242
dontaudit fsadm_t insmod_t:process noatsecure;
#line 5242

#line 5242
#
#line 5242
# Allow the process to execute the program.
#line 5242
# 
#line 5242
allow fsadm_t insmod_exec_t:file { read { getattr execute } };
#line 5242

#line 5242
#
#line 5242
# Allow the process to reap the new domain.
#line 5242
#
#line 5242
allow insmod_t fsadm_t:process sigchld;
#line 5242

#line 5242
#
#line 5242
# Allow the new domain to inherit and use file 
#line 5242
# descriptions from the creating process and vice versa.
#line 5242
#
#line 5242
allow insmod_t fsadm_t:fd use;
#line 5242
allow fsadm_t insmod_t:fd use;
#line 5242

#line 5242
#
#line 5242
# Allow the new domain to write back to the old domain via a pipe.
#line 5242
#
#line 5242
allow insmod_t fsadm_t:fifo_file { ioctl read getattr lock write append };
#line 5242

#line 5242
#
#line 5242
# Allow the new domain to read and execute the program.
#line 5242
#
#line 5242
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 5242

#line 5242
#
#line 5242
# Allow the new domain to be entered via the program.
#line 5242
#
#line 5242
allow insmod_t insmod_exec_t:file entrypoint;
#line 5242

#line 5242
type_transition fsadm_t insmod_exec_t:process insmod_t;
#line 5242


# Allow console log change (updfstab)
allow fsadm_t kernel_t:system syslog_console;

# Access terminals.
allow fsadm_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };

allow fsadm_t privfd:fd use;


#line 5252
allow fsadm_t etc_t:lnk_file read;
#line 5252

#line 5252
allow fsadm_t locale_t:dir { read getattr lock search ioctl };
#line 5252
allow fsadm_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5252

#line 5252

#DESC Getty - Manage ttys
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: util-linux fbgetty mingetty mgetty rungetty
#

#################################
#
# Rules for the getty_t domain.
#

#line 5263

#line 5263
type getty_t, domain, privlog , mlstrustedwriter, privfd;
#line 5263
type getty_exec_t, file_type, sysadmfile, exec_type;
#line 5263

#line 5263
role system_r types getty_t;
#line 5263

#line 5263

#line 5263

#line 5263

#line 5263
#
#line 5263
# Allow the process to transition to the new domain.
#line 5263
#
#line 5263
allow initrc_t getty_t:process transition;
#line 5263

#line 5263
#
#line 5263
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5263
#
#line 5263
dontaudit initrc_t getty_t:process noatsecure;
#line 5263

#line 5263
#
#line 5263
# Allow the process to execute the program.
#line 5263
# 
#line 5263
allow initrc_t getty_exec_t:file { read { getattr execute } };
#line 5263

#line 5263
#
#line 5263
# Allow the process to reap the new domain.
#line 5263
#
#line 5263
allow getty_t initrc_t:process sigchld;
#line 5263

#line 5263
#
#line 5263
# Allow the new domain to inherit and use file 
#line 5263
# descriptions from the creating process and vice versa.
#line 5263
#
#line 5263
allow getty_t initrc_t:fd use;
#line 5263
allow initrc_t getty_t:fd use;
#line 5263

#line 5263
#
#line 5263
# Allow the new domain to write back to the old domain via a pipe.
#line 5263
#
#line 5263
allow getty_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5263

#line 5263
#
#line 5263
# Allow the new domain to read and execute the program.
#line 5263
#
#line 5263
allow getty_t getty_exec_t:file { read getattr lock execute ioctl };
#line 5263

#line 5263
#
#line 5263
# Allow the new domain to be entered via the program.
#line 5263
#
#line 5263
allow getty_t getty_exec_t:file entrypoint;
#line 5263

#line 5263
type_transition initrc_t getty_exec_t:process getty_t;
#line 5263

#line 5263

#line 5263
# Inherit and use descriptors from init.
#line 5263
allow getty_t init_t:fd use;
#line 5263
allow getty_t init_t:process sigchld;
#line 5263
allow getty_t privfd:fd use;
#line 5263
allow getty_t newrole_t:process sigchld;
#line 5263
allow getty_t self:process { { sigchld sigkill sigstop signull signal } fork };
#line 5263

#line 5263

#line 5263
allow getty_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5263
allow getty_t lib_t:lnk_file { read getattr lock ioctl };
#line 5263
allow getty_t ld_so_t:file { read getattr lock execute ioctl };
#line 5263
allow getty_t ld_so_t:file execute_no_trans;
#line 5263
allow getty_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5263
allow getty_t shlib_t:file { read getattr lock execute ioctl };
#line 5263
allow getty_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5263
allow getty_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5263
allow getty_t device_t:dir search;
#line 5263
allow getty_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5263

#line 5263

#line 5263
allow getty_t { self proc_t }:dir { read getattr lock search ioctl };
#line 5263
allow getty_t { self proc_t }:lnk_file read;
#line 5263

#line 5263
allow getty_t device_t:dir { getattr search };
#line 5263
allow getty_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5263
allow getty_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 5263
allow getty_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 5263

#line 5263
# Create pid file.
#line 5263
allow getty_t var_t:dir { getattr search };
#line 5263

#line 5263
type getty_var_run_t alias var_run_getty_t, file_type, sysadmfile, pidfile;
#line 5263

#line 5263

#line 5263

#line 5263

#line 5263
#
#line 5263
# Allow the process to modify the directory.
#line 5263
#
#line 5263
allow getty_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5263

#line 5263
#
#line 5263
# Allow the process to create the file.
#line 5263
#
#line 5263

#line 5263

#line 5263
allow getty_t getty_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5263

#line 5263

#line 5263
type_transition getty_t var_run_t:file getty_var_run_t;
#line 5263

#line 5263

#line 5263

#line 5263
allow getty_t getty_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5263

#line 5263

#line 5263
allow getty_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 5263

#line 5263
# for daemons that look at /root on startup
#line 5263
dontaudit getty_t sysadm_home_dir_t:dir search;
#line 5263

#line 5263
# for df
#line 5263
allow getty_t fs_type:filesystem getattr;
#line 5263

#line 5263

#line 5263
allow getty_t etc_t:lnk_file read;
#line 5263

#line 5263
allow getty_t locale_t:dir { read getattr lock search ioctl };
#line 5263
allow getty_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5263

#line 5263

#line 5263


type etc_getty_t, file_type, sysadmfile;

#line 5266
allow getty_t etc_getty_t:dir { read getattr lock search ioctl };
#line 5266
allow getty_t etc_getty_t:{ file lnk_file } { read getattr lock ioctl };
#line 5266


allow getty_t console_device_t:chr_file setattr;


#line 5270
type getty_tmp_t, file_type, sysadmfile, tmpfile ;
#line 5270

#line 5270

#line 5270

#line 5270

#line 5270
#
#line 5270
# Allow the process to modify the directory.
#line 5270
#
#line 5270
allow getty_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5270

#line 5270
#
#line 5270
# Allow the process to create the file.
#line 5270
#
#line 5270

#line 5270
allow getty_t getty_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5270
allow getty_t getty_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5270

#line 5270

#line 5270
type_transition getty_t tmp_t:dir getty_tmp_t;
#line 5270
type_transition getty_t tmp_t:{ file lnk_file sock_file fifo_file } getty_tmp_t;
#line 5270

#line 5270

#line 5270

#line 5270


#line 5271
type getty_log_t, file_type, sysadmfile, logfile;
#line 5271

#line 5271

#line 5271

#line 5271

#line 5271
#
#line 5271
# Allow the process to modify the directory.
#line 5271
#
#line 5271
allow getty_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5271

#line 5271
#
#line 5271
# Allow the process to create the file.
#line 5271
#
#line 5271

#line 5271
allow getty_t getty_log_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5271
allow getty_t getty_log_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5271

#line 5271

#line 5271
type_transition getty_t var_log_t:dir getty_log_t;
#line 5271
type_transition getty_t var_log_t:{ file lnk_file sock_file fifo_file } getty_log_t;
#line 5271

#line 5271

#line 5271

#line 5271


allow getty_t { etc_t etc_runtime_t }:file { getattr read };
allow getty_t etc_t:lnk_file read;
allow getty_t self:process { getpgid getsession };
allow getty_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow getty_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# for ldap and other authentication services
allow getty_t resolv_conf_t:file { getattr read };

# to allow w to display everyone...
#allow userdomain ttyfile:chr_file getattr;

# Use capabilities.
allow getty_t getty_t:capability { dac_override chown sys_tty_config };

# fbgetty needs fsetid for some reason
allow getty_t getty_t:capability fsetid;

# Run getty in its own domain.

#line 5292

#line 5292

#line 5292
#
#line 5292
# Allow the process to transition to the new domain.
#line 5292
#
#line 5292
allow init_t getty_t:process transition;
#line 5292

#line 5292
#
#line 5292
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5292
#
#line 5292
dontaudit init_t getty_t:process noatsecure;
#line 5292

#line 5292
#
#line 5292
# Allow the process to execute the program.
#line 5292
# 
#line 5292
allow init_t getty_exec_t:file { read { getattr execute } };
#line 5292

#line 5292
#
#line 5292
# Allow the process to reap the new domain.
#line 5292
#
#line 5292
allow getty_t init_t:process sigchld;
#line 5292

#line 5292
#
#line 5292
# Allow the new domain to inherit and use file 
#line 5292
# descriptions from the creating process and vice versa.
#line 5292
#
#line 5292
allow getty_t init_t:fd use;
#line 5292
allow init_t getty_t:fd use;
#line 5292

#line 5292
#
#line 5292
# Allow the new domain to write back to the old domain via a pipe.
#line 5292
#
#line 5292
allow getty_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5292

#line 5292
#
#line 5292
# Allow the new domain to read and execute the program.
#line 5292
#
#line 5292
allow getty_t getty_exec_t:file { read getattr lock execute ioctl };
#line 5292

#line 5292
#
#line 5292
# Allow the new domain to be entered via the program.
#line 5292
#
#line 5292
allow getty_t getty_exec_t:file entrypoint;
#line 5292

#line 5292
type_transition init_t getty_exec_t:process getty_t;
#line 5292


# Inherit and use descriptors from init.
allow getty_t init_t:fd use;

# Run login in local_login_t domain.
allow getty_t bin_t:dir search;

#line 5299

#line 5299

#line 5299
#
#line 5299
# Allow the process to transition to the new domain.
#line 5299
#
#line 5299
allow getty_t local_login_t:process transition;
#line 5299

#line 5299
#
#line 5299
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5299
#
#line 5299
dontaudit getty_t local_login_t:process noatsecure;
#line 5299

#line 5299
#
#line 5299
# Allow the process to execute the program.
#line 5299
# 
#line 5299
allow getty_t login_exec_t:file { read { getattr execute } };
#line 5299

#line 5299
#
#line 5299
# Allow the process to reap the new domain.
#line 5299
#
#line 5299
allow local_login_t getty_t:process sigchld;
#line 5299

#line 5299
#
#line 5299
# Allow the new domain to inherit and use file 
#line 5299
# descriptions from the creating process and vice versa.
#line 5299
#
#line 5299
allow local_login_t getty_t:fd use;
#line 5299
allow getty_t local_login_t:fd use;
#line 5299

#line 5299
#
#line 5299
# Allow the new domain to write back to the old domain via a pipe.
#line 5299
#
#line 5299
allow local_login_t getty_t:fifo_file { ioctl read getattr lock write append };
#line 5299

#line 5299
#
#line 5299
# Allow the new domain to read and execute the program.
#line 5299
#
#line 5299
allow local_login_t login_exec_t:file { read getattr lock execute ioctl };
#line 5299

#line 5299
#
#line 5299
# Allow the new domain to be entered via the program.
#line 5299
#
#line 5299
allow local_login_t login_exec_t:file entrypoint;
#line 5299

#line 5299
type_transition getty_t login_exec_t:process local_login_t;
#line 5299


# Write to /var/run/utmp.
allow getty_t initrc_var_run_t:file { ioctl read getattr lock write append };

# Write to /var/log/wtmp.
allow getty_t wtmp_t:file { ioctl read getattr lock write append };

# Chown, chmod, read and write ttys.
allow getty_t tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
allow getty_t ttyfile:chr_file { setattr { ioctl read getattr lock write append } };



#line 5312
allow getty_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5312
allow getty_t var_lock_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5312

#DESC Ifconfig - Configure network interfaces
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: net-tools
#

#################################
#
# Rules for the ifconfig_t domain.
#
# ifconfig_t is the domain for the ifconfig program.
# ifconfig_exec_t is the type of the corresponding program.
#
type ifconfig_t, domain, privlog;
type ifconfig_exec_t, file_type, sysadmfile, exec_type;

role system_r types ifconfig_t;
role sysadm_r types ifconfig_t;


#line 5332
allow ifconfig_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5332
allow ifconfig_t lib_t:lnk_file { read getattr lock ioctl };
#line 5332
allow ifconfig_t ld_so_t:file { read getattr lock execute ioctl };
#line 5332
allow ifconfig_t ld_so_t:file execute_no_trans;
#line 5332
allow ifconfig_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5332
allow ifconfig_t shlib_t:file { read getattr lock execute ioctl };
#line 5332
allow ifconfig_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5332
allow ifconfig_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5332
allow ifconfig_t device_t:dir search;
#line 5332
allow ifconfig_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5332


#line 5333
# Access other processes in the same domain.
#line 5333
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 5333
# separately if desired.
#line 5333
allow ifconfig_t self:process ~{ptrace setexec setfscreate};
#line 5333

#line 5333
# Access /proc/PID files for processes in the same domain.
#line 5333
allow ifconfig_t self:dir { read getattr lock search ioctl };
#line 5333
allow ifconfig_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5333

#line 5333
# Access file descriptions, pipes, and sockets
#line 5333
# created by processes in the same domain.
#line 5333
allow ifconfig_t self:fd *;
#line 5333
allow ifconfig_t self:fifo_file { ioctl read getattr lock write append };
#line 5333
allow ifconfig_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5333
allow ifconfig_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5333

#line 5333
# Allow the domain to communicate with other processes in the same domain.
#line 5333
allow ifconfig_t self:unix_dgram_socket sendto;
#line 5333
allow ifconfig_t self:unix_stream_socket connectto;
#line 5333

#line 5333
# Access System V IPC objects created by processes in the same domain.
#line 5333
allow ifconfig_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5333
allow ifconfig_t self:msg  { send receive };
#line 5333
allow ifconfig_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5333
allow ifconfig_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5333



#line 5335

#line 5335

#line 5335
#
#line 5335
# Allow the process to transition to the new domain.
#line 5335
#
#line 5335
allow initrc_t ifconfig_t:process transition;
#line 5335

#line 5335
#
#line 5335
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5335
#
#line 5335
dontaudit initrc_t ifconfig_t:process noatsecure;
#line 5335

#line 5335
#
#line 5335
# Allow the process to execute the program.
#line 5335
# 
#line 5335
allow initrc_t ifconfig_exec_t:file { read { getattr execute } };
#line 5335

#line 5335
#
#line 5335
# Allow the process to reap the new domain.
#line 5335
#
#line 5335
allow ifconfig_t initrc_t:process sigchld;
#line 5335

#line 5335
#
#line 5335
# Allow the new domain to inherit and use file 
#line 5335
# descriptions from the creating process and vice versa.
#line 5335
#
#line 5335
allow ifconfig_t initrc_t:fd use;
#line 5335
allow initrc_t ifconfig_t:fd use;
#line 5335

#line 5335
#
#line 5335
# Allow the new domain to write back to the old domain via a pipe.
#line 5335
#
#line 5335
allow ifconfig_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5335

#line 5335
#
#line 5335
# Allow the new domain to read and execute the program.
#line 5335
#
#line 5335
allow ifconfig_t ifconfig_exec_t:file { read getattr lock execute ioctl };
#line 5335

#line 5335
#
#line 5335
# Allow the new domain to be entered via the program.
#line 5335
#
#line 5335
allow ifconfig_t ifconfig_exec_t:file entrypoint;
#line 5335

#line 5335
type_transition initrc_t ifconfig_exec_t:process ifconfig_t;
#line 5335


#line 5336

#line 5336

#line 5336
#
#line 5336
# Allow the process to transition to the new domain.
#line 5336
#
#line 5336
allow sysadm_t ifconfig_t:process transition;
#line 5336

#line 5336
#
#line 5336
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5336
#
#line 5336
dontaudit sysadm_t ifconfig_t:process noatsecure;
#line 5336

#line 5336
#
#line 5336
# Allow the process to execute the program.
#line 5336
# 
#line 5336
allow sysadm_t ifconfig_exec_t:file { read { getattr execute } };
#line 5336

#line 5336
#
#line 5336
# Allow the process to reap the new domain.
#line 5336
#
#line 5336
allow ifconfig_t sysadm_t:process sigchld;
#line 5336

#line 5336
#
#line 5336
# Allow the new domain to inherit and use file 
#line 5336
# descriptions from the creating process and vice versa.
#line 5336
#
#line 5336
allow ifconfig_t sysadm_t:fd use;
#line 5336
allow sysadm_t ifconfig_t:fd use;
#line 5336

#line 5336
#
#line 5336
# Allow the new domain to write back to the old domain via a pipe.
#line 5336
#
#line 5336
allow ifconfig_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5336

#line 5336
#
#line 5336
# Allow the new domain to read and execute the program.
#line 5336
#
#line 5336
allow ifconfig_t ifconfig_exec_t:file { read getattr lock execute ioctl };
#line 5336

#line 5336
#
#line 5336
# Allow the new domain to be entered via the program.
#line 5336
#
#line 5336
allow ifconfig_t ifconfig_exec_t:file entrypoint;
#line 5336

#line 5336
type_transition sysadm_t ifconfig_exec_t:process ifconfig_t;
#line 5336


# Use capabilities.
allow ifconfig_t ifconfig_t:capability { sys_module net_admin };

# Inherit and use descriptors from init.
allow ifconfig_t init_t:fd use;

# Execute insmod.

#line 5345

#line 5345

#line 5345
#
#line 5345
# Allow the process to transition to the new domain.
#line 5345
#
#line 5345
allow ifconfig_t insmod_t:process transition;
#line 5345

#line 5345
#
#line 5345
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5345
#
#line 5345
dontaudit ifconfig_t insmod_t:process noatsecure;
#line 5345

#line 5345
#
#line 5345
# Allow the process to execute the program.
#line 5345
# 
#line 5345
allow ifconfig_t insmod_exec_t:file { read { getattr execute } };
#line 5345

#line 5345
#
#line 5345
# Allow the process to reap the new domain.
#line 5345
#
#line 5345
allow insmod_t ifconfig_t:process sigchld;
#line 5345

#line 5345
#
#line 5345
# Allow the new domain to inherit and use file 
#line 5345
# descriptions from the creating process and vice versa.
#line 5345
#
#line 5345
allow insmod_t ifconfig_t:fd use;
#line 5345
allow ifconfig_t insmod_t:fd use;
#line 5345

#line 5345
#
#line 5345
# Allow the new domain to write back to the old domain via a pipe.
#line 5345
#
#line 5345
allow insmod_t ifconfig_t:fifo_file { ioctl read getattr lock write append };
#line 5345

#line 5345
#
#line 5345
# Allow the new domain to read and execute the program.
#line 5345
#
#line 5345
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 5345

#line 5345
#
#line 5345
# Allow the new domain to be entered via the program.
#line 5345
#
#line 5345
allow insmod_t insmod_exec_t:file entrypoint;
#line 5345

#line 5345
type_transition ifconfig_t insmod_exec_t:process insmod_t;
#line 5345


# Access /proc
allow ifconfig_t proc_t:dir { read getattr lock search ioctl };
allow ifconfig_t proc_t:file { read getattr lock ioctl };

allow ifconfig_t privfd:fd use;

# Create UDP sockets, necessary when called from dhcpc
allow ifconfig_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Access terminals.
allow ifconfig_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };


allow ifconfig_t tun_tap_device_t:chr_file { read write };

# ifconfig attempts to search some sysctl entries.
# Do not audit those attempts; comment out these rules if it is desired to
# see the denials.
dontaudit ifconfig_t { sysctl_t sysctl_net_t }:dir search;

allow ifconfig_t fs_t:filesystem getattr;
#DESC Init - Process initialization
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: sysvinit
#

#################################
#
# Rules for the init_t domain.
#
# init_t is the domain of the init process.
# init_exec_t is the type of the init program.
# initctl_t is the type of the named pipe created 
# by init during initialization.  This pipe is used
# to communicate with init.
# sulogin_exec_t is the type of sulogin.
#
type init_t, domain, privlog, mlstrustedreader, mlstrustedwriter;
role system_r types init_t;

#line 5387
allow init_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5387
allow init_t lib_t:lnk_file { read getattr lock ioctl };
#line 5387
allow init_t ld_so_t:file { read getattr lock execute ioctl };
#line 5387
allow init_t ld_so_t:file execute_no_trans;
#line 5387
allow init_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5387
allow init_t shlib_t:file { read getattr lock execute ioctl };
#line 5387
allow init_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5387
allow init_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5387
allow init_t device_t:dir search;
#line 5387
allow init_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5387
;
type init_exec_t, file_type, sysadmfile, exec_type;
type initctl_t, file_type, sysadmfile;
type sulogin_exec_t, file_type, exec_type, sysadmfile;

# for mount points
allow init_t file_t:dir search;

# Use capabilities.
allow init_t init_t:capability ~sys_module;

# Run /etc/rc.sysinit, /etc/rc, /etc/rc.local in the initrc_t domain.

#line 5399

#line 5399

#line 5399
#
#line 5399
# Allow the process to transition to the new domain.
#line 5399
#
#line 5399
allow init_t initrc_t:process transition;
#line 5399

#line 5399
#
#line 5399
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5399
#
#line 5399
dontaudit init_t initrc_t:process noatsecure;
#line 5399

#line 5399
#
#line 5399
# Allow the process to execute the program.
#line 5399
# 
#line 5399
allow init_t initrc_exec_t:file { read { getattr execute } };
#line 5399

#line 5399
#
#line 5399
# Allow the process to reap the new domain.
#line 5399
#
#line 5399
allow initrc_t init_t:process sigchld;
#line 5399

#line 5399
#
#line 5399
# Allow the new domain to inherit and use file 
#line 5399
# descriptions from the creating process and vice versa.
#line 5399
#
#line 5399
allow initrc_t init_t:fd use;
#line 5399
allow init_t initrc_t:fd use;
#line 5399

#line 5399
#
#line 5399
# Allow the new domain to write back to the old domain via a pipe.
#line 5399
#
#line 5399
allow initrc_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5399

#line 5399
#
#line 5399
# Allow the new domain to read and execute the program.
#line 5399
#
#line 5399
allow initrc_t initrc_exec_t:file { read getattr lock execute ioctl };
#line 5399

#line 5399
#
#line 5399
# Allow the new domain to be entered via the program.
#line 5399
#
#line 5399
allow initrc_t initrc_exec_t:file entrypoint;
#line 5399

#line 5399
type_transition init_t initrc_exec_t:process initrc_t;
#line 5399


# Run the shell or sulogin in the sysadm_t domain for single-user mode.

#line 5402

#line 5402

#line 5402
#
#line 5402
# Allow the process to transition to the new domain.
#line 5402
#
#line 5402
allow init_t sysadm_t:process transition;
#line 5402

#line 5402
#
#line 5402
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5402
#
#line 5402
dontaudit init_t sysadm_t:process noatsecure;
#line 5402

#line 5402
#
#line 5402
# Allow the process to execute the program.
#line 5402
# 
#line 5402
allow init_t shell_exec_t:file { read { getattr execute } };
#line 5402

#line 5402
#
#line 5402
# Allow the process to reap the new domain.
#line 5402
#
#line 5402
allow sysadm_t init_t:process sigchld;
#line 5402

#line 5402
#
#line 5402
# Allow the new domain to inherit and use file 
#line 5402
# descriptions from the creating process and vice versa.
#line 5402
#
#line 5402
allow sysadm_t init_t:fd use;
#line 5402
allow init_t sysadm_t:fd use;
#line 5402

#line 5402
#
#line 5402
# Allow the new domain to write back to the old domain via a pipe.
#line 5402
#
#line 5402
allow sysadm_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5402

#line 5402
#
#line 5402
# Allow the new domain to read and execute the program.
#line 5402
#
#line 5402
allow sysadm_t shell_exec_t:file { read getattr lock execute ioctl };
#line 5402

#line 5402
#
#line 5402
# Allow the new domain to be entered via the program.
#line 5402
#
#line 5402
allow sysadm_t shell_exec_t:file entrypoint;
#line 5402

#line 5402
type_transition init_t shell_exec_t:process sysadm_t;
#line 5402


#line 5403

#line 5403

#line 5403
#
#line 5403
# Allow the process to transition to the new domain.
#line 5403
#
#line 5403
allow init_t sysadm_t:process transition;
#line 5403

#line 5403
#
#line 5403
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5403
#
#line 5403
dontaudit init_t sysadm_t:process noatsecure;
#line 5403

#line 5403
#
#line 5403
# Allow the process to execute the program.
#line 5403
# 
#line 5403
allow init_t sulogin_exec_t:file { read { getattr execute } };
#line 5403

#line 5403
#
#line 5403
# Allow the process to reap the new domain.
#line 5403
#
#line 5403
allow sysadm_t init_t:process sigchld;
#line 5403

#line 5403
#
#line 5403
# Allow the new domain to inherit and use file 
#line 5403
# descriptions from the creating process and vice versa.
#line 5403
#
#line 5403
allow sysadm_t init_t:fd use;
#line 5403
allow init_t sysadm_t:fd use;
#line 5403

#line 5403
#
#line 5403
# Allow the new domain to write back to the old domain via a pipe.
#line 5403
#
#line 5403
allow sysadm_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5403

#line 5403
#
#line 5403
# Allow the new domain to read and execute the program.
#line 5403
#
#line 5403
allow sysadm_t sulogin_exec_t:file { read getattr lock execute ioctl };
#line 5403

#line 5403
#
#line 5403
# Allow the new domain to be entered via the program.
#line 5403
#
#line 5403
allow sysadm_t sulogin_exec_t:file entrypoint;
#line 5403

#line 5403
type_transition init_t sulogin_exec_t:process sysadm_t;
#line 5403


# Run /sbin/update in the init_t domain.

#line 5406
allow init_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5406


# Run init.

#line 5409
allow init_t init_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5409


# Run chroot from initrd scripts.
#line 5414


# Create /dev/initctl.

#line 5417

#line 5417

#line 5417

#line 5417
#
#line 5417
# Allow the process to modify the directory.
#line 5417
#
#line 5417
allow init_t device_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5417

#line 5417
#
#line 5417
# Allow the process to create the file.
#line 5417
#
#line 5417

#line 5417

#line 5417
allow init_t initctl_t:fifo_file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5417

#line 5417

#line 5417
type_transition init_t device_t:fifo_file initctl_t;
#line 5417

#line 5417

#line 5417


# Create ioctl.save.

#line 5420

#line 5420

#line 5420

#line 5420
#
#line 5420
# Allow the process to modify the directory.
#line 5420
#
#line 5420
allow init_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5420

#line 5420
#
#line 5420
# Allow the process to create the file.
#line 5420
#
#line 5420

#line 5420

#line 5420
allow init_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5420

#line 5420

#line 5420
type_transition init_t etc_t:file etc_runtime_t;
#line 5420

#line 5420

#line 5420


# Update /etc/ld.so.cache
allow init_t ld_so_cache_t:file { ioctl read getattr lock write append };

# Allow access to log files
allow init_t var_t:dir search;
allow init_t var_log_t:dir search;


#line 5429
allow init_t etc_t:lnk_file read;
#line 5429

#line 5429
allow init_t locale_t:dir { read getattr lock search ioctl };
#line 5429
allow init_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5429

#line 5429


# Create unix sockets
allow init_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow init_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow init_t self:fifo_file { ioctl read getattr lock write append };

# Permissions required for system startup
allow init_t bin_t:dir { read getattr lock search ioctl };
allow init_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow init_t exec_type:{ file lnk_file } { read getattr lock ioctl };
allow init_t sbin_t:dir { read getattr lock search ioctl };
allow init_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# allow init to fork
allow init_t self:process { fork sigchld };

# Modify utmp.
allow init_t var_run_t:file { ioctl read getattr lock write append };
allow init_t initrc_var_run_t:file { setattr { ioctl read getattr lock write append } };

# For /var/run/shutdown.pid.

#line 5451
type init_var_run_t alias var_run_init_t, file_type, sysadmfile, pidfile;
#line 5451

#line 5451

#line 5451

#line 5451

#line 5451
#
#line 5451
# Allow the process to modify the directory.
#line 5451
#
#line 5451
allow init_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5451

#line 5451
#
#line 5451
# Allow the process to create the file.
#line 5451
#
#line 5451

#line 5451

#line 5451
allow init_t init_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5451

#line 5451

#line 5451
type_transition init_t var_run_t:file init_var_run_t;
#line 5451

#line 5451

#line 5451

#line 5451
allow init_t init_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5451


# Shutdown permissions
allow init_t proc_t:dir { read getattr lock search ioctl };
allow init_t proc_t:lnk_file { read getattr lock ioctl };
allow init_t self:dir { read getattr lock search ioctl };
allow init_t self:lnk_file { read getattr lock ioctl };
allow init_t devpts_t:dir { read getattr lock ioctl };

# Modify wtmp.
allow init_t wtmp_t:file { ioctl read getattr lock write append };

# Kill all processes.
allow init_t domain:process { sigchld sigkill sigstop signull signal };

# Allow all processes to send SIGCHLD to init.
allow domain init_t:process { sigchld signull };

# If you load a new policy that removes active domains, processes can
# get stuck if you do not allow unlabeled processes to signal init
# If you load an incompatible policy, you should probably reboot,
# since you may have compromised system security.
allow unlabeled_t init_t:process sigchld;

# Read and write the console and ttys.
allow init_t console_device_t:chr_file { ioctl read getattr lock write append };
allow init_t tty_device_t:chr_file { ioctl read getattr lock write append };
allow init_t ttyfile:chr_file { ioctl read getattr lock write append };
allow init_t ptyfile:chr_file { ioctl read getattr lock write append };

# Run system executables.

#line 5482
allow init_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5482


# Run /etc/X11/prefdm.

#line 5485
allow init_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5485


# for initrd pivot_root seems to access this
dontaudit init_t file_labels_t:dir { search };
#DESC Initrc - System initialization scripts
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: sysvinit policycoreutils
#

#################################
#
# Rules for the initrc_t domain.
#
# initrc_t is the domain of the init rc scripts.
# initrc_exec_t is the type of the init program.
#
#line 5507

#line 5507
type initrc_t, domain, privlog, privowner, privmail;
#line 5507

role system_r types initrc_t;

#line 5509
allow initrc_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5509
allow initrc_t lib_t:lnk_file { read getattr lock ioctl };
#line 5509
allow initrc_t ld_so_t:file { read getattr lock execute ioctl };
#line 5509
allow initrc_t ld_so_t:file execute_no_trans;
#line 5509
allow initrc_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5509
allow initrc_t shlib_t:file { read getattr lock execute ioctl };
#line 5509
allow initrc_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5509
allow initrc_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5509
allow initrc_t device_t:dir search;
#line 5509
allow initrc_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5509
;
type initrc_exec_t, file_type, sysadmfile, exec_type;

# read files in /etc/init.d
allow initrc_t etc_t:lnk_file { read getattr lock ioctl };


#line 5515
allow initrc_t etc_t:lnk_file read;
#line 5515

#line 5515
allow initrc_t locale_t:dir { read getattr lock search ioctl };
#line 5515
allow initrc_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5515

#line 5515


# Read system information files in /proc.
allow initrc_t proc_t:dir { read getattr lock search ioctl };
allow initrc_t proc_t:{ file lnk_file } { read getattr lock ioctl };

# Allow IPC with self
allow initrc_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow initrc_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow initrc_t self:fifo_file { ioctl read getattr lock write append };

# Read the root directory of a usbdevfs filesystem, and
# the devices and drivers files.  Permit stating of the
# device nodes, but nothing else.
allow initrc_t usbdevfs_t:dir { read getattr lock search ioctl };
allow initrc_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
allow initrc_t usbdevfs_device_t:file getattr;

# allow initrc to fork and renice itself
allow initrc_t self:process { fork sigchld setsched };

# Can create ptys for open_init_pty

#line 5537

#line 5537
# Access the pty master multiplexer.
#line 5537
allow initrc_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 5537

#line 5537

#line 5537
allow initrc_t devpts_t:filesystem getattr;
#line 5537

#line 5537
# allow searching /dev/pts
#line 5537
allow initrc_t devpts_t:dir { getattr read search };
#line 5537

#line 5537
type initrc_devpts_t, file_type, sysadmfile, ptyfile ;
#line 5537

#line 5537
# Allow the pty to be associated with the file system.
#line 5537
allow initrc_devpts_t devpts_t:filesystem associate;
#line 5537

#line 5537
# Label pty files with a derived type.
#line 5537
type_transition initrc_t devpts_t:chr_file initrc_devpts_t;
#line 5537

#line 5537
# Read and write my pty files.
#line 5537
allow initrc_t initrc_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 5537


type initrc_tmp_t, file_type, sysadmfile, tmpfile;

#line 5540

#line 5540

#line 5540

#line 5540
#
#line 5540
# Allow the process to modify the directory.
#line 5540
#
#line 5540
allow initrc_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5540

#line 5540
#
#line 5540
# Allow the process to create the file.
#line 5540
#
#line 5540

#line 5540
allow initrc_t initrc_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5540
allow initrc_t initrc_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5540

#line 5540

#line 5540
type_transition initrc_t tmp_t:dir initrc_tmp_t;
#line 5540
type_transition initrc_t tmp_t:{ file lnk_file sock_file fifo_file } initrc_tmp_t;
#line 5540

#line 5540

#line 5540



#line 5542
type initrc_var_run_t alias var_run_initrc_t, file_type, sysadmfile, pidfile;
#line 5542

#line 5542

#line 5542

#line 5542

#line 5542
#
#line 5542
# Allow the process to modify the directory.
#line 5542
#
#line 5542
allow initrc_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5542

#line 5542
#
#line 5542
# Allow the process to create the file.
#line 5542
#
#line 5542

#line 5542

#line 5542
allow initrc_t initrc_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5542

#line 5542

#line 5542
type_transition initrc_t var_run_t:file initrc_var_run_t;
#line 5542

#line 5542

#line 5542

#line 5542
allow initrc_t initrc_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5542

allow initrc_t var_run_t:{ file sock_file lnk_file } unlink;

allow initrc_t framebuf_device_t:chr_file { read getattr lock ioctl };

# Use capabilities.
allow initrc_t initrc_t:capability ~sys_module;

# Use system operations.
allow initrc_t kernel_t:system *;

# Allow initrc_t to set the enforcing flag.
# The initrc_t domain is granted this permission for 
# people who want to use a development kernel and toggle
# into enforcing mode from an /etc/rc.d script.

#line 5557
allow initrc_t security_t:dir { read search getattr };
#line 5557
allow initrc_t security_t:file { getattr read write };
#line 5557
allow initrc_t security_t:security setenforce;
#line 5557
auditallow initrc_t security_t:security setenforce;
#line 5557


# Set values in /proc/sys.

#line 5560
allow initrc_t sysctl_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_fs_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_kernel_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_net_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_net_unix_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_net_unix_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_vm_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 5560
allow initrc_t sysctl_dev_t:file { setattr { ioctl read getattr lock write append } };
#line 5560
allow initrc_t sysctl_modprobe_t:file { setattr { ioctl read getattr lock write append } };
#line 5560


# Run helper programs in the initrc_t domain.
allow initrc_t {bin_t sbin_t }:dir { read getattr lock search ioctl };
allow initrc_t {bin_t sbin_t }:lnk_file read;

#line 5565
allow initrc_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5565


#line 5566
allow initrc_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5566


#line 5567
allow initrc_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5567


#line 5568
allow initrc_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5568


#line 5569
allow initrc_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5569



# Read conf.modules.
allow initrc_t modules_conf_t:file { read getattr lock ioctl };

# Run other rc scripts in the initrc_t domain.

#line 5576
allow initrc_t initrc_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5576


# Run init (telinit) in the initrc_t domain.

#line 5579
allow initrc_t init_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5579


# Communicate with the init process.
allow initrc_t initctl_t:fifo_file { ioctl read getattr lock write append };

# Send messages to portmap and ypbind.



# Search persistent label mappings.
allow initrc_t file_labels_t:dir { read getattr lock search ioctl };
allow initrc_t file_labels_t:file { getattr };

# Read /proc/PID directories for all domains.
allow initrc_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow initrc_t domain:dir { read getattr lock search ioctl };

# Mount and unmount file systems.
allow initrc_t fs_type:filesystem { mount remount unmount getattr };
allow initrc_t file_t:dir { read search getattr mounton };

# Create runtime files in /etc, e.g. /etc/mtab, /etc/HOSTNAME.

#line 5601

#line 5601

#line 5601

#line 5601
#
#line 5601
# Allow the process to modify the directory.
#line 5601
#
#line 5601
allow initrc_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5601

#line 5601
#
#line 5601
# Allow the process to create the file.
#line 5601
#
#line 5601

#line 5601

#line 5601
allow initrc_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5601

#line 5601

#line 5601
type_transition initrc_t etc_t:file etc_runtime_t;
#line 5601

#line 5601

#line 5601


# Update /etc/ld.so.cache.
allow initrc_t ld_so_cache_t:file { ioctl read getattr lock write append };

#line 5609


#line 5615


# Update /var/log/wtmp and /var/log/dmesg.
allow initrc_t wtmp_t:file { setattr { ioctl read getattr lock write append } };
allow initrc_t var_log_t:file { setattr { ioctl read getattr lock write append } };
allow initrc_t lastlog_t:file { setattr { ioctl read getattr lock write append } };

# remove old locks
allow initrc_t lockfile:dir { read getattr lock search ioctl add_name remove_name write };
allow initrc_t lockfile:file { getattr unlink };

# Access /var/lib/random-seed.
allow initrc_t var_lib_t:file { ioctl read getattr lock write append };
allow initrc_t var_lib_t:file unlink;

# Create lock file.
allow initrc_t var_lock_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
allow initrc_t var_lock_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Set the clock.
allow initrc_t clock_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };

# Kill all processes.
allow initrc_t domain:process { sigchld sigkill sigstop signull signal };

# Read and unlink /var/run/*.pid files.
allow initrc_t pidfile:file { getattr read unlink };

# Write to /dev/urandom.
allow initrc_t random_device_t:chr_file { ioctl read getattr lock write append };

# Access /dev/psaux (for kudzu).
allow initrc_t psaux_t:chr_file { ioctl read getattr lock write append };

# Set device ownerships/modes.
allow initrc_t framebuf_device_t:lnk_file read;
allow initrc_t framebuf_device_t:{ chr_file blk_file } setattr;
allow initrc_t misc_device_t:{ chr_file blk_file } setattr;
allow initrc_t device_t:{ chr_file blk_file } setattr;
allow initrc_t fixed_disk_device_t:{ chr_file blk_file } setattr;
allow initrc_t removable_device_t:{ chr_file blk_file } setattr;

# Stat any file.
allow initrc_t file_type:{ file lnk_file sock_file fifo_file chr_file blk_file } getattr;
allow initrc_t file_type:dir { search getattr };

# Read and write console and ttys.
allow initrc_t devtty_t:chr_file { ioctl read getattr lock write append };
allow initrc_t console_device_t:chr_file { ioctl read getattr lock write append };
allow initrc_t tty_device_t:chr_file { ioctl read getattr lock write append };
allow initrc_t ttyfile:chr_file { ioctl read getattr lock write append };
allow initrc_t ptyfile:chr_file { ioctl read getattr lock write append };

# Reset tty labels.
allow initrc_t ttyfile:chr_file relabelfrom;
allow initrc_t tty_device_t:chr_file relabelto;

#line 5681


allow initrc_t system_map_t:{ file lnk_file } { read getattr lock ioctl };

# Unlink /halt.
allow initrc_t root_t:dir { search write remove_name };
allow initrc_t root_t:file { unlink write };



allow initrc_t var_spool_t:file { ioctl read getattr lock write append };

#
# quota control
#
allow initrc_t fs_type:filesystem { quotamod quotaget };

# Access the mouse (for kudzu).
allow initrc_t mouse_device_t:chr_file { ioctl read getattr lock write append };

# Allow access to the sysadm TTYs. Note that this will give access to the 
# TTYs to any process in the initrc_t domain. Therefore, daemons and such
# started from init should be placed in their own domain.
allow initrc_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };

# Access sound device and files.
allow initrc_t sound_device_t:chr_file { setattr ioctl read write };


#line 5714


# Update /var/log/ksyms.*.

#line 5717

#line 5717

#line 5717

#line 5717
#
#line 5717
# Allow the process to modify the directory.
#line 5717
#
#line 5717
allow initrc_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5717

#line 5717
#
#line 5717
# Allow the process to create the file.
#line 5717
#
#line 5717

#line 5717
allow initrc_t var_log_ksyms_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5717
allow initrc_t var_log_ksyms_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5717

#line 5717

#line 5717
type_transition initrc_t var_log_t:dir var_log_ksyms_t;
#line 5717
type_transition initrc_t var_log_t:{ file lnk_file sock_file fifo_file } var_log_ksyms_t;
#line 5717

#line 5717

#line 5717


#line 5721


# Access /dev/fd0 (for kudzu). Need a separate domain for kudzu?
allow initrc_t removable_device_t:blk_file { ioctl read getattr lock write append };

#line 5729


# Create and delete /.autofsck
allow initrc_t root_t:dir { search write add_name };
allow initrc_t root_t:file { create setattr unlink getattr };
allow initrc_t file_t:file { unlink getattr };

# Read user home directories.
allow initrc_t { home_root_t home_type }:dir { read getattr lock search ioctl };
allow initrc_t home_type:file { read getattr lock ioctl };

# for system start scripts
allow initrc_t pidfile:dir { read getattr lock search ioctl add_name remove_name write };
allow initrc_t pidfile:sock_file unlink;
allow initrc_t tmpfile:sock_file unlink;

#line 5744
allow initrc_t var_lib_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5744
allow initrc_t var_lib_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5744


# allow start scripts to clean /tmp
allow initrc_t tmpfile:dir { { read getattr lock search ioctl add_name remove_name write } rmdir };
allow initrc_t tmpfile:{ file lnk_file sock_file fifo_file } { getattr unlink };

#################################
#
# Rules for the run_init_t domain.
#

#line 5754
type run_init_exec_t, file_type, exec_type, sysadmfile;
#line 5754

#line 5754
# domain for program to run in, needs to change role (privrole), change
#line 5754
# identity to system_u (privuser), log failures to syslog (privlog) and
#line 5754
# authenticate users (auth)
#line 5754
type run_init_t, domain, privrole, privuser, privlog, auth;
#line 5754

#line 5754

#line 5754

#line 5754
#
#line 5754
# Allow the process to transition to the new domain.
#line 5754
#
#line 5754
allow sysadm_t run_init_t:process transition;
#line 5754

#line 5754
#
#line 5754
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5754
#
#line 5754
dontaudit sysadm_t run_init_t:process noatsecure;
#line 5754

#line 5754
#
#line 5754
# Allow the process to execute the program.
#line 5754
# 
#line 5754
allow sysadm_t run_init_exec_t:file { read { getattr execute } };
#line 5754

#line 5754
#
#line 5754
# Allow the process to reap the new domain.
#line 5754
#
#line 5754
allow run_init_t sysadm_t:process sigchld;
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to inherit and use file 
#line 5754
# descriptions from the creating process and vice versa.
#line 5754
#
#line 5754
allow run_init_t sysadm_t:fd use;
#line 5754
allow sysadm_t run_init_t:fd use;
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to write back to the old domain via a pipe.
#line 5754
#
#line 5754
allow run_init_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to read and execute the program.
#line 5754
#
#line 5754
allow run_init_t run_init_exec_t:file { read getattr lock execute ioctl };
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to be entered via the program.
#line 5754
#
#line 5754
allow run_init_t run_init_exec_t:file entrypoint;
#line 5754

#line 5754
type_transition sysadm_t run_init_exec_t:process run_init_t;
#line 5754

#line 5754
role sysadm_r types run_init_t;
#line 5754

#line 5754
# for utmp
#line 5754
allow run_init_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 5754
allow run_init_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };
#line 5754

#line 5754
dontaudit run_init_t devpts_t:dir { getattr read };
#line 5754
dontaudit run_init_t device_t:dir read;
#line 5754

#line 5754
# often the administrator runs such programs from a directory that is owned
#line 5754
# by a different user or has restrictive SE permissions, do not want to audit
#line 5754
# the failed access to the current directory
#line 5754
dontaudit run_init_t file_type:dir search;
#line 5754
dontaudit run_init_t self:capability { dac_override dac_read_search };
#line 5754

#line 5754

#line 5754
allow run_init_t { bin_t chkpwd_exec_t shell_exec_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5754

#line 5754

#line 5754

#line 5754

#line 5754
#
#line 5754
# Allow the process to transition to the new domain.
#line 5754
#
#line 5754
allow run_init_t initrc_t:process transition;
#line 5754

#line 5754
#
#line 5754
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5754
#
#line 5754
dontaudit run_init_t initrc_t:process noatsecure;
#line 5754

#line 5754
#
#line 5754
# Allow the process to execute the program.
#line 5754
# 
#line 5754
allow run_init_t initrc_exec_t:file { read { getattr execute } };
#line 5754

#line 5754
#
#line 5754
# Allow the process to reap the new domain.
#line 5754
#
#line 5754
allow initrc_t run_init_t:process sigchld;
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to inherit and use file 
#line 5754
# descriptions from the creating process and vice versa.
#line 5754
#
#line 5754
allow initrc_t run_init_t:fd use;
#line 5754
allow run_init_t initrc_t:fd use;
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to write back to the old domain via a pipe.
#line 5754
#
#line 5754
allow initrc_t run_init_t:fifo_file { ioctl read getattr lock write append };
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to read and execute the program.
#line 5754
#
#line 5754
allow initrc_t initrc_exec_t:file { read getattr lock execute ioctl };
#line 5754

#line 5754
#
#line 5754
# Allow the new domain to be entered via the program.
#line 5754
#
#line 5754
allow initrc_t initrc_exec_t:file entrypoint;
#line 5754

#line 5754

#line 5754
allow run_init_t self:process setexec;
#line 5754
allow run_init_t proc_t:dir search;
#line 5754
allow run_init_t proc_t:lnk_file read;
#line 5754
allow run_init_t self:dir search;
#line 5754
allow run_init_t self:file { read write };
#line 5754

#line 5754

#line 5754
allow run_init_t privfd:fd use;
#line 5754

#line 5754
allow run_init_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5754
allow run_init_t lib_t:lnk_file { read getattr lock ioctl };
#line 5754
allow run_init_t ld_so_t:file { read getattr lock execute ioctl };
#line 5754
allow run_init_t ld_so_t:file execute_no_trans;
#line 5754
allow run_init_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5754
allow run_init_t shlib_t:file { read getattr lock execute ioctl };
#line 5754
allow run_init_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5754
allow run_init_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5754
allow run_init_t device_t:dir search;
#line 5754
allow run_init_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5754

#line 5754

#line 5754
allow run_init_t security_t:dir { read search getattr };
#line 5754
allow run_init_t security_t:file { getattr read write };
#line 5754
allow run_init_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 5754

#line 5754
allow run_init_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5754
allow run_init_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5754
allow run_init_t etc_t:file { getattr read };
#line 5754

#line 5754
allow run_init_t etc_t:lnk_file read;
#line 5754

#line 5754
allow run_init_t locale_t:dir { read getattr lock search ioctl };
#line 5754
allow run_init_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5754

#line 5754

#line 5754
allow run_init_t fs_t:filesystem getattr;
#line 5754
allow run_init_t { bin_t sbin_t }:dir search;
#line 5754
dontaudit run_init_t { proc_t device_t }:dir { getattr search };
#line 5754

allow initrc_t privfd:fd use;
#DESC Klogd - Kernel log daemon
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: klogd
#

#################################
#
# Rules for the klogd_t domain.
#

#line 5766

#line 5766
type klogd_t, domain, privlog , privmem;
#line 5766
type klogd_exec_t, file_type, sysadmfile, exec_type;
#line 5766

#line 5766
role system_r types klogd_t;
#line 5766

#line 5766

#line 5766

#line 5766

#line 5766
#
#line 5766
# Allow the process to transition to the new domain.
#line 5766
#
#line 5766
allow initrc_t klogd_t:process transition;
#line 5766

#line 5766
#
#line 5766
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5766
#
#line 5766
dontaudit initrc_t klogd_t:process noatsecure;
#line 5766

#line 5766
#
#line 5766
# Allow the process to execute the program.
#line 5766
# 
#line 5766
allow initrc_t klogd_exec_t:file { read { getattr execute } };
#line 5766

#line 5766
#
#line 5766
# Allow the process to reap the new domain.
#line 5766
#
#line 5766
allow klogd_t initrc_t:process sigchld;
#line 5766

#line 5766
#
#line 5766
# Allow the new domain to inherit and use file 
#line 5766
# descriptions from the creating process and vice versa.
#line 5766
#
#line 5766
allow klogd_t initrc_t:fd use;
#line 5766
allow initrc_t klogd_t:fd use;
#line 5766

#line 5766
#
#line 5766
# Allow the new domain to write back to the old domain via a pipe.
#line 5766
#
#line 5766
allow klogd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5766

#line 5766
#
#line 5766
# Allow the new domain to read and execute the program.
#line 5766
#
#line 5766
allow klogd_t klogd_exec_t:file { read getattr lock execute ioctl };
#line 5766

#line 5766
#
#line 5766
# Allow the new domain to be entered via the program.
#line 5766
#
#line 5766
allow klogd_t klogd_exec_t:file entrypoint;
#line 5766

#line 5766
type_transition initrc_t klogd_exec_t:process klogd_t;
#line 5766

#line 5766

#line 5766
# Inherit and use descriptors from init.
#line 5766
allow klogd_t init_t:fd use;
#line 5766
allow klogd_t init_t:process sigchld;
#line 5766
allow klogd_t privfd:fd use;
#line 5766
allow klogd_t newrole_t:process sigchld;
#line 5766
allow klogd_t self:process { { sigchld sigkill sigstop signull signal } fork };
#line 5766

#line 5766

#line 5766
allow klogd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5766
allow klogd_t lib_t:lnk_file { read getattr lock ioctl };
#line 5766
allow klogd_t ld_so_t:file { read getattr lock execute ioctl };
#line 5766
allow klogd_t ld_so_t:file execute_no_trans;
#line 5766
allow klogd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5766
allow klogd_t shlib_t:file { read getattr lock execute ioctl };
#line 5766
allow klogd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5766
allow klogd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5766
allow klogd_t device_t:dir search;
#line 5766
allow klogd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5766

#line 5766

#line 5766
allow klogd_t { self proc_t }:dir { read getattr lock search ioctl };
#line 5766
allow klogd_t { self proc_t }:lnk_file read;
#line 5766

#line 5766
allow klogd_t device_t:dir { getattr search };
#line 5766
allow klogd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5766
allow klogd_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 5766
allow klogd_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 5766

#line 5766
# Create pid file.
#line 5766
allow klogd_t var_t:dir { getattr search };
#line 5766

#line 5766
type klogd_var_run_t alias var_run_klogd_t, file_type, sysadmfile, pidfile;
#line 5766

#line 5766

#line 5766

#line 5766

#line 5766
#
#line 5766
# Allow the process to modify the directory.
#line 5766
#
#line 5766
allow klogd_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5766

#line 5766
#
#line 5766
# Allow the process to create the file.
#line 5766
#
#line 5766

#line 5766

#line 5766
allow klogd_t klogd_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5766

#line 5766

#line 5766
type_transition klogd_t var_run_t:file klogd_var_run_t;
#line 5766

#line 5766

#line 5766

#line 5766
allow klogd_t klogd_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5766

#line 5766

#line 5766
allow klogd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 5766

#line 5766
# for daemons that look at /root on startup
#line 5766
dontaudit klogd_t sysadm_home_dir_t:dir search;
#line 5766

#line 5766
# for df
#line 5766
allow klogd_t fs_type:filesystem getattr;
#line 5766

#line 5766

#line 5766
allow klogd_t etc_t:lnk_file read;
#line 5766

#line 5766
allow klogd_t locale_t:dir { read getattr lock search ioctl };
#line 5766
allow klogd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5766

#line 5766

#line 5766



#line 5768
type klogd_tmp_t, file_type, sysadmfile, tmpfile ;
#line 5768

#line 5768

#line 5768

#line 5768

#line 5768
#
#line 5768
# Allow the process to modify the directory.
#line 5768
#
#line 5768
allow klogd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5768

#line 5768
#
#line 5768
# Allow the process to create the file.
#line 5768
#
#line 5768

#line 5768
allow klogd_t klogd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5768
allow klogd_t klogd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5768

#line 5768

#line 5768
type_transition klogd_t tmp_t:dir klogd_tmp_t;
#line 5768
type_transition klogd_t tmp_t:{ file lnk_file sock_file fifo_file } klogd_tmp_t;
#line 5768

#line 5768

#line 5768

#line 5768

allow klogd_t proc_t:dir { read getattr lock search ioctl };
allow klogd_t proc_t:lnk_file { read getattr lock ioctl };
allow klogd_t proc_t:file { getattr read };
allow klogd_t self:dir { read getattr lock search ioctl };
allow klogd_t self:lnk_file { read getattr lock ioctl };

# read /etc/nsswitch.conf
allow klogd_t etc_t:lnk_file read;
allow klogd_t etc_t:file { read getattr lock ioctl };


#line 5779
allow klogd_t etc_t:lnk_file read;
#line 5779

#line 5779
allow klogd_t locale_t:dir { read getattr lock search ioctl };
#line 5779
allow klogd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5779

#line 5779


allow klogd_t etc_runtime_t:file { getattr read };

# Create unix sockets
allow klogd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Use the sys_admin and sys_rawio capabilities.
allow klogd_t klogd_t:capability { sys_admin sys_rawio };

# Read /proc/kmsg and /dev/mem.
allow klogd_t proc_kmsg_t:file { read getattr lock ioctl };
allow klogd_t memory_device_t:chr_file { read getattr lock ioctl };

# Control syslog and console logging
allow klogd_t kernel_t:system { syslog_mod syslog_console };

# Read /boot/System.map*
allow klogd_t system_map_t:file { read getattr lock ioctl };
allow klogd_t boot_t:dir { read getattr lock search ioctl };
#DESC Ldconfig - Configure dynamic linker bindings
#
# Author:  Russell Coker <russell@coker.com.au>
# X-Debian-Packages: libc6
#

#################################
#
# Rules for the ldconfig_t domain.
#
type ldconfig_t, domain, privlog;
type ldconfig_exec_t, file_type, sysadmfile, exec_type;

role sysadm_r types ldconfig_t;
role system_r types ldconfig_t;


#line 5815

#line 5815

#line 5815
#
#line 5815
# Allow the process to transition to the new domain.
#line 5815
#
#line 5815
allow { sysadm_t initrc_t  } ldconfig_t:process transition;
#line 5815

#line 5815
#
#line 5815
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5815
#
#line 5815
dontaudit { sysadm_t initrc_t  } ldconfig_t:process noatsecure;
#line 5815

#line 5815
#
#line 5815
# Allow the process to execute the program.
#line 5815
# 
#line 5815
allow { sysadm_t initrc_t  } ldconfig_exec_t:file { read { getattr execute } };
#line 5815

#line 5815
#
#line 5815
# Allow the process to reap the new domain.
#line 5815
#
#line 5815
allow ldconfig_t { sysadm_t initrc_t  }:process sigchld;
#line 5815

#line 5815
#
#line 5815
# Allow the new domain to inherit and use file 
#line 5815
# descriptions from the creating process and vice versa.
#line 5815
#
#line 5815
allow ldconfig_t { sysadm_t initrc_t  }:fd use;
#line 5815
allow { sysadm_t initrc_t  } ldconfig_t:fd use;
#line 5815

#line 5815
#
#line 5815
# Allow the new domain to write back to the old domain via a pipe.
#line 5815
#
#line 5815
allow ldconfig_t { sysadm_t initrc_t  }:fifo_file { ioctl read getattr lock write append };
#line 5815

#line 5815
#
#line 5815
# Allow the new domain to read and execute the program.
#line 5815
#
#line 5815
allow ldconfig_t ldconfig_exec_t:file { read getattr lock execute ioctl };
#line 5815

#line 5815
#
#line 5815
# Allow the new domain to be entered via the program.
#line 5815
#
#line 5815
allow ldconfig_t ldconfig_exec_t:file entrypoint;
#line 5815

#line 5815
type_transition { sysadm_t initrc_t  } ldconfig_exec_t:process ldconfig_t;
#line 5815

dontaudit ldconfig_t device_t:dir search;
allow ldconfig_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };
allow ldconfig_t privfd:fd use;


#line 5820
allow ldconfig_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5820
allow ldconfig_t lib_t:lnk_file { read getattr lock ioctl };
#line 5820
allow ldconfig_t ld_so_t:file { read getattr lock execute ioctl };
#line 5820
allow ldconfig_t ld_so_t:file execute_no_trans;
#line 5820
allow ldconfig_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5820
allow ldconfig_t shlib_t:file { read getattr lock execute ioctl };
#line 5820
allow ldconfig_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5820
allow ldconfig_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5820
allow ldconfig_t device_t:dir search;
#line 5820
allow ldconfig_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5820



#line 5822

#line 5822

#line 5822

#line 5822
#
#line 5822
# Allow the process to modify the directory.
#line 5822
#
#line 5822
allow ldconfig_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5822

#line 5822
#
#line 5822
# Allow the process to create the file.
#line 5822
#
#line 5822

#line 5822
allow ldconfig_t ld_so_cache_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5822
allow ldconfig_t ld_so_cache_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5822

#line 5822

#line 5822
type_transition ldconfig_t etc_t:dir ld_so_cache_t;
#line 5822
type_transition ldconfig_t etc_t:{ file lnk_file sock_file fifo_file } ld_so_cache_t;
#line 5822

#line 5822

#line 5822


#line 5823

#line 5823

#line 5823

#line 5823
#
#line 5823
# Allow the process to modify the directory.
#line 5823
#
#line 5823
allow ldconfig_t lib_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5823

#line 5823
#
#line 5823
# Allow the process to create the file.
#line 5823
#
#line 5823

#line 5823
allow ldconfig_t shlib_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5823
allow ldconfig_t shlib_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5823

#line 5823

#line 5823
type_transition ldconfig_t lib_t:dir shlib_t;
#line 5823
type_transition ldconfig_t lib_t:{ file lnk_file sock_file fifo_file } shlib_t;
#line 5823

#line 5823

#line 5823

# allow removing mis-labelled links
allow ldconfig_t lib_t:lnk_file unlink;

allow ldconfig_t userdomain:fd use;
allow ldconfig_t etc_t:file { getattr read };
allow ldconfig_t etc_t:lnk_file read;

allow ldconfig_t fs_t:filesystem getattr;
#DESC LoadPolicy - SELinux policy loading utilities
#
# Authors:  Frank Mayer, mayerf@tresys.com
# X-Debian-Packages: policycoreutils
#

###########################
# load_policy_t is the domain type for load_policy 
# load_policy_exec_t is the file type for the executable


type load_policy_t, domain;
role sysadm_r types load_policy_t;

type load_policy_exec_t, file_type, exec_type, sysadmfile;

##########################
# 
# Rules


#line 5852

#line 5852

#line 5852
#
#line 5852
# Allow the process to transition to the new domain.
#line 5852
#
#line 5852
allow sysadm_t load_policy_t:process transition;
#line 5852

#line 5852
#
#line 5852
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5852
#
#line 5852
dontaudit sysadm_t load_policy_t:process noatsecure;
#line 5852

#line 5852
#
#line 5852
# Allow the process to execute the program.
#line 5852
# 
#line 5852
allow sysadm_t load_policy_exec_t:file { read { getattr execute } };
#line 5852

#line 5852
#
#line 5852
# Allow the process to reap the new domain.
#line 5852
#
#line 5852
allow load_policy_t sysadm_t:process sigchld;
#line 5852

#line 5852
#
#line 5852
# Allow the new domain to inherit and use file 
#line 5852
# descriptions from the creating process and vice versa.
#line 5852
#
#line 5852
allow load_policy_t sysadm_t:fd use;
#line 5852
allow sysadm_t load_policy_t:fd use;
#line 5852

#line 5852
#
#line 5852
# Allow the new domain to write back to the old domain via a pipe.
#line 5852
#
#line 5852
allow load_policy_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5852

#line 5852
#
#line 5852
# Allow the new domain to read and execute the program.
#line 5852
#
#line 5852
allow load_policy_t load_policy_exec_t:file { read getattr lock execute ioctl };
#line 5852

#line 5852
#
#line 5852
# Allow the new domain to be entered via the program.
#line 5852
#
#line 5852
allow load_policy_t load_policy_exec_t:file entrypoint;
#line 5852

#line 5852
type_transition sysadm_t load_policy_exec_t:process load_policy_t;
#line 5852

#line 5856


# Reload the policy configuration (sysadm_t no longer has this ability)

#line 5859
allow load_policy_t security_t:dir { read search getattr };
#line 5859
allow load_policy_t security_t:file { getattr read write };
#line 5859
allow load_policy_t security_t:security load_policy;
#line 5859
auditallow load_policy_t security_t:security load_policy;
#line 5859



###########################
# constrain from where load_policy can load a policy, specifically 
# policy_config_t files 
#

# only allow read of policy config files
allow load_policy_t policy_config_t:dir { read getattr lock search ioctl };
allow load_policy_t policy_config_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# directory search permissions for path to binary policy files
allow load_policy_t root_t:dir search;
allow load_policy_t etc_t:dir search;

# Read the devpts root directory (needed?)  
allow load_policy_t devpts_t:dir { read getattr lock search ioctl };

# Other access
allow load_policy_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { read write ioctl getattr };

#line 5880
allow load_policy_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5880
allow load_policy_t lib_t:lnk_file { read getattr lock ioctl };
#line 5880
allow load_policy_t ld_so_t:file { read getattr lock execute ioctl };
#line 5880
allow load_policy_t ld_so_t:file execute_no_trans;
#line 5880
allow load_policy_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5880
allow load_policy_t shlib_t:file { read getattr lock execute ioctl };
#line 5880
allow load_policy_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5880
allow load_policy_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5880
allow load_policy_t device_t:dir search;
#line 5880
allow load_policy_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5880

allow load_policy_t self:capability dac_override;

allow load_policy_t { initrc_t privfd }:fd use;

allow load_policy_t fs_t:filesystem getattr;

allow load_policy_t sysadm_tmp_t:file { getattr write } ;

#DESC Login - Local/remote login utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# Macroised by Russell Coker <russell@coker.com.au>
# X-Debian-Packages: login
#

#################################
# 
# Rules for the local_login_t domain
# and the remote_login_t domain.
#

# $1 is the name of the domain (local or remote)
# I added "mlstrustedreader, mlstrustedwriter, mlstrustedobject" to
# remote_login_t, not sure if this is right
#line 5982


#################################
#
# Rules for the local_login_t domain.
#
# local_login_t is the domain of a login process 
# spawned by getty.
#
# remote_login_t is the domain of a login process 
# spawned by rlogind.
#
# login_exec_t is the type of the login program
#
type login_exec_t, file_type, sysadmfile, exec_type;


#line 5998
type local_login_t, domain, privuser, privrole, privlog, auth, privowner, mlstrustedreader, mlstrustedwriter, mlstrustedobject, privfd;
#line 5998
role system_r types local_login_t;
#line 5998

#line 5998

#line 5998
# Access other processes in the same domain.
#line 5998
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 5998
# separately if desired.
#line 5998
allow local_login_t self:process ~{ptrace setexec setfscreate};
#line 5998

#line 5998
# Access /proc/PID files for processes in the same domain.
#line 5998
allow local_login_t self:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998

#line 5998
# Access file descriptions, pipes, and sockets
#line 5998
# created by processes in the same domain.
#line 5998
allow local_login_t self:fd *;
#line 5998
allow local_login_t self:fifo_file { ioctl read getattr lock write append };
#line 5998
allow local_login_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5998
allow local_login_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5998

#line 5998
# Allow the domain to communicate with other processes in the same domain.
#line 5998
allow local_login_t self:unix_dgram_socket sendto;
#line 5998
allow local_login_t self:unix_stream_socket connectto;
#line 5998

#line 5998
# Access System V IPC objects created by processes in the same domain.
#line 5998
allow local_login_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5998
allow local_login_t self:msg  { send receive };
#line 5998
allow local_login_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5998
allow local_login_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5998
;
#line 5998

#line 5998
# Read system information files in /proc.
#line 5998
allow local_login_t proc_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998

#line 5998

#line 5998
# Read /.
#line 5998
allow local_login_t root_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998

#line 5998
# Read /home.
#line 5998
allow local_login_t home_root_t:dir { read getattr lock search ioctl };
#line 5998

#line 5998
# Read /usr.
#line 5998
allow local_login_t usr_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998

#line 5998
# Read bin and sbin directories.
#line 5998
allow local_login_t bin_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998
allow local_login_t sbin_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998

#line 5998

#line 5998
# Read directories and files with the readable_t type.
#line 5998
# This type is a general type for "world"-readable files.
#line 5998
allow local_login_t readable_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998

#line 5998
# Read /var, /var/spool, /var/log.
#line 5998
allow local_login_t var_t:dir search;
#line 5998
allow local_login_t var_spool_t:dir search;
#line 5998

#line 5998
# Read /etc.
#line 5998
allow local_login_t etc_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5998
allow local_login_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 5998

#line 5998

#line 5998
allow local_login_t etc_t:lnk_file read;
#line 5998

#line 5998
allow local_login_t locale_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 5998

#line 5998

#line 5998

#line 5998
# Read executable types.
#line 5998
allow local_login_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 5998

#line 5998
# Read /dev directories and any symbolic links.
#line 5998
allow local_login_t device_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t device_t:lnk_file { read getattr lock ioctl };
#line 5998

#line 5998

#line 5998
allow local_login_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t lib_t:lnk_file { read getattr lock ioctl };
#line 5998
allow local_login_t ld_so_t:file { read getattr lock execute ioctl };
#line 5998
allow local_login_t ld_so_t:file execute_no_trans;
#line 5998
allow local_login_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5998
allow local_login_t shlib_t:file { read getattr lock execute ioctl };
#line 5998
allow local_login_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5998
allow local_login_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5998
allow local_login_t device_t:dir search;
#line 5998
allow local_login_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5998
;
#line 5998

#line 5998

#line 5998
type local_login_tmp_t, file_type, sysadmfile, tmpfile ;
#line 5998

#line 5998

#line 5998

#line 5998

#line 5998
#
#line 5998
# Allow the process to modify the directory.
#line 5998
#
#line 5998
allow local_login_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5998

#line 5998
#
#line 5998
# Allow the process to create the file.
#line 5998
#
#line 5998

#line 5998
allow local_login_t local_login_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5998
allow local_login_t local_login_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5998

#line 5998

#line 5998
type_transition local_login_t tmp_t:dir local_login_tmp_t;
#line 5998
type_transition local_login_t tmp_t:{ file lnk_file sock_file fifo_file } local_login_tmp_t;
#line 5998

#line 5998

#line 5998

#line 5998

#line 5998

#line 5998
# Use capabilities
#line 5998
allow local_login_t self:capability { setuid setgid chown fowner fsetid net_bind_service sys_tty_config dac_override sys_nice sys_resource };
#line 5998

#line 5998
# Run shells in user_t by default.
#line 5998

#line 5998

#line 5998

#line 5998
#
#line 5998
# Allow the process to transition to the new domain.
#line 5998
#
#line 5998
allow local_login_t user_t:process transition;
#line 5998

#line 5998
#
#line 5998
# Do not audit when glibc secure mode is enabled upon the transition.
#line 5998
#
#line 5998
dontaudit local_login_t user_t:process noatsecure;
#line 5998

#line 5998
#
#line 5998
# Allow the process to execute the program.
#line 5998
# 
#line 5998
allow local_login_t shell_exec_t:file { read { getattr execute } };
#line 5998

#line 5998
#
#line 5998
# Allow the process to reap the new domain.
#line 5998
#
#line 5998
allow user_t local_login_t:process sigchld;
#line 5998

#line 5998
#
#line 5998
# Allow the new domain to inherit and use file 
#line 5998
# descriptions from the creating process and vice versa.
#line 5998
#
#line 5998
allow user_t local_login_t:fd use;
#line 5998
allow local_login_t user_t:fd use;
#line 5998

#line 5998
#
#line 5998
# Allow the new domain to write back to the old domain via a pipe.
#line 5998
#
#line 5998
allow user_t local_login_t:fifo_file { ioctl read getattr lock write append };
#line 5998

#line 5998
#
#line 5998
# Allow the new domain to read and execute the program.
#line 5998
#
#line 5998
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 5998

#line 5998
#
#line 5998
# Allow the new domain to be entered via the program.
#line 5998
#
#line 5998
allow user_t shell_exec_t:file entrypoint;
#line 5998

#line 5998
type_transition local_login_t shell_exec_t:process user_t;
#line 5998

#line 5998

#line 5998
# Set exec context.
#line 5998

#line 5998
allow local_login_t self:process setexec;
#line 5998
allow local_login_t proc_t:dir search;
#line 5998
allow local_login_t proc_t:lnk_file read;
#line 5998
allow local_login_t self:dir search;
#line 5998
allow local_login_t self:file { read write };
#line 5998

#line 5998

#line 5998
# Permit login to search the user home directories.
#line 5998
allow local_login_t home_root_t:dir search;
#line 5998
allow local_login_t home_dir_type:dir search;
#line 5998

#line 5998
# Write to /var/run/utmp.
#line 5998
allow local_login_t var_run_t:dir search;
#line 5998
allow local_login_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 5998

#line 5998
# Write to /var/log/wtmp.
#line 5998
allow local_login_t var_log_t:dir search;
#line 5998
allow local_login_t wtmp_t:file { ioctl read getattr lock write append };
#line 5998

#line 5998
# Write to /var/log/lastlog.
#line 5998
allow local_login_t lastlog_t:file { ioctl read getattr lock write append };
#line 5998

#line 5998
# Write to /var/log/btmp
#line 5998
allow local_login_t faillog_t:file { append read write };
#line 5998

#line 5998
# Search for mail spool file.
#line 5998
allow local_login_t mail_spool_t:dir { read getattr lock search ioctl };
#line 5998
allow local_login_t mail_spool_t:file getattr;
#line 5998
allow local_login_t mail_spool_t:lnk_file read;
#line 5998

#line 5998
# Get security policy decisions.
#line 5998

#line 5998
allow local_login_t security_t:dir { read search getattr };
#line 5998
allow local_login_t security_t:file { getattr read write };
#line 5998
allow local_login_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 5998

#line 5998

#line 5998
# allow read access to default_contexts in /etc/security
#line 5998
allow local_login_t default_context_t:file { read getattr lock ioctl };
#line 5998

#line 5998


# But also permit other user domains to be entered by login.

#line 6001

#line 6001
#
#line 6001
# Allow the process to transition to the new domain.
#line 6001
#
#line 6001
allow local_login_t userdomain:process transition;
#line 6001

#line 6001
#
#line 6001
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6001
#
#line 6001
dontaudit local_login_t userdomain:process noatsecure;
#line 6001

#line 6001
#
#line 6001
# Allow the process to execute the program.
#line 6001
# 
#line 6001
allow local_login_t shell_exec_t:file { read { getattr execute } };
#line 6001

#line 6001
#
#line 6001
# Allow the process to reap the new domain.
#line 6001
#
#line 6001
allow userdomain local_login_t:process sigchld;
#line 6001

#line 6001
#
#line 6001
# Allow the new domain to inherit and use file 
#line 6001
# descriptions from the creating process and vice versa.
#line 6001
#
#line 6001
allow userdomain local_login_t:fd use;
#line 6001
allow local_login_t userdomain:fd use;
#line 6001

#line 6001
#
#line 6001
# Allow the new domain to write back to the old domain via a pipe.
#line 6001
#
#line 6001
allow userdomain local_login_t:fifo_file { ioctl read getattr lock write append };
#line 6001

#line 6001
#
#line 6001
# Allow the new domain to read and execute the program.
#line 6001
#
#line 6001
allow userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6001

#line 6001
#
#line 6001
# Allow the new domain to be entered via the program.
#line 6001
#
#line 6001
allow userdomain shell_exec_t:file entrypoint;
#line 6001


# Do not audit denied attempts to access devices.
dontaudit local_login_t fixed_disk_device_t:blk_file { getattr setattr };
dontaudit local_login_t removable_device_t:blk_file { getattr setattr };
dontaudit local_login_t device_t:{ chr_file blk_file lnk_file } { getattr setattr };
dontaudit local_login_t misc_device_t:{ chr_file blk_file lnk_file } { getattr setattr };
dontaudit local_login_t framebuf_device_t:{ chr_file blk_file lnk_file } { getattr setattr read };
dontaudit local_login_t apm_bios_t:chr_file { getattr setattr };
dontaudit local_login_t v4l_device_t:{ chr_file blk_file lnk_file } { getattr setattr read };
dontaudit local_login_t v4l_device_t:dir { read search getattr };

# Do not audit denied attempts to access /mnt.
dontaudit local_login_t file_t:dir { read getattr lock search ioctl };


# Create lock file.
allow local_login_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
allow local_login_t var_lock_t:file { create ioctl read getattr lock write setattr append link unlink rename };


# Read and write ttys.
allow local_login_t tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
allow local_login_t ttyfile:chr_file { setattr { ioctl read getattr lock write append } };

# Relabel ttys.
allow local_login_t tty_device_t:chr_file { getattr relabelfrom relabelto };
allow local_login_t ttyfile:chr_file { getattr relabelfrom relabelto };

#line 6031


# Allow setting of attributes on sound devices.
allow local_login_t sound_device_t:chr_file { getattr setattr };

# Allow access to /var/run/console and /var/run/console.lock.  Need a separate type?
allow local_login_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
allow local_login_t var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };

#################################
#
# Rules for the remote_login_t domain.
#


#line 6045
type remote_login_t, domain, privuser, privrole, privlog, auth, privowner, mlstrustedreader, mlstrustedwriter, mlstrustedobject, privfd;
#line 6045
role system_r types remote_login_t;
#line 6045

#line 6045

#line 6045
# Access other processes in the same domain.
#line 6045
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 6045
# separately if desired.
#line 6045
allow remote_login_t self:process ~{ptrace setexec setfscreate};
#line 6045

#line 6045
# Access /proc/PID files for processes in the same domain.
#line 6045
allow remote_login_t self:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045

#line 6045
# Access file descriptions, pipes, and sockets
#line 6045
# created by processes in the same domain.
#line 6045
allow remote_login_t self:fd *;
#line 6045
allow remote_login_t self:fifo_file { ioctl read getattr lock write append };
#line 6045
allow remote_login_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6045
allow remote_login_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6045

#line 6045
# Allow the domain to communicate with other processes in the same domain.
#line 6045
allow remote_login_t self:unix_dgram_socket sendto;
#line 6045
allow remote_login_t self:unix_stream_socket connectto;
#line 6045

#line 6045
# Access System V IPC objects created by processes in the same domain.
#line 6045
allow remote_login_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6045
allow remote_login_t self:msg  { send receive };
#line 6045
allow remote_login_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6045
allow remote_login_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6045
;
#line 6045

#line 6045
# Read system information files in /proc.
#line 6045
allow remote_login_t proc_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045

#line 6045

#line 6045
# Read /.
#line 6045
allow remote_login_t root_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045

#line 6045
# Read /home.
#line 6045
allow remote_login_t home_root_t:dir { read getattr lock search ioctl };
#line 6045

#line 6045
# Read /usr.
#line 6045
allow remote_login_t usr_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045

#line 6045
# Read bin and sbin directories.
#line 6045
allow remote_login_t bin_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045
allow remote_login_t sbin_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045

#line 6045

#line 6045
# Read directories and files with the readable_t type.
#line 6045
# This type is a general type for "world"-readable files.
#line 6045
allow remote_login_t readable_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045

#line 6045
# Read /var, /var/spool, /var/log.
#line 6045
allow remote_login_t var_t:dir search;
#line 6045
allow remote_login_t var_spool_t:dir search;
#line 6045

#line 6045
# Read /etc.
#line 6045
allow remote_login_t etc_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6045
allow remote_login_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6045

#line 6045

#line 6045
allow remote_login_t etc_t:lnk_file read;
#line 6045

#line 6045
allow remote_login_t locale_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6045

#line 6045

#line 6045

#line 6045
# Read executable types.
#line 6045
allow remote_login_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6045

#line 6045
# Read /dev directories and any symbolic links.
#line 6045
allow remote_login_t device_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t device_t:lnk_file { read getattr lock ioctl };
#line 6045

#line 6045

#line 6045
allow remote_login_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t lib_t:lnk_file { read getattr lock ioctl };
#line 6045
allow remote_login_t ld_so_t:file { read getattr lock execute ioctl };
#line 6045
allow remote_login_t ld_so_t:file execute_no_trans;
#line 6045
allow remote_login_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6045
allow remote_login_t shlib_t:file { read getattr lock execute ioctl };
#line 6045
allow remote_login_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6045
allow remote_login_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6045
allow remote_login_t device_t:dir search;
#line 6045
allow remote_login_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6045
;
#line 6045

#line 6045

#line 6045
type remote_login_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6045

#line 6045

#line 6045

#line 6045

#line 6045
#
#line 6045
# Allow the process to modify the directory.
#line 6045
#
#line 6045
allow remote_login_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6045

#line 6045
#
#line 6045
# Allow the process to create the file.
#line 6045
#
#line 6045

#line 6045
allow remote_login_t remote_login_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6045
allow remote_login_t remote_login_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6045

#line 6045

#line 6045
type_transition remote_login_t tmp_t:dir remote_login_tmp_t;
#line 6045
type_transition remote_login_t tmp_t:{ file lnk_file sock_file fifo_file } remote_login_tmp_t;
#line 6045

#line 6045

#line 6045

#line 6045

#line 6045

#line 6045
# Use capabilities
#line 6045
allow remote_login_t self:capability { setuid setgid chown fowner fsetid net_bind_service sys_tty_config dac_override sys_nice sys_resource };
#line 6045

#line 6045
# Run shells in user_t by default.
#line 6045

#line 6045

#line 6045

#line 6045
#
#line 6045
# Allow the process to transition to the new domain.
#line 6045
#
#line 6045
allow remote_login_t user_t:process transition;
#line 6045

#line 6045
#
#line 6045
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6045
#
#line 6045
dontaudit remote_login_t user_t:process noatsecure;
#line 6045

#line 6045
#
#line 6045
# Allow the process to execute the program.
#line 6045
# 
#line 6045
allow remote_login_t shell_exec_t:file { read { getattr execute } };
#line 6045

#line 6045
#
#line 6045
# Allow the process to reap the new domain.
#line 6045
#
#line 6045
allow user_t remote_login_t:process sigchld;
#line 6045

#line 6045
#
#line 6045
# Allow the new domain to inherit and use file 
#line 6045
# descriptions from the creating process and vice versa.
#line 6045
#
#line 6045
allow user_t remote_login_t:fd use;
#line 6045
allow remote_login_t user_t:fd use;
#line 6045

#line 6045
#
#line 6045
# Allow the new domain to write back to the old domain via a pipe.
#line 6045
#
#line 6045
allow user_t remote_login_t:fifo_file { ioctl read getattr lock write append };
#line 6045

#line 6045
#
#line 6045
# Allow the new domain to read and execute the program.
#line 6045
#
#line 6045
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 6045

#line 6045
#
#line 6045
# Allow the new domain to be entered via the program.
#line 6045
#
#line 6045
allow user_t shell_exec_t:file entrypoint;
#line 6045

#line 6045
type_transition remote_login_t shell_exec_t:process user_t;
#line 6045

#line 6045

#line 6045
# Set exec context.
#line 6045

#line 6045
allow remote_login_t self:process setexec;
#line 6045
allow remote_login_t proc_t:dir search;
#line 6045
allow remote_login_t proc_t:lnk_file read;
#line 6045
allow remote_login_t self:dir search;
#line 6045
allow remote_login_t self:file { read write };
#line 6045

#line 6045

#line 6045
# Permit login to search the user home directories.
#line 6045
allow remote_login_t home_root_t:dir search;
#line 6045
allow remote_login_t home_dir_type:dir search;
#line 6045

#line 6045
# Write to /var/run/utmp.
#line 6045
allow remote_login_t var_run_t:dir search;
#line 6045
allow remote_login_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 6045

#line 6045
# Write to /var/log/wtmp.
#line 6045
allow remote_login_t var_log_t:dir search;
#line 6045
allow remote_login_t wtmp_t:file { ioctl read getattr lock write append };
#line 6045

#line 6045
# Write to /var/log/lastlog.
#line 6045
allow remote_login_t lastlog_t:file { ioctl read getattr lock write append };
#line 6045

#line 6045
# Write to /var/log/btmp
#line 6045
allow remote_login_t faillog_t:file { append read write };
#line 6045

#line 6045
# Search for mail spool file.
#line 6045
allow remote_login_t mail_spool_t:dir { read getattr lock search ioctl };
#line 6045
allow remote_login_t mail_spool_t:file getattr;
#line 6045
allow remote_login_t mail_spool_t:lnk_file read;
#line 6045

#line 6045
# Get security policy decisions.
#line 6045

#line 6045
allow remote_login_t security_t:dir { read search getattr };
#line 6045
allow remote_login_t security_t:file { getattr read write };
#line 6045
allow remote_login_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6045

#line 6045

#line 6045
# allow read access to default_contexts in /etc/security
#line 6045
allow remote_login_t default_context_t:file { read getattr lock ioctl };
#line 6045

#line 6045


# Only permit unprivileged user domains to be entered via rlogin,
# since very weak authentication is used.

#line 6049

#line 6049
#
#line 6049
# Allow the process to transition to the new domain.
#line 6049
#
#line 6049
allow remote_login_t unpriv_userdomain:process transition;
#line 6049

#line 6049
#
#line 6049
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6049
#
#line 6049
dontaudit remote_login_t unpriv_userdomain:process noatsecure;
#line 6049

#line 6049
#
#line 6049
# Allow the process to execute the program.
#line 6049
# 
#line 6049
allow remote_login_t shell_exec_t:file { read { getattr execute } };
#line 6049

#line 6049
#
#line 6049
# Allow the process to reap the new domain.
#line 6049
#
#line 6049
allow unpriv_userdomain remote_login_t:process sigchld;
#line 6049

#line 6049
#
#line 6049
# Allow the new domain to inherit and use file 
#line 6049
# descriptions from the creating process and vice versa.
#line 6049
#
#line 6049
allow unpriv_userdomain remote_login_t:fd use;
#line 6049
allow remote_login_t unpriv_userdomain:fd use;
#line 6049

#line 6049
#
#line 6049
# Allow the new domain to write back to the old domain via a pipe.
#line 6049
#
#line 6049
allow unpriv_userdomain remote_login_t:fifo_file { ioctl read getattr lock write append };
#line 6049

#line 6049
#
#line 6049
# Allow the new domain to read and execute the program.
#line 6049
#
#line 6049
allow unpriv_userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6049

#line 6049
#
#line 6049
# Allow the new domain to be entered via the program.
#line 6049
#
#line 6049
allow unpriv_userdomain shell_exec_t:file entrypoint;
#line 6049


allow remote_login_t devpts_t:dir search;

# Use the pty created by rlogind.
#line 6059

allow remote_login_t ptyfile:chr_file { getattr relabelfrom relabelto };

#DESC Logrotate - Rotate log files
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: logrotate
#

#################################
#
# Rules for the logrotate_t domain.
#
# logrotate_t is the domain for the logrotate program.
# logrotate_exec_t is the type of the corresponding program.
#
type logrotate_t, domain, privowner, privmail;
role system_r types logrotate_t;
role sysadm_r types logrotate_t;

#line 6078
allow logrotate_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6078
allow logrotate_t lib_t:lnk_file { read getattr lock ioctl };
#line 6078
allow logrotate_t ld_so_t:file { read getattr lock execute ioctl };
#line 6078
allow logrotate_t ld_so_t:file execute_no_trans;
#line 6078
allow logrotate_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6078
allow logrotate_t shlib_t:file { read getattr lock execute ioctl };
#line 6078
allow logrotate_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6078
allow logrotate_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6078
allow logrotate_t device_t:dir search;
#line 6078
allow logrotate_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6078
;

#line 6079
# Access other processes in the same domain.
#line 6079
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 6079
# separately if desired.
#line 6079
allow logrotate_t self:process ~{ptrace setexec setfscreate};
#line 6079

#line 6079
# Access /proc/PID files for processes in the same domain.
#line 6079
allow logrotate_t self:dir { read getattr lock search ioctl };
#line 6079
allow logrotate_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6079

#line 6079
# Access file descriptions, pipes, and sockets
#line 6079
# created by processes in the same domain.
#line 6079
allow logrotate_t self:fd *;
#line 6079
allow logrotate_t self:fifo_file { ioctl read getattr lock write append };
#line 6079
allow logrotate_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6079
allow logrotate_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6079

#line 6079
# Allow the domain to communicate with other processes in the same domain.
#line 6079
allow logrotate_t self:unix_dgram_socket sendto;
#line 6079
allow logrotate_t self:unix_stream_socket connectto;
#line 6079

#line 6079
# Access System V IPC objects created by processes in the same domain.
#line 6079
allow logrotate_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6079
allow logrotate_t self:msg  { send receive };
#line 6079
allow logrotate_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6079
allow logrotate_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6079
;
type logrotate_exec_t, file_type, sysadmfile, exec_type;


#line 6082

#line 6082

#line 6082

#line 6082
#
#line 6082
# Allow the process to transition to the new domain.
#line 6082
#
#line 6082
allow system_crond_t logrotate_t:process transition;
#line 6082

#line 6082
#
#line 6082
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6082
#
#line 6082
dontaudit system_crond_t logrotate_t:process noatsecure;
#line 6082

#line 6082
#
#line 6082
# Allow the process to execute the program.
#line 6082
# 
#line 6082
allow system_crond_t logrotate_exec_t:file { read { getattr execute } };
#line 6082

#line 6082
#
#line 6082
# Allow the process to reap the new domain.
#line 6082
#
#line 6082
allow logrotate_t system_crond_t:process sigchld;
#line 6082

#line 6082
#
#line 6082
# Allow the new domain to inherit and use file 
#line 6082
# descriptions from the creating process and vice versa.
#line 6082
#
#line 6082
allow logrotate_t system_crond_t:fd use;
#line 6082
allow system_crond_t logrotate_t:fd use;
#line 6082

#line 6082
#
#line 6082
# Allow the new domain to write back to the old domain via a pipe.
#line 6082
#
#line 6082
allow logrotate_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 6082

#line 6082
#
#line 6082
# Allow the new domain to read and execute the program.
#line 6082
#
#line 6082
allow logrotate_t logrotate_exec_t:file { read getattr lock execute ioctl };
#line 6082

#line 6082
#
#line 6082
# Allow the new domain to be entered via the program.
#line 6082
#
#line 6082
allow logrotate_t logrotate_exec_t:file entrypoint;
#line 6082

#line 6082
type_transition system_crond_t logrotate_exec_t:process logrotate_t;
#line 6082

#line 6082
allow logrotate_t crond_t:fifo_file { getattr read write ioctl };
#line 6082
# a rule for privfd may make this obsolete
#line 6082
allow logrotate_t crond_t:fd use;
#line 6082
allow logrotate_t crond_t:process sigchld;
#line 6082


#line 6083

#line 6083

#line 6083
#
#line 6083
# Allow the process to transition to the new domain.
#line 6083
#
#line 6083
allow sysadm_t logrotate_t:process transition;
#line 6083

#line 6083
#
#line 6083
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6083
#
#line 6083
dontaudit sysadm_t logrotate_t:process noatsecure;
#line 6083

#line 6083
#
#line 6083
# Allow the process to execute the program.
#line 6083
# 
#line 6083
allow sysadm_t logrotate_exec_t:file { read { getattr execute } };
#line 6083

#line 6083
#
#line 6083
# Allow the process to reap the new domain.
#line 6083
#
#line 6083
allow logrotate_t sysadm_t:process sigchld;
#line 6083

#line 6083
#
#line 6083
# Allow the new domain to inherit and use file 
#line 6083
# descriptions from the creating process and vice versa.
#line 6083
#
#line 6083
allow logrotate_t sysadm_t:fd use;
#line 6083
allow sysadm_t logrotate_t:fd use;
#line 6083

#line 6083
#
#line 6083
# Allow the new domain to write back to the old domain via a pipe.
#line 6083
#
#line 6083
allow logrotate_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6083

#line 6083
#
#line 6083
# Allow the new domain to read and execute the program.
#line 6083
#
#line 6083
allow logrotate_t logrotate_exec_t:file { read getattr lock execute ioctl };
#line 6083

#line 6083
#
#line 6083
# Allow the new domain to be entered via the program.
#line 6083
#
#line 6083
allow logrotate_t logrotate_exec_t:file entrypoint;
#line 6083

#line 6083
type_transition sysadm_t logrotate_exec_t:process logrotate_t;
#line 6083

allow logrotate_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow logrotate_t devtty_t:chr_file { ioctl read getattr lock write append };

# access files in /etc
allow logrotate_t etc_t:file { getattr read };
allow logrotate_t etc_t:lnk_file read;
allow logrotate_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };

# it should not require this
allow logrotate_t sysadm_home_dir_t:dir { read getattr search };

# create lock files

#line 6096
allow logrotate_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6096
allow logrotate_t var_lock_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6096


# Create temporary files.

#line 6099
type logrotate_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6099

#line 6099

#line 6099

#line 6099

#line 6099
#
#line 6099
# Allow the process to modify the directory.
#line 6099
#
#line 6099
allow logrotate_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6099

#line 6099
#
#line 6099
# Allow the process to create the file.
#line 6099
#
#line 6099

#line 6099
allow logrotate_t logrotate_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6099
allow logrotate_t logrotate_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6099

#line 6099

#line 6099
type_transition logrotate_t tmp_t:dir logrotate_tmp_t;
#line 6099
type_transition logrotate_t tmp_t:{ file lnk_file sock_file fifo_file } logrotate_tmp_t;
#line 6099

#line 6099

#line 6099

#line 6099


# Run helper programs.
allow logrotate_t { bin_t sbin_t }:dir { read getattr lock search ioctl };
allow logrotate_t { bin_t sbin_t }:lnk_file read;

#line 6104
allow logrotate_t { bin_t sbin_t shell_exec_t etc_t ls_exec_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6104
;

# Read PID files.
allow logrotate_t pidfile:file { read getattr lock ioctl };

# Read /proc/PID directories for all domains.
allow logrotate_t proc_t:dir { read getattr lock search ioctl };
allow logrotate_t proc_t:{ file lnk_file } { read getattr lock ioctl };
allow logrotate_t { sysctl_t sysctl_kernel_t }:dir search;
allow logrotate_t sysctl_kernel_t:file { getattr read };
allow logrotate_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow logrotate_t domain:dir { read getattr lock search ioctl };
allow logrotate_t exec_type:file getattr;

# Read /dev directories and any symbolic links.
allow logrotate_t device_t:dir { read getattr lock search ioctl };
allow logrotate_t device_t:lnk_file { read getattr lock ioctl };

# Signal processes.
allow logrotate_t domain:process signal;

# Modify /var/log and other log dirs.
allow logrotate_t var_t:dir { read getattr lock search ioctl };
allow logrotate_t logfile:dir { read getattr lock search ioctl add_name remove_name write };
allow logrotate_t logfile:lnk_file read;

# Create, rename, and truncate log files.
allow logrotate_t logfile:file { create ioctl read getattr lock write setattr append link unlink rename };
allow logrotate_t wtmp_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6138


# Set a context other than the default one for newly created files.

#line 6141
allow logrotate_t self:process setfscreate;
#line 6141
allow logrotate_t proc_t:dir search;
#line 6141
allow logrotate_t proc_t:lnk_file read;
#line 6141
allow logrotate_t self:dir search;
#line 6141
allow logrotate_t self:file { read write };
#line 6141


# Change ownership on log files.
allow logrotate_t self:capability { chown dac_override kill fsetid fowner };
# for mailx
dontaudit logrotate_t self:capability { setuid setgid };

#line 6150


# Access /var/run
allow logrotate_t var_run_t:dir { read getattr lock search ioctl };

# for /var/lib/logrotate.status and /var/lib/logcheck

#line 6156
type logrotate_var_lib_t alias var_lib_logrotate_t, file_type, sysadmfile;
#line 6156

#line 6156

#line 6156

#line 6156

#line 6156
#
#line 6156
# Allow the process to modify the directory.
#line 6156
#
#line 6156
allow logrotate_t var_lib_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6156

#line 6156
#
#line 6156
# Allow the process to create the file.
#line 6156
#
#line 6156

#line 6156
allow logrotate_t logrotate_var_lib_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6156
allow logrotate_t logrotate_var_lib_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6156

#line 6156

#line 6156
type_transition logrotate_t var_lib_t:dir logrotate_var_lib_t;
#line 6156
type_transition logrotate_t var_lib_t:{ file lnk_file sock_file fifo_file } logrotate_var_lib_t;
#line 6156

#line 6156

#line 6156

#line 6156


# Write to /var/spool/slrnpull - should be moved into its own type.
allow logrotate_t var_spool_t:dir { search write add_name remove_name };
allow logrotate_t var_spool_t:file { rename create setattr unlink };

# Access terminals.
allow logrotate_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };


# for /var/backups on Debian
#line 6169



#line 6171
allow logrotate_t etc_t:lnk_file read;
#line 6171

#line 6171
allow logrotate_t locale_t:dir { read getattr lock search ioctl };
#line 6171
allow logrotate_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6171

#line 6171


allow logrotate_t fs_t:filesystem getattr;

#line 6174
allow logrotate_t shell_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6174

#DESC Modutil - Dynamic module utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: modutils
#

#################################
#
# Rules for the module utility domains.
#
type modules_dep_t, file_type, sysadmfile;
type modules_conf_t, file_type, sysadmfile;
type modules_object_t, file_type, sysadmfile;


#################################
#
# Rules for the depmod_t domain.
#
type depmod_t, domain;
role system_r types depmod_t;
role sysadm_r types depmod_t;


#line 6198
allow depmod_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6198
allow depmod_t lib_t:lnk_file { read getattr lock ioctl };
#line 6198
allow depmod_t ld_so_t:file { read getattr lock execute ioctl };
#line 6198
allow depmod_t ld_so_t:file execute_no_trans;
#line 6198
allow depmod_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6198
allow depmod_t shlib_t:file { read getattr lock execute ioctl };
#line 6198
allow depmod_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6198
allow depmod_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6198
allow depmod_t device_t:dir search;
#line 6198
allow depmod_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6198


type depmod_exec_t, file_type, exec_type, sysadmfile;

#line 6201

#line 6201

#line 6201
#
#line 6201
# Allow the process to transition to the new domain.
#line 6201
#
#line 6201
allow initrc_t depmod_t:process transition;
#line 6201

#line 6201
#
#line 6201
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6201
#
#line 6201
dontaudit initrc_t depmod_t:process noatsecure;
#line 6201

#line 6201
#
#line 6201
# Allow the process to execute the program.
#line 6201
# 
#line 6201
allow initrc_t depmod_exec_t:file { read { getattr execute } };
#line 6201

#line 6201
#
#line 6201
# Allow the process to reap the new domain.
#line 6201
#
#line 6201
allow depmod_t initrc_t:process sigchld;
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to inherit and use file 
#line 6201
# descriptions from the creating process and vice versa.
#line 6201
#
#line 6201
allow depmod_t initrc_t:fd use;
#line 6201
allow initrc_t depmod_t:fd use;
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to write back to the old domain via a pipe.
#line 6201
#
#line 6201
allow depmod_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to read and execute the program.
#line 6201
#
#line 6201
allow depmod_t depmod_exec_t:file { read getattr lock execute ioctl };
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to be entered via the program.
#line 6201
#
#line 6201
allow depmod_t depmod_exec_t:file entrypoint;
#line 6201

#line 6201
type_transition initrc_t depmod_exec_t:process depmod_t;
#line 6201

allow depmod_t { bin_t sbin_t }:dir search;

#line 6203
allow depmod_t depmod_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6203


#line 6204

#line 6204

#line 6204
#
#line 6204
# Allow the process to transition to the new domain.
#line 6204
#
#line 6204
allow sysadm_t depmod_t:process transition;
#line 6204

#line 6204
#
#line 6204
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6204
#
#line 6204
dontaudit sysadm_t depmod_t:process noatsecure;
#line 6204

#line 6204
#
#line 6204
# Allow the process to execute the program.
#line 6204
# 
#line 6204
allow sysadm_t depmod_exec_t:file { read { getattr execute } };
#line 6204

#line 6204
#
#line 6204
# Allow the process to reap the new domain.
#line 6204
#
#line 6204
allow depmod_t sysadm_t:process sigchld;
#line 6204

#line 6204
#
#line 6204
# Allow the new domain to inherit and use file 
#line 6204
# descriptions from the creating process and vice versa.
#line 6204
#
#line 6204
allow depmod_t sysadm_t:fd use;
#line 6204
allow sysadm_t depmod_t:fd use;
#line 6204

#line 6204
#
#line 6204
# Allow the new domain to write back to the old domain via a pipe.
#line 6204
#
#line 6204
allow depmod_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6204

#line 6204
#
#line 6204
# Allow the new domain to read and execute the program.
#line 6204
#
#line 6204
allow depmod_t depmod_exec_t:file { read getattr lock execute ioctl };
#line 6204

#line 6204
#
#line 6204
# Allow the new domain to be entered via the program.
#line 6204
#
#line 6204
allow depmod_t depmod_exec_t:file entrypoint;
#line 6204

#line 6204
type_transition sysadm_t depmod_exec_t:process depmod_t;
#line 6204


# Inherit and use descriptors from init and login programs.
allow depmod_t { init_t privfd }:fd use;

allow depmod_t { etc_t etc_runtime_t }:file { getattr read };
allow depmod_t { device_t proc_t }:dir search;
allow depmod_t proc_t:file { getattr read };
allow depmod_t fs_t:filesystem getattr;

# read system.map
allow depmod_t boot_t:dir search;
allow depmod_t system_map_t:file { getattr read };

# Read conf.modules.
allow depmod_t modules_conf_t:file { read getattr lock ioctl };

# Create modules.dep.

#line 6222

#line 6222

#line 6222

#line 6222
#
#line 6222
# Allow the process to modify the directory.
#line 6222
#
#line 6222
allow depmod_t modules_object_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6222

#line 6222
#
#line 6222
# Allow the process to create the file.
#line 6222
#
#line 6222

#line 6222
allow depmod_t modules_dep_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6222
allow depmod_t modules_dep_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6222

#line 6222

#line 6222
type_transition depmod_t modules_object_t:dir modules_dep_t;
#line 6222
type_transition depmod_t modules_object_t:{ file lnk_file sock_file fifo_file } modules_dep_t;
#line 6222

#line 6222

#line 6222


# Read module objects.
allow depmod_t modules_object_t:dir { read getattr lock search ioctl };
allow depmod_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };

# Access terminals.
allow depmod_t { console_device_t initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };


# Read System.map from home directories.
allow depmod_t { home_root_t user_home_dir_type sysadm_home_dir_t }:dir { read getattr lock search ioctl };

#line 6234
allow depmod_t { user_home_type sysadm_home_t }:dir { read getattr lock search ioctl };
#line 6234
allow depmod_t { user_home_type sysadm_home_t }:{ file lnk_file } { read getattr lock ioctl };
#line 6234


#################################
#
# Rules for the insmod_t domain.
#

type insmod_t, domain, privlog;
role system_r types insmod_t;
role sysadm_r types insmod_t;


#line 6245
allow insmod_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6245
allow insmod_t lib_t:lnk_file { read getattr lock ioctl };
#line 6245
allow insmod_t ld_so_t:file { read getattr lock execute ioctl };
#line 6245
allow insmod_t ld_so_t:file execute_no_trans;
#line 6245
allow insmod_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6245
allow insmod_t shlib_t:file { read getattr lock execute ioctl };
#line 6245
allow insmod_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6245
allow insmod_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6245
allow insmod_t device_t:dir search;
#line 6245
allow insmod_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6245


#line 6246
allow insmod_t etc_t:lnk_file read;
#line 6246

#line 6246
allow insmod_t locale_t:dir { read getattr lock search ioctl };
#line 6246
allow insmod_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6246

#line 6246


allow insmod_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

type insmod_exec_t, file_type, exec_type, sysadmfile;

#line 6251

#line 6251

#line 6251
#
#line 6251
# Allow the process to transition to the new domain.
#line 6251
#
#line 6251
allow { initrc_t kernel_t } insmod_t:process transition;
#line 6251

#line 6251
#
#line 6251
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6251
#
#line 6251
dontaudit { initrc_t kernel_t } insmod_t:process noatsecure;
#line 6251

#line 6251
#
#line 6251
# Allow the process to execute the program.
#line 6251
# 
#line 6251
allow { initrc_t kernel_t } insmod_exec_t:file { read { getattr execute } };
#line 6251

#line 6251
#
#line 6251
# Allow the process to reap the new domain.
#line 6251
#
#line 6251
allow insmod_t { initrc_t kernel_t }:process sigchld;
#line 6251

#line 6251
#
#line 6251
# Allow the new domain to inherit and use file 
#line 6251
# descriptions from the creating process and vice versa.
#line 6251
#
#line 6251
allow insmod_t { initrc_t kernel_t }:fd use;
#line 6251
allow { initrc_t kernel_t } insmod_t:fd use;
#line 6251

#line 6251
#
#line 6251
# Allow the new domain to write back to the old domain via a pipe.
#line 6251
#
#line 6251
allow insmod_t { initrc_t kernel_t }:fifo_file { ioctl read getattr lock write append };
#line 6251

#line 6251
#
#line 6251
# Allow the new domain to read and execute the program.
#line 6251
#
#line 6251
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 6251

#line 6251
#
#line 6251
# Allow the new domain to be entered via the program.
#line 6251
#
#line 6251
allow insmod_t insmod_exec_t:file entrypoint;
#line 6251

#line 6251
type_transition { initrc_t kernel_t } insmod_exec_t:process insmod_t;
#line 6251

allow initrc_t insmod_exec_t:lnk_file read;

#line 6253
allow insmod_t insmod_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6253

allow insmod_t { bin_t sbin_t }:dir search;
allow insmod_t sbin_t:lnk_file read;
allow insmod_t init_t:fd use;

#line 6257

#line 6257

#line 6257
#
#line 6257
# Allow the process to transition to the new domain.
#line 6257
#
#line 6257
allow sysadm_t insmod_t:process transition;
#line 6257

#line 6257
#
#line 6257
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6257
#
#line 6257
dontaudit sysadm_t insmod_t:process noatsecure;
#line 6257

#line 6257
#
#line 6257
# Allow the process to execute the program.
#line 6257
# 
#line 6257
allow sysadm_t insmod_exec_t:file { read { getattr execute } };
#line 6257

#line 6257
#
#line 6257
# Allow the process to reap the new domain.
#line 6257
#
#line 6257
allow insmod_t sysadm_t:process sigchld;
#line 6257

#line 6257
#
#line 6257
# Allow the new domain to inherit and use file 
#line 6257
# descriptions from the creating process and vice versa.
#line 6257
#
#line 6257
allow insmod_t sysadm_t:fd use;
#line 6257
allow sysadm_t insmod_t:fd use;
#line 6257

#line 6257
#
#line 6257
# Allow the new domain to write back to the old domain via a pipe.
#line 6257
#
#line 6257
allow insmod_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6257

#line 6257
#
#line 6257
# Allow the new domain to read and execute the program.
#line 6257
#
#line 6257
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 6257

#line 6257
#
#line 6257
# Allow the new domain to be entered via the program.
#line 6257
#
#line 6257
allow insmod_t insmod_exec_t:file entrypoint;
#line 6257

#line 6257
type_transition sysadm_t insmod_exec_t:process insmod_t;
#line 6257


# Read module config and dependency information
allow insmod_t fs_t:filesystem getattr;
allow insmod_t { modules_conf_t modules_dep_t }:file { getattr read };

# Read module objects.
allow insmod_t modules_object_t:dir { read getattr lock search ioctl };
allow insmod_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };

allow insmod_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Use the sys_module capability.
allow insmod_t self:capability { sys_module kill };

# for ipv6
allow insmod_t self:capability net_raw;

# Inherit and use descriptors from init.
allow insmod_t privfd:fd use;

# I do not know why insmod sends signals or what signals it sends
allow insmod_t domain:process signal;

# Rules for /proc/sys/kernel/tainted
allow insmod_t { proc_t sysctl_t sysctl_kernel_t }:dir search;
allow insmod_t sysctl_kernel_t:file { setattr { ioctl read getattr lock write append } };
allow insmod_t sysctl_t:file write;
allow insmod_t proc_t:file { getattr read };

# /var/log/ksymoops/*
allow insmod_t var_t:dir { read getattr lock search ioctl };
allow insmod_t var_log_t:dir { read getattr lock search ioctl };
allow insmod_t var_log_ksyms_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow insmod_t var_log_ksyms_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };

#line 6295

#line 6295

#line 6295
allow system_crond_t var_log_ksyms_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6295
allow system_crond_t var_log_ksyms_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6295

#line 6295


#line 6299


allow insmod_t device_t:dir search;
allow insmod_t etc_runtime_t:file { getattr read };
allow insmod_t self:process { fork { sigchld sigkill sigstop signull signal } };

# Access terminals.
allow insmod_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };



#line 6309
allow insmod_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6309
allow insmod_t lib_t:lnk_file { read getattr lock ioctl };
#line 6309
allow insmod_t ld_so_t:file { read getattr lock execute ioctl };
#line 6309
allow insmod_t ld_so_t:file execute_no_trans;
#line 6309
allow insmod_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6309
allow insmod_t shlib_t:file { read getattr lock execute ioctl };
#line 6309
allow insmod_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6309
allow insmod_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6309
allow insmod_t device_t:dir search;
#line 6309
allow insmod_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6309


# for when /var is not mounted early in the boot
dontaudit insmod_t file_t:dir search;

#################################
#
# Rules for the update_modules_t domain.
#
type update_modules_t, domain, privlog;
type update_modules_exec_t, file_type, exec_type, sysadmfile;

role system_r types update_modules_t;
role sysadm_r types update_modules_t;


#line 6324

#line 6324

#line 6324
#
#line 6324
# Allow the process to transition to the new domain.
#line 6324
#
#line 6324
allow { initrc_t sysadm_t } update_modules_t:process transition;
#line 6324

#line 6324
#
#line 6324
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6324
#
#line 6324
dontaudit { initrc_t sysadm_t } update_modules_t:process noatsecure;
#line 6324

#line 6324
#
#line 6324
# Allow the process to execute the program.
#line 6324
# 
#line 6324
allow { initrc_t sysadm_t } update_modules_exec_t:file { read { getattr execute } };
#line 6324

#line 6324
#
#line 6324
# Allow the process to reap the new domain.
#line 6324
#
#line 6324
allow update_modules_t { initrc_t sysadm_t }:process sigchld;
#line 6324

#line 6324
#
#line 6324
# Allow the new domain to inherit and use file 
#line 6324
# descriptions from the creating process and vice versa.
#line 6324
#
#line 6324
allow update_modules_t { initrc_t sysadm_t }:fd use;
#line 6324
allow { initrc_t sysadm_t } update_modules_t:fd use;
#line 6324

#line 6324
#
#line 6324
# Allow the new domain to write back to the old domain via a pipe.
#line 6324
#
#line 6324
allow update_modules_t { initrc_t sysadm_t }:fifo_file { ioctl read getattr lock write append };
#line 6324

#line 6324
#
#line 6324
# Allow the new domain to read and execute the program.
#line 6324
#
#line 6324
allow update_modules_t update_modules_exec_t:file { read getattr lock execute ioctl };
#line 6324

#line 6324
#
#line 6324
# Allow the new domain to be entered via the program.
#line 6324
#
#line 6324
allow update_modules_t update_modules_exec_t:file entrypoint;
#line 6324

#line 6324
type_transition { initrc_t sysadm_t } update_modules_exec_t:process update_modules_t;
#line 6324

allow update_modules_t privfd:fd use;
allow update_modules_t init_t:fd use;

allow update_modules_t device_t:dir { getattr search };
allow update_modules_t { console_device_t devtty_t }:chr_file { ioctl read getattr lock write append };
allow update_modules_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };

dontaudit update_modules_t sysadm_home_dir_t:dir search;


#line 6334
allow update_modules_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6334
allow update_modules_t lib_t:lnk_file { read getattr lock ioctl };
#line 6334
allow update_modules_t ld_so_t:file { read getattr lock execute ioctl };
#line 6334
allow update_modules_t ld_so_t:file execute_no_trans;
#line 6334
allow update_modules_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6334
allow update_modules_t shlib_t:file { read getattr lock execute ioctl };
#line 6334
allow update_modules_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6334
allow update_modules_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6334
allow update_modules_t device_t:dir search;
#line 6334
allow update_modules_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6334

allow update_modules_t self:process { fork sigchld };
allow update_modules_t self:fifo_file { ioctl read getattr lock write append };
allow update_modules_t modules_dep_t:file { ioctl read getattr lock write append };

#line 6338

#line 6338

#line 6338

#line 6338
#
#line 6338
# Allow the process to modify the directory.
#line 6338
#
#line 6338
allow update_modules_t modules_object_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6338

#line 6338
#
#line 6338
# Allow the process to create the file.
#line 6338
#
#line 6338

#line 6338
allow update_modules_t modules_conf_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6338
allow update_modules_t modules_conf_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6338

#line 6338

#line 6338
type_transition update_modules_t modules_object_t:dir modules_conf_t;
#line 6338
type_transition update_modules_t modules_object_t:{ file lnk_file sock_file fifo_file } modules_conf_t;
#line 6338

#line 6338

#line 6338


#line 6339

#line 6339

#line 6339
#
#line 6339
# Allow the process to transition to the new domain.
#line 6339
#
#line 6339
allow update_modules_t depmod_t:process transition;
#line 6339

#line 6339
#
#line 6339
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6339
#
#line 6339
dontaudit update_modules_t depmod_t:process noatsecure;
#line 6339

#line 6339
#
#line 6339
# Allow the process to execute the program.
#line 6339
# 
#line 6339
allow update_modules_t depmod_exec_t:file { read { getattr execute } };
#line 6339

#line 6339
#
#line 6339
# Allow the process to reap the new domain.
#line 6339
#
#line 6339
allow depmod_t update_modules_t:process sigchld;
#line 6339

#line 6339
#
#line 6339
# Allow the new domain to inherit and use file 
#line 6339
# descriptions from the creating process and vice versa.
#line 6339
#
#line 6339
allow depmod_t update_modules_t:fd use;
#line 6339
allow update_modules_t depmod_t:fd use;
#line 6339

#line 6339
#
#line 6339
# Allow the new domain to write back to the old domain via a pipe.
#line 6339
#
#line 6339
allow depmod_t update_modules_t:fifo_file { ioctl read getattr lock write append };
#line 6339

#line 6339
#
#line 6339
# Allow the new domain to read and execute the program.
#line 6339
#
#line 6339
allow depmod_t depmod_exec_t:file { read getattr lock execute ioctl };
#line 6339

#line 6339
#
#line 6339
# Allow the new domain to be entered via the program.
#line 6339
#
#line 6339
allow depmod_t depmod_exec_t:file entrypoint;
#line 6339

#line 6339
type_transition update_modules_t depmod_exec_t:process depmod_t;
#line 6339


#line 6340
allow update_modules_t { shell_exec_t bin_t sbin_t update_modules_exec_t etc_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6340

allow update_modules_t bin_t:lnk_file read;
allow update_modules_t { sbin_t bin_t }:dir search;
allow update_modules_t { etc_t etc_runtime_t }:file { read getattr lock ioctl };
allow update_modules_t etc_t:lnk_file read;
allow update_modules_t fs_t:filesystem getattr;

allow update_modules_t proc_t:dir search;
allow update_modules_t proc_t:file { read getattr lock ioctl };
allow update_modules_t { self proc_t }:lnk_file read;
allow update_modules_t { sysctl_t sysctl_kernel_t }:dir search;
allow update_modules_t sysctl_kernel_t:file { getattr read };
allow update_modules_t self:dir search;
allow update_modules_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };


#line 6355

#line 6355

#line 6355

#line 6355
#
#line 6355
# Allow the process to modify the directory.
#line 6355
#
#line 6355
allow update_modules_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6355

#line 6355
#
#line 6355
# Allow the process to create the file.
#line 6355
#
#line 6355

#line 6355
allow update_modules_t modules_conf_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6355
allow update_modules_t modules_conf_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6355

#line 6355

#line 6355
type_transition update_modules_t etc_t:dir modules_conf_t;
#line 6355
type_transition update_modules_t etc_t:{ file lnk_file sock_file fifo_file } modules_conf_t;
#line 6355

#line 6355

#line 6355


# for when /etc/modules.conf gets the wrong type
allow update_modules_t etc_t:file unlink;


#line 6360
type update_modules_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6360

#line 6360

#line 6360

#line 6360

#line 6360
#
#line 6360
# Allow the process to modify the directory.
#line 6360
#
#line 6360
allow update_modules_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6360

#line 6360
#
#line 6360
# Allow the process to create the file.
#line 6360
#
#line 6360

#line 6360
allow update_modules_t update_modules_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6360
allow update_modules_t update_modules_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6360

#line 6360

#line 6360
type_transition update_modules_t tmp_t:dir update_modules_tmp_t;
#line 6360
type_transition update_modules_t tmp_t:{ file lnk_file sock_file fifo_file } update_modules_tmp_t;
#line 6360

#line 6360

#line 6360

#line 6360

#DESC Mount - Filesystem mount utilities
#
# Macros for mount
#
# Author:  Brian May <bam@snoopy.apana.org.au>
# X-Debian-Packages: mount
#
# based on the work of:
#          Mark Westerman mark.westerman@csoconline.com
#

type mount_exec_t, file_type, sysadmfile, exec_type;


#line 6374
#
#line 6374
# Rules for the mount_t domain, used by the sysadm_t domain.
#line 6374
#
#line 6374
# mount_t is the domain for the mount process.
#line 6374
#
#line 6374
# This macro will not be included by all users and it may be included twice if
#line 6374
# called from other macros, so we need protection for this do not call this
#line 6374
# macro if mount_def is defined
#line 6374

#line 6374
#
#line 6374
type mount_t, domain, privlog;
#line 6374

#line 6374

#line 6374
allow mount_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6374
allow mount_t lib_t:lnk_file { read getattr lock ioctl };
#line 6374
allow mount_t ld_so_t:file { read getattr lock execute ioctl };
#line 6374
allow mount_t ld_so_t:file execute_no_trans;
#line 6374
allow mount_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6374
allow mount_t shlib_t:file { read getattr lock execute ioctl };
#line 6374
allow mount_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6374
allow mount_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6374
allow mount_t device_t:dir search;
#line 6374
allow mount_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6374

#line 6374

#line 6374
# when mount is run by sysadm goto mount_t domain
#line 6374

#line 6374

#line 6374

#line 6374
#
#line 6374
# Allow the process to transition to the new domain.
#line 6374
#
#line 6374
allow sysadm_t mount_t:process transition;
#line 6374

#line 6374
#
#line 6374
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6374
#
#line 6374
dontaudit sysadm_t mount_t:process noatsecure;
#line 6374

#line 6374
#
#line 6374
# Allow the process to execute the program.
#line 6374
# 
#line 6374
allow sysadm_t mount_exec_t:file { read { getattr execute } };
#line 6374

#line 6374
#
#line 6374
# Allow the process to reap the new domain.
#line 6374
#
#line 6374
allow mount_t sysadm_t:process sigchld;
#line 6374

#line 6374
#
#line 6374
# Allow the new domain to inherit and use file 
#line 6374
# descriptions from the creating process and vice versa.
#line 6374
#
#line 6374
allow mount_t sysadm_t:fd use;
#line 6374
allow sysadm_t mount_t:fd use;
#line 6374

#line 6374
#
#line 6374
# Allow the new domain to write back to the old domain via a pipe.
#line 6374
#
#line 6374
allow mount_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6374

#line 6374
#
#line 6374
# Allow the new domain to read and execute the program.
#line 6374
#
#line 6374
allow mount_t mount_exec_t:file { read getattr lock execute ioctl };
#line 6374

#line 6374
#
#line 6374
# Allow the new domain to be entered via the program.
#line 6374
#
#line 6374
allow mount_t mount_exec_t:file entrypoint;
#line 6374

#line 6374
type_transition sysadm_t mount_exec_t:process mount_t;
#line 6374

#line 6374

#line 6374
allow mount_t proc_t:dir search;
#line 6374

#line 6374

#line 6374
type mount_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6374

#line 6374

#line 6374

#line 6374

#line 6374
#
#line 6374
# Allow the process to modify the directory.
#line 6374
#
#line 6374
allow mount_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6374

#line 6374
#
#line 6374
# Allow the process to create the file.
#line 6374
#
#line 6374

#line 6374
allow mount_t mount_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6374
allow mount_t mount_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6374

#line 6374

#line 6374
type_transition mount_t tmp_t:dir mount_tmp_t;
#line 6374
type_transition mount_t tmp_t:{ file lnk_file sock_file fifo_file } mount_tmp_t;
#line 6374

#line 6374

#line 6374

#line 6374

#line 6374

#line 6374
# Use capabilities.
#line 6374
allow mount_t self:capability { net_bind_service sys_rawio sys_admin };
#line 6374

#line 6374
# Create and modify /etc/mtab.
#line 6374

#line 6374

#line 6374

#line 6374

#line 6374
#
#line 6374
# Allow the process to modify the directory.
#line 6374
#
#line 6374
allow mount_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6374

#line 6374
#
#line 6374
# Allow the process to create the file.
#line 6374
#
#line 6374

#line 6374

#line 6374
allow mount_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6374

#line 6374

#line 6374
type_transition mount_t etc_t:file etc_runtime_t;
#line 6374

#line 6374

#line 6374

#line 6374

#line 6374
allow mount_t etc_t:file { getattr read };
#line 6374

#line 6374

#line 6374
allow mount_t etc_t:lnk_file read;
#line 6374

#line 6374
allow mount_t locale_t:dir { read getattr lock search ioctl };
#line 6374
allow mount_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6374

#line 6374

#line 6374

#line 6374
# Access the terminal.
#line 6374
allow mount_t sysadm_tty_device_t:chr_file { getattr read write ioctl };
#line 6374
allow mount_t sysadm_devpts_t:chr_file { getattr read write };
#line 6374

#line 6374

role sysadm_r types mount_t;
role system_r types mount_t;


#line 6378

#line 6378

#line 6378
#
#line 6378
# Allow the process to transition to the new domain.
#line 6378
#
#line 6378
allow initrc_t mount_t:process transition;
#line 6378

#line 6378
#
#line 6378
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6378
#
#line 6378
dontaudit initrc_t mount_t:process noatsecure;
#line 6378

#line 6378
#
#line 6378
# Allow the process to execute the program.
#line 6378
# 
#line 6378
allow initrc_t mount_exec_t:file { read { getattr execute } };
#line 6378

#line 6378
#
#line 6378
# Allow the process to reap the new domain.
#line 6378
#
#line 6378
allow mount_t initrc_t:process sigchld;
#line 6378

#line 6378
#
#line 6378
# Allow the new domain to inherit and use file 
#line 6378
# descriptions from the creating process and vice versa.
#line 6378
#
#line 6378
allow mount_t initrc_t:fd use;
#line 6378
allow initrc_t mount_t:fd use;
#line 6378

#line 6378
#
#line 6378
# Allow the new domain to write back to the old domain via a pipe.
#line 6378
#
#line 6378
allow mount_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6378

#line 6378
#
#line 6378
# Allow the new domain to read and execute the program.
#line 6378
#
#line 6378
allow mount_t mount_exec_t:file { read getattr lock execute ioctl };
#line 6378

#line 6378
#
#line 6378
# Allow the new domain to be entered via the program.
#line 6378
#
#line 6378
allow mount_t mount_exec_t:file entrypoint;
#line 6378

#line 6378
type_transition initrc_t mount_exec_t:process mount_t;
#line 6378

allow mount_t init_t:fd use;
allow mount_t privfd:fd use;

allow mount_t self:capability { ipc_lock dac_override };
allow mount_t self:process { fork { sigchld sigkill sigstop signull signal } };

allow mount_t file_type:dir search;

# Access disk devices.
allow mount_t fixed_disk_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };
allow mount_t removable_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };

# Mount, remount and unmount file systems.
allow mount_t fs_type:filesystem { mount remount unmount getattr };
allow mount_t file_t:dir mounton;
allow mount_t usr_t:dir mounton;
allow mount_t proc_t:dir mounton;
allow mount_t root_t:dir mounton;
allow mount_t home_root_t:dir mounton;
# On some RedHat systems, /boot is a mount point
allow mount_t boot_t:dir mounton;
allow mount_t device_t:dir mounton;
#line 6403

allow mount_t root_t:filesystem unmount;


#DESC Netutils - Network utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil>
# X-Debian-Packages: netbase iputils arping tcpdump 
#

#
# Rules for the netutils_t domain.
# This domain is for network utilities that require access to
# special protocol families.
#
type netutils_t, domain, privlog;
type netutils_exec_t, file_type, sysadmfile, exec_type;
role system_r types netutils_t;
role sysadm_r types netutils_t;


#line 6423
allow netutils_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6423
allow netutils_t lib_t:lnk_file { read getattr lock ioctl };
#line 6423
allow netutils_t ld_so_t:file { read getattr lock execute ioctl };
#line 6423
allow netutils_t ld_so_t:file execute_no_trans;
#line 6423
allow netutils_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6423
allow netutils_t shlib_t:file { read getattr lock execute ioctl };
#line 6423
allow netutils_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6423
allow netutils_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6423
allow netutils_t device_t:dir search;
#line 6423
allow netutils_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6423


#line 6424
#
#line 6424
# Allow the domain to create and use UDP and TCP sockets.
#line 6424
# Other kinds of sockets must be separately authorized for use.
#line 6424
allow netutils_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6424
allow netutils_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6424

#line 6424
#
#line 6424
# Allow the domain to send UDP packets.
#line 6424
# Since the destination sockets type is unknown, the generic
#line 6424
# any_socket_t type is used as a placeholder.
#line 6424
#
#line 6424
allow netutils_t any_socket_t:udp_socket sendto;
#line 6424

#line 6424
#
#line 6424
# Allow the domain to send using any network interface.
#line 6424
# netif_type is a type attribute for all network interface types.
#line 6424
#
#line 6424
allow netutils_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6424

#line 6424
#
#line 6424
# Allow packets sent by the domain to be received on any network interface.
#line 6424
#
#line 6424
allow netutils_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6424

#line 6424
#
#line 6424
# Allow the domain to receive packets from any network interface.
#line 6424
# netmsg_type is a type attribute for all default message types.
#line 6424
#
#line 6424
allow netutils_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6424

#line 6424
#
#line 6424
# Allow the domain to initiate or accept TCP connections 
#line 6424
# on any network interface.
#line 6424
#
#line 6424
allow netutils_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6424

#line 6424
#
#line 6424
# Receive resets from the TCP reset socket.
#line 6424
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6424
#
#line 6424
allow netutils_t tcp_socket_t:tcp_socket recvfrom;
#line 6424

#line 6424
dontaudit netutils_t tcp_socket_t:tcp_socket connectto;
#line 6424

#line 6424
#
#line 6424
# Allow the domain to send to any node.
#line 6424
# node_type is a type attribute for all node types.
#line 6424
#
#line 6424
allow netutils_t node_type:node { tcp_send udp_send rawip_send };
#line 6424

#line 6424
#
#line 6424
# Allow packets sent by the domain to be received from any node.
#line 6424
#
#line 6424
allow netutils_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6424

#line 6424
#
#line 6424
# Allow the domain to send NFS client requests via the socket
#line 6424
# created by mount.
#line 6424
#
#line 6424
allow netutils_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6424

#line 6424
#
#line 6424
# Bind to the default port type.
#line 6424
# Other port types must be separately authorized.
#line 6424
#
#line 6424
allow netutils_t port_t:udp_socket name_bind;
#line 6424
allow netutils_t port_t:tcp_socket name_bind;
#line 6424



#line 6426

#line 6426

#line 6426
#
#line 6426
# Allow the process to transition to the new domain.
#line 6426
#
#line 6426
allow initrc_t netutils_t:process transition;
#line 6426

#line 6426
#
#line 6426
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6426
#
#line 6426
dontaudit initrc_t netutils_t:process noatsecure;
#line 6426

#line 6426
#
#line 6426
# Allow the process to execute the program.
#line 6426
# 
#line 6426
allow initrc_t netutils_exec_t:file { read { getattr execute } };
#line 6426

#line 6426
#
#line 6426
# Allow the process to reap the new domain.
#line 6426
#
#line 6426
allow netutils_t initrc_t:process sigchld;
#line 6426

#line 6426
#
#line 6426
# Allow the new domain to inherit and use file 
#line 6426
# descriptions from the creating process and vice versa.
#line 6426
#
#line 6426
allow netutils_t initrc_t:fd use;
#line 6426
allow initrc_t netutils_t:fd use;
#line 6426

#line 6426
#
#line 6426
# Allow the new domain to write back to the old domain via a pipe.
#line 6426
#
#line 6426
allow netutils_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6426

#line 6426
#
#line 6426
# Allow the new domain to read and execute the program.
#line 6426
#
#line 6426
allow netutils_t netutils_exec_t:file { read getattr lock execute ioctl };
#line 6426

#line 6426
#
#line 6426
# Allow the new domain to be entered via the program.
#line 6426
#
#line 6426
allow netutils_t netutils_exec_t:file entrypoint;
#line 6426

#line 6426
type_transition initrc_t netutils_exec_t:process netutils_t;
#line 6426


#line 6427

#line 6427

#line 6427
#
#line 6427
# Allow the process to transition to the new domain.
#line 6427
#
#line 6427
allow sysadm_t netutils_t:process transition;
#line 6427

#line 6427
#
#line 6427
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6427
#
#line 6427
dontaudit sysadm_t netutils_t:process noatsecure;
#line 6427

#line 6427
#
#line 6427
# Allow the process to execute the program.
#line 6427
# 
#line 6427
allow sysadm_t netutils_exec_t:file { read { getattr execute } };
#line 6427

#line 6427
#
#line 6427
# Allow the process to reap the new domain.
#line 6427
#
#line 6427
allow netutils_t sysadm_t:process sigchld;
#line 6427

#line 6427
#
#line 6427
# Allow the new domain to inherit and use file 
#line 6427
# descriptions from the creating process and vice versa.
#line 6427
#
#line 6427
allow netutils_t sysadm_t:fd use;
#line 6427
allow sysadm_t netutils_t:fd use;
#line 6427

#line 6427
#
#line 6427
# Allow the new domain to write back to the old domain via a pipe.
#line 6427
#
#line 6427
allow netutils_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6427

#line 6427
#
#line 6427
# Allow the new domain to read and execute the program.
#line 6427
#
#line 6427
allow netutils_t netutils_exec_t:file { read getattr lock execute ioctl };
#line 6427

#line 6427
#
#line 6427
# Allow the new domain to be entered via the program.
#line 6427
#
#line 6427
allow netutils_t netutils_exec_t:file entrypoint;
#line 6427

#line 6427
type_transition sysadm_t netutils_exec_t:process netutils_t;
#line 6427


# Inherit and use descriptors from init.
allow netutils_t init_t:fd use;

allow netutils_t self:process { fork { sigchld sigkill sigstop signull signal } };

# Perform network administration operations and have raw access to the network.
allow netutils_t self:capability { net_admin net_raw setuid setgid };

# Create and use netlink sockets.
allow netutils_t self:netlink_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Create and use packet sockets.
allow netutils_t self:packet_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Create and use UDP sockets.
allow netutils_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Create and use TCP sockets.
allow netutils_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

allow netutils_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Read certain files in /etc
allow netutils_t etc_t:file { read getattr lock ioctl };
allow netutils_t resolv_conf_t:file { read getattr lock ioctl };

#line 6454
allow netutils_t etc_t:lnk_file read;
#line 6454

#line 6454
allow netutils_t locale_t:dir { read getattr lock search ioctl };
#line 6454
allow netutils_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6454

#line 6454


allow netutils_t fs_t:filesystem getattr;

# Access terminals.
allow netutils_t privfd:fd use;
allow netutils_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };

#DESC Newrole - SELinux utility to run a shell with a new role
#
# Authors:  Anthony Colatrella (NSA) 
# Maintained by Stephen Smalley <sds@epoch.ncsc.mil>
# X-Debian-Packages: policycoreutils
#

#################################
#
# Rules for the newrole_t domain.
#
# newrole_t is the domain for the newrole program.
# newrole_exec_t is the type of the newrole executable.
#
type newrole_t, domain, privrole, privowner, privlog, auth, privfd;

#line 6477
role user_r types newrole_t;
#line 6477
role staff_r types newrole_t;
#line 6477

role sysadm_r types newrole_t;


#line 6480
# Access other processes in the same domain.
#line 6480
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 6480
# separately if desired.
#line 6480
allow newrole_t self:process ~{ptrace setexec setfscreate};
#line 6480

#line 6480
# Access /proc/PID files for processes in the same domain.
#line 6480
allow newrole_t self:dir { read getattr lock search ioctl };
#line 6480
allow newrole_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6480

#line 6480
# Access file descriptions, pipes, and sockets
#line 6480
# created by processes in the same domain.
#line 6480
allow newrole_t self:fd *;
#line 6480
allow newrole_t self:fifo_file { ioctl read getattr lock write append };
#line 6480
allow newrole_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6480
allow newrole_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6480

#line 6480
# Allow the domain to communicate with other processes in the same domain.
#line 6480
allow newrole_t self:unix_dgram_socket sendto;
#line 6480
allow newrole_t self:unix_stream_socket connectto;
#line 6480

#line 6480
# Access System V IPC objects created by processes in the same domain.
#line 6480
allow newrole_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6480
allow newrole_t self:msg  { send receive };
#line 6480
allow newrole_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6480
allow newrole_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6480
;


#line 6482
allow newrole_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6482
allow newrole_t lib_t:lnk_file { read getattr lock ioctl };
#line 6482
allow newrole_t ld_so_t:file { read getattr lock execute ioctl };
#line 6482
allow newrole_t ld_so_t:file execute_no_trans;
#line 6482
allow newrole_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6482
allow newrole_t shlib_t:file { read getattr lock execute ioctl };
#line 6482
allow newrole_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6482
allow newrole_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6482
allow newrole_t device_t:dir search;
#line 6482
allow newrole_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6482


#line 6483
allow newrole_t etc_t:lnk_file read;
#line 6483

#line 6483
allow newrole_t locale_t:dir { read getattr lock search ioctl };
#line 6483
allow newrole_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6483

#line 6483


type newrole_exec_t, file_type, exec_type, sysadmfile;

#line 6486

#line 6486

#line 6486
#
#line 6486
# Allow the process to transition to the new domain.
#line 6486
#
#line 6486
allow userdomain newrole_t:process transition;
#line 6486

#line 6486
#
#line 6486
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6486
#
#line 6486
dontaudit userdomain newrole_t:process noatsecure;
#line 6486

#line 6486
#
#line 6486
# Allow the process to execute the program.
#line 6486
# 
#line 6486
allow userdomain newrole_exec_t:file { read { getattr execute } };
#line 6486

#line 6486
#
#line 6486
# Allow the process to reap the new domain.
#line 6486
#
#line 6486
allow newrole_t userdomain:process sigchld;
#line 6486

#line 6486
#
#line 6486
# Allow the new domain to inherit and use file 
#line 6486
# descriptions from the creating process and vice versa.
#line 6486
#
#line 6486
allow newrole_t userdomain:fd use;
#line 6486
allow userdomain newrole_t:fd use;
#line 6486

#line 6486
#
#line 6486
# Allow the new domain to write back to the old domain via a pipe.
#line 6486
#
#line 6486
allow newrole_t userdomain:fifo_file { ioctl read getattr lock write append };
#line 6486

#line 6486
#
#line 6486
# Allow the new domain to read and execute the program.
#line 6486
#
#line 6486
allow newrole_t newrole_exec_t:file { read getattr lock execute ioctl };
#line 6486

#line 6486
#
#line 6486
# Allow the new domain to be entered via the program.
#line 6486
#
#line 6486
allow newrole_t newrole_exec_t:file entrypoint;
#line 6486

#line 6486
type_transition userdomain newrole_exec_t:process newrole_t;
#line 6486


allow newrole_t shadow_t:file { read getattr };

# Inherit descriptors from the current session.
allow newrole_t privfd:fd use;

# Execute /sbin/pwdb_chkpwd to check the password.
allow newrole_t sbin_t:dir { read getattr lock search ioctl };

#line 6495
allow newrole_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6495


# Execute shells
allow newrole_t bin_t:dir { read getattr lock search ioctl };
allow newrole_t bin_t:lnk_file read;
allow newrole_t shell_exec_t:file { read getattr lock ioctl };

# Allow newrole_t to transition to user domains.

#line 6503

#line 6503
#
#line 6503
# Allow the process to transition to the new domain.
#line 6503
#
#line 6503
allow newrole_t userdomain:process transition;
#line 6503

#line 6503
#
#line 6503
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6503
#
#line 6503
dontaudit newrole_t userdomain:process noatsecure;
#line 6503

#line 6503
#
#line 6503
# Allow the process to execute the program.
#line 6503
# 
#line 6503
allow newrole_t shell_exec_t:file { read { getattr execute } };
#line 6503

#line 6503
#
#line 6503
# Allow the process to reap the new domain.
#line 6503
#
#line 6503
allow userdomain newrole_t:process sigchld;
#line 6503

#line 6503
#
#line 6503
# Allow the new domain to inherit and use file 
#line 6503
# descriptions from the creating process and vice versa.
#line 6503
#
#line 6503
allow userdomain newrole_t:fd use;
#line 6503
allow newrole_t userdomain:fd use;
#line 6503

#line 6503
#
#line 6503
# Allow the new domain to write back to the old domain via a pipe.
#line 6503
#
#line 6503
allow userdomain newrole_t:fifo_file { ioctl read getattr lock write append };
#line 6503

#line 6503
#
#line 6503
# Allow the new domain to read and execute the program.
#line 6503
#
#line 6503
allow userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6503

#line 6503
#
#line 6503
# Allow the new domain to be entered via the program.
#line 6503
#
#line 6503
allow userdomain shell_exec_t:file entrypoint;
#line 6503


#line 6504
allow newrole_t self:process setexec;
#line 6504
allow newrole_t proc_t:dir search;
#line 6504
allow newrole_t proc_t:lnk_file read;
#line 6504
allow newrole_t self:dir search;
#line 6504
allow newrole_t self:file { read write };
#line 6504


# Use capabilities.
allow newrole_t self:capability { setuid setgid net_bind_service dac_override };

# Write to utmp.
allow newrole_t var_run_t:dir { read getattr lock search ioctl };
allow newrole_t initrc_var_run_t:file { ioctl read getattr lock write append };

# Read the devpts root directory.
allow newrole_t devpts_t:dir { read getattr lock search ioctl };

# Read the /etc/security/default_type file
allow newrole_t etc_t:file { read getattr lock ioctl };

# Read /var.
allow newrole_t var_t:dir { read getattr lock search ioctl };
allow newrole_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# Read /dev directories and any symbolic links.
allow newrole_t device_t:dir { read getattr lock search ioctl };

# Relabel terminals.
allow newrole_t { ttyfile ptyfile }:chr_file { relabelfrom relabelto };

# Access terminals.
allow newrole_t { ttyfile ptyfile devtty_t }:chr_file { ioctl read getattr lock write append };


#line 6536


#
# Allow newrole to obtain contexts to relabel TTYs
#

#line 6541
allow newrole_t security_t:dir { read search getattr };
#line 6541
allow newrole_t security_t:file { getattr read write };
#line 6541
allow newrole_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6541


allow newrole_t fs_t:filesystem getattr;

# for some PAM modules and for cwd
dontaudit newrole_t { home_root_t home_type }:dir search;

# Failed reads to /proc cause no harm, so do not audit them
dontaudit newrole_t proc_t:dir search;

# for when the network connection is killed
dontaudit unpriv_userdomain newrole_t:process signal;
#DESC Passwd - Password utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: passwd
#

#################################
#
# Rules for the passwd_t domain.
#
# passwd_t is the domain of the passwd process.
# passwd_exec_t is the type of the passwd program.
# This domain and type is also used for chfn and chsh.
#
#line 6619



#line 6621
type passwd_t, domain, privlog, auth, privowner;
#line 6621

#line 6621

#line 6621
# Access other processes in the same domain.
#line 6621
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 6621
# separately if desired.
#line 6621
allow passwd_t self:process ~{ptrace setexec setfscreate};
#line 6621

#line 6621
# Access /proc/PID files for processes in the same domain.
#line 6621
allow passwd_t self:dir { read getattr lock search ioctl };
#line 6621
allow passwd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Access file descriptions, pipes, and sockets
#line 6621
# created by processes in the same domain.
#line 6621
allow passwd_t self:fd *;
#line 6621
allow passwd_t self:fifo_file { ioctl read getattr lock write append };
#line 6621
allow passwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6621
allow passwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6621

#line 6621
# Allow the domain to communicate with other processes in the same domain.
#line 6621
allow passwd_t self:unix_dgram_socket sendto;
#line 6621
allow passwd_t self:unix_stream_socket connectto;
#line 6621

#line 6621
# Access System V IPC objects created by processes in the same domain.
#line 6621
allow passwd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6621
allow passwd_t self:msg  { send receive };
#line 6621
allow passwd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6621
allow passwd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6621
;
#line 6621

#line 6621
allow passwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6621
allow passwd_t lib_t:lnk_file { read getattr lock ioctl };
#line 6621
allow passwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6621
allow passwd_t ld_so_t:file execute_no_trans;
#line 6621
allow passwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6621
allow passwd_t shlib_t:file { read getattr lock execute ioctl };
#line 6621
allow passwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6621
allow passwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6621
allow passwd_t device_t:dir search;
#line 6621
allow passwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6621
;
#line 6621

#line 6621
# Inherit and use descriptors from login.
#line 6621
allow passwd_t privfd:fd use;
#line 6621

#line 6621

#line 6621

#line 6621
allow passwd_t etc_t:lnk_file read;
#line 6621

#line 6621
allow passwd_t locale_t:dir { read getattr lock search ioctl };
#line 6621
allow passwd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6621

#line 6621

#line 6621

#line 6621
allow passwd_t fs_t:filesystem getattr;
#line 6621

#line 6621
# allow checking if a shell is executable
#line 6621
allow passwd_t shell_exec_t:file execute;
#line 6621

#line 6621
# Obtain contexts
#line 6621

#line 6621
allow passwd_t security_t:dir { read search getattr };
#line 6621
allow passwd_t security_t:file { getattr read write };
#line 6621
allow passwd_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6621

#line 6621

#line 6621
# Update /etc/shadow and /etc/passwd
#line 6621

#line 6621

#line 6621

#line 6621

#line 6621
#
#line 6621
# Allow the process to modify the directory.
#line 6621
#
#line 6621
allow passwd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6621

#line 6621
#
#line 6621
# Allow the process to create the file.
#line 6621
#
#line 6621

#line 6621

#line 6621
allow passwd_t shadow_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6621

#line 6621

#line 6621
type_transition passwd_t etc_t:file shadow_t;
#line 6621

#line 6621

#line 6621

#line 6621
allow passwd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6621
allow passwd_t { etc_t shadow_t }:file { relabelfrom relabelto };
#line 6621

#line 6621
allow passwd_t self:process setfscreate;
#line 6621
allow passwd_t proc_t:dir search;
#line 6621
allow passwd_t proc_t:lnk_file read;
#line 6621
allow passwd_t self:dir search;
#line 6621
allow passwd_t self:file { read write };
#line 6621

#line 6621

#line 6621
# Allow etc_t symlinks for /etc/alternatives on Debian.
#line 6621
allow passwd_t etc_t:lnk_file read;
#line 6621

#line 6621
# Use capabilities.
#line 6621
allow passwd_t self:capability { chown dac_override fsetid setuid sys_resource };
#line 6621

#line 6621
# Access terminals.
#line 6621
allow passwd_t { ttyfile ptyfile }:chr_file { ioctl read getattr lock write append };
#line 6621
allow passwd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6621

#line 6621
dontaudit passwd_t devpts_t:dir getattr;
#line 6621

#line 6621
# /usr/bin/passwd asks for w access to utmp, but it will operate
#line 6621
# correctly without it.  Do not audit write denials to utmp.
#line 6621
dontaudit passwd_t initrc_var_run_t:file { read write };
#line 6621

#line 6621
# user generally runs this from their home directory, so do not audit a search
#line 6621
# on user home dir
#line 6621
dontaudit passwd_t { user_home_dir_type user_home_type }:dir search;
#line 6621

#line 6621
# When the wrong current passwd is entered, passwd, for some reason, 
#line 6621
# attempts to access /proc and /dev, but fails appropriately. So dont
#line 6621
# audit those denials.
#line 6621
dontaudit passwd_t { proc_t device_t }:dir { search read };
#line 6621

#line 6621
allow passwd_t device_t:dir getattr;
#line 6621


#line 6622
type sysadm_passwd_t, domain, privlog, auth, privowner;
#line 6622

#line 6622

#line 6622
# Access other processes in the same domain.
#line 6622
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 6622
# separately if desired.
#line 6622
allow sysadm_passwd_t self:process ~{ptrace setexec setfscreate};
#line 6622

#line 6622
# Access /proc/PID files for processes in the same domain.
#line 6622
allow sysadm_passwd_t self:dir { read getattr lock search ioctl };
#line 6622
allow sysadm_passwd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6622

#line 6622
# Access file descriptions, pipes, and sockets
#line 6622
# created by processes in the same domain.
#line 6622
allow sysadm_passwd_t self:fd *;
#line 6622
allow sysadm_passwd_t self:fifo_file { ioctl read getattr lock write append };
#line 6622
allow sysadm_passwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6622
allow sysadm_passwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6622

#line 6622
# Allow the domain to communicate with other processes in the same domain.
#line 6622
allow sysadm_passwd_t self:unix_dgram_socket sendto;
#line 6622
allow sysadm_passwd_t self:unix_stream_socket connectto;
#line 6622

#line 6622
# Access System V IPC objects created by processes in the same domain.
#line 6622
allow sysadm_passwd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6622
allow sysadm_passwd_t self:msg  { send receive };
#line 6622
allow sysadm_passwd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6622
allow sysadm_passwd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6622
;
#line 6622

#line 6622
allow sysadm_passwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6622
allow sysadm_passwd_t lib_t:lnk_file { read getattr lock ioctl };
#line 6622
allow sysadm_passwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6622
allow sysadm_passwd_t ld_so_t:file execute_no_trans;
#line 6622
allow sysadm_passwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6622
allow sysadm_passwd_t shlib_t:file { read getattr lock execute ioctl };
#line 6622
allow sysadm_passwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6622
allow sysadm_passwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6622
allow sysadm_passwd_t device_t:dir search;
#line 6622
allow sysadm_passwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6622
;
#line 6622

#line 6622
# Inherit and use descriptors from login.
#line 6622
allow sysadm_passwd_t privfd:fd use;
#line 6622

#line 6622

#line 6622

#line 6622
allow sysadm_passwd_t etc_t:lnk_file read;
#line 6622

#line 6622
allow sysadm_passwd_t locale_t:dir { read getattr lock search ioctl };
#line 6622
allow sysadm_passwd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6622

#line 6622

#line 6622

#line 6622
allow sysadm_passwd_t fs_t:filesystem getattr;
#line 6622

#line 6622
# allow checking if a shell is executable
#line 6622
allow sysadm_passwd_t shell_exec_t:file execute;
#line 6622

#line 6622
# Obtain contexts
#line 6622

#line 6622
allow sysadm_passwd_t security_t:dir { read search getattr };
#line 6622
allow sysadm_passwd_t security_t:file { getattr read write };
#line 6622
allow sysadm_passwd_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6622

#line 6622

#line 6622
# Update /etc/shadow and /etc/passwd
#line 6622

#line 6622

#line 6622

#line 6622

#line 6622
#
#line 6622
# Allow the process to modify the directory.
#line 6622
#
#line 6622
allow sysadm_passwd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6622

#line 6622
#
#line 6622
# Allow the process to create the file.
#line 6622
#
#line 6622

#line 6622

#line 6622
allow sysadm_passwd_t shadow_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6622

#line 6622

#line 6622
type_transition sysadm_passwd_t etc_t:file shadow_t;
#line 6622

#line 6622

#line 6622

#line 6622
allow sysadm_passwd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6622
allow sysadm_passwd_t { etc_t shadow_t }:file { relabelfrom relabelto };
#line 6622

#line 6622
allow sysadm_passwd_t self:process setfscreate;
#line 6622
allow sysadm_passwd_t proc_t:dir search;
#line 6622
allow sysadm_passwd_t proc_t:lnk_file read;
#line 6622
allow sysadm_passwd_t self:dir search;
#line 6622
allow sysadm_passwd_t self:file { read write };
#line 6622

#line 6622

#line 6622
# Allow etc_t symlinks for /etc/alternatives on Debian.
#line 6622
allow sysadm_passwd_t etc_t:lnk_file read;
#line 6622

#line 6622
# Use capabilities.
#line 6622
allow sysadm_passwd_t self:capability { chown dac_override fsetid setuid sys_resource };
#line 6622

#line 6622
# Access terminals.
#line 6622
allow sysadm_passwd_t { ttyfile ptyfile }:chr_file { ioctl read getattr lock write append };
#line 6622
allow sysadm_passwd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6622

#line 6622
dontaudit sysadm_passwd_t devpts_t:dir getattr;
#line 6622

#line 6622
# /usr/bin/passwd asks for w access to utmp, but it will operate
#line 6622
# correctly without it.  Do not audit write denials to utmp.
#line 6622
dontaudit sysadm_passwd_t initrc_var_run_t:file { read write };
#line 6622

#line 6622
# user generally runs this from their home directory, so do not audit a search
#line 6622
# on user home dir
#line 6622
dontaudit sysadm_passwd_t { user_home_dir_type user_home_type }:dir search;
#line 6622

#line 6622
# When the wrong current passwd is entered, passwd, for some reason, 
#line 6622
# attempts to access /proc and /dev, but fails appropriately. So dont
#line 6622
# audit those denials.
#line 6622
dontaudit sysadm_passwd_t { proc_t device_t }:dir { search read };
#line 6622

#line 6622
allow sysadm_passwd_t device_t:dir getattr;
#line 6622



#line 6624
role user_r types passwd_t;
#line 6624
role staff_r types passwd_t;
#line 6624

role sysadm_r types passwd_t;
role sysadm_r types sysadm_passwd_t;

type admin_passwd_exec_t, file_type, sysadmfile;
type passwd_exec_t, file_type, sysadmfile, exec_type;


#line 6631

#line 6631

#line 6631
#
#line 6631
# Allow the process to transition to the new domain.
#line 6631
#
#line 6631
allow userdomain passwd_t:process transition;
#line 6631

#line 6631
#
#line 6631
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6631
#
#line 6631
dontaudit userdomain passwd_t:process noatsecure;
#line 6631

#line 6631
#
#line 6631
# Allow the process to execute the program.
#line 6631
# 
#line 6631
allow userdomain passwd_exec_t:file { read { getattr execute } };
#line 6631

#line 6631
#
#line 6631
# Allow the process to reap the new domain.
#line 6631
#
#line 6631
allow passwd_t userdomain:process sigchld;
#line 6631

#line 6631
#
#line 6631
# Allow the new domain to inherit and use file 
#line 6631
# descriptions from the creating process and vice versa.
#line 6631
#
#line 6631
allow passwd_t userdomain:fd use;
#line 6631
allow userdomain passwd_t:fd use;
#line 6631

#line 6631
#
#line 6631
# Allow the new domain to write back to the old domain via a pipe.
#line 6631
#
#line 6631
allow passwd_t userdomain:fifo_file { ioctl read getattr lock write append };
#line 6631

#line 6631
#
#line 6631
# Allow the new domain to read and execute the program.
#line 6631
#
#line 6631
allow passwd_t passwd_exec_t:file { read getattr lock execute ioctl };
#line 6631

#line 6631
#
#line 6631
# Allow the new domain to be entered via the program.
#line 6631
#
#line 6631
allow passwd_t passwd_exec_t:file entrypoint;
#line 6631

#line 6631
type_transition userdomain passwd_exec_t:process passwd_t;
#line 6631


#line 6632

#line 6632

#line 6632
#
#line 6632
# Allow the process to transition to the new domain.
#line 6632
#
#line 6632
allow sysadm_t sysadm_passwd_t:process transition;
#line 6632

#line 6632
#
#line 6632
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6632
#
#line 6632
dontaudit sysadm_t sysadm_passwd_t:process noatsecure;
#line 6632

#line 6632
#
#line 6632
# Allow the process to execute the program.
#line 6632
# 
#line 6632
allow sysadm_t admin_passwd_exec_t:file { read { getattr execute } };
#line 6632

#line 6632
#
#line 6632
# Allow the process to reap the new domain.
#line 6632
#
#line 6632
allow sysadm_passwd_t sysadm_t:process sigchld;
#line 6632

#line 6632
#
#line 6632
# Allow the new domain to inherit and use file 
#line 6632
# descriptions from the creating process and vice versa.
#line 6632
#
#line 6632
allow sysadm_passwd_t sysadm_t:fd use;
#line 6632
allow sysadm_t sysadm_passwd_t:fd use;
#line 6632

#line 6632
#
#line 6632
# Allow the new domain to write back to the old domain via a pipe.
#line 6632
#
#line 6632
allow sysadm_passwd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6632

#line 6632
#
#line 6632
# Allow the new domain to read and execute the program.
#line 6632
#
#line 6632
allow sysadm_passwd_t admin_passwd_exec_t:file { read getattr lock execute ioctl };
#line 6632

#line 6632
#
#line 6632
# Allow the new domain to be entered via the program.
#line 6632
#
#line 6632
allow sysadm_passwd_t admin_passwd_exec_t:file entrypoint;
#line 6632

#line 6632
type_transition sysadm_t admin_passwd_exec_t:process sysadm_passwd_t;
#line 6632


#line 6641

#line 6641
dontaudit passwd_t var_t:dir search;
#line 6641


# allow vipw to exec the editor
allow sysadm_passwd_t { root_t usr_t bin_t }:dir search;
allow sysadm_passwd_t { bin_t }:lnk_file read;

#line 6646
allow sysadm_passwd_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6646


# allow vipw to create temporary files under /var/tmp/vi.recover
allow sysadm_passwd_t var_t:dir search;

#line 6650
type sysadm_passwd_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6650

#line 6650

#line 6650

#line 6650

#line 6650
#
#line 6650
# Allow the process to modify the directory.
#line 6650
#
#line 6650
allow sysadm_passwd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6650

#line 6650
#
#line 6650
# Allow the process to create the file.
#line 6650
#
#line 6650

#line 6650
allow sysadm_passwd_t sysadm_passwd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6650
allow sysadm_passwd_t sysadm_passwd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6650

#line 6650

#line 6650
type_transition sysadm_passwd_t tmp_t:dir sysadm_passwd_tmp_t;
#line 6650
type_transition sysadm_passwd_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_passwd_tmp_t;
#line 6650

#line 6650

#line 6650

#line 6650

# for vipw - vi looks in the root home directory for config
dontaudit sysadm_passwd_t sysadm_home_dir_t:dir { getattr search };
# for /etc/alternatives/vi
allow sysadm_passwd_t etc_t:lnk_file read;

# for nscd lookups
dontaudit sysadm_passwd_t var_run_t:dir search;

# make sure that getcon succeeds
allow passwd_t user_t:dir search;
allow passwd_t user_t:file read;
allow passwd_t user_t:process getattr;

#DESC Setfiles - SELinux filesystem labeling utilities
#
# Authors:  Russell Coker <russell@coker.com.au>
# X-Debian-Packages: policycoreutils
#

#################################
#
# Rules for the setfiles_t domain.
#
# setfiles_exec_t is the type of the setfiles executable.
#
type setfiles_t, domain, privlog, privowner;
type setfiles_exec_t, file_type, sysadmfile, exec_type;

role system_r types setfiles_t;
role sysadm_r types setfiles_t;

allow setfiles_t initrc_devpts_t:chr_file { read write ioctl };
allow setfiles_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { read write ioctl };


#line 6685

#line 6685

#line 6685
#
#line 6685
# Allow the process to transition to the new domain.
#line 6685
#
#line 6685
allow { initrc_t sysadm_t } setfiles_t:process transition;
#line 6685

#line 6685
#
#line 6685
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6685
#
#line 6685
dontaudit { initrc_t sysadm_t } setfiles_t:process noatsecure;
#line 6685

#line 6685
#
#line 6685
# Allow the process to execute the program.
#line 6685
# 
#line 6685
allow { initrc_t sysadm_t } setfiles_exec_t:file { read { getattr execute } };
#line 6685

#line 6685
#
#line 6685
# Allow the process to reap the new domain.
#line 6685
#
#line 6685
allow setfiles_t { initrc_t sysadm_t }:process sigchld;
#line 6685

#line 6685
#
#line 6685
# Allow the new domain to inherit and use file 
#line 6685
# descriptions from the creating process and vice versa.
#line 6685
#
#line 6685
allow setfiles_t { initrc_t sysadm_t }:fd use;
#line 6685
allow { initrc_t sysadm_t } setfiles_t:fd use;
#line 6685

#line 6685
#
#line 6685
# Allow the new domain to write back to the old domain via a pipe.
#line 6685
#
#line 6685
allow setfiles_t { initrc_t sysadm_t }:fifo_file { ioctl read getattr lock write append };
#line 6685

#line 6685
#
#line 6685
# Allow the new domain to read and execute the program.
#line 6685
#
#line 6685
allow setfiles_t setfiles_exec_t:file { read getattr lock execute ioctl };
#line 6685

#line 6685
#
#line 6685
# Allow the new domain to be entered via the program.
#line 6685
#
#line 6685
allow setfiles_t setfiles_exec_t:file entrypoint;
#line 6685

#line 6685
type_transition { initrc_t sysadm_t } setfiles_exec_t:process setfiles_t;
#line 6685

allow setfiles_t init_t:fd use;
allow setfiles_t privfd:fd use;


#line 6689
allow setfiles_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6689
allow setfiles_t lib_t:lnk_file { read getattr lock ioctl };
#line 6689
allow setfiles_t ld_so_t:file { read getattr lock execute ioctl };
#line 6689
allow setfiles_t ld_so_t:file execute_no_trans;
#line 6689
allow setfiles_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6689
allow setfiles_t shlib_t:file { read getattr lock execute ioctl };
#line 6689
allow setfiles_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6689
allow setfiles_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6689
allow setfiles_t device_t:dir search;
#line 6689
allow setfiles_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6689

allow setfiles_t self:capability { dac_override dac_read_search };

# for upgrading glibc - without this the glibc upgrade scripts will put things
# in a state such that setfiles can not be run!
allow setfiles_t lib_t:file execute;

# Get security policy decisions.

#line 6697
allow setfiles_t security_t:dir { read search getattr };
#line 6697
allow setfiles_t security_t:file { getattr read write };
#line 6697
allow setfiles_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6697


allow setfiles_t policy_src_t:file { read getattr lock ioctl };

allow setfiles_t file_type:dir { read getattr lock search ioctl };
allow setfiles_t file_type:lnk_file { read getattr lock ioctl };
allow setfiles_t file_type:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { getattr relabelfrom relabelto };

allow setfiles_t file_labels_t:dir { read getattr lock search ioctl add_name remove_name write };
allow setfiles_t file_labels_t:file { create ioctl read getattr lock write setattr append link unlink rename };

allow setfiles_t fs_t:filesystem getattr;
allow setfiles_t fs_type:dir { read getattr lock search ioctl };

allow setfiles_t etc_runtime_t:file read;
allow setfiles_t etc_t:file read;
allow setfiles_t proc_t:file { getattr read };

# for config files in a home directory
allow setfiles_t home_type:file { read getattr lock ioctl };
#DESC SSH - SSH daemon
#
# Authors:  Anthony Colatrella (NSA) <amcolat@epoch.ncsc.mil>
# Modified by: Russell Coker <russell@coker.com.au>
# X-Debian-Packages: ssh
#

type ssh_port_t, port_type;

#line 6800

#################################
#
# Rules for the sshd_t domain, et al.
#
# sshd_t is the domain for the sshd program.
# sshd_login_t is the domain for sshds login spawn
# sshd_exec_t is the type of the sshd executable.
# sshd_key_t is the type of the ssh private key files
#

#line 6810
type sshd_t, domain, privuser, privrole, privlog, privowner, privfd, auth;
#line 6810
role system_r types sshd_t;
#line 6810

#line 6810
allow sshd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t lib_t:lnk_file { read getattr lock ioctl };
#line 6810
allow sshd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6810
allow sshd_t ld_so_t:file execute_no_trans;
#line 6810
allow sshd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6810
allow sshd_t shlib_t:file { read getattr lock execute ioctl };
#line 6810
allow sshd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6810
allow sshd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6810
allow sshd_t device_t:dir search;
#line 6810
allow sshd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6810

#line 6810
allow sshd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6810
allow sshd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6810
allow sshd_t self:fifo_file { ioctl read getattr lock write append };
#line 6810
allow sshd_t self:process { fork sigchld setsched };
#line 6810

#line 6810
# Read system information files in /proc.
#line 6810
allow sshd_t proc_t:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6810
allow sshd_t self:dir search;
#line 6810
allow sshd_t self:lnk_file read;
#line 6810

#line 6810
# Get attributes of file systems.
#line 6810
allow sshd_t fs_type:filesystem getattr;
#line 6810

#line 6810

#line 6810
# Read /.
#line 6810
allow sshd_t root_t:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6810

#line 6810
# Read /home.
#line 6810
allow sshd_t home_root_t:dir { read getattr lock search ioctl };
#line 6810

#line 6810
# Read /usr.
#line 6810
allow sshd_t usr_t:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6810

#line 6810
# Read bin and sbin directories.
#line 6810
allow sshd_t bin_t:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6810
allow sshd_t sbin_t:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6810

#line 6810

#line 6810
# Read /var.
#line 6810
allow sshd_t var_t:dir search;
#line 6810

#line 6810
# Read /var/log.
#line 6810
allow sshd_t var_log_t:dir search;
#line 6810

#line 6810
# Read /etc.
#line 6810
allow sshd_t etc_t:dir { read getattr lock search ioctl };
#line 6810
allow sshd_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6810
allow sshd_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6810
allow sshd_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 6810

#line 6810
# Read the linker, shared library, and executable types.
#line 6810
allow sshd_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 6810
allow sshd_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6810
allow sshd_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6810

#line 6810
# Read and write /dev/tty and /dev/null.
#line 6810
allow sshd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6810
allow sshd_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 6810

#line 6810
# Read /dev/random and /dev/zero.
#line 6810
allow sshd_t random_device_t:chr_file { read getattr lock ioctl };
#line 6810

#line 6810

#line 6810
#
#line 6810
# Allow the domain to create and use UDP and TCP sockets.
#line 6810
# Other kinds of sockets must be separately authorized for use.
#line 6810
allow sshd_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6810
allow sshd_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6810

#line 6810
#
#line 6810
# Allow the domain to send UDP packets.
#line 6810
# Since the destination sockets type is unknown, the generic
#line 6810
# any_socket_t type is used as a placeholder.
#line 6810
#
#line 6810
allow sshd_t any_socket_t:udp_socket sendto;
#line 6810

#line 6810
#
#line 6810
# Allow the domain to send using any network interface.
#line 6810
# netif_type is a type attribute for all network interface types.
#line 6810
#
#line 6810
allow sshd_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6810

#line 6810
#
#line 6810
# Allow packets sent by the domain to be received on any network interface.
#line 6810
#
#line 6810
allow sshd_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6810

#line 6810
#
#line 6810
# Allow the domain to receive packets from any network interface.
#line 6810
# netmsg_type is a type attribute for all default message types.
#line 6810
#
#line 6810
allow sshd_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6810

#line 6810
#
#line 6810
# Allow the domain to initiate or accept TCP connections 
#line 6810
# on any network interface.
#line 6810
#
#line 6810
allow sshd_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6810

#line 6810
#
#line 6810
# Receive resets from the TCP reset socket.
#line 6810
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6810
#
#line 6810
allow sshd_t tcp_socket_t:tcp_socket recvfrom;
#line 6810

#line 6810
dontaudit sshd_t tcp_socket_t:tcp_socket connectto;
#line 6810

#line 6810
#
#line 6810
# Allow the domain to send to any node.
#line 6810
# node_type is a type attribute for all node types.
#line 6810
#
#line 6810
allow sshd_t node_type:node { tcp_send udp_send rawip_send };
#line 6810

#line 6810
#
#line 6810
# Allow packets sent by the domain to be received from any node.
#line 6810
#
#line 6810
allow sshd_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6810

#line 6810
#
#line 6810
# Allow the domain to send NFS client requests via the socket
#line 6810
# created by mount.
#line 6810
#
#line 6810
allow sshd_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6810

#line 6810
#
#line 6810
# Bind to the default port type.
#line 6810
# Other port types must be separately authorized.
#line 6810
#
#line 6810
allow sshd_t port_t:udp_socket name_bind;
#line 6810
allow sshd_t port_t:tcp_socket name_bind;
#line 6810

#line 6810

#line 6810
allow sshd_t self:capability { chown dac_override fowner fsetid setgid setuid net_bind_service sys_tty_config };
#line 6810
allow sshd_t shadow_t:file { read getattr };
#line 6810
allow sshd_t { home_root_t user_home_dir_type sysadm_home_dir_t }:dir { search getattr };
#line 6810

#line 6810
# Run shells in user_t by default
#line 6810

#line 6810

#line 6810

#line 6810
#
#line 6810
# Allow the process to transition to the new domain.
#line 6810
#
#line 6810
allow sshd_t user_t:process transition;
#line 6810

#line 6810
#
#line 6810
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6810
#
#line 6810
dontaudit sshd_t user_t:process noatsecure;
#line 6810

#line 6810
#
#line 6810
# Allow the process to execute the program.
#line 6810
# 
#line 6810
allow sshd_t shell_exec_t:file { read { getattr execute } };
#line 6810

#line 6810
#
#line 6810
# Allow the process to reap the new domain.
#line 6810
#
#line 6810
allow user_t sshd_t:process sigchld;
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to inherit and use file 
#line 6810
# descriptions from the creating process and vice versa.
#line 6810
#
#line 6810
allow user_t sshd_t:fd use;
#line 6810
allow sshd_t user_t:fd use;
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to write back to the old domain via a pipe.
#line 6810
#
#line 6810
allow user_t sshd_t:fifo_file { ioctl read getattr lock write append };
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to read and execute the program.
#line 6810
#
#line 6810
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to be entered via the program.
#line 6810
#
#line 6810
allow user_t shell_exec_t:file entrypoint;
#line 6810

#line 6810
type_transition sshd_t shell_exec_t:process user_t;
#line 6810

#line 6810

#line 6810

#line 6810
#
#line 6810
# Allow the process to transition to the new domain.
#line 6810
#
#line 6810
allow sshd_t unpriv_userdomain:process transition;
#line 6810

#line 6810
#
#line 6810
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6810
#
#line 6810
dontaudit sshd_t unpriv_userdomain:process noatsecure;
#line 6810

#line 6810
#
#line 6810
# Allow the process to execute the program.
#line 6810
# 
#line 6810
allow sshd_t shell_exec_t:file { read { getattr execute } };
#line 6810

#line 6810
#
#line 6810
# Allow the process to reap the new domain.
#line 6810
#
#line 6810
allow unpriv_userdomain sshd_t:process sigchld;
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to inherit and use file 
#line 6810
# descriptions from the creating process and vice versa.
#line 6810
#
#line 6810
allow unpriv_userdomain sshd_t:fd use;
#line 6810
allow sshd_t unpriv_userdomain:fd use;
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to write back to the old domain via a pipe.
#line 6810
#
#line 6810
allow unpriv_userdomain sshd_t:fifo_file { ioctl read getattr lock write append };
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to read and execute the program.
#line 6810
#
#line 6810
allow unpriv_userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6810

#line 6810
#
#line 6810
# Allow the new domain to be entered via the program.
#line 6810
#
#line 6810
allow unpriv_userdomain shell_exec_t:file entrypoint;
#line 6810

#line 6810

#line 6810
# Set exec context.
#line 6810

#line 6810
allow sshd_t self:process setexec;
#line 6810
allow sshd_t proc_t:dir search;
#line 6810
allow sshd_t proc_t:lnk_file read;
#line 6810
allow sshd_t self:dir search;
#line 6810
allow sshd_t self:file { read write };
#line 6810

#line 6810

#line 6810
# Allow shells to be run in sysadm_t as well.
#line 6810
# Commented out.  Use newrole rather than directly entering sysadm_t.
#line 6810
#domain_trans(sshd_t, shell_exec_t, sysadm_t)
#line 6810

#line 6810
# Update utmp.
#line 6810
allow sshd_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 6810

#line 6810
# Update wtmp.
#line 6810
allow sshd_t wtmp_t:file { ioctl read getattr lock write append };
#line 6810

#line 6810
# Get security policy decisions.
#line 6810

#line 6810
allow sshd_t security_t:dir { read search getattr };
#line 6810
allow sshd_t security_t:file { getattr read write };
#line 6810
allow sshd_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6810

#line 6810

#line 6810
# Allow read access to login context
#line 6810
allow sshd_t default_context_t:file { read getattr lock ioctl };
#line 6810

#line 6810

type sshd_exec_t, file_type, exec_type, sysadmfile;


#line 6813

#line 6813

#line 6813
#
#line 6813
# Allow the process to transition to the new domain.
#line 6813
#
#line 6813
allow initrc_t sshd_t:process transition;
#line 6813

#line 6813
#
#line 6813
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6813
#
#line 6813
dontaudit initrc_t sshd_t:process noatsecure;
#line 6813

#line 6813
#
#line 6813
# Allow the process to execute the program.
#line 6813
# 
#line 6813
allow initrc_t sshd_exec_t:file { read { getattr execute } };
#line 6813

#line 6813
#
#line 6813
# Allow the process to reap the new domain.
#line 6813
#
#line 6813
allow sshd_t initrc_t:process sigchld;
#line 6813

#line 6813
#
#line 6813
# Allow the new domain to inherit and use file 
#line 6813
# descriptions from the creating process and vice versa.
#line 6813
#
#line 6813
allow sshd_t initrc_t:fd use;
#line 6813
allow initrc_t sshd_t:fd use;
#line 6813

#line 6813
#
#line 6813
# Allow the new domain to write back to the old domain via a pipe.
#line 6813
#
#line 6813
allow sshd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6813

#line 6813
#
#line 6813
# Allow the new domain to read and execute the program.
#line 6813
#
#line 6813
allow sshd_t sshd_exec_t:file { read getattr lock execute ioctl };
#line 6813

#line 6813
#
#line 6813
# Allow the new domain to be entered via the program.
#line 6813
#
#line 6813
allow sshd_t sshd_exec_t:file entrypoint;
#line 6813

#line 6813
type_transition initrc_t sshd_exec_t:process sshd_t;
#line 6813


#line 6819


#line 6829

#line 6829
allow sshd_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 6829
allow sshd_t ssh_port_t:tcp_socket name_bind;
#line 6829

#line 6829

#line 6829

#line 6829
#
#line 6829
# Allow the process to transition to the new domain.
#line 6829
#
#line 6829
allow initrc_t sshd_t:process transition;
#line 6829

#line 6829
#
#line 6829
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6829
#
#line 6829
dontaudit initrc_t sshd_t:process noatsecure;
#line 6829

#line 6829
#
#line 6829
# Allow the process to execute the program.
#line 6829
# 
#line 6829
allow initrc_t sshd_exec_t:file { read { getattr execute } };
#line 6829

#line 6829
#
#line 6829
# Allow the process to reap the new domain.
#line 6829
#
#line 6829
allow sshd_t initrc_t:process sigchld;
#line 6829

#line 6829
#
#line 6829
# Allow the new domain to inherit and use file 
#line 6829
# descriptions from the creating process and vice versa.
#line 6829
#
#line 6829
allow sshd_t initrc_t:fd use;
#line 6829
allow initrc_t sshd_t:fd use;
#line 6829

#line 6829
#
#line 6829
# Allow the new domain to write back to the old domain via a pipe.
#line 6829
#
#line 6829
allow sshd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6829

#line 6829
#
#line 6829
# Allow the new domain to read and execute the program.
#line 6829
#
#line 6829
allow sshd_t sshd_exec_t:file { read getattr lock execute ioctl };
#line 6829

#line 6829
#
#line 6829
# Allow the new domain to be entered via the program.
#line 6829
#
#line 6829
allow sshd_t sshd_exec_t:file entrypoint;
#line 6829

#line 6829
type_transition initrc_t sshd_exec_t:process sshd_t;
#line 6829

#line 6829


#line 6830
type sshd_login_t, domain, privuser, privrole, privlog, privowner, privfd, auth;
#line 6830
role system_r types sshd_login_t;
#line 6830

#line 6830
allow sshd_login_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t lib_t:lnk_file { read getattr lock ioctl };
#line 6830
allow sshd_login_t ld_so_t:file { read getattr lock execute ioctl };
#line 6830
allow sshd_login_t ld_so_t:file execute_no_trans;
#line 6830
allow sshd_login_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6830
allow sshd_login_t shlib_t:file { read getattr lock execute ioctl };
#line 6830
allow sshd_login_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6830
allow sshd_login_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6830
allow sshd_login_t device_t:dir search;
#line 6830
allow sshd_login_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6830

#line 6830
allow sshd_login_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6830
allow sshd_login_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6830
allow sshd_login_t self:fifo_file { ioctl read getattr lock write append };
#line 6830
allow sshd_login_t self:process { fork sigchld setsched };
#line 6830

#line 6830
# Read system information files in /proc.
#line 6830
allow sshd_login_t proc_t:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6830
allow sshd_login_t self:dir search;
#line 6830
allow sshd_login_t self:lnk_file read;
#line 6830

#line 6830
# Get attributes of file systems.
#line 6830
allow sshd_login_t fs_type:filesystem getattr;
#line 6830

#line 6830

#line 6830
# Read /.
#line 6830
allow sshd_login_t root_t:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6830

#line 6830
# Read /home.
#line 6830
allow sshd_login_t home_root_t:dir { read getattr lock search ioctl };
#line 6830

#line 6830
# Read /usr.
#line 6830
allow sshd_login_t usr_t:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6830

#line 6830
# Read bin and sbin directories.
#line 6830
allow sshd_login_t bin_t:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6830
allow sshd_login_t sbin_t:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6830

#line 6830

#line 6830
# Read /var.
#line 6830
allow sshd_login_t var_t:dir search;
#line 6830

#line 6830
# Read /var/log.
#line 6830
allow sshd_login_t var_log_t:dir search;
#line 6830

#line 6830
# Read /etc.
#line 6830
allow sshd_login_t etc_t:dir { read getattr lock search ioctl };
#line 6830
allow sshd_login_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6830
allow sshd_login_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6830
allow sshd_login_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 6830

#line 6830
# Read the linker, shared library, and executable types.
#line 6830
allow sshd_login_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 6830
allow sshd_login_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6830
allow sshd_login_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6830

#line 6830
# Read and write /dev/tty and /dev/null.
#line 6830
allow sshd_login_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6830
allow sshd_login_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 6830

#line 6830
# Read /dev/random and /dev/zero.
#line 6830
allow sshd_login_t random_device_t:chr_file { read getattr lock ioctl };
#line 6830

#line 6830

#line 6830
#
#line 6830
# Allow the domain to create and use UDP and TCP sockets.
#line 6830
# Other kinds of sockets must be separately authorized for use.
#line 6830
allow sshd_login_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6830
allow sshd_login_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6830

#line 6830
#
#line 6830
# Allow the domain to send UDP packets.
#line 6830
# Since the destination sockets type is unknown, the generic
#line 6830
# any_socket_t type is used as a placeholder.
#line 6830
#
#line 6830
allow sshd_login_t any_socket_t:udp_socket sendto;
#line 6830

#line 6830
#
#line 6830
# Allow the domain to send using any network interface.
#line 6830
# netif_type is a type attribute for all network interface types.
#line 6830
#
#line 6830
allow sshd_login_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6830

#line 6830
#
#line 6830
# Allow packets sent by the domain to be received on any network interface.
#line 6830
#
#line 6830
allow sshd_login_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6830

#line 6830
#
#line 6830
# Allow the domain to receive packets from any network interface.
#line 6830
# netmsg_type is a type attribute for all default message types.
#line 6830
#
#line 6830
allow sshd_login_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6830

#line 6830
#
#line 6830
# Allow the domain to initiate or accept TCP connections 
#line 6830
# on any network interface.
#line 6830
#
#line 6830
allow sshd_login_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6830

#line 6830
#
#line 6830
# Receive resets from the TCP reset socket.
#line 6830
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6830
#
#line 6830
allow sshd_login_t tcp_socket_t:tcp_socket recvfrom;
#line 6830

#line 6830
dontaudit sshd_login_t tcp_socket_t:tcp_socket connectto;
#line 6830

#line 6830
#
#line 6830
# Allow the domain to send to any node.
#line 6830
# node_type is a type attribute for all node types.
#line 6830
#
#line 6830
allow sshd_login_t node_type:node { tcp_send udp_send rawip_send };
#line 6830

#line 6830
#
#line 6830
# Allow packets sent by the domain to be received from any node.
#line 6830
#
#line 6830
allow sshd_login_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6830

#line 6830
#
#line 6830
# Allow the domain to send NFS client requests via the socket
#line 6830
# created by mount.
#line 6830
#
#line 6830
allow sshd_login_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6830

#line 6830
#
#line 6830
# Bind to the default port type.
#line 6830
# Other port types must be separately authorized.
#line 6830
#
#line 6830
allow sshd_login_t port_t:udp_socket name_bind;
#line 6830
allow sshd_login_t port_t:tcp_socket name_bind;
#line 6830

#line 6830

#line 6830
allow sshd_login_t self:capability { chown dac_override fowner fsetid setgid setuid net_bind_service sys_tty_config };
#line 6830
allow sshd_login_t shadow_t:file { read getattr };
#line 6830
allow sshd_login_t { home_root_t user_home_dir_type sysadm_home_dir_t }:dir { search getattr };
#line 6830

#line 6830
# Run shells in user_t by default
#line 6830

#line 6830

#line 6830

#line 6830
#
#line 6830
# Allow the process to transition to the new domain.
#line 6830
#
#line 6830
allow sshd_login_t user_t:process transition;
#line 6830

#line 6830
#
#line 6830
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6830
#
#line 6830
dontaudit sshd_login_t user_t:process noatsecure;
#line 6830

#line 6830
#
#line 6830
# Allow the process to execute the program.
#line 6830
# 
#line 6830
allow sshd_login_t shell_exec_t:file { read { getattr execute } };
#line 6830

#line 6830
#
#line 6830
# Allow the process to reap the new domain.
#line 6830
#
#line 6830
allow user_t sshd_login_t:process sigchld;
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to inherit and use file 
#line 6830
# descriptions from the creating process and vice versa.
#line 6830
#
#line 6830
allow user_t sshd_login_t:fd use;
#line 6830
allow sshd_login_t user_t:fd use;
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to write back to the old domain via a pipe.
#line 6830
#
#line 6830
allow user_t sshd_login_t:fifo_file { ioctl read getattr lock write append };
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to read and execute the program.
#line 6830
#
#line 6830
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to be entered via the program.
#line 6830
#
#line 6830
allow user_t shell_exec_t:file entrypoint;
#line 6830

#line 6830
type_transition sshd_login_t shell_exec_t:process user_t;
#line 6830

#line 6830

#line 6830

#line 6830
#
#line 6830
# Allow the process to transition to the new domain.
#line 6830
#
#line 6830
allow sshd_login_t unpriv_userdomain:process transition;
#line 6830

#line 6830
#
#line 6830
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6830
#
#line 6830
dontaudit sshd_login_t unpriv_userdomain:process noatsecure;
#line 6830

#line 6830
#
#line 6830
# Allow the process to execute the program.
#line 6830
# 
#line 6830
allow sshd_login_t shell_exec_t:file { read { getattr execute } };
#line 6830

#line 6830
#
#line 6830
# Allow the process to reap the new domain.
#line 6830
#
#line 6830
allow unpriv_userdomain sshd_login_t:process sigchld;
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to inherit and use file 
#line 6830
# descriptions from the creating process and vice versa.
#line 6830
#
#line 6830
allow unpriv_userdomain sshd_login_t:fd use;
#line 6830
allow sshd_login_t unpriv_userdomain:fd use;
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to write back to the old domain via a pipe.
#line 6830
#
#line 6830
allow unpriv_userdomain sshd_login_t:fifo_file { ioctl read getattr lock write append };
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to read and execute the program.
#line 6830
#
#line 6830
allow unpriv_userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6830

#line 6830
#
#line 6830
# Allow the new domain to be entered via the program.
#line 6830
#
#line 6830
allow unpriv_userdomain shell_exec_t:file entrypoint;
#line 6830

#line 6830

#line 6830
# Set exec context.
#line 6830

#line 6830
allow sshd_login_t self:process setexec;
#line 6830
allow sshd_login_t proc_t:dir search;
#line 6830
allow sshd_login_t proc_t:lnk_file read;
#line 6830
allow sshd_login_t self:dir search;
#line 6830
allow sshd_login_t self:file { read write };
#line 6830

#line 6830

#line 6830
# Allow shells to be run in sysadm_t as well.
#line 6830
# Commented out.  Use newrole rather than directly entering sysadm_t.
#line 6830
#domain_trans(sshd_login_t, shell_exec_t, sysadm_t)
#line 6830

#line 6830
# Update utmp.
#line 6830
allow sshd_login_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 6830

#line 6830
# Update wtmp.
#line 6830
allow sshd_login_t wtmp_t:file { ioctl read getattr lock write append };
#line 6830

#line 6830
# Get security policy decisions.
#line 6830

#line 6830
allow sshd_login_t security_t:dir { read search getattr };
#line 6830
allow sshd_login_t security_t:file { getattr read write };
#line 6830
allow sshd_login_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 6830

#line 6830

#line 6830
# Allow read access to login context
#line 6830
allow sshd_login_t default_context_t:file { read getattr lock ioctl };
#line 6830

#line 6830


type sshd_key_t, file_type, sysadmfile;

# so a tunnel can point to another ssh tunnel...

#line 6835
allow sshd_t sshd_t:tcp_socket { connectto recvfrom };
#line 6835
allow sshd_t sshd_t:tcp_socket { acceptfrom recvfrom };
#line 6835
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 6835
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 6835


type sshd_tmp_t, file_type, sysadmfile, tmpfile;

#line 6838

#line 6838

#line 6838

#line 6838
#
#line 6838
# Allow the process to modify the directory.
#line 6838
#
#line 6838
allow sshd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6838

#line 6838
#
#line 6838
# Allow the process to create the file.
#line 6838
#
#line 6838

#line 6838
allow sshd_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6838
allow sshd_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6838

#line 6838

#line 6838
type_transition sshd_t tmp_t:dir sshd_tmp_t;
#line 6838
type_transition sshd_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 6838

#line 6838

#line 6838


# Inherit and use descriptors from init.
allow sshd_t init_t:fd use;

# Can create ptys

#line 6844

#line 6844
# Access the pty master multiplexer.
#line 6844
allow sshd_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 6844

#line 6844

#line 6844
allow sshd_t devpts_t:filesystem getattr;
#line 6844

#line 6844
# allow searching /dev/pts
#line 6844
allow sshd_t devpts_t:dir { getattr read search };
#line 6844

#line 6844
type sshd_devpts_t, file_type, sysadmfile, ptyfile ;
#line 6844

#line 6844
# Allow the pty to be associated with the file system.
#line 6844
allow sshd_devpts_t devpts_t:filesystem associate;
#line 6844

#line 6844
# Label pty files with a derived type.
#line 6844
type_transition sshd_t devpts_t:chr_file sshd_devpts_t;
#line 6844

#line 6844
# Read and write my pty files.
#line 6844
allow sshd_t sshd_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 6844


# Execute Login

#line 6847

#line 6847

#line 6847
#
#line 6847
# Allow the process to transition to the new domain.
#line 6847
#
#line 6847
allow sshd_t sshd_login_t:process transition;
#line 6847

#line 6847
#
#line 6847
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6847
#
#line 6847
dontaudit sshd_t sshd_login_t:process noatsecure;
#line 6847

#line 6847
#
#line 6847
# Allow the process to execute the program.
#line 6847
# 
#line 6847
allow sshd_t login_exec_t:file { read { getattr execute } };
#line 6847

#line 6847
#
#line 6847
# Allow the process to reap the new domain.
#line 6847
#
#line 6847
allow sshd_login_t sshd_t:process sigchld;
#line 6847

#line 6847
#
#line 6847
# Allow the new domain to inherit and use file 
#line 6847
# descriptions from the creating process and vice versa.
#line 6847
#
#line 6847
allow sshd_login_t sshd_t:fd use;
#line 6847
allow sshd_t sshd_login_t:fd use;
#line 6847

#line 6847
#
#line 6847
# Allow the new domain to write back to the old domain via a pipe.
#line 6847
#
#line 6847
allow sshd_login_t sshd_t:fifo_file { ioctl read getattr lock write append };
#line 6847

#line 6847
#
#line 6847
# Allow the new domain to read and execute the program.
#line 6847
#
#line 6847
allow sshd_login_t login_exec_t:file { read getattr lock execute ioctl };
#line 6847

#line 6847
#
#line 6847
# Allow the new domain to be entered via the program.
#line 6847
#
#line 6847
allow sshd_login_t login_exec_t:file entrypoint;
#line 6847

#line 6847
type_transition sshd_t login_exec_t:process sshd_login_t;
#line 6847


# Use capabilities.
allow sshd_t self:capability { sys_chroot sys_resource };

# Create /var/run/sshd.pid

#line 6853
type sshd_var_run_t alias var_run_sshd_t, file_type, sysadmfile, pidfile;
#line 6853

#line 6853

#line 6853

#line 6853

#line 6853
#
#line 6853
# Allow the process to modify the directory.
#line 6853
#
#line 6853
allow sshd_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6853

#line 6853
#
#line 6853
# Allow the process to create the file.
#line 6853
#
#line 6853

#line 6853

#line 6853
allow sshd_t sshd_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6853

#line 6853

#line 6853
type_transition sshd_t var_run_t:file sshd_var_run_t;
#line 6853

#line 6853

#line 6853

#line 6853
allow sshd_t sshd_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6853


# Access key files
allow sshd_t sshd_key_t:file { getattr read };

# Update /var/log/lastlog.
allow sshd_t lastlog_t:file { ioctl read getattr lock write append };



# Signal the user domains.
allow sshd_t unpriv_userdomain:process signal;

# Relabel and access ptys created by sshd
allow sshd_t sshd_devpts_t:chr_file { setattr getattr relabelfrom relabelto };
allow sshd_t userpty_type:chr_file { setattr relabelto { ioctl read getattr lock write append } };

# for when the network connection breaks after running newrole -r sysadm_r
dontaudit sshd_t sysadm_devpts_t:chr_file setattr;

#################################
#
# Rules for the sshd_login_t domain
#
# sshd_login_t is the domain of a login process
# spawned by sshd

# Use the pty created by sshd
allow sshd_login_t sshd_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };

# Write to /var/log/lastlog
allow sshd_login_t lastlog_t:file { ioctl read getattr lock write append };

# Relabel ptys created by sshd
allow sshd_login_t sshd_devpts_t:chr_file { relabelfrom relabelto };
allow sshd_login_t userpty_type:chr_file { getattr relabelfrom relabelto };


#line 6890
allow sshd_t etc_t:lnk_file read;
#line 6890

#line 6890
allow sshd_t locale_t:dir { read getattr lock search ioctl };
#line 6890
allow sshd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6890

#line 6890


# Allow checking users mail at login
allow sshd_t { var_spool_t mail_spool_t }:dir search;
allow sshd_t mail_spool_t:lnk_file read;
allow sshd_t mail_spool_t:file getattr;
#
# Author:  Stephen Smalley <sds@epoch.ncsc.mil>
#

# Type for the ssh executable.
type ssh_exec_t, file_type, exec_type, sysadmfile;

allow sysadm_ssh_t user_home_dir_type:dir search;

#line 6904
allow sysadm_ssh_t user_home_ssh_t:dir { read getattr lock search ioctl };
#line 6904
allow sysadm_ssh_t user_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 6904


# Everything else is in the ssh_domain macro in
# macros/program/ssh_macros.te.

#DESC Su - Run shells with substitute user and group
#
# Domains for the su program.
# X-Debian-Packages: login

#
# su_exec_t is the type of the su executable.
#
type su_exec_t, file_type, sysadmfile, exec_type;

allow sysadm_su_t user_home_dir_type:dir search;

# Everything else is in the su_domain macro in
# macros/program/su_macros.te.
#DESC Syslogd - System log daemon
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# X-Debian-Packages: sysklogd
#

#################################
#
# Rules for the syslogd_t domain.
#
# syslogd_t is the domain of syslogd.
# syslogd_exec_t is the type of the syslogd executable.
# devlog_t is the type of the Unix domain socket created 
# by syslogd.
#

#line 6938

#line 6938
type syslogd_t, domain, privlog ;
#line 6938
type syslogd_exec_t, file_type, sysadmfile, exec_type;
#line 6938

#line 6938
role system_r types syslogd_t;
#line 6938

#line 6938

#line 6938

#line 6938

#line 6938
#
#line 6938
# Allow the process to transition to the new domain.
#line 6938
#
#line 6938
allow initrc_t syslogd_t:process transition;
#line 6938

#line 6938
#
#line 6938
# Do not audit when glibc secure mode is enabled upon the transition.
#line 6938
#
#line 6938
dontaudit initrc_t syslogd_t:process noatsecure;
#line 6938

#line 6938
#
#line 6938
# Allow the process to execute the program.
#line 6938
# 
#line 6938
allow initrc_t syslogd_exec_t:file { read { getattr execute } };
#line 6938

#line 6938
#
#line 6938
# Allow the process to reap the new domain.
#line 6938
#
#line 6938
allow syslogd_t initrc_t:process sigchld;
#line 6938

#line 6938
#
#line 6938
# Allow the new domain to inherit and use file 
#line 6938
# descriptions from the creating process and vice versa.
#line 6938
#
#line 6938
allow syslogd_t initrc_t:fd use;
#line 6938
allow initrc_t syslogd_t:fd use;
#line 6938

#line 6938
#
#line 6938
# Allow the new domain to write back to the old domain via a pipe.
#line 6938
#
#line 6938
allow syslogd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6938

#line 6938
#
#line 6938
# Allow the new domain to read and execute the program.
#line 6938
#
#line 6938
allow syslogd_t syslogd_exec_t:file { read getattr lock execute ioctl };
#line 6938

#line 6938
#
#line 6938
# Allow the new domain to be entered via the program.
#line 6938
#
#line 6938
allow syslogd_t syslogd_exec_t:file entrypoint;
#line 6938

#line 6938
type_transition initrc_t syslogd_exec_t:process syslogd_t;
#line 6938

#line 6938

#line 6938
# Inherit and use descriptors from init.
#line 6938
allow syslogd_t init_t:fd use;
#line 6938
allow syslogd_t init_t:process sigchld;
#line 6938
allow syslogd_t privfd:fd use;
#line 6938
allow syslogd_t newrole_t:process sigchld;
#line 6938
allow syslogd_t self:process { { sigchld sigkill sigstop signull signal } fork };
#line 6938

#line 6938

#line 6938
allow syslogd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6938
allow syslogd_t lib_t:lnk_file { read getattr lock ioctl };
#line 6938
allow syslogd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6938
allow syslogd_t ld_so_t:file execute_no_trans;
#line 6938
allow syslogd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6938
allow syslogd_t shlib_t:file { read getattr lock execute ioctl };
#line 6938
allow syslogd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6938
allow syslogd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6938
allow syslogd_t device_t:dir search;
#line 6938
allow syslogd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6938

#line 6938

#line 6938
allow syslogd_t { self proc_t }:dir { read getattr lock search ioctl };
#line 6938
allow syslogd_t { self proc_t }:lnk_file read;
#line 6938

#line 6938
allow syslogd_t device_t:dir { getattr search };
#line 6938
allow syslogd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6938
allow syslogd_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 6938
allow syslogd_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 6938

#line 6938
# Create pid file.
#line 6938
allow syslogd_t var_t:dir { getattr search };
#line 6938

#line 6938
type syslogd_var_run_t alias var_run_syslogd_t, file_type, sysadmfile, pidfile;
#line 6938

#line 6938

#line 6938

#line 6938

#line 6938
#
#line 6938
# Allow the process to modify the directory.
#line 6938
#
#line 6938
allow syslogd_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6938

#line 6938
#
#line 6938
# Allow the process to create the file.
#line 6938
#
#line 6938

#line 6938

#line 6938
allow syslogd_t syslogd_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6938

#line 6938

#line 6938
type_transition syslogd_t var_run_t:file syslogd_var_run_t;
#line 6938

#line 6938

#line 6938

#line 6938
allow syslogd_t syslogd_var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6938

#line 6938

#line 6938
allow syslogd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6938

#line 6938
# for daemons that look at /root on startup
#line 6938
dontaudit syslogd_t sysadm_home_dir_t:dir search;
#line 6938

#line 6938
# for df
#line 6938
allow syslogd_t fs_type:filesystem getattr;
#line 6938

#line 6938

#line 6938
allow syslogd_t etc_t:lnk_file read;
#line 6938

#line 6938
allow syslogd_t locale_t:dir { read getattr lock search ioctl };
#line 6938
allow syslogd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 6938

#line 6938

#line 6938


# can_network is for the UDP socket

#line 6941
#
#line 6941
# Allow the domain to create and use UDP and TCP sockets.
#line 6941
# Other kinds of sockets must be separately authorized for use.
#line 6941
allow syslogd_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6941
allow syslogd_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6941

#line 6941
#
#line 6941
# Allow the domain to send UDP packets.
#line 6941
# Since the destination sockets type is unknown, the generic
#line 6941
# any_socket_t type is used as a placeholder.
#line 6941
#
#line 6941
allow syslogd_t any_socket_t:udp_socket sendto;
#line 6941

#line 6941
#
#line 6941
# Allow the domain to send using any network interface.
#line 6941
# netif_type is a type attribute for all network interface types.
#line 6941
#
#line 6941
allow syslogd_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6941

#line 6941
#
#line 6941
# Allow packets sent by the domain to be received on any network interface.
#line 6941
#
#line 6941
allow syslogd_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6941

#line 6941
#
#line 6941
# Allow the domain to receive packets from any network interface.
#line 6941
# netmsg_type is a type attribute for all default message types.
#line 6941
#
#line 6941
allow syslogd_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6941

#line 6941
#
#line 6941
# Allow the domain to initiate or accept TCP connections 
#line 6941
# on any network interface.
#line 6941
#
#line 6941
allow syslogd_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6941

#line 6941
#
#line 6941
# Receive resets from the TCP reset socket.
#line 6941
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6941
#
#line 6941
allow syslogd_t tcp_socket_t:tcp_socket recvfrom;
#line 6941

#line 6941
dontaudit syslogd_t tcp_socket_t:tcp_socket connectto;
#line 6941

#line 6941
#
#line 6941
# Allow the domain to send to any node.
#line 6941
# node_type is a type attribute for all node types.
#line 6941
#
#line 6941
allow syslogd_t node_type:node { tcp_send udp_send rawip_send };
#line 6941

#line 6941
#
#line 6941
# Allow packets sent by the domain to be received from any node.
#line 6941
#
#line 6941
allow syslogd_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6941

#line 6941
#
#line 6941
# Allow the domain to send NFS client requests via the socket
#line 6941
# created by mount.
#line 6941
#
#line 6941
allow syslogd_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6941

#line 6941
#
#line 6941
# Bind to the default port type.
#line 6941
# Other port types must be separately authorized.
#line 6941
#
#line 6941
allow syslogd_t port_t:udp_socket name_bind;
#line 6941
allow syslogd_t port_t:tcp_socket name_bind;
#line 6941


type devlog_t, file_type, sysadmfile;

# if something can log to syslog they should be able to log to the console
allow privlog console_device_t:chr_file { ioctl read write getattr };


#line 6948
type syslogd_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6948

#line 6948

#line 6948

#line 6948

#line 6948
#
#line 6948
# Allow the process to modify the directory.
#line 6948
#
#line 6948
allow syslogd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6948

#line 6948
#
#line 6948
# Allow the process to create the file.
#line 6948
#
#line 6948

#line 6948
allow syslogd_t syslogd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6948
allow syslogd_t syslogd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6948

#line 6948

#line 6948
type_transition syslogd_t tmp_t:dir syslogd_tmp_t;
#line 6948
type_transition syslogd_t tmp_t:{ file lnk_file sock_file fifo_file } syslogd_tmp_t;
#line 6948

#line 6948

#line 6948

#line 6948


# read files in /etc
allow syslogd_t etc_t:file { read getattr lock ioctl };
allow syslogd_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };

# Use capabilities.
allow syslogd_t syslogd_t:capability { net_bind_service dac_override };

# Inherit and use descriptors from init.
allow syslogd_t init_t:fd use;
allow syslogd_t { initrc_devpts_t console_device_t }:chr_file { read write };

# Modify/create log files.

#line 6962
allow syslogd_t var_log_t:dir { read getattr search add_name write };
#line 6962
allow syslogd_t var_log_t:file { create ioctl getattr setattr append link };
#line 6962


# Create and bind to /dev/log or /var/run/log.

#line 6965

#line 6965

#line 6965

#line 6965
#
#line 6965
# Allow the process to modify the directory.
#line 6965
#
#line 6965
allow syslogd_t { device_t var_run_t }:dir { read getattr lock search ioctl add_name remove_name write };
#line 6965

#line 6965
#
#line 6965
# Allow the process to create the file.
#line 6965
#
#line 6965

#line 6965

#line 6965
allow syslogd_t devlog_t:sock_file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6965

#line 6965

#line 6965
type_transition syslogd_t { device_t var_run_t }:sock_file devlog_t;
#line 6965

#line 6965

#line 6965

allow syslogd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow syslogd_t self:unix_dgram_socket { sendto };
allow syslogd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow syslogd_t self:unix_stream_socket { listen accept };
allow syslogd_t devlog_t:unix_stream_socket name_bind;
allow syslogd_t devlog_t:unix_dgram_socket name_bind;

# Domains with the privlog attribute may log to syslogd.
allow privlog devlog_t:sock_file { ioctl read getattr lock write append };

#line 6975
allow privlog syslogd_t:unix_dgram_socket sendto;
#line 6975


#line 6976
allow privlog syslogd_t:unix_stream_socket connectto;
#line 6976

# allow /dev/log to be a link elsewhere for chroot setup
allow privlog devlog_t:lnk_file read;

#line 6983

#line 6983
# Write to the cron log.
#line 6983
allow syslogd_t cron_log_t:file { ioctl read getattr lock write append };
#line 6983


#line 6987

#line 6987
allow logrotate_t syslogd_exec_t:file { read getattr lock ioctl };
#line 6987


# uncomment this to allow syslogd to log to virtual consoles
#allow syslogd_t tty_device_t:chr_file rw_file_perms;

# Allow access to /proc/kmsg for syslog-ng
#allow syslogd_t proc_t:dir search;
#allow syslogd_t proc_kmsg_t:file { getattr read };

#DESC Tmpreaper - Monitor and maintain temporary files
#
# Author:  Russell Coker <russell@coker.com.au>
# X-Debian-Packages: tmpreaper
#

#################################
#
# Rules for the tmpreaper_t domain.
#
type tmpreaper_t, domain, privlog;
type tmpreaper_exec_t, file_type, sysadmfile, exec_type;

role system_r types tmpreaper_t;


#line 7011

#line 7011

#line 7011

#line 7011
#
#line 7011
# Allow the process to transition to the new domain.
#line 7011
#
#line 7011
allow system_crond_t tmpreaper_t:process transition;
#line 7011

#line 7011
#
#line 7011
# Do not audit when glibc secure mode is enabled upon the transition.
#line 7011
#
#line 7011
dontaudit system_crond_t tmpreaper_t:process noatsecure;
#line 7011

#line 7011
#
#line 7011
# Allow the process to execute the program.
#line 7011
# 
#line 7011
allow system_crond_t tmpreaper_exec_t:file { read { getattr execute } };
#line 7011

#line 7011
#
#line 7011
# Allow the process to reap the new domain.
#line 7011
#
#line 7011
allow tmpreaper_t system_crond_t:process sigchld;
#line 7011

#line 7011
#
#line 7011
# Allow the new domain to inherit and use file 
#line 7011
# descriptions from the creating process and vice versa.
#line 7011
#
#line 7011
allow tmpreaper_t system_crond_t:fd use;
#line 7011
allow system_crond_t tmpreaper_t:fd use;
#line 7011

#line 7011
#
#line 7011
# Allow the new domain to write back to the old domain via a pipe.
#line 7011
#
#line 7011
allow tmpreaper_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 7011

#line 7011
#
#line 7011
# Allow the new domain to read and execute the program.
#line 7011
#
#line 7011
allow tmpreaper_t tmpreaper_exec_t:file { read getattr lock execute ioctl };
#line 7011

#line 7011
#
#line 7011
# Allow the new domain to be entered via the program.
#line 7011
#
#line 7011
allow tmpreaper_t tmpreaper_exec_t:file entrypoint;
#line 7011

#line 7011
type_transition system_crond_t tmpreaper_exec_t:process tmpreaper_t;
#line 7011

#line 7011
allow tmpreaper_t crond_t:fifo_file { getattr read write ioctl };
#line 7011
# a rule for privfd may make this obsolete
#line 7011
allow tmpreaper_t crond_t:fd use;
#line 7011
allow tmpreaper_t crond_t:process sigchld;
#line 7011


#line 7012
allow tmpreaper_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 7012
allow tmpreaper_t lib_t:lnk_file { read getattr lock ioctl };
#line 7012
allow tmpreaper_t ld_so_t:file { read getattr lock execute ioctl };
#line 7012
allow tmpreaper_t ld_so_t:file execute_no_trans;
#line 7012
allow tmpreaper_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 7012
allow tmpreaper_t shlib_t:file { read getattr lock execute ioctl };
#line 7012
allow tmpreaper_t shlib_t:lnk_file { read getattr lock ioctl };
#line 7012
allow tmpreaper_t ld_so_cache_t:file { read getattr lock ioctl };
#line 7012
allow tmpreaper_t device_t:dir search;
#line 7012
allow tmpreaper_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 7012

allow tmpreaper_t tmpfile:dir { { read getattr lock search ioctl add_name remove_name write } rmdir };
allow tmpreaper_t tmpfile:{ file lnk_file sock_file fifo_file } { getattr unlink };
allow tmpreaper_t home_type:{ file lnk_file sock_file fifo_file } { getattr unlink };
allow tmpreaper_t self:process { fork sigchld };
allow tmpreaper_t self:capability { dac_override dac_read_search fowner };
allow tmpreaper_t fs_t:filesystem getattr;


#line 7020
allow tmpreaper_t etc_t:dir { read getattr lock search ioctl };
#line 7020
allow tmpreaper_t etc_t:{ file lnk_file } { read getattr lock ioctl };
#line 7020

allow tmpreaper_t var_t:dir { getattr search };

#line 7022
allow tmpreaper_t var_lib_t:dir { read getattr lock search ioctl };
#line 7022
allow tmpreaper_t var_lib_t:{ file lnk_file } { read getattr lock ioctl };
#line 7022

allow tmpreaper_t device_t:dir { getattr search };
allow tmpreaper_t random_device_t:chr_file { getattr read };

#line 7029

#DESC Useradd - Manage system user accounts
#
# Authors:  Chris Vance <cvance@tislabs.com>  David Caplan <dac@tresys.com>
#           Russell Coker <russell@coker.com.au>
# X-Debian-Packages: passwd
#

#################################
#
# Rules for the useradd_t and groupadd_t domains.
#
# useradd_t is the domain of the useradd/userdel programs.
# groupadd_t is for adding groups (can not create home dirs)
#
#line 7088


#line 7089
type useradd_t, domain, privlog, auth, privowner;
#line 7089
role sysadm_r types useradd_t;
#line 7089

#line 7089

#line 7089
# Access other processes in the same domain.
#line 7089
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 7089
# separately if desired.
#line 7089
allow useradd_t self:process ~{ptrace setexec setfscreate};
#line 7089

#line 7089
# Access /proc/PID files for processes in the same domain.
#line 7089
allow useradd_t self:dir { read getattr lock search ioctl };
#line 7089
allow useradd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 7089

#line 7089
# Access file descriptions, pipes, and sockets
#line 7089
# created by processes in the same domain.
#line 7089
allow useradd_t self:fd *;
#line 7089
allow useradd_t self:fifo_file { ioctl read getattr lock write append };
#line 7089
allow useradd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 7089
allow useradd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 7089

#line 7089
# Allow the domain to communicate with other processes in the same domain.
#line 7089
allow useradd_t self:unix_dgram_socket sendto;
#line 7089
allow useradd_t self:unix_stream_socket connectto;
#line 7089

#line 7089
# Access System V IPC objects created by processes in the same domain.
#line 7089
allow useradd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 7089
allow useradd_t self:msg  { send receive };
#line 7089
allow useradd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 7089
allow useradd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 7089

#line 7089

#line 7089
allow useradd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 7089
allow useradd_t lib_t:lnk_file { read getattr lock ioctl };
#line 7089
allow useradd_t ld_so_t:file { read getattr lock execute ioctl };
#line 7089
allow useradd_t ld_so_t:file execute_no_trans;
#line 7089
allow useradd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 7089
allow useradd_t shlib_t:file { read getattr lock execute ioctl };
#line 7089
allow useradd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 7089
allow useradd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 7089
allow useradd_t device_t:dir search;
#line 7089
allow useradd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 7089

#line 7089

#line 7089
type useradd_exec_t, file_type, sysadmfile, exec_type;
#line 7089

#line 7089

#line 7089

#line 7089
#
#line 7089
# Allow the process to transition to the new domain.
#line 7089
#
#line 7089
allow sysadm_t useradd_t:process transition;
#line 7089

#line 7089
#
#line 7089
# Do not audit when glibc secure mode is enabled upon the transition.
#line 7089
#
#line 7089
dontaudit sysadm_t useradd_t:process noatsecure;
#line 7089

#line 7089
#
#line 7089
# Allow the process to execute the program.
#line 7089
# 
#line 7089
allow sysadm_t useradd_exec_t:file { read { getattr execute } };
#line 7089

#line 7089
#
#line 7089
# Allow the process to reap the new domain.
#line 7089
#
#line 7089
allow useradd_t sysadm_t:process sigchld;
#line 7089

#line 7089
#
#line 7089
# Allow the new domain to inherit and use file 
#line 7089
# descriptions from the creating process and vice versa.
#line 7089
#
#line 7089
allow useradd_t sysadm_t:fd use;
#line 7089
allow sysadm_t useradd_t:fd use;
#line 7089

#line 7089
#
#line 7089
# Allow the new domain to write back to the old domain via a pipe.
#line 7089
#
#line 7089
allow useradd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 7089

#line 7089
#
#line 7089
# Allow the new domain to read and execute the program.
#line 7089
#
#line 7089
allow useradd_t useradd_exec_t:file { read getattr lock execute ioctl };
#line 7089

#line 7089
#
#line 7089
# Allow the new domain to be entered via the program.
#line 7089
#
#line 7089
allow useradd_t useradd_exec_t:file entrypoint;
#line 7089

#line 7089
type_transition sysadm_t useradd_exec_t:process useradd_t;
#line 7089

#line 7089

#line 7089
# Use capabilities.
#line 7089
allow useradd_t self:capability { dac_override chown };
#line 7089

#line 7089
# Allow access to context for shadow file
#line 7089

#line 7089
allow useradd_t security_t:dir { read search getattr };
#line 7089
allow useradd_t security_t:file { getattr read write };
#line 7089
allow useradd_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 7089

#line 7089

#line 7089
# Inherit and use descriptors from login.
#line 7089
allow useradd_t privfd:fd use;
#line 7089

#line 7089
# Update /etc/shadow and /etc/passwd
#line 7089

#line 7089

#line 7089

#line 7089

#line 7089
#
#line 7089
# Allow the process to modify the directory.
#line 7089
#
#line 7089
allow useradd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 7089

#line 7089
#
#line 7089
# Allow the process to create the file.
#line 7089
#
#line 7089

#line 7089

#line 7089
allow useradd_t shadow_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 7089

#line 7089

#line 7089
type_transition useradd_t etc_t:file shadow_t;
#line 7089

#line 7089

#line 7089

#line 7089
allow useradd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 7089

#line 7089
# Set fscreate context.
#line 7089

#line 7089
allow useradd_t self:process setfscreate;
#line 7089
allow useradd_t proc_t:dir search;
#line 7089
allow useradd_t proc_t:lnk_file read;
#line 7089
allow useradd_t self:dir search;
#line 7089
allow useradd_t self:file { read write };
#line 7089

#line 7089

#line 7089
allow useradd_t { etc_t shadow_t }:file { relabelfrom relabelto };
#line 7089

#line 7089

#line 7089
allow useradd_t etc_t:lnk_file read;
#line 7089

#line 7089
allow useradd_t locale_t:dir { read getattr lock search ioctl };
#line 7089
allow useradd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 7089

#line 7089

#line 7089

#line 7089
# useradd/userdel request read/write for /var/log/lastlog, and read of /dev, 
#line 7089
# but will operate without them.
#line 7089
dontaudit useradd_t { device_t var_t var_log_t }:dir search;
#line 7089

#line 7089
# For userdel and groupadd
#line 7089
allow useradd_t fs_t:filesystem getattr;
#line 7089

#line 7089
# Access terminals.
#line 7089
allow useradd_t ttyfile:chr_file { ioctl read getattr lock write append };
#line 7089
allow useradd_t ptyfile:chr_file { ioctl read getattr lock write append };
#line 7089

#line 7089

#line 7089
# for when /root is the cwd
#line 7089
dontaudit useradd_t sysadm_home_dir_t:dir search;
#line 7089


# Add/remove user home directories

#line 7092

#line 7092

#line 7092

#line 7092
#
#line 7092
# Allow the process to modify the directory.
#line 7092
#
#line 7092
allow useradd_t home_root_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 7092

#line 7092
#
#line 7092
# Allow the process to create the file.
#line 7092
#
#line 7092

#line 7092

#line 7092
allow useradd_t user_home_dir_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 7092

#line 7092

#line 7092
type_transition useradd_t home_root_t:dir user_home_dir_t;
#line 7092

#line 7092

#line 7092


#line 7093

#line 7093

#line 7093

#line 7093
#
#line 7093
# Allow the process to modify the directory.
#line 7093
#
#line 7093
allow useradd_t user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 7093

#line 7093
#
#line 7093
# Allow the process to create the file.
#line 7093
#
#line 7093

#line 7093
allow useradd_t user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 7093
allow useradd_t user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 7093

#line 7093

#line 7093
type_transition useradd_t user_home_dir_t:dir user_home_t;
#line 7093
type_transition useradd_t user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 7093

#line 7093

#line 7093


# create/delete mail spool file in /var/mail
allow useradd_t var_spool_t:dir search;
allow useradd_t mail_spool_t:dir { search write add_name remove_name };
allow useradd_t mail_spool_t:file { create setattr getattr unlink };
# /var/mail is a link to /var/spool/mail
allow useradd_t mail_spool_t:lnk_file read;

allow useradd_t self:capability { fowner fsetid setuid sys_resource };

#line 7103
allow useradd_t shell_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 7103


# /usr/bin/userdel locks the user being deleted, allow write access to utmp
allow useradd_t initrc_var_run_t:file { read write lock };


#line 7108
type groupadd_t, domain, privlog, auth, privowner;
#line 7108
role sysadm_r types groupadd_t;
#line 7108

#line 7108

#line 7108
# Access other processes in the same domain.
#line 7108
# Omits ptrace, setexec, and setfscreate.  These must be granted 
#line 7108
# separately if desired.
#line 7108
allow groupadd_t self:process ~{ptrace setexec setfscreate};
#line 7108

#line 7108
# Access /proc/PID files for processes in the same domain.
#line 7108
allow groupadd_t self:dir { read getattr lock search ioctl };
#line 7108
allow groupadd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 7108

#line 7108
# Access file descriptions, pipes, and sockets
#line 7108
# created by processes in the same domain.
#line 7108
allow groupadd_t self:fd *;
#line 7108
allow groupadd_t self:fifo_file { ioctl read getattr lock write append };
#line 7108
allow groupadd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 7108
allow groupadd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 7108

#line 7108
# Allow the domain to communicate with other processes in the same domain.
#line 7108
allow groupadd_t self:unix_dgram_socket sendto;
#line 7108
allow groupadd_t self:unix_stream_socket connectto;
#line 7108

#line 7108
# Access System V IPC objects created by processes in the same domain.
#line 7108
allow groupadd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 7108
allow groupadd_t self:msg  { send receive };
#line 7108
allow groupadd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 7108
allow groupadd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 7108

#line 7108

#line 7108
allow groupadd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 7108
allow groupadd_t lib_t:lnk_file { read getattr lock ioctl };
#line 7108
allow groupadd_t ld_so_t:file { read getattr lock execute ioctl };
#line 7108
allow groupadd_t ld_so_t:file execute_no_trans;
#line 7108
allow groupadd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 7108
allow groupadd_t shlib_t:file { read getattr lock execute ioctl };
#line 7108
allow groupadd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 7108
allow groupadd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 7108
allow groupadd_t device_t:dir search;
#line 7108
allow groupadd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 7108

#line 7108

#line 7108
type groupadd_exec_t, file_type, sysadmfile, exec_type;
#line 7108

#line 7108

#line 7108

#line 7108
#
#line 7108
# Allow the process to transition to the new domain.
#line 7108
#
#line 7108
allow sysadm_t groupadd_t:process transition;
#line 7108

#line 7108
#
#line 7108
# Do not audit when glibc secure mode is enabled upon the transition.
#line 7108
#
#line 7108
dontaudit sysadm_t groupadd_t:process noatsecure;
#line 7108

#line 7108
#
#line 7108
# Allow the process to execute the program.
#line 7108
# 
#line 7108
allow sysadm_t groupadd_exec_t:file { read { getattr execute } };
#line 7108

#line 7108
#
#line 7108
# Allow the process to reap the new domain.
#line 7108
#
#line 7108
allow groupadd_t sysadm_t:process sigchld;
#line 7108

#line 7108
#
#line 7108
# Allow the new domain to inherit and use file 
#line 7108
# descriptions from the creating process and vice versa.
#line 7108
#
#line 7108
allow groupadd_t sysadm_t:fd use;
#line 7108
allow sysadm_t groupadd_t:fd use;
#line 7108

#line 7108
#
#line 7108
# Allow the new domain to write back to the old domain via a pipe.
#line 7108
#
#line 7108
allow groupadd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 7108

#line 7108
#
#line 7108
# Allow the new domain to read and execute the program.
#line 7108
#
#line 7108
allow groupadd_t groupadd_exec_t:file { read getattr lock execute ioctl };
#line 7108

#line 7108
#
#line 7108
# Allow the new domain to be entered via the program.
#line 7108
#
#line 7108
allow groupadd_t groupadd_exec_t:file entrypoint;
#line 7108

#line 7108
type_transition sysadm_t groupadd_exec_t:process groupadd_t;
#line 7108

#line 7108

#line 7108
# Use capabilities.
#line 7108
allow groupadd_t self:capability { dac_override chown };
#line 7108

#line 7108
# Allow access to context for shadow file
#line 7108

#line 7108
allow groupadd_t security_t:dir { read search getattr };
#line 7108
allow groupadd_t security_t:file { getattr read write };
#line 7108
allow groupadd_t security_t:security { check_context compute_av compute_create compute_relabel compute_user };
#line 7108

#line 7108

#line 7108
# Inherit and use descriptors from login.
#line 7108
allow groupadd_t privfd:fd use;
#line 7108

#line 7108
# Update /etc/shadow and /etc/passwd
#line 7108

#line 7108

#line 7108

#line 7108

#line 7108
#
#line 7108
# Allow the process to modify the directory.
#line 7108
#
#line 7108
allow groupadd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 7108

#line 7108
#
#line 7108
# Allow the process to create the file.
#line 7108
#
#line 7108

#line 7108

#line 7108
allow groupadd_t shadow_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 7108

#line 7108

#line 7108
type_transition groupadd_t etc_t:file shadow_t;
#line 7108

#line 7108

#line 7108

#line 7108
allow groupadd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 7108

#line 7108
# Set fscreate context.
#line 7108

#line 7108
allow groupadd_t self:process setfscreate;
#line 7108
allow groupadd_t proc_t:dir search;
#line 7108
allow groupadd_t proc_t:lnk_file read;
#line 7108
allow groupadd_t self:dir search;
#line 7108
allow groupadd_t self:file { read write };
#line 7108

#line 7108

#line 7108
allow groupadd_t { etc_t shadow_t }:file { relabelfrom relabelto };
#line 7108

#line 7108

#line 7108
allow groupadd_t etc_t:lnk_file read;
#line 7108

#line 7108
allow groupadd_t locale_t:dir { read getattr lock search ioctl };
#line 7108
allow groupadd_t locale_t:{ file lnk_file } { read getattr lock ioctl };
#line 7108

#line 7108

#line 7108

#line 7108
# useradd/userdel request read/write for /var/log/lastlog, and read of /dev, 
#line 7108
# but will operate without them.
#line 7108
dontaudit groupadd_t { device_t var_t var_log_t }:dir search;
#line 7108

#line 7108
# For userdel and groupadd
#line 7108
allow groupadd_t fs_t:filesystem getattr;
#line 7108

#line 7108
# Access terminals.
#line 7108
allow groupadd_t ttyfile:chr_file { ioctl read getattr lock write append };
#line 7108
allow groupadd_t ptyfile:chr_file { ioctl read getattr lock write append };
#line 7108

#line 7108

#line 7108
# for when /root is the cwd
#line 7108
dontaudit groupadd_t sysadm_home_dir_t:dir search;
#line 7108


# some apps ask for these accesses, but seems to work regardless
dontaudit groupadd_t initrc_var_run_t:file write;
dontaudit groupadd_t var_run_t:dir search;
dontaudit groupadd_t self:capability fsetid;
##############################
#
# Assertions for the type enforcement (TE) configuration.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

##################################
#
# Access vector assertions.
#
# An access vector assertion specifies permissions that should not be in
# an access vector based on a source type, a target type, and a class.
# If any of the specified permissions are in the corresponding access
# vector, then the policy compiler will reject the policy configuration.
# Currently, there is only one kind of access vector assertion, neverallow, 
# but support for the other kinds of vectors could be easily added.  Access 
# vector assertions use the same syntax as access vector rules.
#

#
# Verify that every type that can be entered by
# a domain is also tagged as a domain.
#
neverallow domain ~domain:process transition;

#
# Verify that only the insmod_t, ifconfig_t, and kernel_t domains 
# have the sys_module capability.
#
neverallow ~{ insmod_t ifconfig_t kernel_t } self:capability sys_module;

#
# Verify that executable types, the system dynamic loaders, and the
# system shared libraries can only be modified by administrators.
#
neverallow ~{ldconfig_t admin} { exec_type ld_so_t shlib_t }:file { write append unlink rename };

#
# Verify that other system software can only be modified by administrators.
#
neverallow ~{ldconfig_t admin} { lib_t bin_t sbin_t }:dir { add_name remove_name rename };
neverallow ~admin { lib_t bin_t sbin_t }:file { write append unlink rename };

#
# Verify that only certain domains have access to the raw disk devices.
#
neverallow ~{  fsadm_t mount_t } fixed_disk_device_t:{ chr_file blk_file } { read write append };

#
# Verify that only the X server and klogd have access to memory devices.
#
neverallow ~privmem memory_device_t:{ chr_file blk_file } { read write append };

#
# Verify that /proc/kmsg is only accessible to klogd.
#
neverallow ~klogd_t proc_kmsg_t:file ~{ getattr };

#
# Verify that /proc/kcore is inaccessible.
#
neverallow * proc_kcore_t:file ~{ getattr };

#
# Verify that sysctl variables are only changeable
# by initrc and administrators.
#
neverallow ~{ initrc_t admin kernel_t insmod_t } sysctl_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_fs_t:file { write append };
neverallow ~{ init_t initrc_t admin kernel_t insmod_t } sysctl_kernel_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_net_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_net_unix_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_vm_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_dev_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_modprobe_t:file { write append };

#
# Verify that certain domains are limited to only being
# entered by their entrypoint types and to only executing
# the dynamic loader without a transition to another domain.
#

#line 7203



#line 7205
    neverallow getty_t ~getty_exec_t:file entrypoint; neverallow getty_t ~{ getty_exec_t ld_so_t }:file execute_no_trans;

#line 7206
    neverallow klogd_t ~klogd_exec_t:file entrypoint; neverallow klogd_t ~{ klogd_exec_t ld_so_t }:file execute_no_trans;




#line 7210
    neverallow syslogd_t ~syslogd_exec_t:file entrypoint; neverallow syslogd_t ~{ syslogd_exec_t ld_so_t }:file execute_no_trans;






#line 7220

#line 7220
neverallow { local_login_t remote_login_t } ~login_exec_t:file entrypoint;
#line 7220
neverallow { local_login_t remote_login_t } ~ld_so_t:file execute_no_trans;
#line 7220


#
# Verify that the passwd domain can only be entered by its
# entrypoint type and can only execute the dynamic loader
# and the ordinary passwd program without a transition to another domain.
#
#line 7229
neverallow passwd_t ~{ admin_passwd_exec_t passwd_exec_t }:file entrypoint;
#line 7229
neverallow passwd_t ~{ ld_so_t }:file execute_no_trans;

#
# Verify that only the admin domains and initrc_t have setenforce.
#
neverallow ~{ admin initrc_t } security_t:security setenforce;

#
# Verify that only the kernel and load_policy_t have load_policy.
#
neverallow ~{ kernel_t load_policy_t } security_t:security load_policy;
#line 1 "rbac"
################################################
#
# Role-based access control (RBAC) configuration.
#

#line 9

#line 13

#line 15

########################################
#
# Role allow rules.
#
# A role allow rule specifies the allowable
# transitions between roles on an execve.
# If no rule is specified, then the change in
# roles will not be permitted.  Additional
# controls over role transitions based on the
# type of the process may be specified through
# the constraints file.
#
# The syntax of a role allow rule is:
# 	allow current_role new_role ;
#

#
# Allow the system_r role to transition 
# into the sysadm_r role.
#
allow system_r sysadm_r;

#
# Allow the user and admin role to transition to httpd_admin_r
#
#line 44


# 
# Allow the admin role to transition to the system
# role for run_init.
#
allow sysadm_r system_r;
